/* SerializableGeeDualKeyMapTest.c generated by valac 0.39.3.9-ecb8a, the Vala compiler
 * generated from SerializableGeeDualKeyMapTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */

#include <glib.h>
#include <glib-object.h>
#include <gxml/gxml.h>
#include <stdlib.h>
#include <string.h>
#include <stdio.h>
#include <gee.h>


#define TYPE_SPACES (spaces_get_type ())
#define SPACES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SPACES, Spaces))
#define SPACES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SPACES, SpacesClass))
#define IS_SPACES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SPACES))
#define IS_SPACES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SPACES))
#define SPACES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SPACES, SpacesClass))

typedef struct _Spaces Spaces;
typedef struct _SpacesClass SpacesClass;
typedef struct _SpacesPrivate SpacesPrivate;
enum  {
	SPACES_0_PROPERTY,
	SPACES_NAME_PROPERTY,
	SPACES_OWNER_PROPERTY,
	SPACES_NUM_PROPERTIES
};
static GParamSpec* spaces_properties[SPACES_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST (serializable_gee_dual_key_map_test_get_type ())
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST, SerializableGeeDualKeyMapTest))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST, SerializableGeeDualKeyMapTestClass))
#define IS_SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST))
#define IS_SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST, SerializableGeeDualKeyMapTestClass))

typedef struct _SerializableGeeDualKeyMapTest SerializableGeeDualKeyMapTest;
typedef struct _SerializableGeeDualKeyMapTestClass SerializableGeeDualKeyMapTestClass;
typedef struct _SerializableGeeDualKeyMapTestPrivate SerializableGeeDualKeyMapTestPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TYPE_BOOK_STORE (book_store_get_type ())
#define BOOK_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BOOK_STORE, BookStore))
#define BOOK_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BOOK_STORE, BookStoreClass))
#define IS_BOOK_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BOOK_STORE))
#define IS_BOOK_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BOOK_STORE))
#define BOOK_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BOOK_STORE, BookStoreClass))

typedef struct _BookStore BookStore;
typedef struct _BookStoreClass BookStoreClass;

#define BOOK_TYPE_ARRAY (book_array_get_type ())
#define BOOK_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOOK_TYPE_ARRAY, BookArray))
#define BOOK_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOOK_TYPE_ARRAY, BookArrayClass))
#define BOOK_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOOK_TYPE_ARRAY))
#define BOOK_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOOK_TYPE_ARRAY))
#define BOOK_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOOK_TYPE_ARRAY, BookArrayClass))

typedef struct _BookArray BookArray;
typedef struct _BookArrayClass BookArrayClass;

#define TYPE_BOOK (book_get_type ())
#define BOOK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BOOK, Book))
#define BOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BOOK, BookClass))
#define IS_BOOK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BOOK))
#define IS_BOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BOOK))
#define BOOK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BOOK, BookClass))

typedef struct _Book Book;
typedef struct _BookClass BookClass;

#define TYPE_NAME (name_get_type ())
#define NAME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NAME, Name))
#define NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_NAME, NameClass))
#define IS_NAME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NAME))
#define IS_NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_NAME))
#define NAME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_NAME, NameClass))

typedef struct _Name Name;
typedef struct _NameClass NameClass;

#define TYPE_AUTHORS (authors_get_type ())
#define AUTHORS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_AUTHORS, Authors))
#define AUTHORS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_AUTHORS, AuthorsClass))
#define IS_AUTHORS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_AUTHORS))
#define IS_AUTHORS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_AUTHORS))
#define AUTHORS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_AUTHORS, AuthorsClass))

typedef struct _Authors Authors;
typedef struct _AuthorsClass AuthorsClass;

#define AUTHOR_TYPE_ARRAY (author_array_get_type ())
#define AUTHOR_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), AUTHOR_TYPE_ARRAY, AuthorArray))
#define AUTHOR_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), AUTHOR_TYPE_ARRAY, AuthorArrayClass))
#define AUTHOR_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), AUTHOR_TYPE_ARRAY))
#define AUTHOR_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), AUTHOR_TYPE_ARRAY))
#define AUTHOR_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), AUTHOR_TYPE_ARRAY, AuthorArrayClass))

typedef struct _AuthorArray AuthorArray;
typedef struct _AuthorArrayClass AuthorArrayClass;

#define INVENTORY_TYPE_DUAL_KEY_MAP (inventory_dual_key_map_get_type ())
#define INVENTORY_DUAL_KEY_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), INVENTORY_TYPE_DUAL_KEY_MAP, InventoryDualKeyMap))
#define INVENTORY_DUAL_KEY_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), INVENTORY_TYPE_DUAL_KEY_MAP, InventoryDualKeyMapClass))
#define INVENTORY_IS_DUAL_KEY_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), INVENTORY_TYPE_DUAL_KEY_MAP))
#define INVENTORY_IS_DUAL_KEY_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), INVENTORY_TYPE_DUAL_KEY_MAP))
#define INVENTORY_DUAL_KEY_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), INVENTORY_TYPE_DUAL_KEY_MAP, InventoryDualKeyMapClass))

typedef struct _InventoryDualKeyMap InventoryDualKeyMap;
typedef struct _InventoryDualKeyMapClass InventoryDualKeyMapClass;

#define TYPE_INVENTORY (inventory_get_type ())
#define INVENTORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_INVENTORY, Inventory))
#define INVENTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_INVENTORY, InventoryClass))
#define IS_INVENTORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_INVENTORY))
#define IS_INVENTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_INVENTORY))
#define INVENTORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_INVENTORY, InventoryClass))

typedef struct _Inventory Inventory;
typedef struct _InventoryClass InventoryClass;

#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BIG_BAG (serializable_gee_dual_key_map_test_big_bag_get_type ())
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BIG_BAG, SerializableGeeDualKeyMapTestBigBag))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BIG_BAG, SerializableGeeDualKeyMapTestBigBagClass))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_IS_BIG_BAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BIG_BAG))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_IS_BIG_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BIG_BAG))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BIG_BAG, SerializableGeeDualKeyMapTestBigBagClass))

typedef struct _SerializableGeeDualKeyMapTestBigBag SerializableGeeDualKeyMapTestBigBag;
typedef struct _SerializableGeeDualKeyMapTestBigBagClass SerializableGeeDualKeyMapTestBigBagClass;

#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_TYPE_DUAL_MAP (serializable_gee_dual_key_map_test_small_bag_dual_map_get_type ())
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_DUAL_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_TYPE_DUAL_MAP, SerializableGeeDualKeyMapTestSmallBagDualMap))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_DUAL_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_TYPE_DUAL_MAP, SerializableGeeDualKeyMapTestSmallBagDualMapClass))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_IS_DUAL_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_TYPE_DUAL_MAP))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_IS_DUAL_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_TYPE_DUAL_MAP))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_DUAL_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_TYPE_DUAL_MAP, SerializableGeeDualKeyMapTestSmallBagDualMapClass))

typedef struct _SerializableGeeDualKeyMapTestSmallBagDualMap SerializableGeeDualKeyMapTestSmallBagDualMap;
typedef struct _SerializableGeeDualKeyMapTestSmallBagDualMapClass SerializableGeeDualKeyMapTestSmallBagDualMapClass;

#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG (serializable_gee_dual_key_map_test_small_bag_get_type ())
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeDualKeyMapTestSmallBag))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeDualKeyMapTestSmallBagClass))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_IS_SMALL_BAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_IS_SMALL_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeDualKeyMapTestSmallBagClass))

typedef struct _SerializableGeeDualKeyMapTestSmallBag SerializableGeeDualKeyMapTestSmallBag;
typedef struct _SerializableGeeDualKeyMapTestSmallBagClass SerializableGeeDualKeyMapTestSmallBagClass;

#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_TYPE_DUAL_MAP (serializable_gee_dual_key_map_test_ball_dual_map_get_type ())
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_DUAL_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_TYPE_DUAL_MAP, SerializableGeeDualKeyMapTestBallDualMap))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_DUAL_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_TYPE_DUAL_MAP, SerializableGeeDualKeyMapTestBallDualMapClass))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_IS_DUAL_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_TYPE_DUAL_MAP))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_IS_DUAL_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_TYPE_DUAL_MAP))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_DUAL_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_TYPE_DUAL_MAP, SerializableGeeDualKeyMapTestBallDualMapClass))

typedef struct _SerializableGeeDualKeyMapTestBallDualMap SerializableGeeDualKeyMapTestBallDualMap;
typedef struct _SerializableGeeDualKeyMapTestBallDualMapClass SerializableGeeDualKeyMapTestBallDualMapClass;

#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL (serializable_gee_dual_key_map_test_ball_get_type ())
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL, SerializableGeeDualKeyMapTestBall))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL, SerializableGeeDualKeyMapTestBallClass))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_IS_BALL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_IS_BALL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL, SerializableGeeDualKeyMapTestBallClass))

typedef struct _SerializableGeeDualKeyMapTestBall SerializableGeeDualKeyMapTestBall;
typedef struct _SerializableGeeDualKeyMapTestBallClass SerializableGeeDualKeyMapTestBallClass;

#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL (serializable_gee_dual_key_map_test_ball_fill_get_type ())
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL, SerializableGeeDualKeyMapTestBallFill))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL, SerializableGeeDualKeyMapTestBallFillClass))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_IS_BALL_FILL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_IS_BALL_FILL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL, SerializableGeeDualKeyMapTestBallFillClass))

typedef struct _SerializableGeeDualKeyMapTestBallFill SerializableGeeDualKeyMapTestBallFill;
typedef struct _SerializableGeeDualKeyMapTestBallFillClass SerializableGeeDualKeyMapTestBallFillClass;
typedef struct _SerializableGeeDualKeyMapTestBallFillPrivate SerializableGeeDualKeyMapTestBallFillPrivate;
enum  {
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_0_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_NAME_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_dual_key_map_test_ball_fill_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_NUM_PROPERTIES];
typedef struct _SerializableGeeDualKeyMapTestBallPrivate SerializableGeeDualKeyMapTestBallPrivate;
enum  {
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_0_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_NAME_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_SIZE_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_BALLFILL_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_dual_key_map_test_ball_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_NUM_PROPERTIES];
typedef struct _SerializableGeeDualKeyMapTestBallDualMapPrivate SerializableGeeDualKeyMapTestBallDualMapPrivate;
enum  {
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_DUAL_MAP_0_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_DUAL_MAP_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_dual_key_map_test_ball_dual_map_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_DUAL_MAP_NUM_PROPERTIES];
typedef struct _SerializableGeeDualKeyMapTestSmallBagPrivate SerializableGeeDualKeyMapTestSmallBagPrivate;
enum  {
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_0_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_NAME_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_CASH_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_BALLS_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_dual_key_map_test_small_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_NUM_PROPERTIES];
typedef struct _SerializableGeeDualKeyMapTestSmallBagDualMapPrivate SerializableGeeDualKeyMapTestSmallBagDualMapPrivate;
enum  {
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_DUAL_MAP_0_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_DUAL_MAP_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_dual_key_map_test_small_bag_dual_map_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_DUAL_MAP_NUM_PROPERTIES];
typedef struct _SerializableGeeDualKeyMapTestBigBagPrivate SerializableGeeDualKeyMapTestBigBagPrivate;
enum  {
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_0_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_NAME_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_BAGS_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_dual_key_map_test_big_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_NUM_PROPERTIES];
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _Spaces {
	GXmlSerializableObjectModel parent_instance;
	SpacesPrivate * priv;
};

struct _SpacesClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SpacesPrivate {
	gchar* _name;
	gchar* _owner;
};

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializableGeeDualKeyMapTest {
	GXmlTest parent_instance;
	SerializableGeeDualKeyMapTestPrivate * priv;
};

struct _SerializableGeeDualKeyMapTestClass {
	GXmlTestClass parent_class;
};

struct _SerializableGeeDualKeyMapTestBallFill {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeDualKeyMapTestBallFillPrivate * priv;
};

struct _SerializableGeeDualKeyMapTestBallFillClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeDualKeyMapTestBallFillPrivate {
	gchar* _name;
};

struct _SerializableGeeDualKeyMapTestBall {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeDualKeyMapTestBallPrivate * priv;
};

struct _SerializableGeeDualKeyMapTestBallClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeDualKeyMapTestBallPrivate {
	gchar* _name;
	gchar* _size;
	SerializableGeeDualKeyMapTestBallFill* _ballfill;
};

struct _SerializableGeeDualKeyMapTestBallDualMap {
	GXmlSerializableDualKeyMap parent_instance;
	SerializableGeeDualKeyMapTestBallDualMapPrivate * priv;
};

struct _SerializableGeeDualKeyMapTestBallDualMapClass {
	GXmlSerializableDualKeyMapClass parent_class;
};

struct _SerializableGeeDualKeyMapTestSmallBag {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeDualKeyMapTestSmallBagPrivate * priv;
};

struct _SerializableGeeDualKeyMapTestSmallBagClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeDualKeyMapTestSmallBagPrivate {
	gchar* _name;
	gchar* _cash;
	SerializableGeeDualKeyMapTestBallDualMap* _balls;
};

struct _SerializableGeeDualKeyMapTestSmallBagDualMap {
	GXmlSerializableDualKeyMap parent_instance;
	SerializableGeeDualKeyMapTestSmallBagDualMapPrivate * priv;
};

struct _SerializableGeeDualKeyMapTestSmallBagDualMapClass {
	GXmlSerializableDualKeyMapClass parent_class;
};

struct _SerializableGeeDualKeyMapTestBigBag {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeDualKeyMapTestBigBagPrivate * priv;
};

struct _SerializableGeeDualKeyMapTestBigBagClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeDualKeyMapTestBigBagPrivate {
	gchar* _name;
	SerializableGeeDualKeyMapTestSmallBagDualMap* _bags;
};


static gpointer spaces_parent_class = NULL;
static GXmlSerializableMapDualKeyIface * spaces_gxml_serializable_map_dual_key_parent_iface = NULL;
static gpointer serializable_gee_dual_key_map_test_parent_class = NULL;
static gpointer serializable_gee_dual_key_map_test_ball_fill_parent_class = NULL;
static gpointer serializable_gee_dual_key_map_test_ball_parent_class = NULL;
static gpointer serializable_gee_dual_key_map_test_ball_dual_map_parent_class = NULL;
static GXmlSerializableMapDualKeyIface * serializable_gee_dual_key_map_test_ball_gxml_serializable_map_dual_key_parent_iface = NULL;
static gpointer serializable_gee_dual_key_map_test_small_bag_parent_class = NULL;
static gpointer serializable_gee_dual_key_map_test_small_bag_dual_map_parent_class = NULL;
static GXmlSerializableMapDualKeyIface * serializable_gee_dual_key_map_test_small_bag_gxml_serializable_map_dual_key_parent_iface = NULL;
static gpointer serializable_gee_dual_key_map_test_big_bag_parent_class = NULL;

GType spaces_get_type (void) G_GNUC_CONST;
#define SPACES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_SPACES, SpacesPrivate))
static gchar* spaces_real_get_map_primary_key (GXmlSerializableMapDualKey* base);
const gchar* spaces_get_owner (Spaces* self);
static gchar* spaces_real_get_map_secondary_key (GXmlSerializableMapDualKey* base);
const gchar* spaces_get_name (Spaces* self);
Spaces* spaces_new_full (const gchar* owner, 
                         const gchar* name);
Spaces* spaces_construct_full (GType object_type, 
                               const gchar* owner, 
                               const gchar* name);
void spaces_set_name (Spaces* self, 
                      const gchar* value);
void spaces_set_owner (Spaces* self, 
                       const gchar* value);
static gchar* spaces_real_to_string (GXmlSerializableObjectModel* base);
Spaces* spaces_new (void);
Spaces* spaces_construct (GType object_type);
static void spaces_finalize (GObject * obj);
static void _vala_spaces_get_property (GObject * object, 
                                guint property_id, 
                                GValue * value, 
                                GParamSpec * pspec);
static void _vala_spaces_set_property (GObject * object, 
                                guint property_id, 
                                const GValue * value, 
                                GParamSpec * pspec);
gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name, 
                                  const gchar* nick, 
                                  const gchar* blurb, 
                                  GType object_type, 
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value, 
                          gpointer v_object);
void value_take_gxml_test (GValue* value, 
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_gee_dual_key_map_test_get_type (void) G_GNUC_CONST;
void serializable_gee_dual_key_map_test_add_tests (void);
static void __lambda54_ (void);
static void ___lambda54__gtest_func (void);
static void __lambda55_ (void);
static void ___lambda55__gtest_func (void);
static void __lambda56_ (void);
static void ___lambda56__gtest_func (void);
static void __lambda57_ (void);
static void ___lambda57__gtest_func (void);
static void __lambda58_ (void);
GType book_store_get_type (void) G_GNUC_CONST;
BookStore* book_store_new (void);
BookStore* book_store_construct (GType object_type);
const gchar* book_store_get_name (BookStore* self);
GType book_array_get_type (void) G_GNUC_CONST;
BookArray* book_store_get_books (BookStore* self);
GType book_get_type (void) G_GNUC_CONST;
GType name_get_type (void) G_GNUC_CONST;
Name* book_get_name (Book* self);
gchar* name_get_name (Name* self);
const gchar* book_get_year (Book* self);
GType authors_get_type (void) G_GNUC_CONST;
Authors* book_get_authors (Book* self);
GType author_array_get_type (void) G_GNUC_CONST;
AuthorArray* authors_get_array (Authors* self);
GType inventory_dual_key_map_get_type (void) G_GNUC_CONST;
InventoryDualKeyMap* book_get_inventory_registers (Book* self);
GType inventory_get_type (void) G_GNUC_CONST;
gint inventory_get_number (Inventory* self);
const gchar* inventory_get_inventory (Inventory* self);
gint inventory_get_row (Inventory* self);
static void ___lambda58__gtest_func (void);
static void __lambda59_ (void);
static GType serializable_gee_dual_key_map_test_big_bag_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeDualKeyMapTestBigBag* serializable_gee_dual_key_map_test_big_bag_new (void);
static SerializableGeeDualKeyMapTestBigBag* serializable_gee_dual_key_map_test_big_bag_construct (GType object_type);
GType serializable_gee_dual_key_map_test_small_bag_dual_map_get_type (void) G_GNUC_CONST;
static SerializableGeeDualKeyMapTestSmallBagDualMap* serializable_gee_dual_key_map_test_big_bag_get_bags (SerializableGeeDualKeyMapTestBigBag* self);
static GType serializable_gee_dual_key_map_test_small_bag_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeDualKeyMapTestSmallBag* serializable_gee_dual_key_map_test_small_bag_new (void);
static SerializableGeeDualKeyMapTestSmallBag* serializable_gee_dual_key_map_test_small_bag_construct (GType object_type);
static void serializable_gee_dual_key_map_test_small_bag_set_name (SerializableGeeDualKeyMapTestSmallBag* self, 
                                                            const gchar* value);
GType serializable_gee_dual_key_map_test_ball_dual_map_get_type (void) G_GNUC_CONST;
static SerializableGeeDualKeyMapTestBallDualMap* serializable_gee_dual_key_map_test_small_bag_get_balls (SerializableGeeDualKeyMapTestSmallBag* self);
static GType serializable_gee_dual_key_map_test_ball_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeDualKeyMapTestBall* serializable_gee_dual_key_map_test_ball_new (void);
static SerializableGeeDualKeyMapTestBall* serializable_gee_dual_key_map_test_ball_construct (GType object_type);
static void serializable_gee_dual_key_map_test_ball_set_name (SerializableGeeDualKeyMapTestBall* self, 
                                                       const gchar* value);
static SerializableGeeDualKeyMapTestBallFill* serializable_gee_dual_key_map_test_ball_fill_new (void);
static SerializableGeeDualKeyMapTestBallFill* serializable_gee_dual_key_map_test_ball_fill_construct (GType object_type);
static GType serializable_gee_dual_key_map_test_ball_fill_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static void serializable_gee_dual_key_map_test_ball_set_ballfill (SerializableGeeDualKeyMapTestBall* self, 
                                                           SerializableGeeDualKeyMapTestBallFill* value);
static SerializableGeeDualKeyMapTestBallFill* serializable_gee_dual_key_map_test_ball_get_ballfill (SerializableGeeDualKeyMapTestBall* self);
static void serializable_gee_dual_key_map_test_ball_fill_set_text (SerializableGeeDualKeyMapTestBallFill* self, 
                                                            const gchar* txt);
static const gchar* serializable_gee_dual_key_map_test_ball_get_size (SerializableGeeDualKeyMapTestBall* self);
static const gchar* serializable_gee_dual_key_map_test_ball_get_name (SerializableGeeDualKeyMapTestBall* self);
static const gchar* serializable_gee_dual_key_map_test_small_bag_get_cash (SerializableGeeDualKeyMapTestSmallBag* self);
static const gchar* serializable_gee_dual_key_map_test_small_bag_get_name (SerializableGeeDualKeyMapTestSmallBag* self);
static void ___lambda59__gtest_func (void);
SerializableGeeDualKeyMapTest* serializable_gee_dual_key_map_test_new (void);
SerializableGeeDualKeyMapTest* serializable_gee_dual_key_map_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL, SerializableGeeDualKeyMapTestBallFillPrivate))
static gchar* serializable_gee_dual_key_map_test_ball_fill_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_dual_key_map_test_ball_fill_get_name (SerializableGeeDualKeyMapTestBallFill* self);
static gchar* serializable_gee_dual_key_map_test_ball_fill_real_node_name (GXmlSerializableObjectModel* base);
static gboolean serializable_gee_dual_key_map_test_ball_fill_real_serialize_use_xml_node_value (GXmlSerializableObjectModel* base);
static void serializable_gee_dual_key_map_test_ball_fill_set_name (SerializableGeeDualKeyMapTestBallFill* self, 
                                                            const gchar* value);
static void serializable_gee_dual_key_map_test_ball_fill_finalize (GObject * obj);
static void _vala_serializable_gee_dual_key_map_test_ball_fill_get_property (GObject * object, 
                                                                      guint property_id, 
                                                                      GValue * value, 
                                                                      GParamSpec * pspec);
static void _vala_serializable_gee_dual_key_map_test_ball_fill_set_property (GObject * object, 
                                                                      guint property_id, 
                                                                      const GValue * value, 
                                                                      GParamSpec * pspec);
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL, SerializableGeeDualKeyMapTestBallPrivate))
static gchar* serializable_gee_dual_key_map_test_ball_real_to_string (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_dual_key_map_test_ball_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_dual_key_map_test_ball_real_get_map_primary_key (GXmlSerializableMapDualKey* base);
static gchar* serializable_gee_dual_key_map_test_ball_real_get_map_secondary_key (GXmlSerializableMapDualKey* base);
static void serializable_gee_dual_key_map_test_ball_set_size (SerializableGeeDualKeyMapTestBall* self, 
                                                       const gchar* value);
static gboolean serializable_gee_dual_key_map_test_ball_dual_map_real_deserialize_proceed (GXmlSerializableDualKeyMap* base);
static SerializableGeeDualKeyMapTestBallDualMap* serializable_gee_dual_key_map_test_ball_dual_map_new (void);
static SerializableGeeDualKeyMapTestBallDualMap* serializable_gee_dual_key_map_test_ball_dual_map_construct (GType object_type);
static void serializable_gee_dual_key_map_test_ball_finalize (GObject * obj);
static void _vala_serializable_gee_dual_key_map_test_ball_get_property (GObject * object, 
                                                                 guint property_id, 
                                                                 GValue * value, 
                                                                 GParamSpec * pspec);
static void _vala_serializable_gee_dual_key_map_test_ball_set_property (GObject * object, 
                                                                 guint property_id, 
                                                                 const GValue * value, 
                                                                 GParamSpec * pspec);
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeDualKeyMapTestSmallBagPrivate))
static gchar* serializable_gee_dual_key_map_test_small_bag_real_to_string (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_dual_key_map_test_small_bag_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_dual_key_map_test_small_bag_real_get_map_primary_key (GXmlSerializableMapDualKey* base);
static gchar* serializable_gee_dual_key_map_test_small_bag_real_get_map_secondary_key (GXmlSerializableMapDualKey* base);
static void serializable_gee_dual_key_map_test_small_bag_set_cash (SerializableGeeDualKeyMapTestSmallBag* self, 
                                                            const gchar* value);
static void serializable_gee_dual_key_map_test_small_bag_set_balls (SerializableGeeDualKeyMapTestSmallBag* self, 
                                                             SerializableGeeDualKeyMapTestBallDualMap* value);
static gboolean serializable_gee_dual_key_map_test_small_bag_dual_map_real_deserialize_proceed (GXmlSerializableDualKeyMap* base);
static SerializableGeeDualKeyMapTestSmallBagDualMap* serializable_gee_dual_key_map_test_small_bag_dual_map_new (void);
static SerializableGeeDualKeyMapTestSmallBagDualMap* serializable_gee_dual_key_map_test_small_bag_dual_map_construct (GType object_type);
static void serializable_gee_dual_key_map_test_small_bag_finalize (GObject * obj);
static void _vala_serializable_gee_dual_key_map_test_small_bag_get_property (GObject * object, 
                                                                      guint property_id, 
                                                                      GValue * value, 
                                                                      GParamSpec * pspec);
static void _vala_serializable_gee_dual_key_map_test_small_bag_set_property (GObject * object, 
                                                                      guint property_id, 
                                                                      const GValue * value, 
                                                                      GParamSpec * pspec);
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BIG_BAG, SerializableGeeDualKeyMapTestBigBagPrivate))
static gchar* serializable_gee_dual_key_map_test_big_bag_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_dual_key_map_test_big_bag_get_name (SerializableGeeDualKeyMapTestBigBag* self);
static gchar* serializable_gee_dual_key_map_test_big_bag_real_node_name (GXmlSerializableObjectModel* base);
static void serializable_gee_dual_key_map_test_big_bag_set_name (SerializableGeeDualKeyMapTestBigBag* self, 
                                                          const gchar* value);
static void serializable_gee_dual_key_map_test_big_bag_set_bags (SerializableGeeDualKeyMapTestBigBag* self, 
                                                          SerializableGeeDualKeyMapTestSmallBagDualMap* value);
static void serializable_gee_dual_key_map_test_big_bag_finalize (GObject * obj);
static void _vala_serializable_gee_dual_key_map_test_big_bag_get_property (GObject * object, 
                                                                    guint property_id, 
                                                                    GValue * value, 
                                                                    GParamSpec * pspec);
static void _vala_serializable_gee_dual_key_map_test_big_bag_set_property (GObject * object, 
                                                                    guint property_id, 
                                                                    const GValue * value, 
                                                                    GParamSpec * pspec);


static gchar*
spaces_real_get_map_primary_key (GXmlSerializableMapDualKey* base)
{
	Spaces * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (Spaces*) base;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_owner;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 570 "SerializableGeeDualKeyMapTest.c"
}


static gchar*
spaces_real_get_map_secondary_key (GXmlSerializableMapDualKey* base)
{
	Spaces * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (Spaces*) base;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 591 "SerializableGeeDualKeyMapTest.c"
}


Spaces*
spaces_construct_full (GType object_type, 
                       const gchar* owner, 
                       const gchar* name)
{
	Spaces * self = NULL;
#line 35 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (owner != NULL, NULL);
#line 35 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 35 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (Spaces*) gxml_serializable_object_model_construct (object_type);
#line 37 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	spaces_set_name (self, name);
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	spaces_set_owner (self, owner);
#line 35 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return self;
#line 613 "SerializableGeeDualKeyMapTest.c"
}


Spaces*
spaces_new_full (const gchar* owner, 
                 const gchar* name)
{
#line 35 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return spaces_construct_full (TYPE_SPACES, owner, name);
#line 623 "SerializableGeeDualKeyMapTest.c"
}


static gchar*
spaces_real_to_string (GXmlSerializableObjectModel* base)
{
	Spaces * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (Spaces*) base;
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 644 "SerializableGeeDualKeyMapTest.c"
}


Spaces*
spaces_construct (GType object_type)
{
	Spaces * self = NULL;
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (Spaces*) gxml_serializable_object_model_construct (object_type);
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return self;
#line 656 "SerializableGeeDualKeyMapTest.c"
}


Spaces*
spaces_new (void)
{
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return spaces_construct (TYPE_SPACES);
#line 665 "SerializableGeeDualKeyMapTest.c"
}


const gchar*
spaces_get_name (Spaces* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 682 "SerializableGeeDualKeyMapTest.c"
}


void
spaces_set_name (Spaces* self, 
                 const gchar* value)
{
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (g_strcmp0 (value, spaces_get_name (self)) != 0) {
#line 694 "SerializableGeeDualKeyMapTest.c"
		gchar* _tmp0_;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (self->priv->_name);
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		self->priv->_name = _tmp0_;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, spaces_properties[SPACES_NAME_PROPERTY]);
#line 704 "SerializableGeeDualKeyMapTest.c"
	}
}


const gchar*
spaces_get_owner (Spaces* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_owner;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 722 "SerializableGeeDualKeyMapTest.c"
}


void
spaces_set_owner (Spaces* self, 
                  const gchar* value)
{
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (g_strcmp0 (value, spaces_get_owner (self)) != 0) {
#line 734 "SerializableGeeDualKeyMapTest.c"
		gchar* _tmp0_;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (self->priv->_owner);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		self->priv->_owner = _tmp0_;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, spaces_properties[SPACES_OWNER_PROPERTY]);
#line 744 "SerializableGeeDualKeyMapTest.c"
	}
}


static void
spaces_class_init (SpacesClass * klass)
{
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	spaces_parent_class = g_type_class_peek_parent (klass);
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_type_class_add_private (klass, sizeof (SpacesPrivate));
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel *)) spaces_real_to_string;
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_spaces_get_property;
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_spaces_set_property;
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = spaces_finalize;
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SPACES_NAME_PROPERTY, spaces_properties[SPACES_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SPACES_OWNER_PROPERTY, spaces_properties[SPACES_OWNER_PROPERTY] = g_param_spec_string ("owner", "owner", "owner", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 768 "SerializableGeeDualKeyMapTest.c"
}


static void
spaces_gxml_serializable_map_dual_key_interface_init (GXmlSerializableMapDualKeyIface * iface)
{
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	spaces_gxml_serializable_map_dual_key_parent_iface = g_type_interface_peek_parent (iface);
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	iface->get_map_primary_key = (gpointer (*) (GXmlSerializableMapDualKey *)) spaces_real_get_map_primary_key;
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	iface->get_map_secondary_key = (gpointer (*) (GXmlSerializableMapDualKey *)) spaces_real_get_map_secondary_key;
#line 781 "SerializableGeeDualKeyMapTest.c"
}


static void
spaces_instance_init (Spaces * self)
{
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self->priv = SPACES_GET_PRIVATE (self);
#line 790 "SerializableGeeDualKeyMapTest.c"
}


static void
spaces_finalize (GObject * obj)
{
	Spaces * self;
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SPACES, Spaces);
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_g_free0 (self->priv->_name);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_g_free0 (self->priv->_owner);
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (spaces_parent_class)->finalize (obj);
#line 806 "SerializableGeeDualKeyMapTest.c"
}


/**
 *
 *  GXml.Serializable.BasicTypeTest
 *
 *  Authors:
 *
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *
 *  Copyright (c) 2013-2015 Daniel Espinosa
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType
spaces_get_type (void)
{
	static volatile gsize spaces_type_id__volatile = 0;
	if (g_once_init_enter (&spaces_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SpacesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spaces_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Spaces), 0, (GInstanceInitFunc) spaces_instance_init, NULL };
		static const GInterfaceInfo gxml_serializable_map_dual_key_info = { (GInterfaceInitFunc) spaces_gxml_serializable_map_dual_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType spaces_type_id;
		spaces_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "Spaces", &g_define_type_info, 0);
		g_type_add_interface_static (spaces_type_id, GXML_TYPE_SERIALIZABLE_MAP_DUAL_KEY, &gxml_serializable_map_dual_key_info);
		g_once_init_leave (&spaces_type_id__volatile, spaces_type_id);
	}
	return spaces_type_id__volatile;
}


static void
_vala_spaces_get_property (GObject * object, 
                           guint property_id, 
                           GValue * value, 
                           GParamSpec * pspec)
{
	Spaces * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_SPACES, Spaces);
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	switch (property_id) {
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SPACES_NAME_PROPERTY:
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_value_set_string (value, spaces_get_name (self));
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SPACES_OWNER_PROPERTY:
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_value_set_string (value, spaces_get_owner (self));
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 872 "SerializableGeeDualKeyMapTest.c"
		default:
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 878 "SerializableGeeDualKeyMapTest.c"
	}
}


static void
_vala_spaces_set_property (GObject * object, 
                           guint property_id, 
                           const GValue * value, 
                           GParamSpec * pspec)
{
	Spaces * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_SPACES, Spaces);
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	switch (property_id) {
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SPACES_NAME_PROPERTY:
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		spaces_set_name (self, g_value_get_string (value));
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SPACES_OWNER_PROPERTY:
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		spaces_set_owner (self, g_value_get_string (value));
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 905 "SerializableGeeDualKeyMapTest.c"
		default:
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 29 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 911 "SerializableGeeDualKeyMapTest.c"
	}
}


static void
__lambda54_ (void)
{
	GXmlSerializableDualKeyMap* c = NULL;
	GXmlSerializableDualKeyMap* _tmp0_;
	Spaces* o1 = NULL;
	Spaces* _tmp1_;
	Spaces* o2 = NULL;
	Spaces* _tmp2_;
	Spaces* o3 = NULL;
	Spaces* _tmp3_;
	Spaces* o4 = NULL;
	Spaces* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	const gchar* _tmp14_;
	const gchar* _tmp15_;
	const gchar* _tmp16_;
	const gchar* _tmp17_;
	const gchar* _tmp18_;
	const gchar* _tmp19_;
	const gchar* _tmp20_;
	gint _tmp21_;
	gint _tmp22_;
	gboolean found1 = FALSE;
	gboolean found2 = FALSE;
	gboolean found3 = FALSE;
	gboolean found4 = FALSE;
	gboolean _tmp65_;
	gboolean _tmp67_;
	gboolean _tmp69_;
	gboolean _tmp71_;
	gboolean _tmp73_;
	gboolean _tmp95_;
	gboolean _tmp97_;
	gboolean _tmp99_;
	gboolean _tmp123_;
	gboolean _tmp125_;
#line 95 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = gxml_serializable_dual_key_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, TYPE_SPACES, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 95 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	c = _tmp0_;
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = spaces_new_full ("Floor", "Big");
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	o1 = _tmp1_;
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp2_ = spaces_new_full ("Wall", "Small");
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	o2 = _tmp2_;
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp3_ = spaces_new_full ("Floor", "Bigger");
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	o3 = _tmp3_;
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp4_ = spaces_new_full ("Wall", "Smallest");
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	o4 = _tmp4_;
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp5_ = spaces_get_owner (o1);
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp6_ = _tmp5_;
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp7_ = spaces_get_name (o1);
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp8_ = _tmp7_;
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	gxml_serializable_dual_key_map_set (c, _tmp6_, _tmp8_, o1);
#line 101 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp9_ = spaces_get_owner (o2);
#line 101 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp10_ = _tmp9_;
#line 101 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp11_ = spaces_get_name (o2);
#line 101 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp12_ = _tmp11_;
#line 101 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	gxml_serializable_dual_key_map_set (c, _tmp10_, _tmp12_, o2);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp13_ = spaces_get_owner (o3);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp14_ = _tmp13_;
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp15_ = spaces_get_name (o3);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp16_ = _tmp15_;
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	gxml_serializable_dual_key_map_set (c, _tmp14_, _tmp16_, o3);
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp17_ = spaces_get_owner (o4);
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp18_ = _tmp17_;
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp19_ = spaces_get_name (o4);
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp20_ = _tmp19_;
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	gxml_serializable_dual_key_map_set (c, _tmp18_, _tmp20_, o4);
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp21_ = gxml_serializable_dual_key_map_get_size (c);
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp22_ = _tmp21_;
#line 104 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (_tmp22_ != 4) {
#line 1027 "SerializableGeeDualKeyMapTest.c"
		FILE* _tmp23_;
		gint _tmp24_;
		gint _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp23_ = stdout;
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp24_ = gxml_serializable_dual_key_map_get_size (c);
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp25_ = _tmp24_;
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp26_ = g_strdup_printf ("%i", _tmp25_);
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp27_ = _tmp26_;
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp28_ = g_strconcat ("SIZE: ", _tmp27_, "\n", NULL);
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp29_ = _tmp28_;
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp23_, "%s", _tmp29_);
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp29_);
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp27_);
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 1057 "SerializableGeeDualKeyMapTest.c"
	}
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	found1 = FALSE;
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	found2 = FALSE;
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	found3 = FALSE;
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	found4 = FALSE;
#line 1067 "SerializableGeeDualKeyMapTest.c"
	{
		GeeIterator* _s_it = NULL;
		GeeCollection* _tmp30_;
		GeeCollection* _tmp31_;
		GeeIterator* _tmp32_;
		GeeIterator* _tmp33_;
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp30_ = gxml_serializable_dual_key_map_values (c);
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp31_ = _tmp30_;
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp32_ = gee_iterable_iterator ((GeeIterable*) _tmp31_);
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp33_ = _tmp32_;
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp31_);
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_s_it = _tmp33_;
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		while (TRUE) {
#line 1088 "SerializableGeeDualKeyMapTest.c"
			GeeIterator* _tmp34_;
			Spaces* s = NULL;
			GeeIterator* _tmp35_;
			gpointer _tmp36_;
			gboolean _tmp37_ = FALSE;
			Spaces* _tmp38_;
			const gchar* _tmp39_;
			const gchar* _tmp40_;
			gboolean _tmp44_ = FALSE;
			Spaces* _tmp45_;
			const gchar* _tmp46_;
			const gchar* _tmp47_;
			gboolean _tmp51_ = FALSE;
			Spaces* _tmp52_;
			const gchar* _tmp53_;
			const gchar* _tmp54_;
			gboolean _tmp58_ = FALSE;
			Spaces* _tmp59_;
			const gchar* _tmp60_;
			const gchar* _tmp61_;
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp34_ = _s_it;
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			if (!gee_iterator_next (_tmp34_)) {
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				break;
#line 1115 "SerializableGeeDualKeyMapTest.c"
			}
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp35_ = _s_it;
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp36_ = gee_iterator_get (_tmp35_);
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			s = (Spaces*) _tmp36_;
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp38_ = s;
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp39_ = spaces_get_owner (_tmp38_);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp40_ = _tmp39_;
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			if (g_strcmp0 (_tmp40_, "Floor") == 0) {
#line 1131 "SerializableGeeDualKeyMapTest.c"
				Spaces* _tmp41_;
				const gchar* _tmp42_;
				const gchar* _tmp43_;
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp41_ = s;
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp42_ = spaces_get_name (_tmp41_);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp43_ = _tmp42_;
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp37_ = g_strcmp0 (_tmp43_, "Big") == 0;
#line 1143 "SerializableGeeDualKeyMapTest.c"
			} else {
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp37_ = FALSE;
#line 1147 "SerializableGeeDualKeyMapTest.c"
			}
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			if (_tmp37_) {
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				found1 = TRUE;
#line 1153 "SerializableGeeDualKeyMapTest.c"
			}
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp45_ = s;
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp46_ = spaces_get_owner (_tmp45_);
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp47_ = _tmp46_;
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			if (g_strcmp0 (_tmp47_, "Wall") == 0) {
#line 1163 "SerializableGeeDualKeyMapTest.c"
				Spaces* _tmp48_;
				const gchar* _tmp49_;
				const gchar* _tmp50_;
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp48_ = s;
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp49_ = spaces_get_name (_tmp48_);
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp50_ = _tmp49_;
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp44_ = g_strcmp0 (_tmp50_, "Small") == 0;
#line 1175 "SerializableGeeDualKeyMapTest.c"
			} else {
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp44_ = FALSE;
#line 1179 "SerializableGeeDualKeyMapTest.c"
			}
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			if (_tmp44_) {
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				found2 = TRUE;
#line 1185 "SerializableGeeDualKeyMapTest.c"
			}
#line 117 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp52_ = s;
#line 117 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp53_ = spaces_get_owner (_tmp52_);
#line 117 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp54_ = _tmp53_;
#line 117 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			if (g_strcmp0 (_tmp54_, "Floor") == 0) {
#line 1195 "SerializableGeeDualKeyMapTest.c"
				Spaces* _tmp55_;
				const gchar* _tmp56_;
				const gchar* _tmp57_;
#line 117 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp55_ = s;
#line 117 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp56_ = spaces_get_name (_tmp55_);
#line 117 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp57_ = _tmp56_;
#line 117 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp51_ = g_strcmp0 (_tmp57_, "Bigger") == 0;
#line 1207 "SerializableGeeDualKeyMapTest.c"
			} else {
#line 117 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp51_ = FALSE;
#line 1211 "SerializableGeeDualKeyMapTest.c"
			}
#line 117 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			if (_tmp51_) {
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				found3 = TRUE;
#line 1217 "SerializableGeeDualKeyMapTest.c"
			}
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp59_ = s;
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp60_ = spaces_get_owner (_tmp59_);
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp61_ = _tmp60_;
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			if (g_strcmp0 (_tmp61_, "Wall") == 0) {
#line 1227 "SerializableGeeDualKeyMapTest.c"
				Spaces* _tmp62_;
				const gchar* _tmp63_;
				const gchar* _tmp64_;
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp62_ = s;
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp63_ = spaces_get_name (_tmp62_);
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp64_ = _tmp63_;
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp58_ = g_strcmp0 (_tmp64_, "Smallest") == 0;
#line 1239 "SerializableGeeDualKeyMapTest.c"
			} else {
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp58_ = FALSE;
#line 1243 "SerializableGeeDualKeyMapTest.c"
			}
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			if (_tmp58_) {
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				found4 = TRUE;
#line 1249 "SerializableGeeDualKeyMapTest.c"
			}
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (s);
#line 1253 "SerializableGeeDualKeyMapTest.c"
		}
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_s_it);
#line 1257 "SerializableGeeDualKeyMapTest.c"
	}
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp65_ = found1;
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (!_tmp65_) {
#line 1263 "SerializableGeeDualKeyMapTest.c"
		FILE* _tmp66_;
#line 123 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp66_ = stdout;
#line 123 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp66_, "%s", "Not found 'Floor' & 'Big':\n");
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 1271 "SerializableGeeDualKeyMapTest.c"
	}
#line 126 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp67_ = found2;
#line 126 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (!_tmp67_) {
#line 1277 "SerializableGeeDualKeyMapTest.c"
		FILE* _tmp68_;
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp68_ = stdout;
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp68_, "%s", "Not found 'Wall' & 'Small':\n");
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 1285 "SerializableGeeDualKeyMapTest.c"
	}
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp69_ = found3;
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (!_tmp69_) {
#line 1291 "SerializableGeeDualKeyMapTest.c"
		FILE* _tmp70_;
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp70_ = stdout;
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp70_, "%s", "Not found 'Floor' & 'Bigger':\n");
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 1299 "SerializableGeeDualKeyMapTest.c"
	}
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp71_ = found4;
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (!_tmp71_) {
#line 1305 "SerializableGeeDualKeyMapTest.c"
		FILE* _tmp72_;
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp72_ = stdout;
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp72_, "%s", "Not found 'Wall' & 'Smallest':\n");
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 1313 "SerializableGeeDualKeyMapTest.c"
	}
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	found3 = FALSE;
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp73_ = found3;
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	found1 = _tmp73_;
#line 1321 "SerializableGeeDualKeyMapTest.c"
	{
		GeeIterator* _s_it = NULL;
		GeeCollection* _tmp74_;
		GeeCollection* _tmp75_;
		GeeIterator* _tmp76_;
		GeeIterator* _tmp77_;
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp74_ = gxml_serializable_dual_key_map_values_for_key (c, "Floor");
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp75_ = _tmp74_;
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp76_ = gee_iterable_iterator ((GeeIterable*) _tmp75_);
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp77_ = _tmp76_;
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp75_);
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_s_it = _tmp77_;
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		while (TRUE) {
#line 1342 "SerializableGeeDualKeyMapTest.c"
			GeeIterator* _tmp78_;
			Spaces* s = NULL;
			GeeIterator* _tmp79_;
			gpointer _tmp80_;
			gboolean _tmp81_ = FALSE;
			Spaces* _tmp82_;
			const gchar* _tmp83_;
			const gchar* _tmp84_;
			gboolean _tmp88_ = FALSE;
			Spaces* _tmp89_;
			const gchar* _tmp90_;
			const gchar* _tmp91_;
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp78_ = _s_it;
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			if (!gee_iterator_next (_tmp78_)) {
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				break;
#line 1361 "SerializableGeeDualKeyMapTest.c"
			}
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp79_ = _s_it;
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp80_ = gee_iterator_get (_tmp79_);
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			s = (Spaces*) _tmp80_;
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp82_ = s;
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp83_ = spaces_get_owner (_tmp82_);
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp84_ = _tmp83_;
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			if (g_strcmp0 (_tmp84_, "Floor") == 0) {
#line 1377 "SerializableGeeDualKeyMapTest.c"
				Spaces* _tmp85_;
				const gchar* _tmp86_;
				const gchar* _tmp87_;
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp85_ = s;
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp86_ = spaces_get_name (_tmp85_);
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp87_ = _tmp86_;
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp81_ = g_strcmp0 (_tmp87_, "Big") == 0;
#line 1389 "SerializableGeeDualKeyMapTest.c"
			} else {
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp81_ = FALSE;
#line 1393 "SerializableGeeDualKeyMapTest.c"
			}
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			if (_tmp81_) {
#line 141 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				found1 = TRUE;
#line 1399 "SerializableGeeDualKeyMapTest.c"
			}
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp89_ = s;
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp90_ = spaces_get_owner (_tmp89_);
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp91_ = _tmp90_;
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			if (g_strcmp0 (_tmp91_, "Floor") == 0) {
#line 1409 "SerializableGeeDualKeyMapTest.c"
				Spaces* _tmp92_;
				const gchar* _tmp93_;
				const gchar* _tmp94_;
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp92_ = s;
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp93_ = spaces_get_name (_tmp92_);
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp94_ = _tmp93_;
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp88_ = g_strcmp0 (_tmp94_, "Bigger") == 0;
#line 1421 "SerializableGeeDualKeyMapTest.c"
			} else {
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp88_ = FALSE;
#line 1425 "SerializableGeeDualKeyMapTest.c"
			}
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			if (_tmp88_) {
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				found3 = TRUE;
#line 1431 "SerializableGeeDualKeyMapTest.c"
			}
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (s);
#line 1435 "SerializableGeeDualKeyMapTest.c"
		}
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_s_it);
#line 1439 "SerializableGeeDualKeyMapTest.c"
	}
#line 145 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp95_ = found1;
#line 145 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (!_tmp95_) {
#line 1445 "SerializableGeeDualKeyMapTest.c"
		FILE* _tmp96_;
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp96_ = stdout;
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp96_, "%s", "Not found 'Floor' & 'Big':\n");
#line 147 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 1453 "SerializableGeeDualKeyMapTest.c"
	}
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp97_ = found3;
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (!_tmp97_) {
#line 1459 "SerializableGeeDualKeyMapTest.c"
		FILE* _tmp98_;
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp98_ = stdout;
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp98_, "%s", "Not found 'Floor' & 'Bigger':\n");
#line 151 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 1467 "SerializableGeeDualKeyMapTest.c"
	}
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	found4 = TRUE;
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp99_ = found4;
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	found2 = _tmp99_;
#line 1475 "SerializableGeeDualKeyMapTest.c"
	{
		GeeIterator* _k2_it = NULL;
		GeeCollection* _tmp100_;
		GeeCollection* _tmp101_;
		GeeIterator* _tmp102_;
		GeeIterator* _tmp103_;
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp100_ = gxml_serializable_dual_key_map_secondary_keys (c, "Wall");
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp101_ = _tmp100_;
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp102_ = gee_iterable_iterator ((GeeIterable*) _tmp101_);
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp103_ = _tmp102_;
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp101_);
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_k2_it = _tmp103_;
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		while (TRUE) {
#line 1496 "SerializableGeeDualKeyMapTest.c"
			GeeIterator* _tmp104_;
			gchar* k2 = NULL;
			GeeIterator* _tmp105_;
			gpointer _tmp106_;
			Spaces* s = NULL;
			const gchar* _tmp107_;
			gpointer _tmp108_;
			gboolean _tmp109_ = FALSE;
			Spaces* _tmp110_;
			const gchar* _tmp111_;
			const gchar* _tmp112_;
			gboolean _tmp116_ = FALSE;
			Spaces* _tmp117_;
			const gchar* _tmp118_;
			const gchar* _tmp119_;
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp104_ = _k2_it;
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			if (!gee_iterator_next (_tmp104_)) {
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				break;
#line 1518 "SerializableGeeDualKeyMapTest.c"
			}
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp105_ = _k2_it;
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp106_ = gee_iterator_get (_tmp105_);
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			k2 = (gchar*) _tmp106_;
#line 155 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp107_ = k2;
#line 155 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp108_ = gxml_serializable_dual_key_map_get (c, "Wall", _tmp107_);
#line 155 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			s = (Spaces*) _tmp108_;
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp110_ = s;
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp111_ = spaces_get_owner (_tmp110_);
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp112_ = _tmp111_;
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			if (g_strcmp0 (_tmp112_, "Wall") == 0) {
#line 1540 "SerializableGeeDualKeyMapTest.c"
				Spaces* _tmp113_;
				const gchar* _tmp114_;
				const gchar* _tmp115_;
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp113_ = s;
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp114_ = spaces_get_name (_tmp113_);
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp115_ = _tmp114_;
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp109_ = g_strcmp0 (_tmp115_, "Small") == 0;
#line 1552 "SerializableGeeDualKeyMapTest.c"
			} else {
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp109_ = FALSE;
#line 1556 "SerializableGeeDualKeyMapTest.c"
			}
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			if (_tmp109_) {
#line 157 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				found2 = TRUE;
#line 1562 "SerializableGeeDualKeyMapTest.c"
			}
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp117_ = s;
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp118_ = spaces_get_owner (_tmp117_);
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp119_ = _tmp118_;
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			if (g_strcmp0 (_tmp119_, "Wall") == 0) {
#line 1572 "SerializableGeeDualKeyMapTest.c"
				Spaces* _tmp120_;
				const gchar* _tmp121_;
				const gchar* _tmp122_;
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp120_ = s;
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp121_ = spaces_get_name (_tmp120_);
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp122_ = _tmp121_;
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp116_ = g_strcmp0 (_tmp122_, "Smallest") == 0;
#line 1584 "SerializableGeeDualKeyMapTest.c"
			} else {
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp116_ = FALSE;
#line 1588 "SerializableGeeDualKeyMapTest.c"
			}
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			if (_tmp116_) {
#line 159 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				found4 = TRUE;
#line 1594 "SerializableGeeDualKeyMapTest.c"
			}
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (s);
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (k2);
#line 1600 "SerializableGeeDualKeyMapTest.c"
		}
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_k2_it);
#line 1604 "SerializableGeeDualKeyMapTest.c"
	}
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp123_ = found2;
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (!_tmp123_) {
#line 1610 "SerializableGeeDualKeyMapTest.c"
		FILE* _tmp124_;
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp124_ = stdout;
#line 162 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp124_, "%s", "Not found 'Wall' & 'Small':\n");
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 1618 "SerializableGeeDualKeyMapTest.c"
	}
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp125_ = found4;
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (!_tmp125_) {
#line 1624 "SerializableGeeDualKeyMapTest.c"
		FILE* _tmp126_;
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp126_ = stdout;
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp126_, "%s", "Not found 'Wall' & 'Smallest':\n");
#line 167 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 1632 "SerializableGeeDualKeyMapTest.c"
	}
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_g_object_unref0 (o4);
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_g_object_unref0 (o3);
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_g_object_unref0 (o2);
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_g_object_unref0 (o1);
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_g_object_unref0 (c);
#line 1644 "SerializableGeeDualKeyMapTest.c"
}


static void
___lambda54__gtest_func (void)
{
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	__lambda54_ ();
#line 1653 "SerializableGeeDualKeyMapTest.c"
}


static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result = NULL;
#line 1456 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1457 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	result = self;
#line 1457 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	return result;
#line 1667 "SerializableGeeDualKeyMapTest.c"
}


static void
__lambda55_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlSerializableDualKeyMap* c = NULL;
		GXmlSerializableDualKeyMap* _tmp0_;
		Spaces* o1 = NULL;
		Spaces* _tmp1_;
		Spaces* o2 = NULL;
		Spaces* _tmp2_;
		Spaces* o3 = NULL;
		Spaces* _tmp3_;
		Spaces* o4 = NULL;
		Spaces* _tmp4_;
		GXmlSerializableDualKeyMap* _tmp5_;
		Spaces* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp8_;
		Spaces* _tmp9_;
		const gchar* _tmp10_;
		const gchar* _tmp11_;
		Spaces* _tmp12_;
		GXmlSerializableDualKeyMap* _tmp13_;
		Spaces* _tmp14_;
		const gchar* _tmp15_;
		const gchar* _tmp16_;
		Spaces* _tmp17_;
		const gchar* _tmp18_;
		const gchar* _tmp19_;
		Spaces* _tmp20_;
		GXmlSerializableDualKeyMap* _tmp21_;
		Spaces* _tmp22_;
		const gchar* _tmp23_;
		const gchar* _tmp24_;
		Spaces* _tmp25_;
		const gchar* _tmp26_;
		const gchar* _tmp27_;
		Spaces* _tmp28_;
		GXmlSerializableDualKeyMap* _tmp29_;
		Spaces* _tmp30_;
		const gchar* _tmp31_;
		const gchar* _tmp32_;
		Spaces* _tmp33_;
		const gchar* _tmp34_;
		const gchar* _tmp35_;
		Spaces* _tmp36_;
		GXmlTDocument* doc = NULL;
		GXmlTDocument* _tmp37_;
		GXmlNode* root = NULL;
		GXmlTDocument* _tmp38_;
		GXmlNode* _tmp39_;
		GXmlTDocument* _tmp40_;
		GeeBidirList* _tmp41_;
		GeeBidirList* _tmp42_;
		GeeBidirList* _tmp43_;
		GXmlNode* _tmp44_;
		GXmlSerializableDualKeyMap* _tmp45_;
		GXmlNode* _tmp46_;
		GXmlNode* _tmp47_;
		GXmlNode* _tmp48_;
		GXmlNode* _tmp49_;
		GeeBidirList* _tmp50_;
		GeeBidirList* _tmp51_;
		GeeBidirList* _tmp52_;
		gint _tmp53_;
		gint _tmp54_;
		gboolean found1 = FALSE;
		gboolean found2 = FALSE;
		gboolean found3 = FALSE;
		gboolean found4 = FALSE;
		gint nodes = 0;
		gint i = 0;
		gint _tmp130_;
		gint _tmp140_;
		gboolean _tmp150_;
		gboolean _tmp157_;
		gboolean _tmp164_;
		gboolean _tmp171_;
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = gxml_serializable_dual_key_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, TYPE_SPACES, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		c = _tmp0_;
#line 174 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp1_ = spaces_new_full ("Floor", "Big");
#line 174 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		o1 = _tmp1_;
#line 175 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp2_ = spaces_new_full ("Wall", "Small");
#line 175 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		o2 = _tmp2_;
#line 176 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp3_ = spaces_new_full ("Floor", "Bigger");
#line 176 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		o3 = _tmp3_;
#line 177 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp4_ = spaces_new_full ("Wall", "Smallest");
#line 177 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		o4 = _tmp4_;
#line 178 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp5_ = c;
#line 178 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp6_ = o1;
#line 178 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp7_ = spaces_get_owner (_tmp6_);
#line 178 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp8_ = _tmp7_;
#line 178 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp9_ = o1;
#line 178 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp10_ = spaces_get_name (_tmp9_);
#line 178 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp11_ = _tmp10_;
#line 178 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp12_ = o1;
#line 178 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_dual_key_map_set (_tmp5_, _tmp8_, _tmp11_, _tmp12_);
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp13_ = c;
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp14_ = o2;
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp15_ = spaces_get_owner (_tmp14_);
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp16_ = _tmp15_;
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp17_ = o2;
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp18_ = spaces_get_name (_tmp17_);
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp19_ = _tmp18_;
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp20_ = o2;
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_dual_key_map_set (_tmp13_, _tmp16_, _tmp19_, _tmp20_);
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp21_ = c;
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp22_ = o3;
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp23_ = spaces_get_owner (_tmp22_);
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp24_ = _tmp23_;
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp25_ = o3;
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp26_ = spaces_get_name (_tmp25_);
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp27_ = _tmp26_;
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp28_ = o3;
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_dual_key_map_set (_tmp21_, _tmp24_, _tmp27_, _tmp28_);
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp29_ = c;
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp30_ = o4;
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp31_ = spaces_get_owner (_tmp30_);
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp32_ = _tmp31_;
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp33_ = o4;
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp34_ = spaces_get_name (_tmp33_);
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp35_ = _tmp34_;
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp36_ = o4;
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_dual_key_map_set (_tmp29_, _tmp32_, _tmp35_, _tmp36_);
#line 182 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp37_ = gxml_tdocument_new ();
#line 182 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		doc = _tmp37_;
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp38_ = doc;
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp39_ = gxml_document_create_element ((GXmlDocument*) _tmp38_, "root", &_inner_error_);
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		root = _tmp39_;
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (doc);
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (o4);
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (o3);
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (o2);
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (o1);
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (c);
#line 1866 "SerializableGeeDualKeyMapTest.c"
			goto __catch93_g_error;
		}
#line 184 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp40_ = doc;
#line 184 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp41_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp40_);
#line 184 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp42_ = _tmp41_;
#line 184 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp43_ = _tmp42_;
#line 184 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp44_ = root;
#line 184 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		gee_collection_add ((GeeCollection*) _tmp43_, _tmp44_);
#line 184 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp43_);
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp45_ = c;
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp46_ = root;
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp47_ = gxml_serializable_dual_key_map_serialize (_tmp45_, _tmp46_, &_inner_error_);
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp48_ = _tmp47_;
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp48_);
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (root);
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (doc);
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (o4);
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (o3);
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (o2);
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (o1);
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (c);
#line 1909 "SerializableGeeDualKeyMapTest.c"
			goto __catch93_g_error;
		}
#line 186 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp49_ = root;
#line 186 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp50_ = gxml_node_get_children_nodes (_tmp49_);
#line 186 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp51_ = _tmp50_;
#line 186 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp52_ = _tmp51_;
#line 186 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp53_ = gee_collection_get_size ((GeeCollection*) _tmp52_);
#line 186 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp54_ = _tmp53_;
#line 186 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp54_ == 4, "root.children_nodes.size == 4");
#line 186 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp52_);
#line 187 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		found1 = FALSE;
#line 188 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		found2 = FALSE;
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		found3 = FALSE;
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		found4 = FALSE;
#line 191 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		nodes = 0;
#line 192 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		i = 0;
#line 1940 "SerializableGeeDualKeyMapTest.c"
		{
			GeeBidirList* _n_list = NULL;
			GXmlNode* _tmp55_;
			GeeBidirList* _tmp56_;
			GeeBidirList* _tmp57_;
			gint _n_size = 0;
			GeeBidirList* _tmp58_;
			gint _tmp59_;
			gint _tmp60_;
			gint _n_index = 0;
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp55_ = root;
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp56_ = gxml_node_get_children_nodes (_tmp55_);
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp57_ = _tmp56_;
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_n_list = _tmp57_;
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp58_ = _n_list;
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp59_ = gee_collection_get_size ((GeeCollection*) _tmp58_);
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp60_ = _tmp59_;
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_n_size = _tmp60_;
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_n_index = -1;
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			while (TRUE) {
#line 1971 "SerializableGeeDualKeyMapTest.c"
				gint _tmp61_;
				gint _tmp62_;
				gint _tmp63_;
				GXmlNode* n = NULL;
				GeeBidirList* _tmp64_;
				gint _tmp65_;
				gpointer _tmp66_;
				gint _tmp67_;
				gboolean _tmp68_ = FALSE;
				GXmlNode* _tmp69_;
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp61_ = _n_index;
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_n_index = _tmp61_ + 1;
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp62_ = _n_index;
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp63_ = _n_size;
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				if (!(_tmp62_ < _tmp63_)) {
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					break;
#line 1994 "SerializableGeeDualKeyMapTest.c"
				}
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp64_ = _n_list;
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp65_ = _n_index;
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp66_ = gee_list_get ((GeeList*) _tmp64_, _tmp65_);
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				n = (GXmlNode*) _tmp66_;
#line 194 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp67_ = nodes;
#line 194 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				nodes = _tmp67_ + 1;
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp69_ = n;
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp69_, GXML_TYPE_ELEMENT)) {
#line 2012 "SerializableGeeDualKeyMapTest.c"
					GXmlNode* _tmp70_;
					gchar* _tmp71_;
					gchar* _tmp72_;
					gchar* _tmp73_;
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp70_ = n;
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp71_ = gxml_node_get_name (_tmp70_);
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp72_ = _tmp71_;
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp73_ = _tmp72_;
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp68_ = g_strcmp0 (_tmp73_, "spaces") == 0;
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_g_free0 (_tmp73_);
#line 2029 "SerializableGeeDualKeyMapTest.c"
				} else {
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp68_ = FALSE;
#line 2033 "SerializableGeeDualKeyMapTest.c"
				}
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				if (_tmp68_) {
#line 2037 "SerializableGeeDualKeyMapTest.c"
					gint _tmp74_;
					GXmlNode* name = NULL;
					GXmlNode* _tmp75_;
					GeeMap* _tmp76_;
					GeeMap* _tmp77_;
					GeeMap* _tmp78_;
					gpointer _tmp79_;
					GXmlNode* _tmp80_;
					GXmlNode* owner = NULL;
					GXmlNode* _tmp81_;
					GeeMap* _tmp82_;
					GeeMap* _tmp83_;
					GeeMap* _tmp84_;
					gpointer _tmp85_;
					GXmlNode* _tmp86_;
					gboolean _tmp87_ = FALSE;
					GXmlNode* _tmp88_;
#line 196 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp74_ = i;
#line 196 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					i = _tmp74_ + 1;
#line 197 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp75_ = n;
#line 197 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp76_ = gxml_node_get_attrs (_tmp75_);
#line 197 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp77_ = _tmp76_;
#line 197 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp78_ = _tmp77_;
#line 197 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp79_ = gee_map_get (_tmp78_, "name");
#line 197 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp80_ = (GXmlNode*) _tmp79_;
#line 197 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_g_object_unref0 (_tmp78_);
#line 197 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					name = _tmp80_;
#line 198 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp81_ = n;
#line 198 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp82_ = gxml_node_get_attrs (_tmp81_);
#line 198 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp83_ = _tmp82_;
#line 198 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp84_ = _tmp83_;
#line 198 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp85_ = gee_map_get (_tmp84_, "owner");
#line 198 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp86_ = (GXmlNode*) _tmp85_;
#line 198 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_g_object_unref0 (_tmp84_);
#line 198 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					owner = _tmp86_;
#line 199 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp88_ = name;
#line 199 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					if (_tmp88_ != NULL) {
#line 2095 "SerializableGeeDualKeyMapTest.c"
						GXmlNode* _tmp89_;
#line 199 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp89_ = owner;
#line 199 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp87_ = _tmp89_ != NULL;
#line 2101 "SerializableGeeDualKeyMapTest.c"
					} else {
#line 199 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp87_ = FALSE;
#line 2105 "SerializableGeeDualKeyMapTest.c"
					}
#line 199 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					if (_tmp87_) {
#line 2109 "SerializableGeeDualKeyMapTest.c"
						gboolean _tmp90_ = FALSE;
						GXmlNode* _tmp91_;
						gchar* _tmp92_;
						gchar* _tmp93_;
						gchar* _tmp94_;
						gboolean _tmp95_;
						gboolean _tmp100_ = FALSE;
						GXmlNode* _tmp101_;
						gchar* _tmp102_;
						gchar* _tmp103_;
						gchar* _tmp104_;
						gboolean _tmp105_;
						gboolean _tmp110_ = FALSE;
						GXmlNode* _tmp111_;
						gchar* _tmp112_;
						gchar* _tmp113_;
						gchar* _tmp114_;
						gboolean _tmp115_;
						gboolean _tmp120_ = FALSE;
						GXmlNode* _tmp121_;
						gchar* _tmp122_;
						gchar* _tmp123_;
						gchar* _tmp124_;
						gboolean _tmp125_;
#line 200 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp91_ = name;
#line 200 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp92_ = gxml_node_get_value (_tmp91_);
#line 200 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp93_ = _tmp92_;
#line 200 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp94_ = _tmp93_;
#line 200 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp95_ = g_strcmp0 (_tmp94_, "Big") == 0;
#line 200 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_g_free0 (_tmp94_);
#line 200 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						if (_tmp95_) {
#line 2148 "SerializableGeeDualKeyMapTest.c"
							GXmlNode* _tmp96_;
							gchar* _tmp97_;
							gchar* _tmp98_;
							gchar* _tmp99_;
#line 200 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp96_ = owner;
#line 200 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp97_ = gxml_node_get_value (_tmp96_);
#line 200 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp98_ = _tmp97_;
#line 200 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp99_ = _tmp98_;
#line 200 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp90_ = g_strcmp0 (_tmp99_, "Floor") == 0;
#line 200 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_g_free0 (_tmp99_);
#line 2165 "SerializableGeeDualKeyMapTest.c"
						} else {
#line 200 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp90_ = FALSE;
#line 2169 "SerializableGeeDualKeyMapTest.c"
						}
#line 200 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						if (_tmp90_) {
#line 200 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							found1 = TRUE;
#line 2175 "SerializableGeeDualKeyMapTest.c"
						}
#line 201 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp101_ = name;
#line 201 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp102_ = gxml_node_get_value (_tmp101_);
#line 201 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp103_ = _tmp102_;
#line 201 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp104_ = _tmp103_;
#line 201 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp105_ = g_strcmp0 (_tmp104_, "Small") == 0;
#line 201 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_g_free0 (_tmp104_);
#line 201 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						if (_tmp105_) {
#line 2191 "SerializableGeeDualKeyMapTest.c"
							GXmlNode* _tmp106_;
							gchar* _tmp107_;
							gchar* _tmp108_;
							gchar* _tmp109_;
#line 201 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp106_ = owner;
#line 201 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp107_ = gxml_node_get_value (_tmp106_);
#line 201 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp108_ = _tmp107_;
#line 201 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp109_ = _tmp108_;
#line 201 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp100_ = g_strcmp0 (_tmp109_, "Wall") == 0;
#line 201 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_g_free0 (_tmp109_);
#line 2208 "SerializableGeeDualKeyMapTest.c"
						} else {
#line 201 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp100_ = FALSE;
#line 2212 "SerializableGeeDualKeyMapTest.c"
						}
#line 201 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						if (_tmp100_) {
#line 201 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							found2 = TRUE;
#line 2218 "SerializableGeeDualKeyMapTest.c"
						}
#line 202 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp111_ = name;
#line 202 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp112_ = gxml_node_get_value (_tmp111_);
#line 202 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp113_ = _tmp112_;
#line 202 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp114_ = _tmp113_;
#line 202 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp115_ = g_strcmp0 (_tmp114_, "Bigger") == 0;
#line 202 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_g_free0 (_tmp114_);
#line 202 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						if (_tmp115_) {
#line 2234 "SerializableGeeDualKeyMapTest.c"
							GXmlNode* _tmp116_;
							gchar* _tmp117_;
							gchar* _tmp118_;
							gchar* _tmp119_;
#line 202 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp116_ = owner;
#line 202 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp117_ = gxml_node_get_value (_tmp116_);
#line 202 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp118_ = _tmp117_;
#line 202 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp119_ = _tmp118_;
#line 202 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp110_ = g_strcmp0 (_tmp119_, "Floor") == 0;
#line 202 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_g_free0 (_tmp119_);
#line 2251 "SerializableGeeDualKeyMapTest.c"
						} else {
#line 202 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp110_ = FALSE;
#line 2255 "SerializableGeeDualKeyMapTest.c"
						}
#line 202 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						if (_tmp110_) {
#line 202 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							found3 = TRUE;
#line 2261 "SerializableGeeDualKeyMapTest.c"
						}
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp121_ = name;
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp122_ = gxml_node_get_value (_tmp121_);
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp123_ = _tmp122_;
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp124_ = _tmp123_;
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp125_ = g_strcmp0 (_tmp124_, "Smallest") == 0;
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_g_free0 (_tmp124_);
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						if (_tmp125_) {
#line 2277 "SerializableGeeDualKeyMapTest.c"
							GXmlNode* _tmp126_;
							gchar* _tmp127_;
							gchar* _tmp128_;
							gchar* _tmp129_;
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp126_ = owner;
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp127_ = gxml_node_get_value (_tmp126_);
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp128_ = _tmp127_;
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp129_ = _tmp128_;
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp120_ = g_strcmp0 (_tmp129_, "Wall") == 0;
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_g_free0 (_tmp129_);
#line 2294 "SerializableGeeDualKeyMapTest.c"
						} else {
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp120_ = FALSE;
#line 2298 "SerializableGeeDualKeyMapTest.c"
						}
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						if (_tmp120_) {
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							found4 = TRUE;
#line 2304 "SerializableGeeDualKeyMapTest.c"
						}
					}
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_g_object_unref0 (owner);
#line 195 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_g_object_unref0 (name);
#line 2311 "SerializableGeeDualKeyMapTest.c"
				}
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_g_object_unref0 (n);
#line 2315 "SerializableGeeDualKeyMapTest.c"
			}
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (_n_list);
#line 2319 "SerializableGeeDualKeyMapTest.c"
		}
#line 207 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp130_ = i;
#line 207 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (_tmp130_ != 4) {
#line 2325 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp131_;
			gint _tmp132_;
			gchar* _tmp133_;
			gchar* _tmp134_;
			GXmlTDocument* _tmp135_;
			gchar* _tmp136_;
			gchar* _tmp137_;
			gchar* _tmp138_;
			gchar* _tmp139_;
#line 208 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp131_ = stdout;
#line 208 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp132_ = nodes;
#line 208 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp133_ = g_strdup_printf ("%i", _tmp132_);
#line 208 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp134_ = _tmp133_;
#line 208 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp135_ = doc;
#line 208 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp136_ = gxml_tnode_to_string ((GXmlTNode*) _tmp135_);
#line 208 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp137_ = _tmp136_;
#line 208 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp138_ = g_strconcat ("ERROR: Incorrect number of space nodes. Expected 4, got: ", _tmp134_, "\n", _tmp137_, NULL);
#line 208 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp139_ = _tmp138_;
#line 208 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp131_, "%s", _tmp139_);
#line 208 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp139_);
#line 208 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp137_);
#line 208 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp134_);
#line 209 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 2363 "SerializableGeeDualKeyMapTest.c"
		}
#line 212 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp140_ = nodes;
#line 212 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (_tmp140_ != 4) {
#line 2369 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp141_;
			gint _tmp142_;
			gchar* _tmp143_;
			gchar* _tmp144_;
			GXmlTDocument* _tmp145_;
			gchar* _tmp146_;
			gchar* _tmp147_;
			gchar* _tmp148_;
			gchar* _tmp149_;
#line 213 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp141_ = stdout;
#line 213 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp142_ = nodes;
#line 213 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp143_ = g_strdup_printf ("%i", _tmp142_);
#line 213 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp144_ = _tmp143_;
#line 213 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp145_ = doc;
#line 213 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp146_ = gxml_tnode_to_string ((GXmlTNode*) _tmp145_);
#line 213 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp147_ = _tmp146_;
#line 213 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp148_ = g_strconcat ("ERROR: Incorrect number of nodes. Expected 5, got: ", _tmp144_, "\n", _tmp147_, NULL);
#line 213 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp149_ = _tmp148_;
#line 213 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp141_, "%s", _tmp149_);
#line 213 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp149_);
#line 213 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp147_);
#line 213 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp144_);
#line 214 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 2407 "SerializableGeeDualKeyMapTest.c"
		}
#line 216 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp150_ = found1;
#line 216 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (!_tmp150_) {
#line 2413 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp151_;
			GXmlTDocument* _tmp152_;
			gchar* _tmp153_;
			gchar* _tmp154_;
			gchar* _tmp155_;
			gchar* _tmp156_;
#line 217 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp151_ = stdout;
#line 217 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp152_ = doc;
#line 217 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp153_ = gxml_tnode_to_string ((GXmlTNode*) _tmp152_);
#line 217 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp154_ = _tmp153_;
#line 217 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp155_ = g_strconcat ("ERROR: 'Big' / 'Floor' not found\n", _tmp154_, NULL);
#line 217 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp156_ = _tmp155_;
#line 217 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp151_, "%s", _tmp156_);
#line 217 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp156_);
#line 217 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp154_);
#line 218 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 2440 "SerializableGeeDualKeyMapTest.c"
		}
#line 220 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp157_ = found2;
#line 220 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (!_tmp157_) {
#line 2446 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp158_;
			GXmlTDocument* _tmp159_;
			gchar* _tmp160_;
			gchar* _tmp161_;
			gchar* _tmp162_;
			gchar* _tmp163_;
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp158_ = stdout;
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp159_ = doc;
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp160_ = gxml_tnode_to_string ((GXmlTNode*) _tmp159_);
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp161_ = _tmp160_;
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp162_ = g_strconcat ("ERROR: 'Small' / 'Wall' not found\n", _tmp161_, NULL);
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp163_ = _tmp162_;
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp158_, "%s", _tmp163_);
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp163_);
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp161_);
#line 222 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 2473 "SerializableGeeDualKeyMapTest.c"
		}
#line 224 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp164_ = found3;
#line 224 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (!_tmp164_) {
#line 2479 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp165_;
			GXmlTDocument* _tmp166_;
			gchar* _tmp167_;
			gchar* _tmp168_;
			gchar* _tmp169_;
			gchar* _tmp170_;
#line 225 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp165_ = stdout;
#line 225 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp166_ = doc;
#line 225 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp167_ = gxml_tnode_to_string ((GXmlTNode*) _tmp166_);
#line 225 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp168_ = _tmp167_;
#line 225 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp169_ = g_strconcat ("ERROR: 'Bigger' / 'Floor' not found\n", _tmp168_, NULL);
#line 225 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp170_ = _tmp169_;
#line 225 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp165_, "%s", _tmp170_);
#line 225 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp170_);
#line 225 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp168_);
#line 226 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 2506 "SerializableGeeDualKeyMapTest.c"
		}
#line 228 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp171_ = found4;
#line 228 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (!_tmp171_) {
#line 2512 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp172_;
			GXmlTDocument* _tmp173_;
			gchar* _tmp174_;
			gchar* _tmp175_;
			gchar* _tmp176_;
			gchar* _tmp177_;
#line 229 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp172_ = stdout;
#line 229 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp173_ = doc;
#line 229 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp174_ = gxml_tnode_to_string ((GXmlTNode*) _tmp173_);
#line 229 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp175_ = _tmp174_;
#line 229 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp176_ = g_strconcat ("ERROR: 'Smallest' / 'Wall' not found\n", _tmp175_, NULL);
#line 229 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp177_ = _tmp176_;
#line 229 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp172_, "%s", _tmp177_);
#line 229 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp177_);
#line 229 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp175_);
#line 230 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 2539 "SerializableGeeDualKeyMapTest.c"
		}
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (root);
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (doc);
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (o4);
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (o3);
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (o2);
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (o1);
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (c);
#line 2555 "SerializableGeeDualKeyMapTest.c"
	}
	goto __finally93;
	__catch93_g_error:
	{
		GError* e = NULL;
		FILE* _tmp178_;
		const gchar* _tmp179_;
		const gchar* _tmp180_;
		gchar* _tmp181_;
		gchar* _tmp182_;
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		e = _inner_error_;
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_inner_error_ = NULL;
#line 234 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp178_ = stdout;
#line 234 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp179_ = e->message;
#line 234 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp180_ = string_to_string (_tmp179_);
#line 234 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp181_ = g_strconcat ("ERROR: ", _tmp180_, NULL);
#line 234 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp182_ = _tmp181_;
#line 234 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp178_, "%s", _tmp182_);
#line 234 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp182_);
#line 235 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_error_free0 (e);
#line 2588 "SerializableGeeDualKeyMapTest.c"
	}
	__finally93:
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_clear_error (&_inner_error_);
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		return;
#line 2599 "SerializableGeeDualKeyMapTest.c"
	}
}


static void
___lambda55__gtest_func (void)
{
#line 170 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	__lambda55_ ();
#line 2609 "SerializableGeeDualKeyMapTest.c"
}


static void
__lambda56_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlSerializableDualKeyMap* c = NULL;
		GXmlSerializableDualKeyMap* _tmp1_;
		GXmlSerializableDualKeyMap* _tmp2_;
		GXmlGDocument* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		GXmlSerializableDualKeyMap* _tmp7_;
		gint _tmp8_;
		gint _tmp9_;
		gboolean found1 = FALSE;
		gboolean found2 = FALSE;
		gboolean found3 = FALSE;
		gboolean found4 = FALSE;
		gboolean _tmp54_;
		gboolean _tmp61_;
		gboolean _tmp68_;
		gboolean _tmp75_;
#line 241 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"<root><spaces name=\"Small\" owner=\"Wall\"/><spaces name=\"Smallest\"" \
" owner=\"Wall\"/><spaces name=\"Big\" owner=\"Floor\"/><spaces name=\"" \
"Bigger\" owner=\"Floor\"/><spark /></root>", 0, &_inner_error_);
#line 241 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		doc = _tmp0_;
#line 241 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2644 "SerializableGeeDualKeyMapTest.c"
			goto __catch94_g_error;
		}
#line 243 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp1_ = gxml_serializable_dual_key_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, TYPE_SPACES, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 243 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		c = _tmp1_;
#line 244 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp2_ = c;
#line 244 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp3_ = doc;
#line 244 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) _tmp3_);
#line 244 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp5_ = _tmp4_;
#line 244 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp6_ = _tmp5_;
#line 244 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_dual_key_map_deserialize (_tmp2_, _tmp6_, &_inner_error_);
#line 244 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp6_);
#line 244 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 244 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (c);
#line 244 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (doc);
#line 2671 "SerializableGeeDualKeyMapTest.c"
			goto __catch94_g_error;
		}
#line 245 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp7_ = c;
#line 245 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp8_ = gxml_serializable_dual_key_map_get_size (_tmp7_);
#line 245 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp9_ = _tmp8_;
#line 245 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (_tmp9_ != 4) {
#line 2682 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp10_;
			GXmlSerializableDualKeyMap* _tmp11_;
			gint _tmp12_;
			gint _tmp13_;
			gchar* _tmp14_;
			gchar* _tmp15_;
			gchar* _tmp16_;
			gchar* _tmp17_;
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp10_ = stdout;
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp11_ = c;
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp12_ = gxml_serializable_dual_key_map_get_size (_tmp11_);
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp13_ = _tmp12_;
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp14_ = g_strdup_printf ("%i", _tmp13_);
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp15_ = _tmp14_;
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp16_ = g_strconcat ("ERROR: incorrect size must be 4 got: ", _tmp15_, "\n", NULL);
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp17_ = _tmp16_;
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp10_, "%s", _tmp17_);
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp17_);
#line 246 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp15_);
#line 247 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 2715 "SerializableGeeDualKeyMapTest.c"
		}
#line 249 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		found1 = FALSE;
#line 250 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		found2 = FALSE;
#line 251 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		found3 = FALSE;
#line 252 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		found4 = FALSE;
#line 2725 "SerializableGeeDualKeyMapTest.c"
		{
			GeeIterator* _s_it = NULL;
			GXmlSerializableDualKeyMap* _tmp18_;
			GeeCollection* _tmp19_;
			GeeCollection* _tmp20_;
			GeeIterator* _tmp21_;
			GeeIterator* _tmp22_;
#line 253 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp18_ = c;
#line 253 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp19_ = gxml_serializable_dual_key_map_values (_tmp18_);
#line 253 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp20_ = _tmp19_;
#line 253 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp21_ = gee_iterable_iterator ((GeeIterable*) _tmp20_);
#line 253 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp22_ = _tmp21_;
#line 253 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (_tmp20_);
#line 253 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_s_it = _tmp22_;
#line 253 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			while (TRUE) {
#line 2749 "SerializableGeeDualKeyMapTest.c"
				GeeIterator* _tmp23_;
				Spaces* s = NULL;
				GeeIterator* _tmp24_;
				gpointer _tmp25_;
				gboolean _tmp26_ = FALSE;
				Spaces* _tmp27_;
				const gchar* _tmp28_;
				const gchar* _tmp29_;
				gboolean _tmp33_ = FALSE;
				Spaces* _tmp34_;
				const gchar* _tmp35_;
				const gchar* _tmp36_;
				gboolean _tmp40_ = FALSE;
				Spaces* _tmp41_;
				const gchar* _tmp42_;
				const gchar* _tmp43_;
				gboolean _tmp47_ = FALSE;
				Spaces* _tmp48_;
				const gchar* _tmp49_;
				const gchar* _tmp50_;
#line 253 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp23_ = _s_it;
#line 253 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				if (!gee_iterator_next (_tmp23_)) {
#line 253 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					break;
#line 2776 "SerializableGeeDualKeyMapTest.c"
				}
#line 253 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp24_ = _s_it;
#line 253 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp25_ = gee_iterator_get (_tmp24_);
#line 253 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				s = (Spaces*) _tmp25_;
#line 254 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp27_ = s;
#line 254 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp28_ = spaces_get_owner (_tmp27_);
#line 254 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp29_ = _tmp28_;
#line 254 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				if (g_strcmp0 (_tmp29_, "Floor") == 0) {
#line 2792 "SerializableGeeDualKeyMapTest.c"
					Spaces* _tmp30_;
					const gchar* _tmp31_;
					const gchar* _tmp32_;
#line 254 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp30_ = s;
#line 254 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp31_ = spaces_get_name (_tmp30_);
#line 254 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp32_ = _tmp31_;
#line 254 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp26_ = g_strcmp0 (_tmp32_, "Big") == 0;
#line 2804 "SerializableGeeDualKeyMapTest.c"
				} else {
#line 254 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp26_ = FALSE;
#line 2808 "SerializableGeeDualKeyMapTest.c"
				}
#line 254 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				if (_tmp26_) {
#line 254 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					found1 = TRUE;
#line 2814 "SerializableGeeDualKeyMapTest.c"
				}
#line 255 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp34_ = s;
#line 255 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp35_ = spaces_get_owner (_tmp34_);
#line 255 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp36_ = _tmp35_;
#line 255 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				if (g_strcmp0 (_tmp36_, "Wall") == 0) {
#line 2824 "SerializableGeeDualKeyMapTest.c"
					Spaces* _tmp37_;
					const gchar* _tmp38_;
					const gchar* _tmp39_;
#line 255 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp37_ = s;
#line 255 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp38_ = spaces_get_name (_tmp37_);
#line 255 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp39_ = _tmp38_;
#line 255 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp33_ = g_strcmp0 (_tmp39_, "Small") == 0;
#line 2836 "SerializableGeeDualKeyMapTest.c"
				} else {
#line 255 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp33_ = FALSE;
#line 2840 "SerializableGeeDualKeyMapTest.c"
				}
#line 255 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				if (_tmp33_) {
#line 255 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					found2 = TRUE;
#line 2846 "SerializableGeeDualKeyMapTest.c"
				}
#line 256 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp41_ = s;
#line 256 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp42_ = spaces_get_owner (_tmp41_);
#line 256 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp43_ = _tmp42_;
#line 256 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				if (g_strcmp0 (_tmp43_, "Floor") == 0) {
#line 2856 "SerializableGeeDualKeyMapTest.c"
					Spaces* _tmp44_;
					const gchar* _tmp45_;
					const gchar* _tmp46_;
#line 256 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp44_ = s;
#line 256 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp45_ = spaces_get_name (_tmp44_);
#line 256 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp46_ = _tmp45_;
#line 256 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp40_ = g_strcmp0 (_tmp46_, "Bigger") == 0;
#line 2868 "SerializableGeeDualKeyMapTest.c"
				} else {
#line 256 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp40_ = FALSE;
#line 2872 "SerializableGeeDualKeyMapTest.c"
				}
#line 256 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				if (_tmp40_) {
#line 256 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					found3 = TRUE;
#line 2878 "SerializableGeeDualKeyMapTest.c"
				}
#line 257 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp48_ = s;
#line 257 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp49_ = spaces_get_owner (_tmp48_);
#line 257 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp50_ = _tmp49_;
#line 257 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				if (g_strcmp0 (_tmp50_, "Wall") == 0) {
#line 2888 "SerializableGeeDualKeyMapTest.c"
					Spaces* _tmp51_;
					const gchar* _tmp52_;
					const gchar* _tmp53_;
#line 257 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp51_ = s;
#line 257 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp52_ = spaces_get_name (_tmp51_);
#line 257 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp53_ = _tmp52_;
#line 257 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp47_ = g_strcmp0 (_tmp53_, "Smallest") == 0;
#line 2900 "SerializableGeeDualKeyMapTest.c"
				} else {
#line 257 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp47_ = FALSE;
#line 2904 "SerializableGeeDualKeyMapTest.c"
				}
#line 257 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				if (_tmp47_) {
#line 257 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					found4 = TRUE;
#line 2910 "SerializableGeeDualKeyMapTest.c"
				}
#line 253 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_g_object_unref0 (s);
#line 2914 "SerializableGeeDualKeyMapTest.c"
			}
#line 253 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (_s_it);
#line 2918 "SerializableGeeDualKeyMapTest.c"
		}
#line 259 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp54_ = found1;
#line 259 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (!_tmp54_) {
#line 2924 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp55_;
			GXmlGDocument* _tmp56_;
			gchar* _tmp57_;
			gchar* _tmp58_;
			gchar* _tmp59_;
			gchar* _tmp60_;
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp55_ = stdout;
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp56_ = doc;
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp57_ = gxml_gnode_to_string ((GXmlGNode*) _tmp56_);
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp58_ = _tmp57_;
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp59_ = g_strconcat ("ERROR: 'Big' / 'Floor' not found\n", _tmp58_, NULL);
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp60_ = _tmp59_;
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp55_, "%s", _tmp60_);
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp60_);
#line 260 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp58_);
#line 261 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 2951 "SerializableGeeDualKeyMapTest.c"
		}
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp61_ = found2;
#line 263 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (!_tmp61_) {
#line 2957 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp62_;
			GXmlGDocument* _tmp63_;
			gchar* _tmp64_;
			gchar* _tmp65_;
			gchar* _tmp66_;
			gchar* _tmp67_;
#line 264 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp62_ = stdout;
#line 264 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp63_ = doc;
#line 264 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp64_ = gxml_gnode_to_string ((GXmlGNode*) _tmp63_);
#line 264 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp65_ = _tmp64_;
#line 264 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp66_ = g_strconcat ("ERROR: 'Small' / 'Wall' not found\n", _tmp65_, NULL);
#line 264 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp67_ = _tmp66_;
#line 264 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp62_, "%s", _tmp67_);
#line 264 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp67_);
#line 264 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp65_);
#line 265 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 2984 "SerializableGeeDualKeyMapTest.c"
		}
#line 267 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp68_ = found3;
#line 267 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (!_tmp68_) {
#line 2990 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp69_;
			GXmlGDocument* _tmp70_;
			gchar* _tmp71_;
			gchar* _tmp72_;
			gchar* _tmp73_;
			gchar* _tmp74_;
#line 268 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp69_ = stdout;
#line 268 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp70_ = doc;
#line 268 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp71_ = gxml_gnode_to_string ((GXmlGNode*) _tmp70_);
#line 268 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp72_ = _tmp71_;
#line 268 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp73_ = g_strconcat ("ERROR: 'Bigger' / 'Floor' not found\n", _tmp72_, NULL);
#line 268 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp74_ = _tmp73_;
#line 268 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp69_, "%s", _tmp74_);
#line 268 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp74_);
#line 268 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp72_);
#line 269 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 3017 "SerializableGeeDualKeyMapTest.c"
		}
#line 271 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp75_ = found4;
#line 271 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (!_tmp75_) {
#line 3023 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp76_;
			GXmlGDocument* _tmp77_;
			gchar* _tmp78_;
			gchar* _tmp79_;
			gchar* _tmp80_;
			gchar* _tmp81_;
#line 272 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp76_ = stdout;
#line 272 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp77_ = doc;
#line 272 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp78_ = gxml_gnode_to_string ((GXmlGNode*) _tmp77_);
#line 272 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp79_ = _tmp78_;
#line 272 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp80_ = g_strconcat ("ERROR: 'Smallest' / 'Wall' not found\n", _tmp79_, NULL);
#line 272 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp81_ = _tmp80_;
#line 272 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp76_, "%s", _tmp81_);
#line 272 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp81_);
#line 272 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp79_);
#line 273 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 3050 "SerializableGeeDualKeyMapTest.c"
		}
#line 240 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (c);
#line 240 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (doc);
#line 3056 "SerializableGeeDualKeyMapTest.c"
	}
	goto __finally94;
	__catch94_g_error:
	{
		GError* e = NULL;
		FILE* _tmp82_;
		const gchar* _tmp83_;
		const gchar* _tmp84_;
		gchar* _tmp85_;
		gchar* _tmp86_;
#line 240 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		e = _inner_error_;
#line 240 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_inner_error_ = NULL;
#line 277 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp82_ = stdout;
#line 277 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp83_ = e->message;
#line 277 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp84_ = string_to_string (_tmp83_);
#line 277 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp85_ = g_strconcat ("ERROR: ", _tmp84_, NULL);
#line 277 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp86_ = _tmp85_;
#line 277 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp82_, "%s", _tmp86_);
#line 277 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp86_);
#line 278 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 240 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_error_free0 (e);
#line 3089 "SerializableGeeDualKeyMapTest.c"
	}
	__finally94:
#line 240 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 240 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 240 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_clear_error (&_inner_error_);
#line 240 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		return;
#line 3100 "SerializableGeeDualKeyMapTest.c"
	}
}


static void
___lambda56__gtest_func (void)
{
#line 238 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	__lambda56_ ();
#line 3110 "SerializableGeeDualKeyMapTest.c"
}


static void
__lambda57_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* idoc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlSerializableDualKeyMap* ic = NULL;
		GXmlSerializableDualKeyMap* _tmp1_;
		GXmlSerializableDualKeyMap* _tmp2_;
		GXmlGDocument* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		GXmlSerializableDualKeyMap* _tmp7_;
		gint _tmp8_;
		gint _tmp9_;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp21_;
		GXmlSerializableDualKeyMap* _tmp22_;
		GXmlGDocument* _tmp23_;
		GXmlNode* _tmp24_;
		GXmlNode* _tmp25_;
		GXmlNode* _tmp26_;
		GXmlNode* _tmp27_;
		GXmlNode* _tmp28_;
		GXmlSerializableDualKeyMap* c = NULL;
		GXmlSerializableDualKeyMap* _tmp29_;
		GXmlSerializableDualKeyMap* _tmp30_;
		GXmlGDocument* _tmp31_;
		GXmlNode* _tmp32_;
		GXmlNode* _tmp33_;
		GXmlNode* _tmp34_;
		GXmlSerializableDualKeyMap* _tmp35_;
		gint _tmp36_;
		gint _tmp37_;
#line 284 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"<root><spaces name=\"Small\" owner=\"Wall\"/><spaces name=\"Smallest\"" \
" owner=\"Wall\"/><spaces name=\"Big\" owner=\"Floor\"/><spaces name=\"" \
"Bigger\" owner=\"Floor\"/><spark /></root>", 0, &_inner_error_);
#line 284 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		idoc = _tmp0_;
#line 284 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3156 "SerializableGeeDualKeyMapTest.c"
			goto __catch95_g_error;
		}
#line 286 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp1_ = gxml_serializable_dual_key_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, TYPE_SPACES, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 286 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		ic = _tmp1_;
#line 287 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp2_ = ic;
#line 287 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp3_ = idoc;
#line 287 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) _tmp3_);
#line 287 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp5_ = _tmp4_;
#line 287 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp6_ = _tmp5_;
#line 287 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_dual_key_map_deserialize (_tmp2_, _tmp6_, &_inner_error_);
#line 287 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp6_);
#line 287 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 287 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (ic);
#line 287 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (idoc);
#line 3183 "SerializableGeeDualKeyMapTest.c"
			goto __catch95_g_error;
		}
#line 288 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp7_ = ic;
#line 288 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp8_ = gxml_serializable_dual_key_map_get_size (_tmp7_);
#line 288 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp9_ = _tmp8_;
#line 288 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (_tmp9_ != 4) {
#line 3194 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp10_;
			GXmlSerializableDualKeyMap* _tmp11_;
			gint _tmp12_;
			gint _tmp13_;
			gchar* _tmp14_;
			gchar* _tmp15_;
			GXmlGDocument* _tmp16_;
			gchar* _tmp17_;
			gchar* _tmp18_;
			gchar* _tmp19_;
			gchar* _tmp20_;
#line 289 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp10_ = stdout;
#line 289 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp11_ = ic;
#line 289 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp12_ = gxml_serializable_dual_key_map_get_size (_tmp11_);
#line 289 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp13_ = _tmp12_;
#line 289 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp14_ = g_strdup_printf ("%i", _tmp13_);
#line 289 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp15_ = _tmp14_;
#line 289 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp16_ = idoc;
#line 289 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp17_ = gxml_gnode_to_string ((GXmlGNode*) _tmp16_);
#line 289 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp18_ = _tmp17_;
#line 289 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp19_ = g_strconcat ("ERROR: Incorrect size (1st deserialize). Expected 4, got: ", _tmp15_, "\n", _tmp18_, "\n", NULL);
#line 289 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp20_ = _tmp19_;
#line 289 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp10_, "%s", _tmp20_);
#line 289 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp20_);
#line 289 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp18_);
#line 289 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp15_);
#line 290 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 3238 "SerializableGeeDualKeyMapTest.c"
		}
#line 292 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp21_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<root />", 0, &_inner_error_);
#line 292 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		doc = _tmp21_;
#line 292 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 292 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (ic);
#line 292 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (idoc);
#line 3250 "SerializableGeeDualKeyMapTest.c"
			goto __catch95_g_error;
		}
#line 294 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp22_ = ic;
#line 294 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp23_ = doc;
#line 294 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp24_ = gxml_document_get_root ((GXmlDocument*) _tmp23_);
#line 294 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp25_ = _tmp24_;
#line 294 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp26_ = _tmp25_;
#line 294 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp27_ = gxml_serializable_dual_key_map_serialize (_tmp22_, _tmp26_, &_inner_error_);
#line 294 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp28_ = _tmp27_;
#line 294 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp28_);
#line 294 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp26_);
#line 294 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 294 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (doc);
#line 294 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (ic);
#line 294 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (idoc);
#line 3279 "SerializableGeeDualKeyMapTest.c"
			goto __catch95_g_error;
		}
#line 295 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp29_ = gxml_serializable_dual_key_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, TYPE_SPACES, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 295 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		c = _tmp29_;
#line 296 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp30_ = c;
#line 296 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp31_ = doc;
#line 296 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp32_ = gxml_document_get_root ((GXmlDocument*) _tmp31_);
#line 296 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp33_ = _tmp32_;
#line 296 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp34_ = _tmp33_;
#line 296 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_dual_key_map_deserialize (_tmp30_, _tmp34_, &_inner_error_);
#line 296 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp34_);
#line 296 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 296 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (c);
#line 296 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (doc);
#line 296 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (ic);
#line 296 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (idoc);
#line 3310 "SerializableGeeDualKeyMapTest.c"
			goto __catch95_g_error;
		}
#line 297 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp35_ = c;
#line 297 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp36_ = gxml_serializable_dual_key_map_get_size (_tmp35_);
#line 297 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp37_ = _tmp36_;
#line 297 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (_tmp37_ != 4) {
#line 3321 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp38_;
			GXmlSerializableDualKeyMap* _tmp39_;
			gint _tmp40_;
			gint _tmp41_;
			gchar* _tmp42_;
			gchar* _tmp43_;
			GXmlGDocument* _tmp44_;
			gchar* _tmp45_;
			gchar* _tmp46_;
			gchar* _tmp47_;
			gchar* _tmp48_;
#line 298 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp38_ = stdout;
#line 298 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp39_ = c;
#line 298 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp40_ = gxml_serializable_dual_key_map_get_size (_tmp39_);
#line 298 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp41_ = _tmp40_;
#line 298 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp42_ = g_strdup_printf ("%i", _tmp41_);
#line 298 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp43_ = _tmp42_;
#line 298 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp44_ = doc;
#line 298 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp45_ = gxml_gnode_to_string ((GXmlGNode*) _tmp44_);
#line 298 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp46_ = _tmp45_;
#line 298 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp47_ = g_strconcat ("ERROR: Incorrect size. Expected 4, got: ", _tmp43_, "\n", _tmp46_, "\n", NULL);
#line 298 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_tmp48_ = _tmp47_;
#line 298 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp38_, "%s", _tmp48_);
#line 298 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp48_);
#line 298 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp46_);
#line 298 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp43_);
#line 299 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 3365 "SerializableGeeDualKeyMapTest.c"
		}
#line 283 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (c);
#line 283 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (doc);
#line 283 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (ic);
#line 283 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (idoc);
#line 3375 "SerializableGeeDualKeyMapTest.c"
	}
	goto __finally95;
	__catch95_g_error:
	{
		GError* e = NULL;
		FILE* _tmp49_;
		const gchar* _tmp50_;
		const gchar* _tmp51_;
		gchar* _tmp52_;
		gchar* _tmp53_;
#line 283 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		e = _inner_error_;
#line 283 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_inner_error_ = NULL;
#line 303 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp49_ = stdout;
#line 303 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp50_ = e->message;
#line 303 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp51_ = string_to_string (_tmp50_);
#line 303 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp52_ = g_strconcat ("ERROR: ", _tmp51_, NULL);
#line 303 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp53_ = _tmp52_;
#line 303 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp49_, "%s", _tmp53_);
#line 303 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp53_);
#line 304 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 283 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_error_free0 (e);
#line 3408 "SerializableGeeDualKeyMapTest.c"
	}
	__finally95:
#line 283 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 283 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 283 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_clear_error (&_inner_error_);
#line 283 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		return;
#line 3419 "SerializableGeeDualKeyMapTest.c"
	}
}


static void
___lambda57__gtest_func (void)
{
#line 281 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	__lambda57_ ();
#line 3429 "SerializableGeeDualKeyMapTest.c"
}


static void
__lambda58_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* d = NULL;
		GXmlGDocument* _tmp0_;
		BookStore* bs = NULL;
		BookStore* _tmp1_;
		BookStore* _tmp2_;
		GXmlGDocument* _tmp3_;
		BookStore* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		BookStore* _tmp7_;
		BookArray* _tmp8_;
		BookArray* _tmp9_;
		gint _tmp10_;
		gint _tmp11_;
		Book* b = NULL;
		BookStore* _tmp12_;
		BookArray* _tmp13_;
		BookArray* _tmp14_;
		gpointer _tmp15_;
		Name* _tmp16_;
		Name* _tmp17_;
		Name* _tmp18_;
		Name* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		const gchar* _tmp22_;
		const gchar* _tmp23_;
		Authors* _tmp24_;
		Authors* _tmp25_;
		Authors* _tmp26_;
		Authors* _tmp27_;
		AuthorArray* _tmp28_;
		AuthorArray* _tmp29_;
		Authors* _tmp30_;
		Authors* _tmp31_;
		AuthorArray* _tmp32_;
		AuthorArray* _tmp33_;
		gint _tmp34_;
		gint _tmp35_;
		InventoryDualKeyMap* _tmp36_;
		InventoryDualKeyMap* _tmp37_;
		InventoryDualKeyMap* _tmp38_;
		InventoryDualKeyMap* _tmp39_;
		gint _tmp40_;
		gint _tmp41_;
		Inventory* ir = NULL;
		InventoryDualKeyMap* _tmp42_;
		InventoryDualKeyMap* _tmp43_;
		gpointer _tmp44_;
		gint _tmp45_;
		gint _tmp46_;
		const gchar* _tmp47_;
		const gchar* _tmp48_;
		gint _tmp49_;
		gint _tmp50_;
#line 310 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = gxml_gdocument_new_from_path (TEST_DIR "/test-collection.xml", 0, &_inner_error_);
#line 310 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		d = _tmp0_;
#line 310 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3499 "SerializableGeeDualKeyMapTest.c"
			goto __catch96_g_error;
		}
#line 311 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp1_ = book_store_new ();
#line 311 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		bs = _tmp1_;
#line 312 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp2_ = bs;
#line 312 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp3_ = d;
#line 312 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error_);
#line 312 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 312 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bs);
#line 312 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d);
#line 3518 "SerializableGeeDualKeyMapTest.c"
			goto __catch96_g_error;
		}
#line 313 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp4_ = bs;
#line 313 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp5_ = book_store_get_name (_tmp4_);
#line 313 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp6_ = _tmp5_;
#line 313 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp6_, "The Great Book") == 0, "bs.name == \"The Great Book\"");
#line 314 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp7_ = bs;
#line 314 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp8_ = book_store_get_books (_tmp7_);
#line 314 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp9_ = _tmp8_;
#line 314 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp10_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp9_);
#line 314 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp11_ = _tmp10_;
#line 314 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp11_ == 3, "bs.books.size == 3");
#line 315 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp12_ = bs;
#line 315 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp13_ = book_store_get_books (_tmp12_);
#line 315 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp14_ = _tmp13_;
#line 315 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp15_ = gee_list_first ((GeeList*) _tmp14_);
#line 315 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		b = (Book*) _tmp15_;
#line 316 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (b != NULL, "b != null");
#line 317 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp16_ = book_get_name (b);
#line 317 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp17_ = _tmp16_;
#line 317 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp17_ != NULL, "b.name != null");
#line 318 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp18_ = book_get_name (b);
#line 318 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp19_ = _tmp18_;
#line 318 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp20_ = name_get_name (_tmp19_);
#line 318 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp21_ = _tmp20_;
#line 318 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp21_, "Book1") == 0, "b.name.get_name () == \"Book1\"");
#line 318 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp21_);
#line 319 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp22_ = book_get_year (b);
#line 319 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp23_ = _tmp22_;
#line 319 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp23_, "2015") == 0, "b.year == \"2015\"");
#line 320 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp24_ = book_get_authors (b);
#line 320 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp25_ = _tmp24_;
#line 320 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp25_ != NULL, "b.authors != null");
#line 321 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp26_ = book_get_authors (b);
#line 321 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp27_ = _tmp26_;
#line 321 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp28_ = authors_get_array (_tmp27_);
#line 321 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp29_ = _tmp28_;
#line 321 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp29_ != NULL, "b.authors.array != null");
#line 322 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp30_ = book_get_authors (b);
#line 322 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp31_ = _tmp30_;
#line 322 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp32_ = authors_get_array (_tmp31_);
#line 322 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp33_ = _tmp32_;
#line 322 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp34_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp33_);
#line 322 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp35_ = _tmp34_;
#line 322 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp35_ == 2, "b.authors.array.size == 2");
#line 323 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp36_ = book_get_inventory_registers (b);
#line 323 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp37_ = _tmp36_;
#line 323 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp37_ != NULL, "b.inventory_registers != null");
#line 324 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp38_ = book_get_inventory_registers (b);
#line 324 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp39_ = _tmp38_;
#line 324 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp40_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp39_);
#line 324 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp41_ = _tmp40_;
#line 324 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp41_ == 4, "b.inventory_registers.size == 4");
#line 325 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp42_ = book_get_inventory_registers (b);
#line 325 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp43_ = _tmp42_;
#line 325 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp44_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp43_, (gpointer) ((gintptr) 1), "K001");
#line 325 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		ir = (Inventory*) _tmp44_;
#line 326 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (ir != NULL, "ir != null");
#line 327 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp45_ = inventory_get_number (ir);
#line 327 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp46_ = _tmp45_;
#line 327 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp46_ == 1, "ir.number == 1");
#line 328 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp47_ = inventory_get_inventory (ir);
#line 328 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp48_ = _tmp47_;
#line 328 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp48_, "K001") == 0, "ir.inventory == \"K001\"");
#line 329 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp49_ = inventory_get_row (ir);
#line 329 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp50_ = _tmp49_;
#line 329 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp50_ == 5, "ir.row == 5");
#line 309 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (ir);
#line 309 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (b);
#line 309 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (bs);
#line 309 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (d);
#line 3659 "SerializableGeeDualKeyMapTest.c"
	}
	goto __finally96;
	__catch96_g_error:
	{
		GError* e = NULL;
#line 309 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		e = _inner_error_;
#line 309 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_inner_error_ = NULL;
#line 334 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 309 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_error_free0 (e);
#line 3673 "SerializableGeeDualKeyMapTest.c"
	}
	__finally96:
#line 309 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 309 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 309 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_clear_error (&_inner_error_);
#line 309 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		return;
#line 3684 "SerializableGeeDualKeyMapTest.c"
	}
}


static void
___lambda58__gtest_func (void)
{
#line 307 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	__lambda58_ ();
#line 3694 "SerializableGeeDualKeyMapTest.c"
}


static void
__lambda59_ (void)
{
	GError * _inner_error_ = NULL;
	{
		SerializableGeeDualKeyMapTestBigBag* bag = NULL;
		SerializableGeeDualKeyMapTestBigBag* _tmp0_;
		SerializableGeeDualKeyMapTestBigBag* _tmp1_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp2_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp3_;
		SerializableGeeDualKeyMapTestBigBag* _tmp58_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp59_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp60_;
		gint _tmp61_;
		gint _tmp62_;
		GXmlGDocument* d = NULL;
		GXmlGDocument* _tmp63_;
		SerializableGeeDualKeyMapTestBigBag* _tmp64_;
		GXmlGDocument* _tmp65_;
		GXmlNode* _tmp66_;
		GXmlNode* _tmp67_;
		GXmlGDocument* _tmp68_;
		GXmlNode* _tmp69_;
		GXmlNode* _tmp70_;
		GXmlNode* _tmp71_;
		GXmlGDocument* _tmp72_;
		GXmlNode* _tmp73_;
		GXmlNode* _tmp74_;
		GXmlNode* _tmp75_;
		gchar* _tmp76_;
		gchar* _tmp77_;
		gchar* _tmp78_;
		GXmlGDocument* _tmp79_;
		GXmlNode* _tmp80_;
		GXmlNode* _tmp81_;
		GXmlNode* _tmp82_;
		GeeBidirList* _tmp83_;
		GeeBidirList* _tmp84_;
		GeeBidirList* _tmp85_;
		gint _tmp86_;
		gint _tmp87_;
		GXmlGDocument* _tmp88_;
		GXmlNode* _tmp89_;
		GXmlNode* _tmp90_;
		GXmlNode* _tmp91_;
		GeeBidirList* _tmp92_;
		GeeBidirList* _tmp93_;
		GeeBidirList* _tmp94_;
		gpointer _tmp95_;
		GXmlNode* _tmp96_;
		gchar* _tmp97_;
		gchar* _tmp98_;
		gchar* _tmp99_;
		GXmlGDocument* _tmp100_;
		GXmlNode* _tmp101_;
		GXmlNode* _tmp102_;
		GXmlNode* _tmp103_;
		GeeBidirList* _tmp104_;
		GeeBidirList* _tmp105_;
		GeeBidirList* _tmp106_;
		gpointer _tmp107_;
		GXmlNode* _tmp108_;
		GeeBidirList* _tmp109_;
		GeeBidirList* _tmp110_;
		GeeBidirList* _tmp111_;
		gint _tmp112_;
		gint _tmp113_;
		GXmlGDocument* _tmp114_;
		GXmlNode* _tmp115_;
		GXmlNode* _tmp116_;
		GXmlNode* _tmp117_;
		GeeBidirList* _tmp118_;
		GeeBidirList* _tmp119_;
		GeeBidirList* _tmp120_;
		gpointer _tmp121_;
		GXmlNode* _tmp122_;
		GeeBidirList* _tmp123_;
		GeeBidirList* _tmp124_;
		GeeBidirList* _tmp125_;
		gpointer _tmp126_;
		GXmlNode* _tmp127_;
		gchar* _tmp128_;
		gchar* _tmp129_;
		gchar* _tmp130_;
		GXmlGDocument* _tmp131_;
		GXmlNode* _tmp132_;
		GXmlNode* _tmp133_;
		GXmlNode* _tmp134_;
		GeeBidirList* _tmp135_;
		GeeBidirList* _tmp136_;
		GeeBidirList* _tmp137_;
		gpointer _tmp138_;
		GXmlNode* _tmp139_;
		GeeBidirList* _tmp140_;
		GeeBidirList* _tmp141_;
		GeeBidirList* _tmp142_;
		gpointer _tmp143_;
		GXmlNode* _tmp144_;
		GeeBidirList* _tmp145_;
		GeeBidirList* _tmp146_;
		GeeBidirList* _tmp147_;
		gint _tmp148_;
		gint _tmp149_;
		GXmlGDocument* _tmp150_;
		GXmlNode* _tmp151_;
		GXmlNode* _tmp152_;
		GXmlNode* _tmp153_;
		GeeBidirList* _tmp154_;
		GeeBidirList* _tmp155_;
		GeeBidirList* _tmp156_;
		gpointer _tmp157_;
		GXmlNode* _tmp158_;
		GeeBidirList* _tmp159_;
		GeeBidirList* _tmp160_;
		GeeBidirList* _tmp161_;
		gpointer _tmp162_;
		GXmlNode* _tmp163_;
		GeeBidirList* _tmp164_;
		GeeBidirList* _tmp165_;
		GeeBidirList* _tmp166_;
		gpointer _tmp167_;
		GXmlNode* _tmp168_;
		gchar* _tmp169_;
		gchar* _tmp170_;
		gchar* _tmp171_;
		GXmlGDocument* _tmp172_;
		GXmlNode* _tmp173_;
		GXmlNode* _tmp174_;
		GXmlNode* _tmp175_;
		GeeBidirList* _tmp176_;
		GeeBidirList* _tmp177_;
		GeeBidirList* _tmp178_;
		gpointer _tmp179_;
		GXmlNode* _tmp180_;
		GeeBidirList* _tmp181_;
		GeeBidirList* _tmp182_;
		GeeBidirList* _tmp183_;
		gpointer _tmp184_;
		GXmlNode* _tmp185_;
		GeeBidirList* _tmp186_;
		GeeBidirList* _tmp187_;
		GeeBidirList* _tmp188_;
		gpointer _tmp189_;
		GXmlNode* _tmp190_;
		GeeBidirList* _tmp191_;
		GeeBidirList* _tmp192_;
		GeeBidirList* _tmp193_;
		gint _tmp194_;
		gint _tmp195_;
		GXmlGDocument* _tmp196_;
		GXmlNode* _tmp197_;
		GXmlNode* _tmp198_;
		GXmlNode* _tmp199_;
		GeeBidirList* _tmp200_;
		GeeBidirList* _tmp201_;
		GeeBidirList* _tmp202_;
		gpointer _tmp203_;
		GXmlNode* _tmp204_;
		GeeBidirList* _tmp205_;
		GeeBidirList* _tmp206_;
		GeeBidirList* _tmp207_;
		gpointer _tmp208_;
		GXmlNode* _tmp209_;
		GeeBidirList* _tmp210_;
		GeeBidirList* _tmp211_;
		GeeBidirList* _tmp212_;
		gpointer _tmp213_;
		GXmlNode* _tmp214_;
		GeeBidirList* _tmp215_;
		GeeBidirList* _tmp216_;
		GeeBidirList* _tmp217_;
		gpointer _tmp218_;
		GXmlNode* _tmp219_;
		GXmlGDocument* _tmp220_;
		GXmlNode* _tmp221_;
		GXmlNode* _tmp222_;
		GXmlNode* _tmp223_;
		GeeBidirList* _tmp224_;
		GeeBidirList* _tmp225_;
		GeeBidirList* _tmp226_;
		gpointer _tmp227_;
		GXmlNode* _tmp228_;
		GeeBidirList* _tmp229_;
		GeeBidirList* _tmp230_;
		GeeBidirList* _tmp231_;
		gpointer _tmp232_;
		GXmlNode* _tmp233_;
		GeeBidirList* _tmp234_;
		GeeBidirList* _tmp235_;
		GeeBidirList* _tmp236_;
		gpointer _tmp237_;
		GXmlNode* _tmp238_;
		GeeBidirList* _tmp239_;
		GeeBidirList* _tmp240_;
		GeeBidirList* _tmp241_;
		gpointer _tmp242_;
		GXmlNode* _tmp243_;
		gchar* _tmp244_;
		gchar* _tmp245_;
		gchar* _tmp246_;
		SerializableGeeDualKeyMapTestBigBag* bagt = NULL;
		SerializableGeeDualKeyMapTestBigBag* _tmp247_;
		SerializableGeeDualKeyMapTestBigBag* _tmp248_;
		GXmlGDocument* _tmp249_;
		SerializableGeeDualKeyMapTestBigBag* _tmp250_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp251_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp252_;
		gint _tmp253_;
		gint _tmp254_;
		gboolean _tmp255_ = FALSE;
		SerializableGeeDualKeyMapTestBigBag* _tmp256_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp257_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp258_;
		SerializableGeeDualKeyMapTestBigBag* _tmp259_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp260_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp261_;
		gint _tmp262_;
		gint _tmp263_;
		gboolean _tmp264_ = FALSE;
		SerializableGeeDualKeyMapTestBigBag* _tmp265_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp266_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp267_;
		gpointer _tmp268_;
		SerializableGeeDualKeyMapTestSmallBag* _tmp269_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp270_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp271_;
		gboolean _tmp272_;
		SerializableGeeDualKeyMapTestBigBag* _tmp273_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp274_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp275_;
		gpointer _tmp276_;
		SerializableGeeDualKeyMapTestSmallBag* _tmp277_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp278_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp279_;
		gint _tmp280_;
		gint _tmp281_;
		SerializableGeeDualKeyMapTestBigBag* _tmp282_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp283_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp284_;
		gpointer _tmp285_;
		SerializableGeeDualKeyMapTestSmallBag* _tmp286_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp287_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp288_;
		gpointer _tmp289_;
		SerializableGeeDualKeyMapTestBall* _tmp290_;
		const gchar* _tmp291_;
		const gchar* _tmp292_;
		SerializableGeeDualKeyMapTestBigBag* _tmp293_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp294_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp295_;
		gpointer _tmp296_;
		SerializableGeeDualKeyMapTestSmallBag* _tmp297_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp298_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp299_;
		gpointer _tmp300_;
		SerializableGeeDualKeyMapTestBall* _tmp301_;
		SerializableGeeDualKeyMapTestBallFill* _tmp302_;
		SerializableGeeDualKeyMapTestBallFill* _tmp303_;
		SerializableGeeDualKeyMapTestBigBag* _tmp304_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp305_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp306_;
		gpointer _tmp307_;
		SerializableGeeDualKeyMapTestSmallBag* _tmp308_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp309_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp310_;
		gpointer _tmp311_;
		SerializableGeeDualKeyMapTestBall* _tmp312_;
		SerializableGeeDualKeyMapTestBallFill* _tmp313_;
		SerializableGeeDualKeyMapTestBallFill* _tmp314_;
		gchar* _tmp315_;
		gchar* _tmp316_;
		gchar* _tmp317_;
		SerializableGeeDualKeyMapTestBigBag* _tmp318_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp319_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp320_;
		gpointer _tmp321_;
		SerializableGeeDualKeyMapTestSmallBag* _tmp322_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp323_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp324_;
		gpointer _tmp325_;
		SerializableGeeDualKeyMapTestBall* _tmp326_;
		SerializableGeeDualKeyMapTestBallFill* _tmp327_;
		SerializableGeeDualKeyMapTestBallFill* _tmp328_;
		gchar* _tmp329_;
		gchar* _tmp330_;
		gchar* _tmp331_;
		SerializableGeeDualKeyMapTestBigBag* bag3 = NULL;
		SerializableGeeDualKeyMapTestBigBag* _tmp332_;
		SerializableGeeDualKeyMapTestBigBag* _tmp333_;
		GXmlGDocument* _tmp334_;
		SerializableGeeDualKeyMapTestBigBag* _tmp335_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp336_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp337_;
		gint _tmp338_;
		gint _tmp339_;
		gboolean _tmp340_ = FALSE;
		SerializableGeeDualKeyMapTestBigBag* _tmp341_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp342_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp343_;
		SerializableGeeDualKeyMapTestBigBag* _tmp344_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp345_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp346_;
		gint _tmp347_;
		gint _tmp348_;
		SerializableGeeDualKeyMapTestBigBag* _tmp349_;
		GXmlGDocument* _tmp350_;
		SerializableGeeDualKeyMapTestBigBag* _tmp351_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp352_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp353_;
		SerializableGeeDualKeyMapTestBigBag* bag2 = NULL;
		SerializableGeeDualKeyMapTestBigBag* _tmp354_;
		SerializableGeeDualKeyMapTestBigBag* _tmp355_;
		GXmlGDocument* _tmp356_;
		SerializableGeeDualKeyMapTestBigBag* _tmp357_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp358_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp359_;
		GXmlGDocument* d2 = NULL;
		GXmlGDocument* _tmp360_;
		SerializableGeeDualKeyMapTestBigBag* _tmp361_;
		GXmlGDocument* _tmp362_;
		GXmlNode* _tmp363_;
		GXmlNode* _tmp364_;
		GXmlGDocument* _tmp365_;
		GXmlNode* _tmp366_;
		GXmlNode* _tmp367_;
		GXmlNode* _tmp368_;
		GXmlGDocument* _tmp369_;
		GXmlNode* _tmp370_;
		GXmlNode* _tmp371_;
		GXmlNode* _tmp372_;
		gchar* _tmp373_;
		gchar* _tmp374_;
		gchar* _tmp375_;
		GXmlGDocument* _tmp376_;
		GXmlNode* _tmp377_;
		GXmlNode* _tmp378_;
		GXmlNode* _tmp379_;
		GeeBidirList* _tmp380_;
		GeeBidirList* _tmp381_;
		GeeBidirList* _tmp382_;
		gint _tmp383_;
		gint _tmp384_;
		GXmlGDocument* _tmp385_;
		GXmlNode* _tmp386_;
		GXmlNode* _tmp387_;
		GXmlNode* _tmp388_;
		GeeBidirList* _tmp389_;
		GeeBidirList* _tmp390_;
		GeeBidirList* _tmp391_;
		gpointer _tmp392_;
		GXmlNode* _tmp393_;
		gchar* _tmp394_;
		gchar* _tmp395_;
		gchar* _tmp396_;
		GXmlGDocument* _tmp397_;
		GXmlNode* _tmp398_;
		GXmlNode* _tmp399_;
		GXmlNode* _tmp400_;
		GeeBidirList* _tmp401_;
		GeeBidirList* _tmp402_;
		GeeBidirList* _tmp403_;
		gpointer _tmp404_;
		GXmlNode* _tmp405_;
		GeeBidirList* _tmp406_;
		GeeBidirList* _tmp407_;
		GeeBidirList* _tmp408_;
		gint _tmp409_;
		gint _tmp410_;
		GXmlGDocument* _tmp411_;
		GXmlNode* _tmp412_;
		GXmlNode* _tmp413_;
		GXmlNode* _tmp414_;
		GeeBidirList* _tmp415_;
		GeeBidirList* _tmp416_;
		GeeBidirList* _tmp417_;
		gpointer _tmp418_;
		GXmlNode* _tmp419_;
		GeeBidirList* _tmp420_;
		GeeBidirList* _tmp421_;
		GeeBidirList* _tmp422_;
		gpointer _tmp423_;
		GXmlNode* _tmp424_;
		gchar* _tmp425_;
		gchar* _tmp426_;
		gchar* _tmp427_;
		GXmlGDocument* _tmp428_;
		GXmlNode* _tmp429_;
		GXmlNode* _tmp430_;
		GXmlNode* _tmp431_;
		GeeBidirList* _tmp432_;
		GeeBidirList* _tmp433_;
		GeeBidirList* _tmp434_;
		gpointer _tmp435_;
		GXmlNode* _tmp436_;
		GeeBidirList* _tmp437_;
		GeeBidirList* _tmp438_;
		GeeBidirList* _tmp439_;
		gpointer _tmp440_;
		GXmlNode* _tmp441_;
		GeeBidirList* _tmp442_;
		GeeBidirList* _tmp443_;
		GeeBidirList* _tmp444_;
		gint _tmp445_;
		gint _tmp446_;
		GXmlGDocument* _tmp447_;
		GXmlNode* _tmp448_;
		GXmlNode* _tmp449_;
		GXmlNode* _tmp450_;
		GeeBidirList* _tmp451_;
		GeeBidirList* _tmp452_;
		GeeBidirList* _tmp453_;
		gpointer _tmp454_;
		GXmlNode* _tmp455_;
		GeeBidirList* _tmp456_;
		GeeBidirList* _tmp457_;
		GeeBidirList* _tmp458_;
		gpointer _tmp459_;
		GXmlNode* _tmp460_;
		GeeBidirList* _tmp461_;
		GeeBidirList* _tmp462_;
		GeeBidirList* _tmp463_;
		gpointer _tmp464_;
		GXmlNode* _tmp465_;
		gchar* _tmp466_;
		gchar* _tmp467_;
		gchar* _tmp468_;
		GXmlGDocument* _tmp469_;
		GXmlNode* _tmp470_;
		GXmlNode* _tmp471_;
		GXmlNode* _tmp472_;
		GeeBidirList* _tmp473_;
		GeeBidirList* _tmp474_;
		GeeBidirList* _tmp475_;
		gpointer _tmp476_;
		GXmlNode* _tmp477_;
		GeeBidirList* _tmp478_;
		GeeBidirList* _tmp479_;
		GeeBidirList* _tmp480_;
		gpointer _tmp481_;
		GXmlNode* _tmp482_;
		GeeBidirList* _tmp483_;
		GeeBidirList* _tmp484_;
		GeeBidirList* _tmp485_;
		gpointer _tmp486_;
		GXmlNode* _tmp487_;
		GeeBidirList* _tmp488_;
		GeeBidirList* _tmp489_;
		GeeBidirList* _tmp490_;
		gint _tmp491_;
		gint _tmp492_;
		GXmlGDocument* _tmp493_;
		GXmlNode* _tmp494_;
		GXmlNode* _tmp495_;
		GXmlNode* _tmp496_;
		GeeBidirList* _tmp497_;
		GeeBidirList* _tmp498_;
		GeeBidirList* _tmp499_;
		gpointer _tmp500_;
		GXmlNode* _tmp501_;
		GeeBidirList* _tmp502_;
		GeeBidirList* _tmp503_;
		GeeBidirList* _tmp504_;
		gpointer _tmp505_;
		GXmlNode* _tmp506_;
		GeeBidirList* _tmp507_;
		GeeBidirList* _tmp508_;
		GeeBidirList* _tmp509_;
		gpointer _tmp510_;
		GXmlNode* _tmp511_;
		GeeBidirList* _tmp512_;
		GeeBidirList* _tmp513_;
		GeeBidirList* _tmp514_;
		gpointer _tmp515_;
		GXmlNode* _tmp516_;
		GXmlGDocument* _tmp517_;
		GXmlNode* _tmp518_;
		GXmlNode* _tmp519_;
		GXmlNode* _tmp520_;
		GeeBidirList* _tmp521_;
		GeeBidirList* _tmp522_;
		GeeBidirList* _tmp523_;
		gpointer _tmp524_;
		GXmlNode* _tmp525_;
		GeeBidirList* _tmp526_;
		GeeBidirList* _tmp527_;
		GeeBidirList* _tmp528_;
		gpointer _tmp529_;
		GXmlNode* _tmp530_;
		GeeBidirList* _tmp531_;
		GeeBidirList* _tmp532_;
		GeeBidirList* _tmp533_;
		gpointer _tmp534_;
		GXmlNode* _tmp535_;
		GeeBidirList* _tmp536_;
		GeeBidirList* _tmp537_;
		GeeBidirList* _tmp538_;
		gpointer _tmp539_;
		GXmlNode* _tmp540_;
		gchar* _tmp541_;
		gchar* _tmp542_;
		gchar* _tmp543_;
#line 341 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = serializable_gee_dual_key_map_test_big_bag_new ();
#line 341 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		bag = _tmp0_;
#line 342 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp1_ = bag;
#line 342 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp2_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp1_);
#line 342 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp3_ = _tmp2_;
#line 342 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp3_ != NULL, "bag.bags != null");
#line 4211 "SerializableGeeDualKeyMapTest.c"
		{
			gint i = 0;
#line 343 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			i = 0;
#line 4216 "SerializableGeeDualKeyMapTest.c"
			{
				gboolean _tmp4_ = FALSE;
#line 343 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				_tmp4_ = TRUE;
#line 343 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
				while (TRUE) {
#line 4223 "SerializableGeeDualKeyMapTest.c"
					gint _tmp6_;
					SerializableGeeDualKeyMapTestSmallBag* sbag = NULL;
					SerializableGeeDualKeyMapTestSmallBag* _tmp7_;
					SerializableGeeDualKeyMapTestSmallBag* _tmp8_;
					gint _tmp9_;
					gchar* _tmp10_;
					gchar* _tmp11_;
					gchar* _tmp12_;
					gchar* _tmp13_;
					SerializableGeeDualKeyMapTestSmallBag* _tmp14_;
					SerializableGeeDualKeyMapTestBallDualMap* _tmp15_;
					SerializableGeeDualKeyMapTestBallDualMap* _tmp16_;
					SerializableGeeDualKeyMapTestSmallBag* _tmp43_;
					SerializableGeeDualKeyMapTestBallDualMap* _tmp44_;
					SerializableGeeDualKeyMapTestBallDualMap* _tmp45_;
					gint _tmp46_;
					gint _tmp47_;
					SerializableGeeDualKeyMapTestBigBag* _tmp48_;
					SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp49_;
					SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp50_;
					SerializableGeeDualKeyMapTestSmallBag* _tmp51_;
					const gchar* _tmp52_;
					const gchar* _tmp53_;
					SerializableGeeDualKeyMapTestSmallBag* _tmp54_;
					const gchar* _tmp55_;
					const gchar* _tmp56_;
					SerializableGeeDualKeyMapTestSmallBag* _tmp57_;
#line 343 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					if (!_tmp4_) {
#line 4253 "SerializableGeeDualKeyMapTest.c"
						gint _tmp5_;
#line 343 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						_tmp5_ = i;
#line 343 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						i = _tmp5_ + 1;
#line 4259 "SerializableGeeDualKeyMapTest.c"
					}
#line 343 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp4_ = FALSE;
#line 343 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp6_ = i;
#line 343 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					if (!(_tmp6_ < 2)) {
#line 343 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						break;
#line 4269 "SerializableGeeDualKeyMapTest.c"
					}
#line 344 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp7_ = serializable_gee_dual_key_map_test_small_bag_new ();
#line 344 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					sbag = _tmp7_;
#line 345 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp8_ = sbag;
#line 345 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp9_ = i;
#line 345 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp10_ = g_strdup_printf ("%i", _tmp9_);
#line 345 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp11_ = _tmp10_;
#line 345 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp12_ = g_strconcat ("SmallBag", _tmp11_, NULL);
#line 345 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp13_ = _tmp12_;
#line 345 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					serializable_gee_dual_key_map_test_small_bag_set_name (_tmp8_, _tmp13_);
#line 345 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_g_free0 (_tmp13_);
#line 345 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_g_free0 (_tmp11_);
#line 346 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp14_ = sbag;
#line 346 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp15_ = serializable_gee_dual_key_map_test_small_bag_get_balls (_tmp14_);
#line 346 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp16_ = _tmp15_;
#line 346 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_vala_assert (_tmp16_ != NULL, "sbag.balls != null");
#line 4301 "SerializableGeeDualKeyMapTest.c"
					{
						gint j = 0;
#line 347 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
						j = 0;
#line 4306 "SerializableGeeDualKeyMapTest.c"
						{
							gboolean _tmp17_ = FALSE;
#line 347 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							_tmp17_ = TRUE;
#line 347 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
							while (TRUE) {
#line 4313 "SerializableGeeDualKeyMapTest.c"
								gint _tmp19_;
								SerializableGeeDualKeyMapTestBall* b = NULL;
								SerializableGeeDualKeyMapTestBall* _tmp20_;
								SerializableGeeDualKeyMapTestBall* _tmp21_;
								gint _tmp22_;
								gchar* _tmp23_;
								gchar* _tmp24_;
								gchar* _tmp25_;
								gchar* _tmp26_;
								SerializableGeeDualKeyMapTestBall* _tmp27_;
								SerializableGeeDualKeyMapTestBallFill* _tmp28_;
								SerializableGeeDualKeyMapTestBallFill* _tmp29_;
								SerializableGeeDualKeyMapTestBall* _tmp30_;
								SerializableGeeDualKeyMapTestBallFill* _tmp31_;
								SerializableGeeDualKeyMapTestBallFill* _tmp32_;
								SerializableGeeDualKeyMapTestSmallBag* _tmp33_;
								SerializableGeeDualKeyMapTestBallDualMap* _tmp34_;
								SerializableGeeDualKeyMapTestBallDualMap* _tmp35_;
								SerializableGeeDualKeyMapTestBall* _tmp36_;
								const gchar* _tmp37_;
								const gchar* _tmp38_;
								SerializableGeeDualKeyMapTestBall* _tmp39_;
								const gchar* _tmp40_;
								const gchar* _tmp41_;
								SerializableGeeDualKeyMapTestBall* _tmp42_;
#line 347 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								if (!_tmp17_) {
#line 4341 "SerializableGeeDualKeyMapTest.c"
									gint _tmp18_;
#line 347 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
									_tmp18_ = j;
#line 347 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
									j = _tmp18_ + 1;
#line 4347 "SerializableGeeDualKeyMapTest.c"
								}
#line 347 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp17_ = FALSE;
#line 347 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp19_ = j;
#line 347 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								if (!(_tmp19_ < 2)) {
#line 347 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
									break;
#line 4357 "SerializableGeeDualKeyMapTest.c"
								}
#line 348 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp20_ = serializable_gee_dual_key_map_test_ball_new ();
#line 348 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								b = _tmp20_;
#line 349 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp21_ = b;
#line 349 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp22_ = j;
#line 349 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp23_ = g_strdup_printf ("%i", _tmp22_);
#line 349 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp24_ = _tmp23_;
#line 349 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp25_ = g_strconcat ("Ball", _tmp24_, NULL);
#line 349 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp26_ = _tmp25_;
#line 349 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								serializable_gee_dual_key_map_test_ball_set_name (_tmp21_, _tmp26_);
#line 349 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_g_free0 (_tmp26_);
#line 349 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_g_free0 (_tmp24_);
#line 350 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp27_ = b;
#line 350 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp28_ = serializable_gee_dual_key_map_test_ball_fill_new ();
#line 350 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp29_ = _tmp28_;
#line 350 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								serializable_gee_dual_key_map_test_ball_set_ballfill (_tmp27_, _tmp29_);
#line 350 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_g_object_unref0 (_tmp29_);
#line 351 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp30_ = b;
#line 351 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp31_ = serializable_gee_dual_key_map_test_ball_get_ballfill (_tmp30_);
#line 351 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp32_ = _tmp31_;
#line 351 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								serializable_gee_dual_key_map_test_ball_fill_set_text (_tmp32_, "golden dust");
#line 352 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp33_ = sbag;
#line 352 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp34_ = serializable_gee_dual_key_map_test_small_bag_get_balls (_tmp33_);
#line 352 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp35_ = _tmp34_;
#line 352 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp36_ = b;
#line 352 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp37_ = serializable_gee_dual_key_map_test_ball_get_size (_tmp36_);
#line 352 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp38_ = _tmp37_;
#line 352 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp39_ = b;
#line 352 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp40_ = serializable_gee_dual_key_map_test_ball_get_name (_tmp39_);
#line 352 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp41_ = _tmp40_;
#line 352 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_tmp42_ = b;
#line 352 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								gxml_serializable_dual_key_map_set ((GXmlSerializableDualKeyMap*) _tmp35_, _tmp38_, _tmp41_, _tmp42_);
#line 347 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
								_g_object_unref0 (b);
#line 4423 "SerializableGeeDualKeyMapTest.c"
							}
						}
					}
#line 354 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp43_ = sbag;
#line 354 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp44_ = serializable_gee_dual_key_map_test_small_bag_get_balls (_tmp43_);
#line 354 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp45_ = _tmp44_;
#line 354 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp46_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp45_);
#line 354 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp47_ = _tmp46_;
#line 354 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_vala_assert (_tmp47_ == 2, "sbag.balls.size == 2");
#line 355 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp48_ = bag;
#line 355 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp49_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp48_);
#line 355 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp50_ = _tmp49_;
#line 355 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp51_ = sbag;
#line 355 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp52_ = serializable_gee_dual_key_map_test_small_bag_get_cash (_tmp51_);
#line 355 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp53_ = _tmp52_;
#line 355 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp54_ = sbag;
#line 355 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp55_ = serializable_gee_dual_key_map_test_small_bag_get_name (_tmp54_);
#line 355 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp56_ = _tmp55_;
#line 355 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_tmp57_ = sbag;
#line 355 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					gxml_serializable_dual_key_map_set ((GXmlSerializableDualKeyMap*) _tmp50_, _tmp53_, _tmp56_, _tmp57_);
#line 343 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
					_g_object_unref0 (sbag);
#line 4463 "SerializableGeeDualKeyMapTest.c"
				}
			}
		}
#line 357 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp58_ = bag;
#line 357 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp59_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp58_);
#line 357 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp60_ = _tmp59_;
#line 357 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp61_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp60_);
#line 357 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp62_ = _tmp61_;
#line 357 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp62_ == 2, "bag.bags.size == 2");
#line 359 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp63_ = gxml_gdocument_new ();
#line 359 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		d = _tmp63_;
#line 360 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp64_ = bag;
#line 360 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp65_ = d;
#line 360 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp66_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp64_, (GXmlNode*) _tmp65_, &_inner_error_);
#line 360 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp67_ = _tmp66_;
#line 360 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp67_);
#line 360 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 360 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d);
#line 360 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag);
#line 4499 "SerializableGeeDualKeyMapTest.c"
			goto __catch97_g_error;
		}
#line 361 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp68_ = d;
#line 361 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp69_ = gxml_document_get_root ((GXmlDocument*) _tmp68_);
#line 361 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp70_ = _tmp69_;
#line 361 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp71_ = _tmp70_;
#line 361 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp71_ != NULL, "d.root != null");
#line 361 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp71_);
#line 362 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp72_ = d;
#line 362 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp73_ = gxml_document_get_root ((GXmlDocument*) _tmp72_);
#line 362 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp74_ = _tmp73_;
#line 362 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp75_ = _tmp74_;
#line 362 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp76_ = gxml_node_get_name (_tmp75_);
#line 362 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp77_ = _tmp76_;
#line 362 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp78_ = _tmp77_;
#line 362 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp78_, "BigBag") == 0, "d.root.name == \"BigBag\"");
#line 362 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp78_);
#line 362 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp75_);
#line 363 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp79_ = d;
#line 363 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp80_ = gxml_document_get_root ((GXmlDocument*) _tmp79_);
#line 363 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp81_ = _tmp80_;
#line 363 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp82_ = _tmp81_;
#line 363 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp83_ = gxml_node_get_children_nodes (_tmp82_);
#line 363 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp84_ = _tmp83_;
#line 363 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp85_ = _tmp84_;
#line 363 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp86_ = gee_collection_get_size ((GeeCollection*) _tmp85_);
#line 363 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp87_ = _tmp86_;
#line 363 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp87_ == 2, "d.root.children_nodes.size == 2");
#line 363 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp85_);
#line 363 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp82_);
#line 364 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp88_ = d;
#line 364 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp89_ = gxml_document_get_root ((GXmlDocument*) _tmp88_);
#line 364 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp90_ = _tmp89_;
#line 364 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp91_ = _tmp90_;
#line 364 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp92_ = gxml_node_get_children_nodes (_tmp91_);
#line 364 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp93_ = _tmp92_;
#line 364 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp94_ = _tmp93_;
#line 364 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp95_ = gee_list_get ((GeeList*) _tmp94_, 0);
#line 364 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp96_ = (GXmlNode*) _tmp95_;
#line 364 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp97_ = gxml_node_get_name (_tmp96_);
#line 364 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp98_ = _tmp97_;
#line 364 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp99_ = _tmp98_;
#line 364 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp99_, "SmallBag") == 0, "d.root.children_nodes[0].name == \"SmallBag\"");
#line 364 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp99_);
#line 364 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp96_);
#line 364 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp94_);
#line 364 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp91_);
#line 365 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp100_ = d;
#line 365 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp101_ = gxml_document_get_root ((GXmlDocument*) _tmp100_);
#line 365 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp102_ = _tmp101_;
#line 365 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp103_ = _tmp102_;
#line 365 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp104_ = gxml_node_get_children_nodes (_tmp103_);
#line 365 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp105_ = _tmp104_;
#line 365 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp106_ = _tmp105_;
#line 365 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp107_ = gee_list_get ((GeeList*) _tmp106_, 0);
#line 365 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp108_ = (GXmlNode*) _tmp107_;
#line 365 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp109_ = gxml_node_get_children_nodes (_tmp108_);
#line 365 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp110_ = _tmp109_;
#line 365 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp111_ = _tmp110_;
#line 365 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp112_ = gee_collection_get_size ((GeeCollection*) _tmp111_);
#line 365 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp113_ = _tmp112_;
#line 365 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp113_ == 2, "d.root.children_nodes[0].children_nodes.size == 2");
#line 365 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp111_);
#line 365 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp108_);
#line 365 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp106_);
#line 365 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp103_);
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp114_ = d;
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp115_ = gxml_document_get_root ((GXmlDocument*) _tmp114_);
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp116_ = _tmp115_;
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp117_ = _tmp116_;
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp118_ = gxml_node_get_children_nodes (_tmp117_);
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp119_ = _tmp118_;
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp120_ = _tmp119_;
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp121_ = gee_list_get ((GeeList*) _tmp120_, 0);
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp122_ = (GXmlNode*) _tmp121_;
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp123_ = gxml_node_get_children_nodes (_tmp122_);
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp124_ = _tmp123_;
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp125_ = _tmp124_;
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp126_ = gee_list_get ((GeeList*) _tmp125_, 0);
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp127_ = (GXmlNode*) _tmp126_;
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp128_ = gxml_node_get_name (_tmp127_);
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp129_ = _tmp128_;
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp130_ = _tmp129_;
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp130_, "Ball") == 0, "d.root.children_nodes[0].children_nodes[0].name == \"Ball\"");
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp130_);
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp127_);
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp125_);
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp122_);
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp120_);
#line 366 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp117_);
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp131_ = d;
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp132_ = gxml_document_get_root ((GXmlDocument*) _tmp131_);
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp133_ = _tmp132_;
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp134_ = _tmp133_;
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp135_ = gxml_node_get_children_nodes (_tmp134_);
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp136_ = _tmp135_;
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp137_ = _tmp136_;
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp138_ = gee_list_get ((GeeList*) _tmp137_, 0);
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp139_ = (GXmlNode*) _tmp138_;
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp140_ = gxml_node_get_children_nodes (_tmp139_);
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp141_ = _tmp140_;
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp142_ = _tmp141_;
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp143_ = gee_list_get ((GeeList*) _tmp142_, 0);
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp144_ = (GXmlNode*) _tmp143_;
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp145_ = gxml_node_get_children_nodes (_tmp144_);
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp146_ = _tmp145_;
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp147_ = _tmp146_;
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp148_ = gee_collection_get_size ((GeeCollection*) _tmp147_);
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp149_ = _tmp148_;
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp149_ == 1, "d.root.children_nodes[0].children_nodes[0].children_nodes.size == 1");
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp147_);
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp144_);
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp142_);
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp139_);
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp137_);
#line 367 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp134_);
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp150_ = d;
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp151_ = gxml_document_get_root ((GXmlDocument*) _tmp150_);
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp152_ = _tmp151_;
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp153_ = _tmp152_;
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp154_ = gxml_node_get_children_nodes (_tmp153_);
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp155_ = _tmp154_;
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp156_ = _tmp155_;
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp157_ = gee_list_get ((GeeList*) _tmp156_, 0);
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp158_ = (GXmlNode*) _tmp157_;
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp159_ = gxml_node_get_children_nodes (_tmp158_);
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp160_ = _tmp159_;
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp161_ = _tmp160_;
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp162_ = gee_list_get ((GeeList*) _tmp161_, 0);
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp163_ = (GXmlNode*) _tmp162_;
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp164_ = gxml_node_get_children_nodes (_tmp163_);
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp165_ = _tmp164_;
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp166_ = _tmp165_;
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp167_ = gee_list_get ((GeeList*) _tmp166_, 0);
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp168_ = (GXmlNode*) _tmp167_;
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp169_ = gxml_node_get_name (_tmp168_);
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp170_ = _tmp169_;
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp171_ = _tmp170_;
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp171_, "BallFill") == 0, "d.root.children_nodes[0].children_nodes[0].children_nodes[0].name == \"BallFill\"");
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp171_);
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp168_);
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp166_);
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp163_);
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp161_);
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp158_);
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp156_);
#line 368 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp153_);
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp172_ = d;
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp173_ = gxml_document_get_root ((GXmlDocument*) _tmp172_);
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp174_ = _tmp173_;
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp175_ = _tmp174_;
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp176_ = gxml_node_get_children_nodes (_tmp175_);
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp177_ = _tmp176_;
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp178_ = _tmp177_;
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp179_ = gee_list_get ((GeeList*) _tmp178_, 0);
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp180_ = (GXmlNode*) _tmp179_;
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp181_ = gxml_node_get_children_nodes (_tmp180_);
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp182_ = _tmp181_;
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp183_ = _tmp182_;
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp184_ = gee_list_get ((GeeList*) _tmp183_, 0);
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp185_ = (GXmlNode*) _tmp184_;
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp186_ = gxml_node_get_children_nodes (_tmp185_);
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp187_ = _tmp186_;
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp188_ = _tmp187_;
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp189_ = gee_list_get ((GeeList*) _tmp188_, 0);
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp190_ = (GXmlNode*) _tmp189_;
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp191_ = gxml_node_get_children_nodes (_tmp190_);
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp192_ = _tmp191_;
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp193_ = _tmp192_;
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp194_ = gee_collection_get_size ((GeeCollection*) _tmp193_);
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp195_ = _tmp194_;
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp195_ == 1, "d.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes.size == 1");
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp193_);
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp190_);
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp188_);
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp185_);
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp183_);
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp180_);
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp178_);
#line 369 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp175_);
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp196_ = d;
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp197_ = gxml_document_get_root ((GXmlDocument*) _tmp196_);
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp198_ = _tmp197_;
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp199_ = _tmp198_;
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp200_ = gxml_node_get_children_nodes (_tmp199_);
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp201_ = _tmp200_;
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp202_ = _tmp201_;
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp203_ = gee_list_get ((GeeList*) _tmp202_, 0);
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp204_ = (GXmlNode*) _tmp203_;
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp205_ = gxml_node_get_children_nodes (_tmp204_);
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp206_ = _tmp205_;
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp207_ = _tmp206_;
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp208_ = gee_list_get ((GeeList*) _tmp207_, 0);
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp209_ = (GXmlNode*) _tmp208_;
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp210_ = gxml_node_get_children_nodes (_tmp209_);
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp211_ = _tmp210_;
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp212_ = _tmp211_;
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp213_ = gee_list_get ((GeeList*) _tmp212_, 0);
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp214_ = (GXmlNode*) _tmp213_;
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp215_ = gxml_node_get_children_nodes (_tmp214_);
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp216_ = _tmp215_;
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp217_ = _tmp216_;
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp218_ = gee_list_get ((GeeList*) _tmp217_, 0);
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp219_ = (GXmlNode*) _tmp218_;
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp219_, GXML_TYPE_TEXT), "d.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes[0] is Text");
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp219_);
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp217_);
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp214_);
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp212_);
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp209_);
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp207_);
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp204_);
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp202_);
#line 370 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp199_);
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp220_ = d;
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp221_ = gxml_document_get_root ((GXmlDocument*) _tmp220_);
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp222_ = _tmp221_;
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp223_ = _tmp222_;
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp224_ = gxml_node_get_children_nodes (_tmp223_);
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp225_ = _tmp224_;
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp226_ = _tmp225_;
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp227_ = gee_list_get ((GeeList*) _tmp226_, 0);
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp228_ = (GXmlNode*) _tmp227_;
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp229_ = gxml_node_get_children_nodes (_tmp228_);
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp230_ = _tmp229_;
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp231_ = _tmp230_;
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp232_ = gee_list_get ((GeeList*) _tmp231_, 0);
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp233_ = (GXmlNode*) _tmp232_;
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp234_ = gxml_node_get_children_nodes (_tmp233_);
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp235_ = _tmp234_;
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp236_ = _tmp235_;
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp237_ = gee_list_get ((GeeList*) _tmp236_, 0);
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp238_ = (GXmlNode*) _tmp237_;
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp239_ = gxml_node_get_children_nodes (_tmp238_);
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp240_ = _tmp239_;
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp241_ = _tmp240_;
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp242_ = gee_list_get ((GeeList*) _tmp241_, 0);
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp243_ = (GXmlNode*) _tmp242_;
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp244_ = gxml_node_get_value (_tmp243_);
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp245_ = _tmp244_;
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp246_ = _tmp245_;
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp246_, "golden dust") == 0, "d.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes[0].value == \"golden dust\"");
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp246_);
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp243_);
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp241_);
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp238_);
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp236_);
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp233_);
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp231_);
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp228_);
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp226_);
#line 371 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp223_);
#line 374 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp247_ = serializable_gee_dual_key_map_test_big_bag_new ();
#line 374 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		bagt = _tmp247_;
#line 375 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp248_ = bagt;
#line 375 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp249_ = d;
#line 375 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp248_, (GXmlNode*) _tmp249_, &_inner_error_);
#line 375 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 375 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bagt);
#line 375 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d);
#line 375 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag);
#line 5020 "SerializableGeeDualKeyMapTest.c"
			goto __catch97_g_error;
		}
#line 376 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp250_ = bagt;
#line 376 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp251_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp250_);
#line 376 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp252_ = _tmp251_;
#line 376 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp253_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp252_);
#line 376 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp254_ = _tmp253_;
#line 376 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp254_ == 0, "bagt.bags.size == 0");
#line 377 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp256_ = bagt;
#line 377 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp257_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp256_);
#line 377 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp258_ = _tmp257_;
#line 377 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp255_ = gxml_serializable_dual_key_map_deserialize_children ((GXmlSerializableDualKeyMap*) _tmp258_, &_inner_error_);
#line 377 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 377 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bagt);
#line 377 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d);
#line 377 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag);
#line 5051 "SerializableGeeDualKeyMapTest.c"
			goto __catch97_g_error;
		}
#line 377 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp255_, "bagt.bags.deserialize_children ()");
#line 378 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp259_ = bagt;
#line 378 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp260_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp259_);
#line 378 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp261_ = _tmp260_;
#line 378 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp262_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp261_);
#line 378 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp263_ = _tmp262_;
#line 378 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp263_ == 2, "bagt.bags.size == 2");
#line 379 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp265_ = bagt;
#line 379 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp266_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp265_);
#line 379 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp267_ = _tmp266_;
#line 379 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp268_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp267_, "money", "SmallBag1");
#line 379 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp269_ = (SerializableGeeDualKeyMapTestSmallBag*) _tmp268_;
#line 379 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp270_ = serializable_gee_dual_key_map_test_small_bag_get_balls (_tmp269_);
#line 379 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp271_ = _tmp270_;
#line 379 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp272_ = gxml_serializable_dual_key_map_deserialize_children ((GXmlSerializableDualKeyMap*) _tmp271_, &_inner_error_);
#line 379 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp269_);
#line 379 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp264_ = _tmp272_;
#line 379 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 379 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bagt);
#line 379 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d);
#line 379 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag);
#line 5096 "SerializableGeeDualKeyMapTest.c"
			goto __catch97_g_error;
		}
#line 379 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp264_, "bagt.bags.get(\"money\",\"SmallBag1\").balls.deserialize_children ()");
#line 380 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp273_ = bagt;
#line 380 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp274_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp273_);
#line 380 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp275_ = _tmp274_;
#line 380 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp276_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp275_, "money", "SmallBag1");
#line 380 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp277_ = (SerializableGeeDualKeyMapTestSmallBag*) _tmp276_;
#line 380 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp278_ = serializable_gee_dual_key_map_test_small_bag_get_balls (_tmp277_);
#line 380 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp279_ = _tmp278_;
#line 380 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp280_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp279_);
#line 380 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp281_ = _tmp280_;
#line 380 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp281_ == 2, "bagt.bags.get(\"money\",\"SmallBag1\").balls.size == 2");
#line 380 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp277_);
#line 381 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp282_ = bagt;
#line 381 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp283_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp282_);
#line 381 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp284_ = _tmp283_;
#line 381 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp285_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp284_, "money", "SmallBag1");
#line 381 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp286_ = (SerializableGeeDualKeyMapTestSmallBag*) _tmp285_;
#line 381 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp287_ = serializable_gee_dual_key_map_test_small_bag_get_balls (_tmp286_);
#line 381 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp288_ = _tmp287_;
#line 381 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp289_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp288_, "medium", "Ball1");
#line 381 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp290_ = (SerializableGeeDualKeyMapTestBall*) _tmp289_;
#line 381 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp291_ = serializable_gee_dual_key_map_test_ball_get_name (_tmp290_);
#line 381 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp292_ = _tmp291_;
#line 381 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp292_, "Ball1") == 0, "bagt.bags.get(\"money\",\"SmallBag1\").balls.get(\"medium\",\"Ball1\").name == \"Ball1\"");
#line 381 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp290_);
#line 381 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp286_);
#line 382 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp293_ = bagt;
#line 382 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp294_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp293_);
#line 382 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp295_ = _tmp294_;
#line 382 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp296_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp295_, "money", "SmallBag1");
#line 382 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp297_ = (SerializableGeeDualKeyMapTestSmallBag*) _tmp296_;
#line 382 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp298_ = serializable_gee_dual_key_map_test_small_bag_get_balls (_tmp297_);
#line 382 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp299_ = _tmp298_;
#line 382 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp300_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp299_, "medium", "Ball1");
#line 382 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp301_ = (SerializableGeeDualKeyMapTestBall*) _tmp300_;
#line 382 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp302_ = serializable_gee_dual_key_map_test_ball_get_ballfill (_tmp301_);
#line 382 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp303_ = _tmp302_;
#line 382 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp303_ != NULL, "bagt.bags.get(\"money\",\"SmallBag1\").balls.get(\"medium\",\"Ball1\").ballfill !=null");
#line 382 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp301_);
#line 382 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp297_);
#line 383 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp304_ = bagt;
#line 383 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp305_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp304_);
#line 383 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp306_ = _tmp305_;
#line 383 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp307_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp306_, "money", "SmallBag1");
#line 383 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp308_ = (SerializableGeeDualKeyMapTestSmallBag*) _tmp307_;
#line 383 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp309_ = serializable_gee_dual_key_map_test_small_bag_get_balls (_tmp308_);
#line 383 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp310_ = _tmp309_;
#line 383 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp311_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp310_, "medium", "Ball1");
#line 383 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp312_ = (SerializableGeeDualKeyMapTestBall*) _tmp311_;
#line 383 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp313_ = serializable_gee_dual_key_map_test_ball_get_ballfill (_tmp312_);
#line 383 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp314_ = _tmp313_;
#line 383 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp315_ = gxml_serializable_get_serialized_xml_node_value ((GXmlSerializable*) _tmp314_);
#line 383 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp316_ = _tmp315_;
#line 383 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp317_ = _tmp316_;
#line 383 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp317_ != NULL, "bagt.bags.get(\"money\",\"SmallBag1\").balls.get(\"medium\",\"Ball1\").ballfill.serialized_xml_node_value !=null");
#line 383 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp317_);
#line 383 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp312_);
#line 383 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp308_);
#line 384 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp318_ = bagt;
#line 384 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp319_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp318_);
#line 384 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp320_ = _tmp319_;
#line 384 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp321_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp320_, "money", "SmallBag1");
#line 384 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp322_ = (SerializableGeeDualKeyMapTestSmallBag*) _tmp321_;
#line 384 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp323_ = serializable_gee_dual_key_map_test_small_bag_get_balls (_tmp322_);
#line 384 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp324_ = _tmp323_;
#line 384 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp325_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp324_, "medium", "Ball1");
#line 384 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp326_ = (SerializableGeeDualKeyMapTestBall*) _tmp325_;
#line 384 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp327_ = serializable_gee_dual_key_map_test_ball_get_ballfill (_tmp326_);
#line 384 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp328_ = _tmp327_;
#line 384 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp329_ = gxml_serializable_get_serialized_xml_node_value ((GXmlSerializable*) _tmp328_);
#line 384 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp330_ = _tmp329_;
#line 384 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp331_ = _tmp330_;
#line 384 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp331_, "golden dust") == 0, "bagt.bags.get(\"money\",\"SmallBag1\").balls.get(\"medium\",\"Ball1\").ballfill.serialized_xml_node_value ==\"golden dust\"");
#line 384 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp331_);
#line 384 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp326_);
#line 384 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp322_);
#line 385 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp332_ = serializable_gee_dual_key_map_test_big_bag_new ();
#line 385 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		bag3 = _tmp332_;
#line 386 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp333_ = bag3;
#line 386 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp334_ = d;
#line 386 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp333_, (GXmlNode*) _tmp334_, &_inner_error_);
#line 386 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 386 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag3);
#line 386 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bagt);
#line 386 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d);
#line 386 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag);
#line 5271 "SerializableGeeDualKeyMapTest.c"
			goto __catch97_g_error;
		}
#line 387 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp335_ = bag3;
#line 387 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp336_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp335_);
#line 387 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp337_ = _tmp336_;
#line 387 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp338_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp337_);
#line 387 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp339_ = _tmp338_;
#line 387 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp339_ == 0, "bag3.bags.size == 0");
#line 388 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp341_ = bag3;
#line 388 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp342_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp341_);
#line 388 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp343_ = _tmp342_;
#line 388 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp340_ = gxml_serializable_dual_key_map_deserialize_children ((GXmlSerializableDualKeyMap*) _tmp343_, &_inner_error_);
#line 388 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 388 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag3);
#line 388 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bagt);
#line 388 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d);
#line 388 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag);
#line 5304 "SerializableGeeDualKeyMapTest.c"
			goto __catch97_g_error;
		}
#line 388 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp340_, "bag3.bags.deserialize_children ()");
#line 389 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp344_ = bag3;
#line 389 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp345_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp344_);
#line 389 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp346_ = _tmp345_;
#line 389 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp347_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp346_);
#line 389 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp348_ = _tmp347_;
#line 389 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp348_ == 2, "bag3.bags.size == 2");
#line 390 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp349_ = bag3;
#line 390 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp350_ = d;
#line 390 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp349_, (GXmlNode*) _tmp350_, &_inner_error_);
#line 390 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 390 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag3);
#line 390 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bagt);
#line 390 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d);
#line 390 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag);
#line 5337 "SerializableGeeDualKeyMapTest.c"
			goto __catch97_g_error;
		}
#line 391 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp351_ = bag3;
#line 391 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp352_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp351_);
#line 391 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp353_ = _tmp352_;
#line 391 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (!gxml_serializable_dual_key_map_deserialized ((GXmlSerializableDualKeyMap*) _tmp353_), "!bag3.bags.deserialized ()");
#line 393 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp354_ = serializable_gee_dual_key_map_test_big_bag_new ();
#line 393 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		bag2 = _tmp354_;
#line 394 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp355_ = bag2;
#line 394 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp356_ = d;
#line 394 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp355_, (GXmlNode*) _tmp356_, &_inner_error_);
#line 394 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 394 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag2);
#line 394 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag3);
#line 394 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bagt);
#line 394 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d);
#line 394 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag);
#line 5370 "SerializableGeeDualKeyMapTest.c"
			goto __catch97_g_error;
		}
#line 395 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp357_ = bag2;
#line 395 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp358_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp357_);
#line 395 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp359_ = _tmp358_;
#line 395 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (!gxml_serializable_dual_key_map_deserialized ((GXmlSerializableDualKeyMap*) _tmp359_), "!bag2.bags.deserialized ()");
#line 396 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp360_ = gxml_gdocument_new ();
#line 396 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		d2 = _tmp360_;
#line 397 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp361_ = bag2;
#line 397 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp362_ = d2;
#line 397 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp363_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp361_, (GXmlNode*) _tmp362_, &_inner_error_);
#line 397 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp364_ = _tmp363_;
#line 397 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp364_);
#line 397 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 397 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d2);
#line 397 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag2);
#line 397 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag3);
#line 397 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bagt);
#line 397 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d);
#line 397 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag);
#line 5409 "SerializableGeeDualKeyMapTest.c"
			goto __catch97_g_error;
		}
#line 399 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp365_ = d2;
#line 399 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp366_ = gxml_document_get_root ((GXmlDocument*) _tmp365_);
#line 399 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp367_ = _tmp366_;
#line 399 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp368_ = _tmp367_;
#line 399 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp368_ != NULL, "d2.root != null");
#line 399 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp368_);
#line 400 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp369_ = d2;
#line 400 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp370_ = gxml_document_get_root ((GXmlDocument*) _tmp369_);
#line 400 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp371_ = _tmp370_;
#line 400 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp372_ = _tmp371_;
#line 400 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp373_ = gxml_node_get_name (_tmp372_);
#line 400 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp374_ = _tmp373_;
#line 400 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp375_ = _tmp374_;
#line 400 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp375_, "BigBag") == 0, "d2.root.name == \"BigBag\"");
#line 400 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp375_);
#line 400 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp372_);
#line 401 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp376_ = d2;
#line 401 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp377_ = gxml_document_get_root ((GXmlDocument*) _tmp376_);
#line 401 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp378_ = _tmp377_;
#line 401 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp379_ = _tmp378_;
#line 401 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp380_ = gxml_node_get_children_nodes (_tmp379_);
#line 401 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp381_ = _tmp380_;
#line 401 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp382_ = _tmp381_;
#line 401 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp383_ = gee_collection_get_size ((GeeCollection*) _tmp382_);
#line 401 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp384_ = _tmp383_;
#line 401 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp384_ == 2, "d2.root.children_nodes.size == 2");
#line 401 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp382_);
#line 401 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp379_);
#line 402 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp385_ = d2;
#line 402 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp386_ = gxml_document_get_root ((GXmlDocument*) _tmp385_);
#line 402 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp387_ = _tmp386_;
#line 402 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp388_ = _tmp387_;
#line 402 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp389_ = gxml_node_get_children_nodes (_tmp388_);
#line 402 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp390_ = _tmp389_;
#line 402 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp391_ = _tmp390_;
#line 402 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp392_ = gee_list_get ((GeeList*) _tmp391_, 0);
#line 402 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp393_ = (GXmlNode*) _tmp392_;
#line 402 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp394_ = gxml_node_get_name (_tmp393_);
#line 402 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp395_ = _tmp394_;
#line 402 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp396_ = _tmp395_;
#line 402 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp396_, "SmallBag") == 0, "d2.root.children_nodes[0].name == \"SmallBag\"");
#line 402 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp396_);
#line 402 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp393_);
#line 402 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp391_);
#line 402 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp388_);
#line 403 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp397_ = d2;
#line 403 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp398_ = gxml_document_get_root ((GXmlDocument*) _tmp397_);
#line 403 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp399_ = _tmp398_;
#line 403 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp400_ = _tmp399_;
#line 403 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp401_ = gxml_node_get_children_nodes (_tmp400_);
#line 403 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp402_ = _tmp401_;
#line 403 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp403_ = _tmp402_;
#line 403 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp404_ = gee_list_get ((GeeList*) _tmp403_, 0);
#line 403 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp405_ = (GXmlNode*) _tmp404_;
#line 403 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp406_ = gxml_node_get_children_nodes (_tmp405_);
#line 403 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp407_ = _tmp406_;
#line 403 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp408_ = _tmp407_;
#line 403 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp409_ = gee_collection_get_size ((GeeCollection*) _tmp408_);
#line 403 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp410_ = _tmp409_;
#line 403 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp410_ == 2, "d2.root.children_nodes[0].children_nodes.size == 2");
#line 403 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp408_);
#line 403 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp405_);
#line 403 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp403_);
#line 403 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp400_);
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp411_ = d2;
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp412_ = gxml_document_get_root ((GXmlDocument*) _tmp411_);
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp413_ = _tmp412_;
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp414_ = _tmp413_;
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp415_ = gxml_node_get_children_nodes (_tmp414_);
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp416_ = _tmp415_;
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp417_ = _tmp416_;
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp418_ = gee_list_get ((GeeList*) _tmp417_, 0);
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp419_ = (GXmlNode*) _tmp418_;
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp420_ = gxml_node_get_children_nodes (_tmp419_);
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp421_ = _tmp420_;
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp422_ = _tmp421_;
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp423_ = gee_list_get ((GeeList*) _tmp422_, 0);
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp424_ = (GXmlNode*) _tmp423_;
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp425_ = gxml_node_get_name (_tmp424_);
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp426_ = _tmp425_;
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp427_ = _tmp426_;
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp427_, "Ball") == 0, "d2.root.children_nodes[0].children_nodes[0].name == \"Ball\"");
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp427_);
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp424_);
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp422_);
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp419_);
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp417_);
#line 404 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp414_);
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp428_ = d2;
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp429_ = gxml_document_get_root ((GXmlDocument*) _tmp428_);
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp430_ = _tmp429_;
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp431_ = _tmp430_;
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp432_ = gxml_node_get_children_nodes (_tmp431_);
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp433_ = _tmp432_;
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp434_ = _tmp433_;
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp435_ = gee_list_get ((GeeList*) _tmp434_, 0);
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp436_ = (GXmlNode*) _tmp435_;
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp437_ = gxml_node_get_children_nodes (_tmp436_);
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp438_ = _tmp437_;
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp439_ = _tmp438_;
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp440_ = gee_list_get ((GeeList*) _tmp439_, 0);
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp441_ = (GXmlNode*) _tmp440_;
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp442_ = gxml_node_get_children_nodes (_tmp441_);
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp443_ = _tmp442_;
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp444_ = _tmp443_;
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp445_ = gee_collection_get_size ((GeeCollection*) _tmp444_);
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp446_ = _tmp445_;
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp446_ == 1, "d2.root.children_nodes[0].children_nodes[0].children_nodes.size == 1");
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp444_);
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp441_);
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp439_);
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp436_);
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp434_);
#line 405 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp431_);
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp447_ = d2;
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp448_ = gxml_document_get_root ((GXmlDocument*) _tmp447_);
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp449_ = _tmp448_;
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp450_ = _tmp449_;
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp451_ = gxml_node_get_children_nodes (_tmp450_);
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp452_ = _tmp451_;
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp453_ = _tmp452_;
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp454_ = gee_list_get ((GeeList*) _tmp453_, 0);
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp455_ = (GXmlNode*) _tmp454_;
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp456_ = gxml_node_get_children_nodes (_tmp455_);
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp457_ = _tmp456_;
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp458_ = _tmp457_;
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp459_ = gee_list_get ((GeeList*) _tmp458_, 0);
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp460_ = (GXmlNode*) _tmp459_;
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp461_ = gxml_node_get_children_nodes (_tmp460_);
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp462_ = _tmp461_;
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp463_ = _tmp462_;
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp464_ = gee_list_get ((GeeList*) _tmp463_, 0);
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp465_ = (GXmlNode*) _tmp464_;
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp466_ = gxml_node_get_name (_tmp465_);
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp467_ = _tmp466_;
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp468_ = _tmp467_;
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp468_, "BallFill") == 0, "d2.root.children_nodes[0].children_nodes[0].children_nodes[0].name == \"BallFill\"");
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp468_);
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp465_);
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp463_);
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp460_);
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp458_);
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp455_);
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp453_);
#line 406 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp450_);
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp469_ = d2;
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp470_ = gxml_document_get_root ((GXmlDocument*) _tmp469_);
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp471_ = _tmp470_;
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp472_ = _tmp471_;
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp473_ = gxml_node_get_children_nodes (_tmp472_);
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp474_ = _tmp473_;
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp475_ = _tmp474_;
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp476_ = gee_list_get ((GeeList*) _tmp475_, 0);
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp477_ = (GXmlNode*) _tmp476_;
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp478_ = gxml_node_get_children_nodes (_tmp477_);
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp479_ = _tmp478_;
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp480_ = _tmp479_;
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp481_ = gee_list_get ((GeeList*) _tmp480_, 0);
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp482_ = (GXmlNode*) _tmp481_;
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp483_ = gxml_node_get_children_nodes (_tmp482_);
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp484_ = _tmp483_;
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp485_ = _tmp484_;
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp486_ = gee_list_get ((GeeList*) _tmp485_, 0);
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp487_ = (GXmlNode*) _tmp486_;
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp488_ = gxml_node_get_children_nodes (_tmp487_);
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp489_ = _tmp488_;
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp490_ = _tmp489_;
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp491_ = gee_collection_get_size ((GeeCollection*) _tmp490_);
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp492_ = _tmp491_;
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp492_ == 1, "d2.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes.size == 1");
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp490_);
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp487_);
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp485_);
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp482_);
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp480_);
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp477_);
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp475_);
#line 407 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp472_);
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp493_ = d2;
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp494_ = gxml_document_get_root ((GXmlDocument*) _tmp493_);
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp495_ = _tmp494_;
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp496_ = _tmp495_;
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp497_ = gxml_node_get_children_nodes (_tmp496_);
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp498_ = _tmp497_;
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp499_ = _tmp498_;
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp500_ = gee_list_get ((GeeList*) _tmp499_, 0);
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp501_ = (GXmlNode*) _tmp500_;
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp502_ = gxml_node_get_children_nodes (_tmp501_);
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp503_ = _tmp502_;
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp504_ = _tmp503_;
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp505_ = gee_list_get ((GeeList*) _tmp504_, 0);
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp506_ = (GXmlNode*) _tmp505_;
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp507_ = gxml_node_get_children_nodes (_tmp506_);
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp508_ = _tmp507_;
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp509_ = _tmp508_;
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp510_ = gee_list_get ((GeeList*) _tmp509_, 0);
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp511_ = (GXmlNode*) _tmp510_;
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp512_ = gxml_node_get_children_nodes (_tmp511_);
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp513_ = _tmp512_;
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp514_ = _tmp513_;
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp515_ = gee_list_get ((GeeList*) _tmp514_, 0);
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp516_ = (GXmlNode*) _tmp515_;
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp516_, GXML_TYPE_TEXT), "d2.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes[0] is GXml.Text");
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp516_);
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp514_);
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp511_);
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp509_);
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp506_);
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp504_);
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp501_);
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp499_);
#line 408 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp496_);
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp517_ = d2;
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp518_ = gxml_document_get_root ((GXmlDocument*) _tmp517_);
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp519_ = _tmp518_;
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp520_ = _tmp519_;
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp521_ = gxml_node_get_children_nodes (_tmp520_);
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp522_ = _tmp521_;
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp523_ = _tmp522_;
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp524_ = gee_list_get ((GeeList*) _tmp523_, 0);
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp525_ = (GXmlNode*) _tmp524_;
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp526_ = gxml_node_get_children_nodes (_tmp525_);
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp527_ = _tmp526_;
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp528_ = _tmp527_;
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp529_ = gee_list_get ((GeeList*) _tmp528_, 0);
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp530_ = (GXmlNode*) _tmp529_;
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp531_ = gxml_node_get_children_nodes (_tmp530_);
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp532_ = _tmp531_;
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp533_ = _tmp532_;
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp534_ = gee_list_get ((GeeList*) _tmp533_, 0);
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp535_ = (GXmlNode*) _tmp534_;
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp536_ = gxml_node_get_children_nodes (_tmp535_);
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp537_ = _tmp536_;
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp538_ = _tmp537_;
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp539_ = gee_list_get ((GeeList*) _tmp538_, 0);
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp540_ = (GXmlNode*) _tmp539_;
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp541_ = gxml_node_get_value (_tmp540_);
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp542_ = _tmp541_;
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp543_ = _tmp542_;
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp543_, "golden dust") == 0, "d2.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes[0].value == \"golden dust\"");
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp543_);
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp540_);
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp538_);
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp535_);
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp533_);
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp530_);
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp528_);
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp525_);
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp523_);
#line 409 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp520_);
#line 339 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (d2);
#line 339 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (bag2);
#line 339 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (bag3);
#line 339 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (bagt);
#line 339 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (d);
#line 339 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (bag);
#line 5924 "SerializableGeeDualKeyMapTest.c"
	}
	goto __finally97;
	__catch97_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp544_;
		gchar* _tmp545_;
		gchar* _tmp546_;
#line 339 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		e = _inner_error_;
#line 339 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_inner_error_ = NULL;
#line 411 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp544_ = e->message;
#line 411 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp545_ = g_strconcat ("ERROR: ", _tmp544_, NULL);
#line 411 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp546_ = _tmp545_;
#line 411 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_message ("SerializableGeeDualKeyMapTest.vala:411: %s", _tmp546_);
#line 411 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp546_);
#line 412 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 339 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_error_free0 (e);
#line 5951 "SerializableGeeDualKeyMapTest.c"
	}
	__finally97:
#line 339 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 339 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 339 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_clear_error (&_inner_error_);
#line 339 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		return;
#line 5962 "SerializableGeeDualKeyMapTest.c"
	}
}


static void
___lambda59__gtest_func (void)
{
#line 337 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	__lambda59_ ();
#line 5972 "SerializableGeeDualKeyMapTest.c"
}


void
serializable_gee_dual_key_map_test_add_tests (void)
{
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_test_add_func ("/gxml/serializable/dualkeymap/api", ___lambda54__gtest_func);
#line 170 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_test_add_func ("/gxml/serializable/dualkeymap/serialize", ___lambda55__gtest_func);
#line 238 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_test_add_func ("/gxml/serializable/dualkeymap/deserialize", ___lambda56__gtest_func);
#line 281 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_test_add_func ("/gxml/serializable/dualkeymap/de-se-deserialize", ___lambda57__gtest_func);
#line 307 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_test_add_func ("/gxml/serializable/dualkeymap/deserialize-node-names", ___lambda58__gtest_func);
#line 337 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_test_add_func ("/gxml/serializable/dualkeymap/post-deserialization/serialize/contents", ___lambda59__gtest_func);
#line 5991 "SerializableGeeDualKeyMapTest.c"
}


SerializableGeeDualKeyMapTest*
serializable_gee_dual_key_map_test_construct (GType object_type)
{
	SerializableGeeDualKeyMapTest* self = NULL;
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTest*) gxml_test_construct (object_type);
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return self;
#line 6003 "SerializableGeeDualKeyMapTest.c"
}


SerializableGeeDualKeyMapTest*
serializable_gee_dual_key_map_test_new (void)
{
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return serializable_gee_dual_key_map_test_construct (TYPE_SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST);
#line 6012 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_ball_fill_set_text (SerializableGeeDualKeyMapTestBallFill* self, 
                                                       const gchar* txt)
{
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (txt != NULL);
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	gxml_serializable_set_serialized_xml_node_value ((GXmlSerializable*) self, txt);
#line 6026 "SerializableGeeDualKeyMapTest.c"
}


static gchar*
serializable_gee_dual_key_map_test_ball_fill_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeDualKeyMapTestBallFill * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBallFill*) base;
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6047 "SerializableGeeDualKeyMapTest.c"
}


static gchar*
serializable_gee_dual_key_map_test_ball_fill_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeDualKeyMapTestBallFill * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBallFill*) base;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = g_strdup ("BallFill");
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6065 "SerializableGeeDualKeyMapTest.c"
}


static gboolean
serializable_gee_dual_key_map_test_ball_fill_real_serialize_use_xml_node_value (GXmlSerializableObjectModel* base)
{
	SerializableGeeDualKeyMapTestBallFill * self;
	gboolean result = FALSE;
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBallFill*) base;
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = TRUE;
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6080 "SerializableGeeDualKeyMapTest.c"
}


static SerializableGeeDualKeyMapTestBallFill*
serializable_gee_dual_key_map_test_ball_fill_construct (GType object_type)
{
	SerializableGeeDualKeyMapTestBallFill * self = NULL;
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBallFill*) gxml_serializable_object_model_construct (object_type);
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return self;
#line 6092 "SerializableGeeDualKeyMapTest.c"
}


static SerializableGeeDualKeyMapTestBallFill*
serializable_gee_dual_key_map_test_ball_fill_new (void)
{
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return serializable_gee_dual_key_map_test_ball_fill_construct (SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL);
#line 6101 "SerializableGeeDualKeyMapTest.c"
}


static const gchar*
serializable_gee_dual_key_map_test_ball_fill_get_name (SerializableGeeDualKeyMapTestBallFill* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6118 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_ball_fill_set_name (SerializableGeeDualKeyMapTestBallFill* self, 
                                                       const gchar* value)
{
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_dual_key_map_test_ball_fill_get_name (self)) != 0) {
#line 6130 "SerializableGeeDualKeyMapTest.c"
		gchar* _tmp0_;
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (self->priv->_name);
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		self->priv->_name = _tmp0_;
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_dual_key_map_test_ball_fill_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_NAME_PROPERTY]);
#line 6140 "SerializableGeeDualKeyMapTest.c"
	}
}


static void
serializable_gee_dual_key_map_test_ball_fill_class_init (SerializableGeeDualKeyMapTestBallFillClass * klass)
{
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	serializable_gee_dual_key_map_test_ball_fill_parent_class = g_type_class_peek_parent (klass);
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_type_class_add_private (klass, sizeof (SerializableGeeDualKeyMapTestBallFillPrivate));
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel *)) serializable_gee_dual_key_map_test_ball_fill_real_to_string;
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel *)) serializable_gee_dual_key_map_test_ball_fill_real_node_name;
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->serialize_use_xml_node_value = (gboolean (*) (GXmlSerializableObjectModel *)) serializable_gee_dual_key_map_test_ball_fill_real_serialize_use_xml_node_value;
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_dual_key_map_test_ball_fill_get_property;
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_dual_key_map_test_ball_fill_set_property;
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_dual_key_map_test_ball_fill_finalize;
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_NAME_PROPERTY, serializable_gee_dual_key_map_test_ball_fill_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6166 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_ball_fill_instance_init (SerializableGeeDualKeyMapTestBallFill * self)
{
	gchar* _tmp0_;
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self->priv = SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_GET_PRIVATE (self);
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = g_strdup ("Fill");
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self->priv->_name = _tmp0_;
#line 6180 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_ball_fill_finalize (GObject * obj)
{
	SerializableGeeDualKeyMapTestBallFill * self;
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL, SerializableGeeDualKeyMapTestBallFill);
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_g_free0 (self->priv->_name);
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (serializable_gee_dual_key_map_test_ball_fill_parent_class)->finalize (obj);
#line 6194 "SerializableGeeDualKeyMapTest.c"
}


static GType
serializable_gee_dual_key_map_test_ball_fill_get_type (void)
{
	static volatile gsize serializable_gee_dual_key_map_test_ball_fill_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_dual_key_map_test_ball_fill_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeDualKeyMapTestBallFillClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_dual_key_map_test_ball_fill_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeDualKeyMapTestBallFill), 0, (GInstanceInitFunc) serializable_gee_dual_key_map_test_ball_fill_instance_init, NULL };
		GType serializable_gee_dual_key_map_test_ball_fill_type_id;
		serializable_gee_dual_key_map_test_ball_fill_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeDualKeyMapTestBallFill", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_dual_key_map_test_ball_fill_type_id__volatile, serializable_gee_dual_key_map_test_ball_fill_type_id);
	}
	return serializable_gee_dual_key_map_test_ball_fill_type_id__volatile;
}


static void
_vala_serializable_gee_dual_key_map_test_ball_fill_get_property (GObject * object, 
                                                                 guint property_id, 
                                                                 GValue * value, 
                                                                 GParamSpec * pspec)
{
	SerializableGeeDualKeyMapTestBallFill * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL, SerializableGeeDualKeyMapTestBallFill);
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	switch (property_id) {
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_NAME_PROPERTY:
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_value_set_string (value, serializable_gee_dual_key_map_test_ball_fill_get_name (self));
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 6228 "SerializableGeeDualKeyMapTest.c"
		default:
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 6234 "SerializableGeeDualKeyMapTest.c"
	}
}


static void
_vala_serializable_gee_dual_key_map_test_ball_fill_set_property (GObject * object, 
                                                                 guint property_id, 
                                                                 const GValue * value, 
                                                                 GParamSpec * pspec)
{
	SerializableGeeDualKeyMapTestBallFill * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL, SerializableGeeDualKeyMapTestBallFill);
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	switch (property_id) {
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_NAME_PROPERTY:
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		serializable_gee_dual_key_map_test_ball_fill_set_name (self, g_value_get_string (value));
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 6255 "SerializableGeeDualKeyMapTest.c"
		default:
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 6261 "SerializableGeeDualKeyMapTest.c"
	}
}


static gchar*
serializable_gee_dual_key_map_test_ball_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeDualKeyMapTestBall * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBall*) base;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6283 "SerializableGeeDualKeyMapTest.c"
}


static gchar*
serializable_gee_dual_key_map_test_ball_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeDualKeyMapTestBall * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBall*) base;
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = g_strdup ("Ball");
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6301 "SerializableGeeDualKeyMapTest.c"
}


static gchar*
serializable_gee_dual_key_map_test_ball_real_get_map_primary_key (GXmlSerializableMapDualKey* base)
{
	SerializableGeeDualKeyMapTestBall * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBall*) base;
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_size;
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6322 "SerializableGeeDualKeyMapTest.c"
}


static gchar*
serializable_gee_dual_key_map_test_ball_real_get_map_secondary_key (GXmlSerializableMapDualKey* base)
{
	SerializableGeeDualKeyMapTestBall * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBall*) base;
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6343 "SerializableGeeDualKeyMapTest.c"
}


static SerializableGeeDualKeyMapTestBall*
serializable_gee_dual_key_map_test_ball_construct (GType object_type)
{
	SerializableGeeDualKeyMapTestBall * self = NULL;
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBall*) gxml_serializable_object_model_construct (object_type);
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return self;
#line 6355 "SerializableGeeDualKeyMapTest.c"
}


static SerializableGeeDualKeyMapTestBall*
serializable_gee_dual_key_map_test_ball_new (void)
{
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return serializable_gee_dual_key_map_test_ball_construct (SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL);
#line 6364 "SerializableGeeDualKeyMapTest.c"
}


static const gchar*
serializable_gee_dual_key_map_test_ball_get_name (SerializableGeeDualKeyMapTestBall* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6381 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_ball_set_name (SerializableGeeDualKeyMapTestBall* self, 
                                                  const gchar* value)
{
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_dual_key_map_test_ball_get_name (self)) != 0) {
#line 6393 "SerializableGeeDualKeyMapTest.c"
		gchar* _tmp0_;
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (self->priv->_name);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		self->priv->_name = _tmp0_;
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_dual_key_map_test_ball_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_NAME_PROPERTY]);
#line 6403 "SerializableGeeDualKeyMapTest.c"
	}
}


static const gchar*
serializable_gee_dual_key_map_test_ball_get_size (SerializableGeeDualKeyMapTestBall* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_size;
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6421 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_ball_set_size (SerializableGeeDualKeyMapTestBall* self, 
                                                  const gchar* value)
{
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_dual_key_map_test_ball_get_size (self)) != 0) {
#line 6433 "SerializableGeeDualKeyMapTest.c"
		gchar* _tmp0_;
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (self->priv->_size);
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		self->priv->_size = _tmp0_;
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_dual_key_map_test_ball_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_SIZE_PROPERTY]);
#line 6443 "SerializableGeeDualKeyMapTest.c"
	}
}


static SerializableGeeDualKeyMapTestBallFill*
serializable_gee_dual_key_map_test_ball_get_ballfill (SerializableGeeDualKeyMapTestBall* self)
{
	SerializableGeeDualKeyMapTestBallFill* result;
	SerializableGeeDualKeyMapTestBallFill* _tmp0_;
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_ballfill;
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6461 "SerializableGeeDualKeyMapTest.c"
}


static gpointer
_g_object_ref0 (gpointer self)
{
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 6470 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_ball_set_ballfill (SerializableGeeDualKeyMapTestBall* self, 
                                                      SerializableGeeDualKeyMapTestBallFill* value)
{
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (serializable_gee_dual_key_map_test_ball_get_ballfill (self) != value) {
#line 6482 "SerializableGeeDualKeyMapTest.c"
		SerializableGeeDualKeyMapTestBallFill* _tmp0_;
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (self->priv->_ballfill);
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		self->priv->_ballfill = _tmp0_;
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_dual_key_map_test_ball_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_BALLFILL_PROPERTY]);
#line 6492 "SerializableGeeDualKeyMapTest.c"
	}
}


static gboolean
serializable_gee_dual_key_map_test_ball_dual_map_real_deserialize_proceed (GXmlSerializableDualKeyMap* base)
{
	SerializableGeeDualKeyMapTestBallDualMap * self;
	gboolean result = FALSE;
#line 65 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBallDualMap*) base;
#line 65 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = FALSE;
#line 65 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6508 "SerializableGeeDualKeyMapTest.c"
}


static SerializableGeeDualKeyMapTestBallDualMap*
serializable_gee_dual_key_map_test_ball_dual_map_construct (GType object_type)
{
	SerializableGeeDualKeyMapTestBallDualMap * self = NULL;
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBallDualMap*) gxml_serializable_dual_key_map_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return self;
#line 6520 "SerializableGeeDualKeyMapTest.c"
}


static SerializableGeeDualKeyMapTestBallDualMap*
serializable_gee_dual_key_map_test_ball_dual_map_new (void)
{
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return serializable_gee_dual_key_map_test_ball_dual_map_construct (SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_TYPE_DUAL_MAP);
#line 6529 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_ball_dual_map_class_init (SerializableGeeDualKeyMapTestBallDualMapClass * klass)
{
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	serializable_gee_dual_key_map_test_ball_dual_map_parent_class = g_type_class_peek_parent (klass);
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableDualKeyMapClass *) klass)->deserialize_proceed = (gboolean (*) (GXmlSerializableDualKeyMap *)) serializable_gee_dual_key_map_test_ball_dual_map_real_deserialize_proceed;
#line 6540 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_ball_dual_map_instance_init (SerializableGeeDualKeyMapTestBallDualMap * self)
{
}


GType
serializable_gee_dual_key_map_test_ball_dual_map_get_type (void)
{
	static volatile gsize serializable_gee_dual_key_map_test_ball_dual_map_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_dual_key_map_test_ball_dual_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeDualKeyMapTestBallDualMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_dual_key_map_test_ball_dual_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeDualKeyMapTestBallDualMap), 0, (GInstanceInitFunc) serializable_gee_dual_key_map_test_ball_dual_map_instance_init, NULL };
		GType serializable_gee_dual_key_map_test_ball_dual_map_type_id;
		serializable_gee_dual_key_map_test_ball_dual_map_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_DUAL_KEY_MAP, "SerializableGeeDualKeyMapTestBallDualMap", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_dual_key_map_test_ball_dual_map_type_id__volatile, serializable_gee_dual_key_map_test_ball_dual_map_type_id);
	}
	return serializable_gee_dual_key_map_test_ball_dual_map_type_id__volatile;
}


static void
serializable_gee_dual_key_map_test_ball_class_init (SerializableGeeDualKeyMapTestBallClass * klass)
{
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	serializable_gee_dual_key_map_test_ball_parent_class = g_type_class_peek_parent (klass);
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_type_class_add_private (klass, sizeof (SerializableGeeDualKeyMapTestBallPrivate));
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel *)) serializable_gee_dual_key_map_test_ball_real_to_string;
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel *)) serializable_gee_dual_key_map_test_ball_real_node_name;
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_dual_key_map_test_ball_get_property;
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_dual_key_map_test_ball_set_property;
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_dual_key_map_test_ball_finalize;
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_NAME_PROPERTY, serializable_gee_dual_key_map_test_ball_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_SIZE_PROPERTY, serializable_gee_dual_key_map_test_ball_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_SIZE_PROPERTY] = g_param_spec_string ("size", "size", "size", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_BALLFILL_PROPERTY, serializable_gee_dual_key_map_test_ball_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_BALLFILL_PROPERTY] = g_param_spec_object ("ballfill", "ballfill", "ballfill", SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6587 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_ball_gxml_serializable_map_dual_key_interface_init (GXmlSerializableMapDualKeyIface * iface)
{
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	serializable_gee_dual_key_map_test_ball_gxml_serializable_map_dual_key_parent_iface = g_type_interface_peek_parent (iface);
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	iface->get_map_primary_key = (gpointer (*) (GXmlSerializableMapDualKey *)) serializable_gee_dual_key_map_test_ball_real_get_map_primary_key;
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	iface->get_map_secondary_key = (gpointer (*) (GXmlSerializableMapDualKey *)) serializable_gee_dual_key_map_test_ball_real_get_map_secondary_key;
#line 6600 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_ball_instance_init (SerializableGeeDualKeyMapTestBall * self)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self->priv = SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_GET_PRIVATE (self);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = g_strdup ("Ball");
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self->priv->_name = _tmp0_;
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup ("medium");
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self->priv->_size = _tmp1_;
#line 6619 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_ball_finalize (GObject * obj)
{
	SerializableGeeDualKeyMapTestBall * self;
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL, SerializableGeeDualKeyMapTestBall);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_g_free0 (self->priv->_name);
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_g_free0 (self->priv->_size);
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_g_object_unref0 (self->priv->_ballfill);
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (serializable_gee_dual_key_map_test_ball_parent_class)->finalize (obj);
#line 6637 "SerializableGeeDualKeyMapTest.c"
}


static GType
serializable_gee_dual_key_map_test_ball_get_type (void)
{
	static volatile gsize serializable_gee_dual_key_map_test_ball_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_dual_key_map_test_ball_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeDualKeyMapTestBallClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_dual_key_map_test_ball_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeDualKeyMapTestBall), 0, (GInstanceInitFunc) serializable_gee_dual_key_map_test_ball_instance_init, NULL };
		static const GInterfaceInfo gxml_serializable_map_dual_key_info = { (GInterfaceInitFunc) serializable_gee_dual_key_map_test_ball_gxml_serializable_map_dual_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType serializable_gee_dual_key_map_test_ball_type_id;
		serializable_gee_dual_key_map_test_ball_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeDualKeyMapTestBall", &g_define_type_info, 0);
		g_type_add_interface_static (serializable_gee_dual_key_map_test_ball_type_id, GXML_TYPE_SERIALIZABLE_MAP_DUAL_KEY, &gxml_serializable_map_dual_key_info);
		g_once_init_leave (&serializable_gee_dual_key_map_test_ball_type_id__volatile, serializable_gee_dual_key_map_test_ball_type_id);
	}
	return serializable_gee_dual_key_map_test_ball_type_id__volatile;
}


static void
_vala_serializable_gee_dual_key_map_test_ball_get_property (GObject * object, 
                                                            guint property_id, 
                                                            GValue * value, 
                                                            GParamSpec * pspec)
{
	SerializableGeeDualKeyMapTestBall * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL, SerializableGeeDualKeyMapTestBall);
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	switch (property_id) {
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_NAME_PROPERTY:
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_value_set_string (value, serializable_gee_dual_key_map_test_ball_get_name (self));
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_SIZE_PROPERTY:
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_value_set_string (value, serializable_gee_dual_key_map_test_ball_get_size (self));
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_BALLFILL_PROPERTY:
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_value_set_object (value, serializable_gee_dual_key_map_test_ball_get_ballfill (self));
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 6685 "SerializableGeeDualKeyMapTest.c"
		default:
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 6691 "SerializableGeeDualKeyMapTest.c"
	}
}


static void
_vala_serializable_gee_dual_key_map_test_ball_set_property (GObject * object, 
                                                            guint property_id, 
                                                            const GValue * value, 
                                                            GParamSpec * pspec)
{
	SerializableGeeDualKeyMapTestBall * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL, SerializableGeeDualKeyMapTestBall);
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	switch (property_id) {
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_NAME_PROPERTY:
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		serializable_gee_dual_key_map_test_ball_set_name (self, g_value_get_string (value));
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_SIZE_PROPERTY:
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		serializable_gee_dual_key_map_test_ball_set_size (self, g_value_get_string (value));
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_BALLFILL_PROPERTY:
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		serializable_gee_dual_key_map_test_ball_set_ballfill (self, g_value_get_object (value));
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 6724 "SerializableGeeDualKeyMapTest.c"
		default:
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 6730 "SerializableGeeDualKeyMapTest.c"
	}
}


static gchar*
serializable_gee_dual_key_map_test_small_bag_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeDualKeyMapTestSmallBag * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestSmallBag*) base;
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6752 "SerializableGeeDualKeyMapTest.c"
}


static gchar*
serializable_gee_dual_key_map_test_small_bag_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeDualKeyMapTestSmallBag * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestSmallBag*) base;
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = g_strdup ("SmallBag");
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6770 "SerializableGeeDualKeyMapTest.c"
}


static gchar*
serializable_gee_dual_key_map_test_small_bag_real_get_map_primary_key (GXmlSerializableMapDualKey* base)
{
	SerializableGeeDualKeyMapTestSmallBag * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 76 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestSmallBag*) base;
#line 76 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_cash;
#line 76 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 76 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 76 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6791 "SerializableGeeDualKeyMapTest.c"
}


static gchar*
serializable_gee_dual_key_map_test_small_bag_real_get_map_secondary_key (GXmlSerializableMapDualKey* base)
{
	SerializableGeeDualKeyMapTestSmallBag * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestSmallBag*) base;
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6812 "SerializableGeeDualKeyMapTest.c"
}


static SerializableGeeDualKeyMapTestSmallBag*
serializable_gee_dual_key_map_test_small_bag_construct (GType object_type)
{
	SerializableGeeDualKeyMapTestSmallBag * self = NULL;
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestSmallBag*) gxml_serializable_object_model_construct (object_type);
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return self;
#line 6824 "SerializableGeeDualKeyMapTest.c"
}


static SerializableGeeDualKeyMapTestSmallBag*
serializable_gee_dual_key_map_test_small_bag_new (void)
{
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return serializable_gee_dual_key_map_test_small_bag_construct (SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG);
#line 6833 "SerializableGeeDualKeyMapTest.c"
}


static const gchar*
serializable_gee_dual_key_map_test_small_bag_get_name (SerializableGeeDualKeyMapTestSmallBag* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6850 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_small_bag_set_name (SerializableGeeDualKeyMapTestSmallBag* self, 
                                                       const gchar* value)
{
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_dual_key_map_test_small_bag_get_name (self)) != 0) {
#line 6862 "SerializableGeeDualKeyMapTest.c"
		gchar* _tmp0_;
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (self->priv->_name);
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		self->priv->_name = _tmp0_;
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_dual_key_map_test_small_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_NAME_PROPERTY]);
#line 6872 "SerializableGeeDualKeyMapTest.c"
	}
}


static const gchar*
serializable_gee_dual_key_map_test_small_bag_get_cash (SerializableGeeDualKeyMapTestSmallBag* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_cash;
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6890 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_small_bag_set_cash (SerializableGeeDualKeyMapTestSmallBag* self, 
                                                       const gchar* value)
{
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_dual_key_map_test_small_bag_get_cash (self)) != 0) {
#line 6902 "SerializableGeeDualKeyMapTest.c"
		gchar* _tmp0_;
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (self->priv->_cash);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		self->priv->_cash = _tmp0_;
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_dual_key_map_test_small_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_CASH_PROPERTY]);
#line 6912 "SerializableGeeDualKeyMapTest.c"
	}
}


static SerializableGeeDualKeyMapTestBallDualMap*
serializable_gee_dual_key_map_test_small_bag_get_balls (SerializableGeeDualKeyMapTestSmallBag* self)
{
	SerializableGeeDualKeyMapTestBallDualMap* result;
	SerializableGeeDualKeyMapTestBallDualMap* _tmp0_;
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_balls;
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6930 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_small_bag_set_balls (SerializableGeeDualKeyMapTestSmallBag* self, 
                                                        SerializableGeeDualKeyMapTestBallDualMap* value)
{
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (serializable_gee_dual_key_map_test_small_bag_get_balls (self) != value) {
#line 6942 "SerializableGeeDualKeyMapTest.c"
		SerializableGeeDualKeyMapTestBallDualMap* _tmp0_;
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (self->priv->_balls);
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		self->priv->_balls = _tmp0_;
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_dual_key_map_test_small_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_BALLS_PROPERTY]);
#line 6952 "SerializableGeeDualKeyMapTest.c"
	}
}


static gboolean
serializable_gee_dual_key_map_test_small_bag_dual_map_real_deserialize_proceed (GXmlSerializableDualKeyMap* base)
{
	SerializableGeeDualKeyMapTestSmallBagDualMap * self;
	gboolean result = FALSE;
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestSmallBagDualMap*) base;
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = FALSE;
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6968 "SerializableGeeDualKeyMapTest.c"
}


static SerializableGeeDualKeyMapTestSmallBagDualMap*
serializable_gee_dual_key_map_test_small_bag_dual_map_construct (GType object_type)
{
	SerializableGeeDualKeyMapTestSmallBagDualMap * self = NULL;
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestSmallBagDualMap*) gxml_serializable_dual_key_map_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return self;
#line 6980 "SerializableGeeDualKeyMapTest.c"
}


static SerializableGeeDualKeyMapTestSmallBagDualMap*
serializable_gee_dual_key_map_test_small_bag_dual_map_new (void)
{
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return serializable_gee_dual_key_map_test_small_bag_dual_map_construct (SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_TYPE_DUAL_MAP);
#line 6989 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_small_bag_dual_map_class_init (SerializableGeeDualKeyMapTestSmallBagDualMapClass * klass)
{
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	serializable_gee_dual_key_map_test_small_bag_dual_map_parent_class = g_type_class_peek_parent (klass);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableDualKeyMapClass *) klass)->deserialize_proceed = (gboolean (*) (GXmlSerializableDualKeyMap *)) serializable_gee_dual_key_map_test_small_bag_dual_map_real_deserialize_proceed;
#line 7000 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_small_bag_dual_map_instance_init (SerializableGeeDualKeyMapTestSmallBagDualMap * self)
{
}


GType
serializable_gee_dual_key_map_test_small_bag_dual_map_get_type (void)
{
	static volatile gsize serializable_gee_dual_key_map_test_small_bag_dual_map_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_dual_key_map_test_small_bag_dual_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeDualKeyMapTestSmallBagDualMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_dual_key_map_test_small_bag_dual_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeDualKeyMapTestSmallBagDualMap), 0, (GInstanceInitFunc) serializable_gee_dual_key_map_test_small_bag_dual_map_instance_init, NULL };
		GType serializable_gee_dual_key_map_test_small_bag_dual_map_type_id;
		serializable_gee_dual_key_map_test_small_bag_dual_map_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_DUAL_KEY_MAP, "SerializableGeeDualKeyMapTestSmallBagDualMap", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_dual_key_map_test_small_bag_dual_map_type_id__volatile, serializable_gee_dual_key_map_test_small_bag_dual_map_type_id);
	}
	return serializable_gee_dual_key_map_test_small_bag_dual_map_type_id__volatile;
}


static void
serializable_gee_dual_key_map_test_small_bag_class_init (SerializableGeeDualKeyMapTestSmallBagClass * klass)
{
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	serializable_gee_dual_key_map_test_small_bag_parent_class = g_type_class_peek_parent (klass);
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_type_class_add_private (klass, sizeof (SerializableGeeDualKeyMapTestSmallBagPrivate));
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel *)) serializable_gee_dual_key_map_test_small_bag_real_to_string;
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel *)) serializable_gee_dual_key_map_test_small_bag_real_node_name;
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_dual_key_map_test_small_bag_get_property;
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_dual_key_map_test_small_bag_set_property;
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_dual_key_map_test_small_bag_finalize;
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_NAME_PROPERTY, serializable_gee_dual_key_map_test_small_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_CASH_PROPERTY, serializable_gee_dual_key_map_test_small_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_CASH_PROPERTY] = g_param_spec_string ("cash", "cash", "cash", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_BALLS_PROPERTY, serializable_gee_dual_key_map_test_small_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_BALLS_PROPERTY] = g_param_spec_object ("balls", "balls", "balls", SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_TYPE_DUAL_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 7047 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_small_bag_gxml_serializable_map_dual_key_interface_init (GXmlSerializableMapDualKeyIface * iface)
{
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	serializable_gee_dual_key_map_test_small_bag_gxml_serializable_map_dual_key_parent_iface = g_type_interface_peek_parent (iface);
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	iface->get_map_primary_key = (gpointer (*) (GXmlSerializableMapDualKey *)) serializable_gee_dual_key_map_test_small_bag_real_get_map_primary_key;
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	iface->get_map_secondary_key = (gpointer (*) (GXmlSerializableMapDualKey *)) serializable_gee_dual_key_map_test_small_bag_real_get_map_secondary_key;
#line 7060 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_small_bag_instance_init (SerializableGeeDualKeyMapTestSmallBag * self)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	SerializableGeeDualKeyMapTestBallDualMap* _tmp2_;
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self->priv = SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_GET_PRIVATE (self);
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = g_strdup ("SmallBag");
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self->priv->_name = _tmp0_;
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup ("money");
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self->priv->_cash = _tmp1_;
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp2_ = serializable_gee_dual_key_map_test_ball_dual_map_new ();
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self->priv->_balls = _tmp2_;
#line 7084 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_small_bag_finalize (GObject * obj)
{
	SerializableGeeDualKeyMapTestSmallBag * self;
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeDualKeyMapTestSmallBag);
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_g_free0 (self->priv->_name);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_g_free0 (self->priv->_cash);
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_g_object_unref0 (self->priv->_balls);
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (serializable_gee_dual_key_map_test_small_bag_parent_class)->finalize (obj);
#line 7102 "SerializableGeeDualKeyMapTest.c"
}


static GType
serializable_gee_dual_key_map_test_small_bag_get_type (void)
{
	static volatile gsize serializable_gee_dual_key_map_test_small_bag_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_dual_key_map_test_small_bag_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeDualKeyMapTestSmallBagClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_dual_key_map_test_small_bag_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeDualKeyMapTestSmallBag), 0, (GInstanceInitFunc) serializable_gee_dual_key_map_test_small_bag_instance_init, NULL };
		static const GInterfaceInfo gxml_serializable_map_dual_key_info = { (GInterfaceInitFunc) serializable_gee_dual_key_map_test_small_bag_gxml_serializable_map_dual_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType serializable_gee_dual_key_map_test_small_bag_type_id;
		serializable_gee_dual_key_map_test_small_bag_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeDualKeyMapTestSmallBag", &g_define_type_info, 0);
		g_type_add_interface_static (serializable_gee_dual_key_map_test_small_bag_type_id, GXML_TYPE_SERIALIZABLE_MAP_DUAL_KEY, &gxml_serializable_map_dual_key_info);
		g_once_init_leave (&serializable_gee_dual_key_map_test_small_bag_type_id__volatile, serializable_gee_dual_key_map_test_small_bag_type_id);
	}
	return serializable_gee_dual_key_map_test_small_bag_type_id__volatile;
}


static void
_vala_serializable_gee_dual_key_map_test_small_bag_get_property (GObject * object, 
                                                                 guint property_id, 
                                                                 GValue * value, 
                                                                 GParamSpec * pspec)
{
	SerializableGeeDualKeyMapTestSmallBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeDualKeyMapTestSmallBag);
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	switch (property_id) {
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_NAME_PROPERTY:
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_value_set_string (value, serializable_gee_dual_key_map_test_small_bag_get_name (self));
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_CASH_PROPERTY:
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_value_set_string (value, serializable_gee_dual_key_map_test_small_bag_get_cash (self));
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_BALLS_PROPERTY:
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_value_set_object (value, serializable_gee_dual_key_map_test_small_bag_get_balls (self));
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 7150 "SerializableGeeDualKeyMapTest.c"
		default:
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 7156 "SerializableGeeDualKeyMapTest.c"
	}
}


static void
_vala_serializable_gee_dual_key_map_test_small_bag_set_property (GObject * object, 
                                                                 guint property_id, 
                                                                 const GValue * value, 
                                                                 GParamSpec * pspec)
{
	SerializableGeeDualKeyMapTestSmallBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeDualKeyMapTestSmallBag);
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	switch (property_id) {
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_NAME_PROPERTY:
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		serializable_gee_dual_key_map_test_small_bag_set_name (self, g_value_get_string (value));
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_CASH_PROPERTY:
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		serializable_gee_dual_key_map_test_small_bag_set_cash (self, g_value_get_string (value));
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_BALLS_PROPERTY:
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		serializable_gee_dual_key_map_test_small_bag_set_balls (self, g_value_get_object (value));
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 7189 "SerializableGeeDualKeyMapTest.c"
		default:
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 7195 "SerializableGeeDualKeyMapTest.c"
	}
}


static gchar*
serializable_gee_dual_key_map_test_big_bag_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeDualKeyMapTestBigBag * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBigBag*) base;
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 7217 "SerializableGeeDualKeyMapTest.c"
}


static gchar*
serializable_gee_dual_key_map_test_big_bag_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeDualKeyMapTestBigBag * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBigBag*) base;
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = g_strdup ("BigBag");
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 7235 "SerializableGeeDualKeyMapTest.c"
}


static SerializableGeeDualKeyMapTestBigBag*
serializable_gee_dual_key_map_test_big_bag_construct (GType object_type)
{
	SerializableGeeDualKeyMapTestBigBag * self = NULL;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBigBag*) gxml_serializable_object_model_construct (object_type);
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return self;
#line 7247 "SerializableGeeDualKeyMapTest.c"
}


static SerializableGeeDualKeyMapTestBigBag*
serializable_gee_dual_key_map_test_big_bag_new (void)
{
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return serializable_gee_dual_key_map_test_big_bag_construct (SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BIG_BAG);
#line 7256 "SerializableGeeDualKeyMapTest.c"
}


static const gchar*
serializable_gee_dual_key_map_test_big_bag_get_name (SerializableGeeDualKeyMapTestBigBag* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 7273 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_big_bag_set_name (SerializableGeeDualKeyMapTestBigBag* self, 
                                                     const gchar* value)
{
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_dual_key_map_test_big_bag_get_name (self)) != 0) {
#line 7285 "SerializableGeeDualKeyMapTest.c"
		gchar* _tmp0_;
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_free0 (self->priv->_name);
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		self->priv->_name = _tmp0_;
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_dual_key_map_test_big_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_NAME_PROPERTY]);
#line 7295 "SerializableGeeDualKeyMapTest.c"
	}
}


static SerializableGeeDualKeyMapTestSmallBagDualMap*
serializable_gee_dual_key_map_test_big_bag_get_bags (SerializableGeeDualKeyMapTestBigBag* self)
{
	SerializableGeeDualKeyMapTestSmallBagDualMap* result;
	SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp0_;
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_bags;
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	return result;
#line 7313 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_big_bag_set_bags (SerializableGeeDualKeyMapTestBigBag* self, 
                                                     SerializableGeeDualKeyMapTestSmallBagDualMap* value)
{
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	if (serializable_gee_dual_key_map_test_big_bag_get_bags (self) != value) {
#line 7325 "SerializableGeeDualKeyMapTest.c"
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp0_;
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (self->priv->_bags);
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		self->priv->_bags = _tmp0_;
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_dual_key_map_test_big_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_BAGS_PROPERTY]);
#line 7335 "SerializableGeeDualKeyMapTest.c"
	}
}


static void
serializable_gee_dual_key_map_test_big_bag_class_init (SerializableGeeDualKeyMapTestBigBagClass * klass)
{
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	serializable_gee_dual_key_map_test_big_bag_parent_class = g_type_class_peek_parent (klass);
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_type_class_add_private (klass, sizeof (SerializableGeeDualKeyMapTestBigBagPrivate));
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel *)) serializable_gee_dual_key_map_test_big_bag_real_to_string;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel *)) serializable_gee_dual_key_map_test_big_bag_real_node_name;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_dual_key_map_test_big_bag_get_property;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_dual_key_map_test_big_bag_set_property;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_dual_key_map_test_big_bag_finalize;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_NAME_PROPERTY, serializable_gee_dual_key_map_test_big_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_BAGS_PROPERTY, serializable_gee_dual_key_map_test_big_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_BAGS_PROPERTY] = g_param_spec_object ("bags", "bags", "bags", SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_TYPE_DUAL_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 7361 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_big_bag_instance_init (SerializableGeeDualKeyMapTestBigBag * self)
{
	gchar* _tmp0_;
	SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp1_;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self->priv = SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_GET_PRIVATE (self);
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = g_strdup ("ball");
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self->priv->_name = _tmp0_;
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = serializable_gee_dual_key_map_test_small_bag_dual_map_new ();
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self->priv->_bags = _tmp1_;
#line 7380 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_big_bag_finalize (GObject * obj)
{
	SerializableGeeDualKeyMapTestBigBag * self;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BIG_BAG, SerializableGeeDualKeyMapTestBigBag);
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_g_free0 (self->priv->_name);
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	_g_object_unref0 (self->priv->_bags);
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (serializable_gee_dual_key_map_test_big_bag_parent_class)->finalize (obj);
#line 7396 "SerializableGeeDualKeyMapTest.c"
}


static GType
serializable_gee_dual_key_map_test_big_bag_get_type (void)
{
	static volatile gsize serializable_gee_dual_key_map_test_big_bag_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_dual_key_map_test_big_bag_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeDualKeyMapTestBigBagClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_dual_key_map_test_big_bag_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeDualKeyMapTestBigBag), 0, (GInstanceInitFunc) serializable_gee_dual_key_map_test_big_bag_instance_init, NULL };
		GType serializable_gee_dual_key_map_test_big_bag_type_id;
		serializable_gee_dual_key_map_test_big_bag_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeDualKeyMapTestBigBag", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_dual_key_map_test_big_bag_type_id__volatile, serializable_gee_dual_key_map_test_big_bag_type_id);
	}
	return serializable_gee_dual_key_map_test_big_bag_type_id__volatile;
}


static void
_vala_serializable_gee_dual_key_map_test_big_bag_get_property (GObject * object, 
                                                               guint property_id, 
                                                               GValue * value, 
                                                               GParamSpec * pspec)
{
	SerializableGeeDualKeyMapTestBigBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BIG_BAG, SerializableGeeDualKeyMapTestBigBag);
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	switch (property_id) {
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_NAME_PROPERTY:
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_value_set_string (value, serializable_gee_dual_key_map_test_big_bag_get_name (self));
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_BAGS_PROPERTY:
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		g_value_set_object (value, serializable_gee_dual_key_map_test_big_bag_get_bags (self));
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 7436 "SerializableGeeDualKeyMapTest.c"
		default:
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 7442 "SerializableGeeDualKeyMapTest.c"
	}
}


static void
_vala_serializable_gee_dual_key_map_test_big_bag_set_property (GObject * object, 
                                                               guint property_id, 
                                                               const GValue * value, 
                                                               GParamSpec * pspec)
{
	SerializableGeeDualKeyMapTestBigBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BIG_BAG, SerializableGeeDualKeyMapTestBigBag);
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	switch (property_id) {
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_NAME_PROPERTY:
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		serializable_gee_dual_key_map_test_big_bag_set_name (self, g_value_get_string (value));
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_BAGS_PROPERTY:
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		serializable_gee_dual_key_map_test_big_bag_set_bags (self, g_value_get_object (value));
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 7469 "SerializableGeeDualKeyMapTest.c"
		default:
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
		break;
#line 7475 "SerializableGeeDualKeyMapTest.c"
	}
}


static void
serializable_gee_dual_key_map_test_class_init (SerializableGeeDualKeyMapTestClass * klass)
{
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializableGeeDualKeyMapTest.vala"
	serializable_gee_dual_key_map_test_parent_class = g_type_class_peek_parent (klass);
#line 7485 "SerializableGeeDualKeyMapTest.c"
}


static void
serializable_gee_dual_key_map_test_instance_init (SerializableGeeDualKeyMapTest * self)
{
}


GType
serializable_gee_dual_key_map_test_get_type (void)
{
	static volatile gsize serializable_gee_dual_key_map_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_dual_key_map_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeDualKeyMapTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_dual_key_map_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeDualKeyMapTest), 0, (GInstanceInitFunc) serializable_gee_dual_key_map_test_instance_init, NULL };
		GType serializable_gee_dual_key_map_test_type_id;
		serializable_gee_dual_key_map_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializableGeeDualKeyMapTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_dual_key_map_test_type_id__volatile, serializable_gee_dual_key_map_test_type_id);
	}
	return serializable_gee_dual_key_map_test_type_id__volatile;
}



