/* CssSelectorTest.c generated by valac 0.39.3.9-ecb8a, the Vala compiler
 * generated from CssSelectorTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* Notation.vala
 *
 * Copyright (C) 2017  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <gxml/gxml.h>
#include <gee.h>


#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_CSS_SELECTOR_TEST (css_selector_test_get_type ())
#define CSS_SELECTOR_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CSS_SELECTOR_TEST, CssSelectorTest))
#define CSS_SELECTOR_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CSS_SELECTOR_TEST, CssSelectorTestClass))
#define IS_CSS_SELECTOR_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CSS_SELECTOR_TEST))
#define IS_CSS_SELECTOR_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CSS_SELECTOR_TEST))
#define CSS_SELECTOR_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CSS_SELECTOR_TEST, CssSelectorTestClass))

typedef struct _CssSelectorTest CssSelectorTest;
typedef struct _CssSelectorTestClass CssSelectorTestClass;
typedef struct _CssSelectorTestPrivate CssSelectorTestPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _CssSelectorTest {
	GXmlTest parent_instance;
	CssSelectorTestPrivate * priv;
};

struct _CssSelectorTestClass {
	GXmlTestClass parent_class;
};


static gpointer css_selector_test_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name, 
                                  const gchar* nick, 
                                  const gchar* blurb, 
                                  GType object_type, 
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value, 
                          gpointer v_object);
void value_take_gxml_test (GValue* value, 
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType css_selector_test_get_type (void) G_GNUC_CONST;
void css_selector_test_add_tests (void);
static void __lambda284_ (void);
static void ___lambda284__gtest_func (void);
static void __lambda285_ (void);
static void ___lambda285__gtest_func (void);
static void __lambda286_ (void);
static void ___lambda286__gtest_func (void);
static void __lambda287_ (void);
static void ___lambda287__gtest_func (void);
static void __lambda288_ (void);
static void ___lambda288__gtest_func (void);
static void __lambda289_ (void);
static void ___lambda289__gtest_func (void);
static void __lambda290_ (void);
static void ___lambda290__gtest_func (void);
static void __lambda291_ (void);
static void ___lambda291__gtest_func (void);
static void __lambda292_ (void);
static void ___lambda292__gtest_func (void);
static void __lambda293_ (void);
static void ___lambda293__gtest_func (void);
static void __lambda294_ (void);
static void ___lambda294__gtest_func (void);
static void __lambda295_ (void);
static void ___lambda295__gtest_func (void);
static void __lambda296_ (void);
static void ___lambda296__gtest_func (void);
static void __lambda297_ (void);
static void ___lambda297__gtest_func (void);
static void __lambda298_ (void);
static void ___lambda298__gtest_func (void);
static void __lambda299_ (void);
static void ___lambda299__gtest_func (void);
CssSelectorTest* css_selector_test_new (void);
CssSelectorTest* css_selector_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);


static void
__lambda284_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelectorData* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelectorData* _tmp11_;
		GXmlCssSelectorData* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp15_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlGomDocument* _tmp18_;
		GXmlDomElement* _tmp19_;
		GXmlDomNode* _tmp20_;
		GXmlDomNode* _tmp21_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp22_;
		GXmlDomElement* _tmp23_;
		GXmlDomElement* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlDomNode* _tmp26_;
		GXmlDomNode* _tmp27_;
		gboolean _tmp28_ = FALSE;
		GXmlCssSelectorParser* _tmp29_;
		GXmlDomElement* _tmp30_;
		gboolean _tmp31_ = FALSE;
		GXmlCssSelectorParser* _tmp32_;
		GXmlDomElement* _tmp33_;
#line 29 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 29 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		cp = _tmp0_;
#line 30 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp1_ = cp;
#line 30 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "*", &_inner_error_);
#line 30 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 30 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 194 "CssSelectorTest.c"
			goto __catch0_g_error;
		}
#line 31 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp2_ = cp;
#line 31 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 31 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 31 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 31 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 31 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 1, "cp.selectors.size == 1");
#line 32 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp7_ = cp;
#line 32 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 32 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 32 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 32 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		s = (GXmlCssSelectorData*) _tmp10_;
#line 33 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp11_ = s;
#line 33 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 34 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp12_ = s;
#line 34 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_data_get_selector_type (_tmp12_);
#line 34 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 34 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ALL, "s.selector_type == CssSelectorType.ALL");
#line 35 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp15_ = gxml_gom_document_new ();
#line 35 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		d = _tmp15_;
#line 36 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp16_ = d;
#line 36 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp17_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp16_, "root", &_inner_error_);
#line 36 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		r = _tmp17_;
#line 36 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 36 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 36 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 36 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 249 "CssSelectorTest.c"
			goto __catch0_g_error;
		}
#line 37 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp18_ = d;
#line 37 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp19_ = r;
#line 37 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp20_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp18_, (GXmlDomNode*) _tmp19_, &_inner_error_);
#line 37 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp21_ = _tmp20_;
#line 37 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp21_);
#line 37 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 37 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 37 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 37 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 37 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 272 "CssSelectorTest.c"
			goto __catch0_g_error;
		}
#line 38 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp22_ = d;
#line 38 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp23_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp22_, "child", &_inner_error_);
#line 38 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c1 = _tmp23_;
#line 38 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 38 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 38 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 38 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 38 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 291 "CssSelectorTest.c"
			goto __catch0_g_error;
		}
#line 39 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp24_ = r;
#line 39 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp25_ = c1;
#line 39 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp26_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp24_, (GXmlDomNode*) _tmp25_, &_inner_error_);
#line 39 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp27_ = _tmp26_;
#line 39 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp27_);
#line 39 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 39 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 39 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 39 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 39 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 39 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 316 "CssSelectorTest.c"
			goto __catch0_g_error;
		}
#line 40 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp29_ = cp;
#line 40 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp30_ = r;
#line 40 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp28_ = gxml_css_selector_parser_match (_tmp29_, _tmp30_, &_inner_error_);
#line 40 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 40 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 40 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 40 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 40 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 40 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 337 "CssSelectorTest.c"
			goto __catch0_g_error;
		}
#line 40 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp28_, "cp.match (r)");
#line 41 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp32_ = cp;
#line 41 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp33_ = c1;
#line 41 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp31_ = gxml_css_selector_parser_match (_tmp32_, _tmp33_, &_inner_error_);
#line 41 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 41 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 41 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 41 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 41 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 41 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 360 "CssSelectorTest.c"
			goto __catch0_g_error;
		}
#line 41 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp31_, "cp.match (c1)");
#line 28 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 28 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 28 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 28 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 28 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 375 "CssSelectorTest.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp34_;
		const gchar* _tmp35_;
		gchar* _tmp36_;
		gchar* _tmp37_;
#line 28 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		e = _inner_error_;
#line 28 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_inner_error_ = NULL;
#line 43 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp34_ = e;
#line 43 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp35_ = _tmp34_->message;
#line 43 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp36_ = g_strconcat ("ERROR: ", _tmp35_, NULL);
#line 43 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp37_ = _tmp36_;
#line 43 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:43: %s", _tmp37_);
#line 43 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_free0 (_tmp37_);
#line 28 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_error_free0 (e);
#line 403 "CssSelectorTest.c"
	}
	__finally0:
#line 28 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 28 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 28 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_clear_error (&_inner_error_);
#line 28 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		return;
#line 414 "CssSelectorTest.c"
	}
}


static void
___lambda284__gtest_func (void)
{
#line 27 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	__lambda284_ ();
#line 424 "CssSelectorTest.c"
}


static void
__lambda285_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelectorData* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelectorData* _tmp11_;
		GXmlCssSelectorData* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp15_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlGomDocument* _tmp18_;
		GXmlDomElement* _tmp19_;
		GXmlDomNode* _tmp20_;
		GXmlDomNode* _tmp21_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp22_;
		GXmlDomElement* _tmp23_;
		GXmlDomElement* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlDomNode* _tmp26_;
		GXmlDomNode* _tmp27_;
		gboolean _tmp28_ = FALSE;
		GXmlCssSelectorParser* _tmp29_;
		GXmlDomElement* _tmp30_;
		gboolean _tmp31_ = FALSE;
		GXmlCssSelectorParser* _tmp32_;
		GXmlDomElement* _tmp33_;
#line 48 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 48 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		cp = _tmp0_;
#line 49 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp1_ = cp;
#line 49 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "child", &_inner_error_);
#line 49 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 49 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 484 "CssSelectorTest.c"
			goto __catch1_g_error;
		}
#line 50 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp2_ = cp;
#line 50 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 50 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 50 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 50 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 50 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 1, "cp.selectors.size == 1");
#line 51 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp7_ = cp;
#line 51 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 51 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 51 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 51 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		s = (GXmlCssSelectorData*) _tmp10_;
#line 52 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp11_ = s;
#line 52 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 53 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp12_ = s;
#line 53 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_data_get_selector_type (_tmp12_);
#line 53 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 53 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 54 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp15_ = gxml_gom_document_new ();
#line 54 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		d = _tmp15_;
#line 55 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp16_ = d;
#line 55 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp17_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp16_, "root", &_inner_error_);
#line 55 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		r = _tmp17_;
#line 55 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 55 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 55 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 55 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 539 "CssSelectorTest.c"
			goto __catch1_g_error;
		}
#line 56 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp18_ = d;
#line 56 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp19_ = r;
#line 56 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp20_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp18_, (GXmlDomNode*) _tmp19_, &_inner_error_);
#line 56 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp21_ = _tmp20_;
#line 56 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp21_);
#line 56 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 56 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 56 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 56 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 56 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 562 "CssSelectorTest.c"
			goto __catch1_g_error;
		}
#line 57 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp22_ = d;
#line 57 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp23_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp22_, "child", &_inner_error_);
#line 57 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c1 = _tmp23_;
#line 57 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 57 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 57 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 57 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 57 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 581 "CssSelectorTest.c"
			goto __catch1_g_error;
		}
#line 58 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp24_ = r;
#line 58 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp25_ = c1;
#line 58 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp26_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp24_, (GXmlDomNode*) _tmp25_, &_inner_error_);
#line 58 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp27_ = _tmp26_;
#line 58 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp27_);
#line 58 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 58 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 58 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 58 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 58 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 58 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 606 "CssSelectorTest.c"
			goto __catch1_g_error;
		}
#line 59 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp29_ = cp;
#line 59 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp30_ = r;
#line 59 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp28_ = gxml_css_selector_parser_match (_tmp29_, _tmp30_, &_inner_error_);
#line 59 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 59 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 59 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 59 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 59 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 59 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 627 "CssSelectorTest.c"
			goto __catch1_g_error;
		}
#line 59 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp28_, "!cp.match (r)");
#line 60 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp32_ = cp;
#line 60 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp33_ = c1;
#line 60 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp31_ = gxml_css_selector_parser_match (_tmp32_, _tmp33_, &_inner_error_);
#line 60 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 60 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 60 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 60 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 60 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 60 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 650 "CssSelectorTest.c"
			goto __catch1_g_error;
		}
#line 60 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp31_, "cp.match (c1)");
#line 47 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 47 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 47 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 47 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 47 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 665 "CssSelectorTest.c"
	}
	goto __finally1;
	__catch1_g_error:
	{
		GError* e = NULL;
		GError* _tmp34_;
		const gchar* _tmp35_;
		gchar* _tmp36_;
		gchar* _tmp37_;
#line 47 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		e = _inner_error_;
#line 47 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_inner_error_ = NULL;
#line 62 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp34_ = e;
#line 62 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp35_ = _tmp34_->message;
#line 62 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp36_ = g_strconcat ("ERROR: ", _tmp35_, NULL);
#line 62 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp37_ = _tmp36_;
#line 62 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:62: %s", _tmp37_);
#line 62 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_free0 (_tmp37_);
#line 47 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_error_free0 (e);
#line 693 "CssSelectorTest.c"
	}
	__finally1:
#line 47 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 47 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 47 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_clear_error (&_inner_error_);
#line 47 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		return;
#line 704 "CssSelectorTest.c"
	}
}


static void
___lambda285__gtest_func (void)
{
#line 46 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	__lambda285_ ();
#line 714 "CssSelectorTest.c"
}


static void
__lambda286_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelectorData* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelectorData* _tmp11_;
		GXmlCssSelectorData* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelectorData* si = NULL;
		GXmlCssSelectorParser* _tmp15_;
		GeeList* _tmp16_;
		GeeList* _tmp17_;
		gpointer _tmp18_;
		GXmlCssSelectorData* _tmp19_;
		GXmlCssSelectorData* _tmp20_;
		GXmlCssSelectorType _tmp21_;
		GXmlCssSelectorType _tmp22_;
		GXmlCssSelectorData* sa = NULL;
		GXmlCssSelectorParser* _tmp23_;
		GeeList* _tmp24_;
		GeeList* _tmp25_;
		gpointer _tmp26_;
		GXmlCssSelectorData* _tmp27_;
		GXmlCssSelectorData* _tmp28_;
		GXmlCssSelectorType _tmp29_;
		GXmlCssSelectorType _tmp30_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp31_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlGomDocument* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomNode* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomNode* _tmp42_;
		GXmlDomNode* _tmp43_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp44_;
		GXmlDomElement* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomNode* _tmp49_;
		GXmlDomNode* _tmp50_;
		gboolean _tmp51_ = FALSE;
		GXmlCssSelectorParser* _tmp52_;
		GXmlDomElement* _tmp53_;
		gboolean _tmp54_ = FALSE;
		GXmlCssSelectorParser* _tmp55_;
		GXmlDomElement* _tmp56_;
		gboolean _tmp57_ = FALSE;
		GXmlCssSelectorParser* _tmp58_;
		GXmlDomElement* _tmp59_;
#line 67 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 67 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		cp = _tmp0_;
#line 68 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp1_ = cp;
#line 68 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "child[prop-name]", &_inner_error_);
#line 68 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 68 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 803 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 69 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp2_ = cp;
#line 69 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 69 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 69 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 69 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 69 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 3, "cp.selectors.size == 3");
#line 70 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp7_ = cp;
#line 70 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 70 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 70 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 70 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		s = (GXmlCssSelectorData*) _tmp10_;
#line 71 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp11_ = s;
#line 71 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 72 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp12_ = s;
#line 72 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_data_get_selector_type (_tmp12_);
#line 72 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 72 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 73 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp15_ = cp;
#line 73 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_parser_get_selectors (_tmp15_);
#line 73 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 73 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp18_ = gee_list_get (_tmp17_, 1);
#line 73 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		si = (GXmlCssSelectorData*) _tmp18_;
#line 74 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp19_ = si;
#line 74 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp19_ != NULL, "si != null");
#line 75 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp20_ = si;
#line 75 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp21_ = gxml_css_selector_data_get_selector_type (_tmp20_);
#line 75 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp22_ = _tmp21_;
#line 75 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp22_ == GXML_CSS_SELECTOR_TYPE_INSIDE, "si.selector_type == CssSelectorType.INSIDE");
#line 76 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp23_ = cp;
#line 76 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_parser_get_selectors (_tmp23_);
#line 76 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 76 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp26_ = gee_list_get (_tmp25_, 2);
#line 76 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		sa = (GXmlCssSelectorData*) _tmp26_;
#line 77 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp27_ = sa;
#line 77 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp27_ != NULL, "sa != null");
#line 78 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp28_ = sa;
#line 78 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp29_ = gxml_css_selector_data_get_selector_type (_tmp28_);
#line 78 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp30_ = _tmp29_;
#line 78 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp30_ == GXML_CSS_SELECTOR_TYPE_ATTRIBUTE, "sa.selector_type == CssSelectorType.ATTRIBUTE");
#line 79 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp31_ = gxml_gom_document_new ();
#line 79 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		d = _tmp31_;
#line 80 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp32_ = d;
#line 80 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp33_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp32_, "root", &_inner_error_);
#line 80 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		r = _tmp33_;
#line 80 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 80 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 80 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 80 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 80 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 80 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 906 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 81 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp34_ = d;
#line 81 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp35_ = r;
#line 81 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp36_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp34_, (GXmlDomNode*) _tmp35_, &_inner_error_);
#line 81 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp37_ = _tmp36_;
#line 81 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp37_);
#line 81 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 81 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 81 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 81 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 81 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 81 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 81 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 933 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 82 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp38_ = d;
#line 82 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp39_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp38_, "child", &_inner_error_);
#line 82 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c1 = _tmp39_;
#line 82 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 82 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 82 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 82 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 82 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 82 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 82 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 956 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 83 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp40_ = r;
#line 83 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp41_ = c1;
#line 83 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp42_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp40_, (GXmlDomNode*) _tmp41_, &_inner_error_);
#line 83 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp43_ = _tmp42_;
#line 83 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp43_);
#line 83 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 83 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 83 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 83 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 83 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 83 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 83 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 83 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 985 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 84 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp44_ = d;
#line 84 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp45_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp44_, "child", &_inner_error_);
#line 84 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c2 = _tmp45_;
#line 84 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 84 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 84 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 84 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 84 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 84 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 84 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 84 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1010 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 85 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp46_ = c2;
#line 85 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp46_, "prop-name", "val", &_inner_error_);
#line 85 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 85 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 85 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 85 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 85 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 85 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 85 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 85 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 85 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1035 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 86 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp47_ = r;
#line 86 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp48_ = c2;
#line 86 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp49_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp47_, (GXmlDomNode*) _tmp48_, &_inner_error_);
#line 86 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp50_ = _tmp49_;
#line 86 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp50_);
#line 86 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 86 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 86 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 86 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 86 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 86 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 86 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 86 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 86 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1066 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 87 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp52_ = cp;
#line 87 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp53_ = r;
#line 87 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp51_ = gxml_css_selector_parser_match (_tmp52_, _tmp53_, &_inner_error_);
#line 87 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 87 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 87 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 87 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 87 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 87 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 87 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 87 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 87 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1093 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 87 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp51_, "!cp.match (r)");
#line 88 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp55_ = cp;
#line 88 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp56_ = c1;
#line 88 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp54_ = gxml_css_selector_parser_match (_tmp55_, _tmp56_, &_inner_error_);
#line 88 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 88 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 88 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 88 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 88 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 88 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 88 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 88 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 88 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1122 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 88 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp54_, "!cp.match (c1)");
#line 89 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp58_ = cp;
#line 89 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp59_ = c2;
#line 89 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp57_ = gxml_css_selector_parser_match (_tmp58_, _tmp59_, &_inner_error_);
#line 89 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 89 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 89 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 89 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 89 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 89 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 89 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 89 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 89 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1151 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 89 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp57_, "cp.match (c2)");
#line 66 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 66 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 66 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 66 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 66 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 66 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (si);
#line 66 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 66 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 1172 "CssSelectorTest.c"
	}
	goto __finally2;
	__catch2_g_error:
	{
		GError* e = NULL;
		GError* _tmp60_;
		const gchar* _tmp61_;
		gchar* _tmp62_;
		gchar* _tmp63_;
#line 66 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		e = _inner_error_;
#line 66 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_inner_error_ = NULL;
#line 91 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp60_ = e;
#line 91 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp61_ = _tmp60_->message;
#line 91 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp62_ = g_strconcat ("ERROR: ", _tmp61_, NULL);
#line 91 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp63_ = _tmp62_;
#line 91 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:91: %s", _tmp63_);
#line 91 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_free0 (_tmp63_);
#line 66 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_error_free0 (e);
#line 1200 "CssSelectorTest.c"
	}
	__finally2:
#line 66 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 66 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 66 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_clear_error (&_inner_error_);
#line 66 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		return;
#line 1211 "CssSelectorTest.c"
	}
}


static void
___lambda286__gtest_func (void)
{
#line 65 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	__lambda286_ ();
#line 1221 "CssSelectorTest.c"
}


static void
__lambda287_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelectorData* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelectorData* _tmp11_;
		GXmlCssSelectorData* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelectorData* si = NULL;
		GXmlCssSelectorParser* _tmp15_;
		GeeList* _tmp16_;
		GeeList* _tmp17_;
		gpointer _tmp18_;
		GXmlCssSelectorData* _tmp19_;
		GXmlCssSelectorData* _tmp20_;
		GXmlCssSelectorType _tmp21_;
		GXmlCssSelectorType _tmp22_;
		GXmlCssSelectorData* sa = NULL;
		GXmlCssSelectorParser* _tmp23_;
		GeeList* _tmp24_;
		GeeList* _tmp25_;
		gpointer _tmp26_;
		GXmlCssSelectorData* _tmp27_;
		GXmlCssSelectorData* _tmp28_;
		GXmlCssSelectorType _tmp29_;
		GXmlCssSelectorType _tmp30_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp31_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlGomDocument* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomNode* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomNode* _tmp42_;
		GXmlDomNode* _tmp43_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp44_;
		GXmlDomElement* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomNode* _tmp49_;
		GXmlDomNode* _tmp50_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp51_;
		GXmlDomElement* _tmp52_;
		GXmlDomElement* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomNode* _tmp56_;
		GXmlDomNode* _tmp57_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp58_;
		GXmlDomElement* _tmp59_;
		GXmlDomElement* _tmp60_;
		GXmlDomElement* _tmp61_;
		GXmlDomElement* _tmp62_;
		GXmlDomNode* _tmp63_;
		GXmlDomNode* _tmp64_;
		gboolean _tmp65_ = FALSE;
		GXmlCssSelectorParser* _tmp66_;
		GXmlDomElement* _tmp67_;
		gboolean _tmp68_ = FALSE;
		GXmlCssSelectorParser* _tmp69_;
		GXmlDomElement* _tmp70_;
		gboolean _tmp71_ = FALSE;
		GXmlCssSelectorParser* _tmp72_;
		GXmlDomElement* _tmp73_;
		gboolean _tmp74_ = FALSE;
		GXmlCssSelectorParser* _tmp75_;
		GXmlDomElement* _tmp76_;
		gboolean _tmp77_ = FALSE;
		GXmlCssSelectorParser* _tmp78_;
		GXmlDomElement* _tmp79_;
#line 96 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 96 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		cp = _tmp0_;
#line 97 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp1_ = cp;
#line 97 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "child[prop-name~=\"val\"]", &_inner_error_);
#line 97 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 97 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1332 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 98 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp2_ = cp;
#line 98 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 98 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 98 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 98 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 98 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 3, "cp.selectors.size == 3");
#line 99 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp7_ = cp;
#line 99 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 99 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 99 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 99 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		s = (GXmlCssSelectorData*) _tmp10_;
#line 100 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp11_ = s;
#line 100 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 101 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp12_ = s;
#line 101 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_data_get_selector_type (_tmp12_);
#line 101 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 101 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 102 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp15_ = cp;
#line 102 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_parser_get_selectors (_tmp15_);
#line 102 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 102 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp18_ = gee_list_get (_tmp17_, 1);
#line 102 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		si = (GXmlCssSelectorData*) _tmp18_;
#line 103 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp19_ = si;
#line 103 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp19_ != NULL, "si != null");
#line 104 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp20_ = si;
#line 104 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp21_ = gxml_css_selector_data_get_selector_type (_tmp20_);
#line 104 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp22_ = _tmp21_;
#line 104 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp22_ == GXML_CSS_SELECTOR_TYPE_INSIDE, "si.selector_type == CssSelectorType.INSIDE");
#line 105 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp23_ = cp;
#line 105 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_parser_get_selectors (_tmp23_);
#line 105 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 105 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp26_ = gee_list_get (_tmp25_, 2);
#line 105 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		sa = (GXmlCssSelectorData*) _tmp26_;
#line 106 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp27_ = sa;
#line 106 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp27_ != NULL, "sa != null");
#line 107 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp28_ = sa;
#line 107 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp29_ = gxml_css_selector_data_get_selector_type (_tmp28_);
#line 107 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp30_ = _tmp29_;
#line 107 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp30_ == GXML_CSS_SELECTOR_TYPE_ATTRIBUTE_CONTAINS, "sa.selector_type == CssSelectorType.ATTRIBUTE_CONTAINS");
#line 108 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp31_ = gxml_gom_document_new ();
#line 108 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		d = _tmp31_;
#line 109 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp32_ = d;
#line 109 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp33_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp32_, "root", &_inner_error_);
#line 109 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		r = _tmp33_;
#line 109 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 109 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 109 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 109 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 109 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 109 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1435 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 110 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp34_ = d;
#line 110 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp35_ = r;
#line 110 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp36_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp34_, (GXmlDomNode*) _tmp35_, &_inner_error_);
#line 110 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp37_ = _tmp36_;
#line 110 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp37_);
#line 110 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 110 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 110 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 110 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 110 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 110 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 110 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1462 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 111 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp38_ = d;
#line 111 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp39_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp38_, "child", &_inner_error_);
#line 111 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c1 = _tmp39_;
#line 111 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 111 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 111 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 111 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 111 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 111 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 111 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1485 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 112 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp40_ = r;
#line 112 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp41_ = c1;
#line 112 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp42_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp40_, (GXmlDomNode*) _tmp41_, &_inner_error_);
#line 112 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp43_ = _tmp42_;
#line 112 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp43_);
#line 112 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 112 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 112 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 112 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 112 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 112 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 112 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 112 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1514 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 113 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp44_ = d;
#line 113 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp45_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp44_, "child", &_inner_error_);
#line 113 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c2 = _tmp45_;
#line 113 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 113 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 113 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 113 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 113 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 113 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 113 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 113 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1539 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 114 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp46_ = c2;
#line 114 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp46_, "prop-name", "val calc soup", &_inner_error_);
#line 114 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 114 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 114 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 114 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 114 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 114 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 114 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 114 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 114 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1564 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 115 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp47_ = r;
#line 115 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp48_ = c2;
#line 115 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp49_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp47_, (GXmlDomNode*) _tmp48_, &_inner_error_);
#line 115 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp50_ = _tmp49_;
#line 115 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp50_);
#line 115 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 115 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 115 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 115 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 115 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 115 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 115 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 115 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 115 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1595 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 116 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp51_ = d;
#line 116 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp52_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp51_, "child", &_inner_error_);
#line 116 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c3 = _tmp52_;
#line 116 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 116 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 116 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 116 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 116 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 116 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 116 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 116 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 116 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1622 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 117 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp53_ = c3;
#line 117 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp53_, "prop-name", "calc val soup", &_inner_error_);
#line 117 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 117 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 117 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 117 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 117 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 117 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 117 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 117 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 117 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 117 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1649 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 118 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp54_ = r;
#line 118 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp55_ = c3;
#line 118 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp56_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp54_, (GXmlDomNode*) _tmp55_, &_inner_error_);
#line 118 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp57_ = _tmp56_;
#line 118 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp57_);
#line 118 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 118 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 118 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 118 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 118 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 118 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 118 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 118 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 118 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 118 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1682 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 119 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp58_ = d;
#line 119 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp59_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp58_, "child", &_inner_error_);
#line 119 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c4 = _tmp59_;
#line 119 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 119 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 119 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 119 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 119 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 119 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 119 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 119 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 119 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 119 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1711 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 120 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp60_ = c4;
#line 120 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp60_, "prop-name", "calc secondary soup", &_inner_error_);
#line 120 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 120 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 120 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 120 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 120 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 120 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 120 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 120 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 120 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 120 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 120 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1740 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 121 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp61_ = r;
#line 121 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp62_ = c4;
#line 121 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp63_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp61_, (GXmlDomNode*) _tmp62_, &_inner_error_);
#line 121 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp64_ = _tmp63_;
#line 121 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp64_);
#line 121 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 121 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 121 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 121 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 121 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 121 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 121 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 121 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 121 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 121 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 121 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1775 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 122 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp66_ = cp;
#line 122 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp67_ = r;
#line 122 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp65_ = gxml_css_selector_parser_match (_tmp66_, _tmp67_, &_inner_error_);
#line 122 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 122 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 122 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 122 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 122 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 122 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 122 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 122 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 122 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 122 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 122 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1806 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 122 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp65_, "!cp.match (r)");
#line 123 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp69_ = cp;
#line 123 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp70_ = c1;
#line 123 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp68_ = gxml_css_selector_parser_match (_tmp69_, _tmp70_, &_inner_error_);
#line 123 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 123 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 123 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 123 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 123 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 123 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 123 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 123 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 123 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 123 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 123 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1839 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 123 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp68_, "!cp.match (c1)");
#line 124 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp72_ = cp;
#line 124 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp73_ = c2;
#line 124 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp71_ = gxml_css_selector_parser_match (_tmp72_, _tmp73_, &_inner_error_);
#line 124 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 124 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 124 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 124 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 124 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 124 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 124 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 124 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 124 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 124 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 124 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1872 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 124 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp71_, "cp.match (c2)");
#line 125 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp75_ = cp;
#line 125 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp76_ = c3;
#line 125 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp74_ = gxml_css_selector_parser_match (_tmp75_, _tmp76_, &_inner_error_);
#line 125 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 125 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 125 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 125 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 125 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 125 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 125 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 125 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 125 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 125 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 125 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1905 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 125 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp74_, "cp.match (c3)");
#line 126 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp78_ = cp;
#line 126 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp79_ = c4;
#line 126 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp77_ = gxml_css_selector_parser_match (_tmp78_, _tmp79_, &_inner_error_);
#line 126 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 126 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 126 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 126 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 126 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 126 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 126 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 126 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 126 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 126 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 126 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1938 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 126 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp77_, "!cp.match (c4)");
#line 95 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 95 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 95 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 95 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 95 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 95 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 95 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 95 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (si);
#line 95 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 95 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 1963 "CssSelectorTest.c"
	}
	goto __finally3;
	__catch3_g_error:
	{
		GError* e = NULL;
		GError* _tmp80_;
		const gchar* _tmp81_;
		gchar* _tmp82_;
		gchar* _tmp83_;
#line 95 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		e = _inner_error_;
#line 95 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_inner_error_ = NULL;
#line 128 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp80_ = e;
#line 128 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp81_ = _tmp80_->message;
#line 128 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp82_ = g_strconcat ("ERROR: ", _tmp81_, NULL);
#line 128 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp83_ = _tmp82_;
#line 128 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:128: %s", _tmp83_);
#line 128 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_free0 (_tmp83_);
#line 95 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_error_free0 (e);
#line 1991 "CssSelectorTest.c"
	}
	__finally3:
#line 95 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 95 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 95 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_clear_error (&_inner_error_);
#line 95 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		return;
#line 2002 "CssSelectorTest.c"
	}
}


static void
___lambda287__gtest_func (void)
{
#line 94 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	__lambda287_ ();
#line 2012 "CssSelectorTest.c"
}


static void
__lambda288_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelectorData* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelectorData* _tmp11_;
		GXmlCssSelectorData* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelectorData* si = NULL;
		GXmlCssSelectorParser* _tmp15_;
		GeeList* _tmp16_;
		GeeList* _tmp17_;
		gpointer _tmp18_;
		GXmlCssSelectorData* _tmp19_;
		GXmlCssSelectorData* _tmp20_;
		GXmlCssSelectorType _tmp21_;
		GXmlCssSelectorType _tmp22_;
		GXmlCssSelectorData* sa = NULL;
		GXmlCssSelectorParser* _tmp23_;
		GeeList* _tmp24_;
		GeeList* _tmp25_;
		gpointer _tmp26_;
		GXmlCssSelectorData* _tmp27_;
		GXmlCssSelectorData* _tmp28_;
		GXmlCssSelectorType _tmp29_;
		GXmlCssSelectorType _tmp30_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp31_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlGomDocument* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomNode* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomNode* _tmp42_;
		GXmlDomNode* _tmp43_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp44_;
		GXmlDomElement* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomNode* _tmp49_;
		GXmlDomNode* _tmp50_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp51_;
		GXmlDomElement* _tmp52_;
		GXmlDomElement* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomNode* _tmp56_;
		GXmlDomNode* _tmp57_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp58_;
		GXmlDomElement* _tmp59_;
		GXmlDomElement* _tmp60_;
		GXmlDomElement* _tmp61_;
		GXmlDomElement* _tmp62_;
		GXmlDomNode* _tmp63_;
		GXmlDomNode* _tmp64_;
		gboolean _tmp65_ = FALSE;
		GXmlCssSelectorParser* _tmp66_;
		GXmlDomElement* _tmp67_;
		gboolean _tmp68_ = FALSE;
		GXmlCssSelectorParser* _tmp69_;
		GXmlDomElement* _tmp70_;
		gboolean _tmp71_ = FALSE;
		GXmlCssSelectorParser* _tmp72_;
		GXmlDomElement* _tmp73_;
		gboolean _tmp74_ = FALSE;
		GXmlCssSelectorParser* _tmp75_;
		GXmlDomElement* _tmp76_;
		gboolean _tmp77_ = FALSE;
		GXmlCssSelectorParser* _tmp78_;
		GXmlDomElement* _tmp79_;
#line 133 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 133 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		cp = _tmp0_;
#line 134 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp1_ = cp;
#line 134 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "child[prop-name^=\"val\"]", &_inner_error_);
#line 134 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 134 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2123 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 135 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp2_ = cp;
#line 135 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 135 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 135 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 135 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 135 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 3, "cp.selectors.size == 3");
#line 136 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp7_ = cp;
#line 136 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 136 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 136 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 136 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		s = (GXmlCssSelectorData*) _tmp10_;
#line 137 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp11_ = s;
#line 137 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 138 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp12_ = s;
#line 138 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_data_get_selector_type (_tmp12_);
#line 138 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 138 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 139 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp15_ = cp;
#line 139 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_parser_get_selectors (_tmp15_);
#line 139 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 139 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp18_ = gee_list_get (_tmp17_, 1);
#line 139 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		si = (GXmlCssSelectorData*) _tmp18_;
#line 140 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp19_ = si;
#line 140 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp19_ != NULL, "si != null");
#line 141 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp20_ = si;
#line 141 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp21_ = gxml_css_selector_data_get_selector_type (_tmp20_);
#line 141 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp22_ = _tmp21_;
#line 141 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp22_ == GXML_CSS_SELECTOR_TYPE_INSIDE, "si.selector_type == CssSelectorType.INSIDE");
#line 142 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp23_ = cp;
#line 142 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_parser_get_selectors (_tmp23_);
#line 142 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 142 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp26_ = gee_list_get (_tmp25_, 2);
#line 142 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		sa = (GXmlCssSelectorData*) _tmp26_;
#line 143 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp27_ = sa;
#line 143 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp27_ != NULL, "sa != null");
#line 144 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp28_ = sa;
#line 144 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp29_ = gxml_css_selector_data_get_selector_type (_tmp28_);
#line 144 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp30_ = _tmp29_;
#line 144 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp30_ == GXML_CSS_SELECTOR_TYPE_ATTRIBUTE_START_WITH, "sa.selector_type == CssSelectorType.ATTRIBUTE_START_WITH");
#line 145 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp31_ = gxml_gom_document_new ();
#line 145 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		d = _tmp31_;
#line 146 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp32_ = d;
#line 146 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp33_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp32_, "root", &_inner_error_);
#line 146 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		r = _tmp33_;
#line 146 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 146 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 146 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 146 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 146 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 146 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2226 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 147 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp34_ = d;
#line 147 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp35_ = r;
#line 147 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp36_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp34_, (GXmlDomNode*) _tmp35_, &_inner_error_);
#line 147 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp37_ = _tmp36_;
#line 147 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp37_);
#line 147 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 147 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 147 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 147 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 147 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 147 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 147 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2253 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 148 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp38_ = d;
#line 148 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp39_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp38_, "child", &_inner_error_);
#line 148 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c1 = _tmp39_;
#line 148 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 148 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 148 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 148 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 148 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 148 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 148 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2276 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 149 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp40_ = r;
#line 149 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp41_ = c1;
#line 149 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp42_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp40_, (GXmlDomNode*) _tmp41_, &_inner_error_);
#line 149 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp43_ = _tmp42_;
#line 149 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp43_);
#line 149 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 149 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 149 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 149 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 149 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 149 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 149 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 149 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2305 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 150 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp44_ = d;
#line 150 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp45_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp44_, "child", &_inner_error_);
#line 150 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c2 = _tmp45_;
#line 150 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 150 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 150 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 150 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 150 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 150 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 150 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 150 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2330 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 151 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp46_ = c2;
#line 151 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp46_, "prop-name", "val", &_inner_error_);
#line 151 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 151 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 151 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 151 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 151 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 151 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 151 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 151 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 151 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2355 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 152 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp47_ = r;
#line 152 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp48_ = c2;
#line 152 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp49_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp47_, (GXmlDomNode*) _tmp48_, &_inner_error_);
#line 152 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp50_ = _tmp49_;
#line 152 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp50_);
#line 152 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 152 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 152 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 152 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 152 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 152 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 152 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 152 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 152 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2386 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 153 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp51_ = d;
#line 153 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp52_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp51_, "child", &_inner_error_);
#line 153 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c3 = _tmp52_;
#line 153 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 153 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 153 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 153 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 153 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 153 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 153 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 153 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 153 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2413 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 154 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp53_ = c3;
#line 154 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp53_, "prop-name", "value", &_inner_error_);
#line 154 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 154 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 154 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 154 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 154 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 154 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 154 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 154 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 154 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 154 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2440 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 155 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp54_ = r;
#line 155 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp55_ = c3;
#line 155 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp56_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp54_, (GXmlDomNode*) _tmp55_, &_inner_error_);
#line 155 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp57_ = _tmp56_;
#line 155 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp57_);
#line 155 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 155 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 155 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 155 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 155 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 155 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 155 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 155 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 155 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 155 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2473 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 156 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp58_ = d;
#line 156 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp59_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp58_, "child", &_inner_error_);
#line 156 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c4 = _tmp59_;
#line 156 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 156 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 156 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 156 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 156 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 156 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 156 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 156 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 156 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 156 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2502 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 157 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp60_ = c4;
#line 157 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp60_, "prop-name", "secondaryvalue", &_inner_error_);
#line 157 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 157 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 157 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 157 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 157 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 157 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 157 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 157 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 157 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 157 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 157 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2531 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 158 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp61_ = r;
#line 158 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp62_ = c4;
#line 158 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp63_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp61_, (GXmlDomNode*) _tmp62_, &_inner_error_);
#line 158 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp64_ = _tmp63_;
#line 158 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp64_);
#line 158 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 158 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 158 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 158 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 158 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 158 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 158 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 158 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 158 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 158 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 158 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2566 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 159 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp66_ = cp;
#line 159 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp67_ = r;
#line 159 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp65_ = gxml_css_selector_parser_match (_tmp66_, _tmp67_, &_inner_error_);
#line 159 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 159 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 159 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 159 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 159 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 159 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 159 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 159 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 159 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 159 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 159 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2597 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 159 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp65_, "!cp.match (r)");
#line 160 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp69_ = cp;
#line 160 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp70_ = c1;
#line 160 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp68_ = gxml_css_selector_parser_match (_tmp69_, _tmp70_, &_inner_error_);
#line 160 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 160 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 160 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 160 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 160 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 160 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 160 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 160 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 160 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 160 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 160 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2630 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 160 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp68_, "!cp.match (c1)");
#line 161 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp72_ = cp;
#line 161 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp73_ = c2;
#line 161 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp71_ = gxml_css_selector_parser_match (_tmp72_, _tmp73_, &_inner_error_);
#line 161 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 161 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 161 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 161 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 161 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 161 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 161 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 161 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 161 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 161 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 161 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2663 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 161 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp71_, "cp.match (c2)");
#line 162 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp75_ = cp;
#line 162 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp76_ = c3;
#line 162 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp74_ = gxml_css_selector_parser_match (_tmp75_, _tmp76_, &_inner_error_);
#line 162 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 162 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 162 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 162 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 162 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 162 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 162 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 162 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 162 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 162 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 162 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2696 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 162 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp74_, "cp.match (c3)");
#line 163 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp78_ = cp;
#line 163 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp79_ = c4;
#line 163 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp77_ = gxml_css_selector_parser_match (_tmp78_, _tmp79_, &_inner_error_);
#line 163 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 163 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 163 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 163 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 163 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 163 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 163 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 163 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 163 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 163 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 163 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2729 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 163 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp77_, "!cp.match (c4)");
#line 132 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 132 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 132 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 132 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 132 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 132 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 132 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 132 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (si);
#line 132 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 132 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 2754 "CssSelectorTest.c"
	}
	goto __finally4;
	__catch4_g_error:
	{
		GError* e = NULL;
		GError* _tmp80_;
		const gchar* _tmp81_;
		gchar* _tmp82_;
		gchar* _tmp83_;
#line 132 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		e = _inner_error_;
#line 132 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_inner_error_ = NULL;
#line 165 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp80_ = e;
#line 165 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp81_ = _tmp80_->message;
#line 165 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp82_ = g_strconcat ("ERROR: ", _tmp81_, NULL);
#line 165 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp83_ = _tmp82_;
#line 165 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:165: %s", _tmp83_);
#line 165 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_free0 (_tmp83_);
#line 132 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_error_free0 (e);
#line 2782 "CssSelectorTest.c"
	}
	__finally4:
#line 132 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 132 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 132 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_clear_error (&_inner_error_);
#line 132 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		return;
#line 2793 "CssSelectorTest.c"
	}
}


static void
___lambda288__gtest_func (void)
{
#line 131 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	__lambda288_ ();
#line 2803 "CssSelectorTest.c"
}


static void
__lambda289_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelectorData* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelectorData* _tmp11_;
		GXmlCssSelectorData* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelectorData* si = NULL;
		GXmlCssSelectorParser* _tmp15_;
		GeeList* _tmp16_;
		GeeList* _tmp17_;
		gpointer _tmp18_;
		GXmlCssSelectorData* _tmp19_;
		GXmlCssSelectorData* _tmp20_;
		GXmlCssSelectorType _tmp21_;
		GXmlCssSelectorType _tmp22_;
		GXmlCssSelectorData* sa = NULL;
		GXmlCssSelectorParser* _tmp23_;
		GeeList* _tmp24_;
		GeeList* _tmp25_;
		gpointer _tmp26_;
		GXmlCssSelectorData* _tmp27_;
		GXmlCssSelectorData* _tmp28_;
		GXmlCssSelectorType _tmp29_;
		GXmlCssSelectorType _tmp30_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp31_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlGomDocument* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomNode* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomNode* _tmp42_;
		GXmlDomNode* _tmp43_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp44_;
		GXmlDomElement* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomNode* _tmp49_;
		GXmlDomNode* _tmp50_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp51_;
		GXmlDomElement* _tmp52_;
		GXmlDomElement* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomNode* _tmp56_;
		GXmlDomNode* _tmp57_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp58_;
		GXmlDomElement* _tmp59_;
		GXmlDomElement* _tmp60_;
		GXmlDomElement* _tmp61_;
		GXmlDomElement* _tmp62_;
		GXmlDomNode* _tmp63_;
		GXmlDomNode* _tmp64_;
		gboolean _tmp65_ = FALSE;
		GXmlCssSelectorParser* _tmp66_;
		GXmlDomElement* _tmp67_;
		gboolean _tmp68_ = FALSE;
		GXmlCssSelectorParser* _tmp69_;
		GXmlDomElement* _tmp70_;
		gboolean _tmp71_ = FALSE;
		GXmlCssSelectorParser* _tmp72_;
		GXmlDomElement* _tmp73_;
		gboolean _tmp74_ = FALSE;
		GXmlCssSelectorParser* _tmp75_;
		GXmlDomElement* _tmp76_;
		gboolean _tmp77_ = FALSE;
		GXmlCssSelectorParser* _tmp78_;
		GXmlDomElement* _tmp79_;
#line 170 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 170 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		cp = _tmp0_;
#line 171 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp1_ = cp;
#line 171 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "child[prop-name|=\"val\"]", &_inner_error_);
#line 171 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 171 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2914 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 172 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp2_ = cp;
#line 172 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 172 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 172 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 172 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 172 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 3, "cp.selectors.size == 3");
#line 173 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp7_ = cp;
#line 173 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 173 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 173 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 173 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		s = (GXmlCssSelectorData*) _tmp10_;
#line 174 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp11_ = s;
#line 174 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 175 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp12_ = s;
#line 175 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_data_get_selector_type (_tmp12_);
#line 175 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 175 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 176 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp15_ = cp;
#line 176 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_parser_get_selectors (_tmp15_);
#line 176 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 176 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp18_ = gee_list_get (_tmp17_, 1);
#line 176 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		si = (GXmlCssSelectorData*) _tmp18_;
#line 177 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp19_ = si;
#line 177 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp19_ != NULL, "si != null");
#line 178 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp20_ = si;
#line 178 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp21_ = gxml_css_selector_data_get_selector_type (_tmp20_);
#line 178 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp22_ = _tmp21_;
#line 178 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp22_ == GXML_CSS_SELECTOR_TYPE_INSIDE, "si.selector_type == CssSelectorType.INSIDE");
#line 179 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp23_ = cp;
#line 179 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_parser_get_selectors (_tmp23_);
#line 179 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 179 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp26_ = gee_list_get (_tmp25_, 2);
#line 179 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		sa = (GXmlCssSelectorData*) _tmp26_;
#line 180 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp27_ = sa;
#line 180 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp27_ != NULL, "sa != null");
#line 181 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp28_ = sa;
#line 181 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp29_ = gxml_css_selector_data_get_selector_type (_tmp28_);
#line 181 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp30_ = _tmp29_;
#line 181 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp30_ == GXML_CSS_SELECTOR_TYPE_ATTRIBUTE_START_WITH_HYPHEN, "sa.selector_type == CssSelectorType.ATTRIBUTE_START_WITH_HYPHEN");
#line 182 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp31_ = gxml_gom_document_new ();
#line 182 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		d = _tmp31_;
#line 183 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp32_ = d;
#line 183 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp33_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp32_, "root", &_inner_error_);
#line 183 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		r = _tmp33_;
#line 183 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 183 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 183 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 183 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 183 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 183 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3017 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 184 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp34_ = d;
#line 184 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp35_ = r;
#line 184 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp36_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp34_, (GXmlDomNode*) _tmp35_, &_inner_error_);
#line 184 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp37_ = _tmp36_;
#line 184 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp37_);
#line 184 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 184 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 184 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 184 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 184 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 184 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 184 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3044 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 185 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp38_ = d;
#line 185 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp39_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp38_, "child", &_inner_error_);
#line 185 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c1 = _tmp39_;
#line 185 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 185 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 185 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 185 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 185 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 185 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 185 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3067 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 186 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp40_ = r;
#line 186 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp41_ = c1;
#line 186 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp42_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp40_, (GXmlDomNode*) _tmp41_, &_inner_error_);
#line 186 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp43_ = _tmp42_;
#line 186 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp43_);
#line 186 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 186 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 186 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 186 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 186 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 186 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 186 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 186 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3096 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 187 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp44_ = d;
#line 187 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp45_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp44_, "child", &_inner_error_);
#line 187 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c2 = _tmp45_;
#line 187 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 187 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 187 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 187 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 187 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 187 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 187 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 187 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3121 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 188 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp46_ = c2;
#line 188 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp46_, "prop-name", "val-", &_inner_error_);
#line 188 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 188 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 188 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 188 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 188 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 188 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 188 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 188 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 188 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3146 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 189 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp47_ = r;
#line 189 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp48_ = c2;
#line 189 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp49_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp47_, (GXmlDomNode*) _tmp48_, &_inner_error_);
#line 189 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp50_ = _tmp49_;
#line 189 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp50_);
#line 189 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 189 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 189 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 189 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 189 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 189 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 189 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 189 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 189 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3177 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 190 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp51_ = d;
#line 190 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp52_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp51_, "child", &_inner_error_);
#line 190 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c3 = _tmp52_;
#line 190 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 190 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 190 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 190 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 190 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 190 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 190 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 190 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 190 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3204 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 191 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp53_ = c3;
#line 191 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp53_, "prop-name", "value", &_inner_error_);
#line 191 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 191 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 191 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 191 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 191 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 191 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 191 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 191 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 191 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 191 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3231 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 192 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp54_ = r;
#line 192 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp55_ = c3;
#line 192 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp56_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp54_, (GXmlDomNode*) _tmp55_, &_inner_error_);
#line 192 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp57_ = _tmp56_;
#line 192 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp57_);
#line 192 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 192 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 192 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 192 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 192 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 192 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 192 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 192 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 192 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 192 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3264 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 193 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp58_ = d;
#line 193 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp59_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp58_, "child", &_inner_error_);
#line 193 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c4 = _tmp59_;
#line 193 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 193 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 193 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 193 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 193 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 193 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 193 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 193 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 193 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 193 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3293 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 194 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp60_ = c4;
#line 194 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp60_, "prop-name", "secondaryvalue", &_inner_error_);
#line 194 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 194 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 194 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 194 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 194 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 194 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 194 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 194 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 194 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 194 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 194 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3322 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 195 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp61_ = r;
#line 195 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp62_ = c4;
#line 195 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp63_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp61_, (GXmlDomNode*) _tmp62_, &_inner_error_);
#line 195 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp64_ = _tmp63_;
#line 195 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp64_);
#line 195 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 195 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 195 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 195 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 195 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 195 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 195 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 195 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 195 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 195 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 195 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3357 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 196 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp66_ = cp;
#line 196 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp67_ = r;
#line 196 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp65_ = gxml_css_selector_parser_match (_tmp66_, _tmp67_, &_inner_error_);
#line 196 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 196 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 196 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 196 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 196 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 196 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 196 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 196 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 196 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 196 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 196 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3388 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 196 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp65_, "!cp.match (r)");
#line 197 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp69_ = cp;
#line 197 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp70_ = c1;
#line 197 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp68_ = gxml_css_selector_parser_match (_tmp69_, _tmp70_, &_inner_error_);
#line 197 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 197 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 197 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 197 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 197 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 197 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 197 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 197 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 197 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 197 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 197 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3421 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 197 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp68_, "!cp.match (c1)");
#line 198 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp72_ = cp;
#line 198 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp73_ = c2;
#line 198 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp71_ = gxml_css_selector_parser_match (_tmp72_, _tmp73_, &_inner_error_);
#line 198 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 198 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 198 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 198 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 198 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 198 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 198 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 198 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 198 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 198 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 198 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3454 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 198 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp71_, "cp.match (c2)");
#line 199 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp75_ = cp;
#line 199 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp76_ = c3;
#line 199 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp74_ = gxml_css_selector_parser_match (_tmp75_, _tmp76_, &_inner_error_);
#line 199 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 199 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 199 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 199 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 199 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 199 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 199 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 199 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 199 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 199 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 199 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3487 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 199 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp74_, "!cp.match (c3)");
#line 200 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp78_ = cp;
#line 200 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp79_ = c4;
#line 200 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp77_ = gxml_css_selector_parser_match (_tmp78_, _tmp79_, &_inner_error_);
#line 200 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 200 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 200 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 200 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 200 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 200 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 200 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 200 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 200 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 200 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 200 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3520 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 200 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp77_, "!cp.match (c4)");
#line 169 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 169 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 169 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 169 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 169 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 169 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 169 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 169 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (si);
#line 169 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 169 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 3545 "CssSelectorTest.c"
	}
	goto __finally5;
	__catch5_g_error:
	{
		GError* e = NULL;
		GError* _tmp80_;
		const gchar* _tmp81_;
		gchar* _tmp82_;
		gchar* _tmp83_;
#line 169 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		e = _inner_error_;
#line 169 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_inner_error_ = NULL;
#line 202 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp80_ = e;
#line 202 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp81_ = _tmp80_->message;
#line 202 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp82_ = g_strconcat ("ERROR: ", _tmp81_, NULL);
#line 202 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp83_ = _tmp82_;
#line 202 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:202: %s", _tmp83_);
#line 202 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_free0 (_tmp83_);
#line 169 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_error_free0 (e);
#line 3573 "CssSelectorTest.c"
	}
	__finally5:
#line 169 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 169 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 169 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_clear_error (&_inner_error_);
#line 169 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		return;
#line 3584 "CssSelectorTest.c"
	}
}


static void
___lambda289__gtest_func (void)
{
#line 168 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	__lambda289_ ();
#line 3594 "CssSelectorTest.c"
}


static void
__lambda290_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelectorData* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelectorData* _tmp11_;
		GXmlCssSelectorData* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelectorData* si = NULL;
		GXmlCssSelectorParser* _tmp15_;
		GeeList* _tmp16_;
		GeeList* _tmp17_;
		gpointer _tmp18_;
		GXmlCssSelectorData* _tmp19_;
		GXmlCssSelectorData* _tmp20_;
		GXmlCssSelectorType _tmp21_;
		GXmlCssSelectorType _tmp22_;
		GXmlCssSelectorData* sa = NULL;
		GXmlCssSelectorParser* _tmp23_;
		GeeList* _tmp24_;
		GeeList* _tmp25_;
		gpointer _tmp26_;
		GXmlCssSelectorData* _tmp27_;
		GXmlCssSelectorData* _tmp28_;
		GXmlCssSelectorType _tmp29_;
		GXmlCssSelectorType _tmp30_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp31_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlGomDocument* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomNode* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomNode* _tmp42_;
		GXmlDomNode* _tmp43_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp44_;
		GXmlDomElement* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomNode* _tmp49_;
		GXmlDomNode* _tmp50_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp51_;
		GXmlDomElement* _tmp52_;
		GXmlDomElement* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomNode* _tmp56_;
		GXmlDomNode* _tmp57_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp58_;
		GXmlDomElement* _tmp59_;
		GXmlDomElement* _tmp60_;
		GXmlDomElement* _tmp61_;
		GXmlDomElement* _tmp62_;
		GXmlDomNode* _tmp63_;
		GXmlDomNode* _tmp64_;
		gboolean _tmp65_ = FALSE;
		GXmlCssSelectorParser* _tmp66_;
		GXmlDomElement* _tmp67_;
		gboolean _tmp68_ = FALSE;
		GXmlCssSelectorParser* _tmp69_;
		GXmlDomElement* _tmp70_;
		gboolean _tmp71_ = FALSE;
		GXmlCssSelectorParser* _tmp72_;
		GXmlDomElement* _tmp73_;
		gboolean _tmp74_ = FALSE;
		GXmlCssSelectorParser* _tmp75_;
		GXmlDomElement* _tmp76_;
		gboolean _tmp77_ = FALSE;
		GXmlCssSelectorParser* _tmp78_;
		GXmlDomElement* _tmp79_;
#line 207 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 207 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		cp = _tmp0_;
#line 208 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp1_ = cp;
#line 208 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "child[prop-name$=\"val\"]", &_inner_error_);
#line 208 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 208 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3705 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 209 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp2_ = cp;
#line 209 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 209 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 209 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 209 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 209 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 3, "cp.selectors.size == 3");
#line 210 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp7_ = cp;
#line 210 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 210 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 210 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 210 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		s = (GXmlCssSelectorData*) _tmp10_;
#line 211 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp11_ = s;
#line 211 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 212 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp12_ = s;
#line 212 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_data_get_selector_type (_tmp12_);
#line 212 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 212 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 213 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp15_ = cp;
#line 213 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_parser_get_selectors (_tmp15_);
#line 213 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 213 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp18_ = gee_list_get (_tmp17_, 1);
#line 213 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		si = (GXmlCssSelectorData*) _tmp18_;
#line 214 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp19_ = si;
#line 214 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp19_ != NULL, "si != null");
#line 215 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp20_ = si;
#line 215 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp21_ = gxml_css_selector_data_get_selector_type (_tmp20_);
#line 215 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp22_ = _tmp21_;
#line 215 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp22_ == GXML_CSS_SELECTOR_TYPE_INSIDE, "si.selector_type == CssSelectorType.INSIDE");
#line 216 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp23_ = cp;
#line 216 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_parser_get_selectors (_tmp23_);
#line 216 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 216 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp26_ = gee_list_get (_tmp25_, 2);
#line 216 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		sa = (GXmlCssSelectorData*) _tmp26_;
#line 217 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp27_ = sa;
#line 217 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp27_ != NULL, "sa != null");
#line 218 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp28_ = sa;
#line 218 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp29_ = gxml_css_selector_data_get_selector_type (_tmp28_);
#line 218 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp30_ = _tmp29_;
#line 218 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp30_ == GXML_CSS_SELECTOR_TYPE_ATTRIBUTE_END_WITH, "sa.selector_type == CssSelectorType.ATTRIBUTE_END_WITH");
#line 219 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp31_ = gxml_gom_document_new ();
#line 219 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		d = _tmp31_;
#line 220 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp32_ = d;
#line 220 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp33_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp32_, "root", &_inner_error_);
#line 220 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		r = _tmp33_;
#line 220 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 220 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 220 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 220 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 220 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 220 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3808 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 221 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp34_ = d;
#line 221 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp35_ = r;
#line 221 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp36_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp34_, (GXmlDomNode*) _tmp35_, &_inner_error_);
#line 221 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp37_ = _tmp36_;
#line 221 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp37_);
#line 221 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 221 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 221 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 221 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 221 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 221 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 221 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3835 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 222 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp38_ = d;
#line 222 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp39_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp38_, "child", &_inner_error_);
#line 222 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c1 = _tmp39_;
#line 222 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 222 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 222 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 222 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 222 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 222 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 222 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3858 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 223 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp40_ = r;
#line 223 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp41_ = c1;
#line 223 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp42_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp40_, (GXmlDomNode*) _tmp41_, &_inner_error_);
#line 223 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp43_ = _tmp42_;
#line 223 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp43_);
#line 223 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 223 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 223 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 223 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 223 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 223 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 223 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 223 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3887 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 224 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp44_ = d;
#line 224 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp45_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp44_, "child", &_inner_error_);
#line 224 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c2 = _tmp45_;
#line 224 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 224 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 224 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 224 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 224 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 224 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 224 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 224 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3912 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 225 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp46_ = c2;
#line 225 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp46_, "prop-name", "subval", &_inner_error_);
#line 225 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 225 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 225 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 225 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 225 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 225 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 225 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 225 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 225 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3937 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 226 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp47_ = r;
#line 226 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp48_ = c2;
#line 226 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp49_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp47_, (GXmlDomNode*) _tmp48_, &_inner_error_);
#line 226 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp50_ = _tmp49_;
#line 226 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp50_);
#line 226 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 226 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 226 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 226 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 226 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 226 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 226 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 226 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 226 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3968 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 227 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp51_ = d;
#line 227 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp52_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp51_, "child", &_inner_error_);
#line 227 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c3 = _tmp52_;
#line 227 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 227 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 227 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 227 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 227 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 227 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 227 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 227 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 227 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3995 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 228 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp53_ = c3;
#line 228 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp53_, "prop-name", "techval", &_inner_error_);
#line 228 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 228 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 228 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 228 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 228 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 228 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 228 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 228 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 228 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 228 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4022 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 229 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp54_ = r;
#line 229 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp55_ = c3;
#line 229 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp56_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp54_, (GXmlDomNode*) _tmp55_, &_inner_error_);
#line 229 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp57_ = _tmp56_;
#line 229 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp57_);
#line 229 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 229 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 229 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 229 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 229 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 229 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 229 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 229 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 229 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 229 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4055 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 230 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp58_ = d;
#line 230 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp59_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp58_, "child", &_inner_error_);
#line 230 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c4 = _tmp59_;
#line 230 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 230 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 230 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 230 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 230 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 230 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 230 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 230 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 230 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 230 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4084 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 231 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp60_ = c4;
#line 231 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp60_, "prop-name", "secondaryvalue", &_inner_error_);
#line 231 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 231 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 231 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 231 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 231 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 231 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 231 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 231 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 231 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 231 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 231 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4113 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 232 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp61_ = r;
#line 232 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp62_ = c4;
#line 232 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp63_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp61_, (GXmlDomNode*) _tmp62_, &_inner_error_);
#line 232 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp64_ = _tmp63_;
#line 232 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp64_);
#line 232 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 232 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 232 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 232 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 232 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 232 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 232 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 232 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 232 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 232 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 232 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4148 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 233 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp66_ = cp;
#line 233 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp67_ = r;
#line 233 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp65_ = gxml_css_selector_parser_match (_tmp66_, _tmp67_, &_inner_error_);
#line 233 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 233 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 233 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 233 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 233 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 233 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 233 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 233 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 233 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 233 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 233 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4179 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 233 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp65_, "!cp.match (r)");
#line 234 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp69_ = cp;
#line 234 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp70_ = c1;
#line 234 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp68_ = gxml_css_selector_parser_match (_tmp69_, _tmp70_, &_inner_error_);
#line 234 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 234 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 234 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 234 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 234 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 234 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 234 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 234 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 234 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 234 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 234 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4212 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 234 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp68_, "!cp.match (c1)");
#line 235 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp72_ = cp;
#line 235 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp73_ = c2;
#line 235 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp71_ = gxml_css_selector_parser_match (_tmp72_, _tmp73_, &_inner_error_);
#line 235 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 235 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 235 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 235 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 235 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 235 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 235 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 235 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 235 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 235 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 235 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4245 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 235 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp71_, "cp.match (c2)");
#line 236 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp75_ = cp;
#line 236 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp76_ = c3;
#line 236 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp74_ = gxml_css_selector_parser_match (_tmp75_, _tmp76_, &_inner_error_);
#line 236 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 236 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 236 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 236 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 236 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 236 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 236 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 236 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 236 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 236 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 236 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4278 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 236 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp74_, "cp.match (c3)");
#line 237 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp78_ = cp;
#line 237 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp79_ = c4;
#line 237 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp77_ = gxml_css_selector_parser_match (_tmp78_, _tmp79_, &_inner_error_);
#line 237 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 237 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 237 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 237 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 237 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 237 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 237 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 237 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 237 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 237 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 237 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4311 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 237 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp77_, "!cp.match (c4)");
#line 206 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 206 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 206 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 206 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 206 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 206 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 206 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 206 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (si);
#line 206 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 206 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 4336 "CssSelectorTest.c"
	}
	goto __finally6;
	__catch6_g_error:
	{
		GError* e = NULL;
		GError* _tmp80_;
		const gchar* _tmp81_;
		gchar* _tmp82_;
		gchar* _tmp83_;
#line 206 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		e = _inner_error_;
#line 206 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_inner_error_ = NULL;
#line 239 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp80_ = e;
#line 239 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp81_ = _tmp80_->message;
#line 239 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp82_ = g_strconcat ("ERROR: ", _tmp81_, NULL);
#line 239 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp83_ = _tmp82_;
#line 239 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:239: %s", _tmp83_);
#line 239 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_free0 (_tmp83_);
#line 206 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_error_free0 (e);
#line 4364 "CssSelectorTest.c"
	}
	__finally6:
#line 206 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 206 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 206 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_clear_error (&_inner_error_);
#line 206 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		return;
#line 4375 "CssSelectorTest.c"
	}
}


static void
___lambda290__gtest_func (void)
{
#line 205 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	__lambda290_ ();
#line 4385 "CssSelectorTest.c"
}


static void
__lambda291_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelectorData* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelectorData* _tmp11_;
		GXmlCssSelectorData* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelectorData* si = NULL;
		GXmlCssSelectorParser* _tmp15_;
		GeeList* _tmp16_;
		GeeList* _tmp17_;
		gpointer _tmp18_;
		GXmlCssSelectorData* _tmp19_;
		GXmlCssSelectorData* _tmp20_;
		GXmlCssSelectorType _tmp21_;
		GXmlCssSelectorType _tmp22_;
		GXmlCssSelectorData* sa = NULL;
		GXmlCssSelectorParser* _tmp23_;
		GeeList* _tmp24_;
		GeeList* _tmp25_;
		gpointer _tmp26_;
		GXmlCssSelectorData* _tmp27_;
		GXmlCssSelectorData* _tmp28_;
		GXmlCssSelectorType _tmp29_;
		GXmlCssSelectorType _tmp30_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp31_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlGomDocument* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomNode* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomNode* _tmp42_;
		GXmlDomNode* _tmp43_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp44_;
		GXmlDomElement* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomElement* _tmp51_;
		GXmlDomNode* _tmp52_;
		GXmlDomNode* _tmp53_;
		gboolean _tmp54_ = FALSE;
		GXmlCssSelectorParser* _tmp55_;
		GXmlDomElement* _tmp56_;
		gboolean _tmp57_ = FALSE;
		GXmlCssSelectorParser* _tmp58_;
		GXmlDomElement* _tmp59_;
		gboolean _tmp60_ = FALSE;
		GXmlCssSelectorParser* _tmp61_;
		GXmlDomElement* _tmp62_;
		gboolean _tmp63_ = FALSE;
		GXmlCssSelectorParser* _tmp64_;
		GXmlDomElement* _tmp65_;
#line 244 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 244 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		cp = _tmp0_;
#line 245 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp1_ = cp;
#line 245 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "child[prop-name=va7u3_unqu§ted]", &_inner_error_);
#line 245 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 245 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4481 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 246 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp2_ = cp;
#line 246 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 246 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 246 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 246 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 246 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 3, "cp.selectors.size == 3");
#line 247 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp7_ = cp;
#line 247 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 247 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 247 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 247 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		s = (GXmlCssSelectorData*) _tmp10_;
#line 248 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp11_ = s;
#line 248 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 249 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp12_ = s;
#line 249 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_data_get_selector_type (_tmp12_);
#line 249 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 249 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 250 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp15_ = cp;
#line 250 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_parser_get_selectors (_tmp15_);
#line 250 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 250 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp18_ = gee_list_get (_tmp17_, 1);
#line 250 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		si = (GXmlCssSelectorData*) _tmp18_;
#line 251 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp19_ = si;
#line 251 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp19_ != NULL, "si != null");
#line 252 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp20_ = si;
#line 252 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp21_ = gxml_css_selector_data_get_selector_type (_tmp20_);
#line 252 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp22_ = _tmp21_;
#line 252 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp22_ == GXML_CSS_SELECTOR_TYPE_INSIDE, "si.selector_type == CssSelectorType.INSIDE");
#line 253 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp23_ = cp;
#line 253 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_parser_get_selectors (_tmp23_);
#line 253 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 253 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp26_ = gee_list_get (_tmp25_, 2);
#line 253 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		sa = (GXmlCssSelectorData*) _tmp26_;
#line 254 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp27_ = sa;
#line 254 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp27_ != NULL, "sa != null");
#line 255 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp28_ = sa;
#line 255 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp29_ = gxml_css_selector_data_get_selector_type (_tmp28_);
#line 255 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp30_ = _tmp29_;
#line 255 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp30_ == GXML_CSS_SELECTOR_TYPE_ATTRIBUTE_EQUAL, "sa.selector_type == CssSelectorType.ATTRIBUTE_EQUAL");
#line 256 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp31_ = gxml_gom_document_new ();
#line 256 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		d = _tmp31_;
#line 257 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp32_ = d;
#line 257 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp33_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp32_, "root", &_inner_error_);
#line 257 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		r = _tmp33_;
#line 257 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 257 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 257 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 257 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 257 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 257 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4584 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 258 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp34_ = d;
#line 258 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp35_ = r;
#line 258 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp36_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp34_, (GXmlDomNode*) _tmp35_, &_inner_error_);
#line 258 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp37_ = _tmp36_;
#line 258 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp37_);
#line 258 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 258 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 258 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 258 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 258 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 258 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 258 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4611 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 259 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp38_ = d;
#line 259 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp39_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp38_, "child", &_inner_error_);
#line 259 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c1 = _tmp39_;
#line 259 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 259 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 259 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 259 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 259 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 259 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 259 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4634 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 260 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp40_ = r;
#line 260 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp41_ = c1;
#line 260 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp42_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp40_, (GXmlDomNode*) _tmp41_, &_inner_error_);
#line 260 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp43_ = _tmp42_;
#line 260 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp43_);
#line 260 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 260 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 260 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 260 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 260 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 260 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 260 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 260 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4663 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 261 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp44_ = d;
#line 261 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp45_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp44_, "child", &_inner_error_);
#line 261 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c2 = _tmp45_;
#line 261 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 261 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 261 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 261 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 261 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 261 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 261 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 261 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4688 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 262 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp46_ = c2;
#line 262 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp46_, "prop-name", "t", &_inner_error_);
#line 262 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 262 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 262 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 262 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 262 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 262 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 262 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 262 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 262 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4713 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 263 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp47_ = d;
#line 263 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp48_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp47_, "child", &_inner_error_);
#line 263 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c3 = _tmp48_;
#line 263 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 263 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 263 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 263 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 263 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 263 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 263 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 263 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 263 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4740 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 264 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp49_ = c3;
#line 264 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp49_, "prop-name", "va7u3_unqu§ted", &_inner_error_);
#line 264 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 264 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 264 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 264 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 264 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 264 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 264 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 264 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 264 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 264 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4767 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 265 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp50_ = r;
#line 265 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp51_ = c3;
#line 265 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp52_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp50_, (GXmlDomNode*) _tmp51_, &_inner_error_);
#line 265 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp53_ = _tmp52_;
#line 265 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp53_);
#line 265 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 265 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 265 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 265 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 265 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 265 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 265 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 265 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 265 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 265 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4800 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 266 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp55_ = cp;
#line 266 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp56_ = r;
#line 266 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp54_ = gxml_css_selector_parser_match (_tmp55_, _tmp56_, &_inner_error_);
#line 266 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 266 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 266 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 266 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 266 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 266 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 266 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 266 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 266 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 266 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4829 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 266 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp54_, "!cp.match (r)");
#line 267 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp58_ = cp;
#line 267 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp59_ = c1;
#line 267 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp57_ = gxml_css_selector_parser_match (_tmp58_, _tmp59_, &_inner_error_);
#line 267 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 267 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 267 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 267 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 267 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 267 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 267 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 267 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 267 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 267 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4860 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 267 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp57_, "!cp.match (c1)");
#line 268 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp61_ = cp;
#line 268 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp62_ = c2;
#line 268 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp60_ = gxml_css_selector_parser_match (_tmp61_, _tmp62_, &_inner_error_);
#line 268 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 268 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 268 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 268 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 268 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 268 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 268 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 268 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 268 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 268 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4891 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 268 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp60_, "!cp.match (c2)");
#line 269 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp64_ = cp;
#line 269 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp65_ = c3;
#line 269 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp63_ = gxml_css_selector_parser_match (_tmp64_, _tmp65_, &_inner_error_);
#line 269 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 269 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 269 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 269 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 269 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 269 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 269 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 269 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 269 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 269 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4922 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 269 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp63_, "cp.match (c3)");
#line 243 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 243 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 243 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 243 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 243 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 243 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 243 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (si);
#line 243 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 243 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 4945 "CssSelectorTest.c"
	}
	goto __finally7;
	__catch7_g_error:
	{
		GError* e = NULL;
		GError* _tmp66_;
		const gchar* _tmp67_;
		gchar* _tmp68_;
		gchar* _tmp69_;
#line 243 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		e = _inner_error_;
#line 243 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_inner_error_ = NULL;
#line 271 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp66_ = e;
#line 271 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp67_ = _tmp66_->message;
#line 271 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp68_ = g_strconcat ("ERROR: ", _tmp67_, NULL);
#line 271 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp69_ = _tmp68_;
#line 271 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:271: %s", _tmp69_);
#line 271 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_free0 (_tmp69_);
#line 243 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_error_free0 (e);
#line 4973 "CssSelectorTest.c"
	}
	__finally7:
#line 243 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 243 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 243 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_clear_error (&_inner_error_);
#line 243 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		return;
#line 4984 "CssSelectorTest.c"
	}
}


static void
___lambda291__gtest_func (void)
{
#line 242 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	__lambda291_ ();
#line 4994 "CssSelectorTest.c"
}


static void
__lambda292_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelectorData* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelectorData* _tmp11_;
		GXmlCssSelectorData* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelectorData* si = NULL;
		GXmlCssSelectorParser* _tmp15_;
		GeeList* _tmp16_;
		GeeList* _tmp17_;
		gpointer _tmp18_;
		GXmlCssSelectorData* _tmp19_;
		GXmlCssSelectorData* _tmp20_;
		GXmlCssSelectorType _tmp21_;
		GXmlCssSelectorType _tmp22_;
		GXmlCssSelectorData* sa = NULL;
		GXmlCssSelectorParser* _tmp23_;
		GeeList* _tmp24_;
		GeeList* _tmp25_;
		gpointer _tmp26_;
		GXmlCssSelectorData* _tmp27_;
		GXmlCssSelectorData* _tmp28_;
		GXmlCssSelectorType _tmp29_;
		GXmlCssSelectorType _tmp30_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp31_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlGomDocument* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomNode* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomNode* _tmp42_;
		GXmlDomNode* _tmp43_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp44_;
		GXmlDomElement* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomElement* _tmp51_;
		GXmlDomNode* _tmp52_;
		GXmlDomNode* _tmp53_;
		gboolean _tmp54_ = FALSE;
		GXmlCssSelectorParser* _tmp55_;
		GXmlDomElement* _tmp56_;
		gboolean _tmp57_ = FALSE;
		GXmlCssSelectorParser* _tmp58_;
		GXmlDomElement* _tmp59_;
		gboolean _tmp60_ = FALSE;
		GXmlCssSelectorParser* _tmp61_;
		GXmlDomElement* _tmp62_;
		gboolean _tmp63_ = FALSE;
		GXmlCssSelectorParser* _tmp64_;
		GXmlDomElement* _tmp65_;
#line 276 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 276 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		cp = _tmp0_;
#line 277 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp1_ = cp;
#line 277 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "child[prop-name=\"val\"]", &_inner_error_);
#line 277 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 277 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5090 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 278 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp2_ = cp;
#line 278 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 278 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 278 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 278 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 278 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 3, "cp.selectors.size == 3");
#line 279 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp7_ = cp;
#line 279 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 279 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 279 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 279 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		s = (GXmlCssSelectorData*) _tmp10_;
#line 280 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp11_ = s;
#line 280 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 281 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp12_ = s;
#line 281 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_data_get_selector_type (_tmp12_);
#line 281 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 281 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 282 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp15_ = cp;
#line 282 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_parser_get_selectors (_tmp15_);
#line 282 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 282 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp18_ = gee_list_get (_tmp17_, 1);
#line 282 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		si = (GXmlCssSelectorData*) _tmp18_;
#line 283 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp19_ = si;
#line 283 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp19_ != NULL, "si != null");
#line 284 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp20_ = si;
#line 284 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp21_ = gxml_css_selector_data_get_selector_type (_tmp20_);
#line 284 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp22_ = _tmp21_;
#line 284 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp22_ == GXML_CSS_SELECTOR_TYPE_INSIDE, "si.selector_type == CssSelectorType.INSIDE");
#line 285 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp23_ = cp;
#line 285 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_parser_get_selectors (_tmp23_);
#line 285 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 285 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp26_ = gee_list_get (_tmp25_, 2);
#line 285 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		sa = (GXmlCssSelectorData*) _tmp26_;
#line 286 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp27_ = sa;
#line 286 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp27_ != NULL, "sa != null");
#line 287 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp28_ = sa;
#line 287 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp29_ = gxml_css_selector_data_get_selector_type (_tmp28_);
#line 287 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp30_ = _tmp29_;
#line 287 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp30_ == GXML_CSS_SELECTOR_TYPE_ATTRIBUTE_EQUAL, "sa.selector_type == CssSelectorType.ATTRIBUTE_EQUAL");
#line 288 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp31_ = gxml_gom_document_new ();
#line 288 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		d = _tmp31_;
#line 289 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp32_ = d;
#line 289 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp33_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp32_, "root", &_inner_error_);
#line 289 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		r = _tmp33_;
#line 289 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 289 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 289 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 289 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 289 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 289 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5193 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 290 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp34_ = d;
#line 290 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp35_ = r;
#line 290 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp36_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp34_, (GXmlDomNode*) _tmp35_, &_inner_error_);
#line 290 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp37_ = _tmp36_;
#line 290 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp37_);
#line 290 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 290 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 290 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 290 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 290 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 290 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 290 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5220 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 291 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp38_ = d;
#line 291 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp39_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp38_, "child", &_inner_error_);
#line 291 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c1 = _tmp39_;
#line 291 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 291 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 291 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 291 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 291 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 291 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 291 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5243 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 292 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp40_ = r;
#line 292 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp41_ = c1;
#line 292 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp42_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp40_, (GXmlDomNode*) _tmp41_, &_inner_error_);
#line 292 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp43_ = _tmp42_;
#line 292 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp43_);
#line 292 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 292 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 292 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 292 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 292 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 292 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 292 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 292 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5272 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 293 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp44_ = d;
#line 293 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp45_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp44_, "child", &_inner_error_);
#line 293 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c2 = _tmp45_;
#line 293 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 293 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 293 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 293 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 293 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 293 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 293 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 293 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5297 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 294 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp46_ = c2;
#line 294 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp46_, "prop-name", "t", &_inner_error_);
#line 294 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 294 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 294 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 294 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 294 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 294 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 294 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 294 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 294 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5322 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 295 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp47_ = d;
#line 295 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp48_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp47_, "child", &_inner_error_);
#line 295 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c3 = _tmp48_;
#line 295 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 295 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 295 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 295 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 295 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 295 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 295 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 295 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 295 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5349 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 296 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp49_ = c3;
#line 296 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp49_, "prop-name", "val", &_inner_error_);
#line 296 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 296 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 296 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 296 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 296 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 296 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 296 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 296 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 296 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 296 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5376 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 297 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp50_ = r;
#line 297 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp51_ = c3;
#line 297 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp52_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp50_, (GXmlDomNode*) _tmp51_, &_inner_error_);
#line 297 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp53_ = _tmp52_;
#line 297 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp53_);
#line 297 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 297 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 297 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 297 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 297 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 297 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 297 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 297 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 297 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 297 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5409 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 298 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp55_ = cp;
#line 298 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp56_ = r;
#line 298 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp54_ = gxml_css_selector_parser_match (_tmp55_, _tmp56_, &_inner_error_);
#line 298 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 298 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 298 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 298 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 298 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 298 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 298 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 298 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 298 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 298 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5438 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 298 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp54_, "!cp.match (r)");
#line 299 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp58_ = cp;
#line 299 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp59_ = c1;
#line 299 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp57_ = gxml_css_selector_parser_match (_tmp58_, _tmp59_, &_inner_error_);
#line 299 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 299 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 299 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 299 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 299 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 299 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 299 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 299 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 299 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 299 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5469 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 299 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp57_, "!cp.match (c1)");
#line 300 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp61_ = cp;
#line 300 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp62_ = c2;
#line 300 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp60_ = gxml_css_selector_parser_match (_tmp61_, _tmp62_, &_inner_error_);
#line 300 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 300 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 300 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 300 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 300 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 300 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 300 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 300 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 300 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 300 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5500 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 300 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp60_, "!cp.match (c2)");
#line 301 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp64_ = cp;
#line 301 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp65_ = c3;
#line 301 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp63_ = gxml_css_selector_parser_match (_tmp64_, _tmp65_, &_inner_error_);
#line 301 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 301 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 301 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 301 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 301 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 301 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 301 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 301 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 301 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 301 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5531 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 301 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp63_, "cp.match (c3)");
#line 275 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 275 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 275 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 275 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 275 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 275 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 275 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (si);
#line 275 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 275 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 5554 "CssSelectorTest.c"
	}
	goto __finally8;
	__catch8_g_error:
	{
		GError* e = NULL;
		GError* _tmp66_;
		const gchar* _tmp67_;
		gchar* _tmp68_;
		gchar* _tmp69_;
#line 275 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		e = _inner_error_;
#line 275 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_inner_error_ = NULL;
#line 303 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp66_ = e;
#line 303 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp67_ = _tmp66_->message;
#line 303 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp68_ = g_strconcat ("ERROR: ", _tmp67_, NULL);
#line 303 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp69_ = _tmp68_;
#line 303 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:303: %s", _tmp69_);
#line 303 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_free0 (_tmp69_);
#line 275 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_error_free0 (e);
#line 5582 "CssSelectorTest.c"
	}
	__finally8:
#line 275 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 275 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 275 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_clear_error (&_inner_error_);
#line 275 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		return;
#line 5593 "CssSelectorTest.c"
	}
}


static void
___lambda292__gtest_func (void)
{
#line 274 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	__lambda292_ ();
#line 5603 "CssSelectorTest.c"
}


static void
__lambda293_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelectorData* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelectorData* _tmp11_;
		GXmlCssSelectorData* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelectorData* si = NULL;
		GXmlCssSelectorParser* _tmp15_;
		GeeList* _tmp16_;
		GeeList* _tmp17_;
		gpointer _tmp18_;
		GXmlCssSelectorData* _tmp19_;
		GXmlCssSelectorData* _tmp20_;
		GXmlCssSelectorType _tmp21_;
		GXmlCssSelectorType _tmp22_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp23_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlGomDocument* _tmp26_;
		GXmlDomElement* _tmp27_;
		GXmlDomNode* _tmp28_;
		GXmlDomNode* _tmp29_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp30_;
		GXmlDomElement* _tmp31_;
		GXmlDomElement* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlDomElement* _tmp34_;
		GXmlDomNode* _tmp35_;
		GXmlDomNode* _tmp36_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp37_;
		GXmlDomElement* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomNode* _tmp42_;
		GXmlDomNode* _tmp43_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp44_;
		GXmlDomElement* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomNode* _tmp49_;
		GXmlDomNode* _tmp50_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp51_;
		GXmlDomElement* _tmp52_;
		GXmlDomElement* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomNode* _tmp56_;
		GXmlDomNode* _tmp57_;
		GXmlDomElement* c5 = NULL;
		GXmlGomDocument* _tmp58_;
		GXmlDomElement* _tmp59_;
		GXmlDomElement* _tmp60_;
		GXmlDomElement* _tmp61_;
		GXmlDomNode* _tmp62_;
		GXmlDomNode* _tmp63_;
		gboolean _tmp64_ = FALSE;
		GXmlCssSelectorParser* _tmp65_;
		GXmlDomElement* _tmp66_;
		gboolean _tmp67_ = FALSE;
		GXmlCssSelectorParser* _tmp68_;
		GXmlDomElement* _tmp69_;
		gboolean _tmp70_ = FALSE;
		GXmlCssSelectorParser* _tmp71_;
		GXmlDomElement* _tmp72_;
		gboolean _tmp73_ = FALSE;
		GXmlCssSelectorParser* _tmp74_;
		GXmlDomElement* _tmp75_;
		gboolean _tmp76_ = FALSE;
		GXmlCssSelectorParser* _tmp77_;
		GXmlDomElement* _tmp78_;
		gboolean _tmp79_ = FALSE;
		GXmlCssSelectorParser* _tmp80_;
		GXmlDomElement* _tmp81_;
#line 308 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 308 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		cp = _tmp0_;
#line 309 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp1_ = cp;
#line 309 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, ".warning", &_inner_error_);
#line 309 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 309 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5716 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 310 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp2_ = cp;
#line 310 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 310 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 310 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 310 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 310 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 2, "cp.selectors.size == 2");
#line 311 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp7_ = cp;
#line 311 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 311 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 311 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 311 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		s = (GXmlCssSelectorData*) _tmp10_;
#line 312 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp11_ = s;
#line 312 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 313 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp12_ = s;
#line 313 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_data_get_selector_type (_tmp12_);
#line 313 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 313 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_INSIDE, "s.selector_type == CssSelectorType.INSIDE");
#line 314 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp15_ = cp;
#line 314 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_parser_get_selectors (_tmp15_);
#line 314 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 314 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp18_ = gee_list_get (_tmp17_, 1);
#line 314 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		si = (GXmlCssSelectorData*) _tmp18_;
#line 315 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp19_ = si;
#line 315 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp19_ != NULL, "si != null");
#line 316 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp20_ = si;
#line 316 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp21_ = gxml_css_selector_data_get_selector_type (_tmp20_);
#line 316 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp22_ = _tmp21_;
#line 316 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp22_ == GXML_CSS_SELECTOR_TYPE_CLASS, "si.selector_type == CssSelectorType.CLASS");
#line 317 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp23_ = gxml_gom_document_new ();
#line 317 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		d = _tmp23_;
#line 318 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp24_ = d;
#line 318 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp25_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp24_, "root", &_inner_error_);
#line 318 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		r = _tmp25_;
#line 318 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 318 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 318 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 318 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 318 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5795 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 319 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp26_ = d;
#line 319 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp27_ = r;
#line 319 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp28_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp26_, (GXmlDomNode*) _tmp27_, &_inner_error_);
#line 319 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp29_ = _tmp28_;
#line 319 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp29_);
#line 319 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 319 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 319 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 319 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 319 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 319 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5820 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 320 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp30_ = d;
#line 320 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp31_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp30_, "child", &_inner_error_);
#line 320 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c1 = _tmp31_;
#line 320 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 320 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 320 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 320 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 320 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 320 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5841 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 321 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp32_ = c1;
#line 321 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp32_, "class", "error", &_inner_error_);
#line 321 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 321 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 321 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 321 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 321 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 321 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 321 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5862 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 322 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp33_ = r;
#line 322 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp34_ = c1;
#line 322 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp35_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp33_, (GXmlDomNode*) _tmp34_, &_inner_error_);
#line 322 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp36_ = _tmp35_;
#line 322 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp36_);
#line 322 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 322 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 322 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 322 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 322 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 322 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 322 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5889 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 323 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp37_ = d;
#line 323 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp38_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp37_, "child", &_inner_error_);
#line 323 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c2 = _tmp38_;
#line 323 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 323 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 323 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 323 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 323 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 323 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 323 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5912 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 324 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp39_ = c2;
#line 324 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp39_, "class", "warning", &_inner_error_);
#line 324 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 324 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 324 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 324 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 324 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 324 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 324 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 324 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5935 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 325 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp40_ = r;
#line 325 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp41_ = c2;
#line 325 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp42_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp40_, (GXmlDomNode*) _tmp41_, &_inner_error_);
#line 325 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp43_ = _tmp42_;
#line 325 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp43_);
#line 325 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 325 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 325 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 325 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 325 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 325 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 325 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 325 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5964 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 326 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp44_ = d;
#line 326 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp45_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp44_, "child", &_inner_error_);
#line 326 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c3 = _tmp45_;
#line 326 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 326 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 326 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 326 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 326 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 326 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 326 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 326 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5989 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 327 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp46_ = c3;
#line 327 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp46_, "class", "error warning", &_inner_error_);
#line 327 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 327 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 327 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 327 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 327 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 327 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 327 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 327 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 327 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6014 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 328 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp47_ = r;
#line 328 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp48_ = c3;
#line 328 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp49_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp47_, (GXmlDomNode*) _tmp48_, &_inner_error_);
#line 328 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp50_ = _tmp49_;
#line 328 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp50_);
#line 328 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 328 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 328 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 328 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 328 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 328 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 328 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 328 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 328 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6045 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 329 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp51_ = d;
#line 329 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp52_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp51_, "child", &_inner_error_);
#line 329 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c4 = _tmp52_;
#line 329 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 329 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 329 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 329 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 329 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 329 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 329 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 329 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 329 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6072 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 330 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp53_ = c4;
#line 330 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp53_, "class", "error calc", &_inner_error_);
#line 330 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 330 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 330 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 330 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 330 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 330 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 330 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 330 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 330 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 330 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6099 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 331 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp54_ = r;
#line 331 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp55_ = c4;
#line 331 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp56_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp54_, (GXmlDomNode*) _tmp55_, &_inner_error_);
#line 331 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp57_ = _tmp56_;
#line 331 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp57_);
#line 331 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 331 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 331 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 331 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 331 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 331 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 331 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 331 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 331 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 331 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6132 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 332 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp58_ = d;
#line 332 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp59_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp58_, "child", &_inner_error_);
#line 332 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c5 = _tmp59_;
#line 332 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 332 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 332 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 332 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 332 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 332 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 332 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 332 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 332 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 332 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6161 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 333 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp60_ = r;
#line 333 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp61_ = c5;
#line 333 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp62_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp60_, (GXmlDomNode*) _tmp61_, &_inner_error_);
#line 333 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp63_ = _tmp62_;
#line 333 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp63_);
#line 333 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 333 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 333 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 333 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 333 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 333 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 333 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 333 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 333 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 333 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 333 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6196 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 334 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp65_ = cp;
#line 334 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp66_ = r;
#line 334 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp64_ = gxml_css_selector_parser_match (_tmp65_, _tmp66_, &_inner_error_);
#line 334 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 334 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 334 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 334 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 334 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 334 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 334 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 334 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 334 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 334 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 334 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6227 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 334 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp64_, "!cp.match (r)");
#line 335 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp68_ = cp;
#line 335 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp69_ = c1;
#line 335 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp67_ = gxml_css_selector_parser_match (_tmp68_, _tmp69_, &_inner_error_);
#line 335 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 335 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 335 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 335 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 335 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 335 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 335 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 335 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 335 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 335 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 335 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6260 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 335 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp67_, "!cp.match (c1)");
#line 336 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp71_ = cp;
#line 336 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp72_ = c2;
#line 336 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp70_ = gxml_css_selector_parser_match (_tmp71_, _tmp72_, &_inner_error_);
#line 336 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 336 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 336 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 336 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 336 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 336 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 336 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 336 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 336 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 336 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 336 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6293 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 336 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp70_, "cp.match (c2)");
#line 337 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp74_ = cp;
#line 337 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp75_ = c3;
#line 337 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp73_ = gxml_css_selector_parser_match (_tmp74_, _tmp75_, &_inner_error_);
#line 337 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 337 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 337 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 337 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 337 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 337 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 337 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 337 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 337 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 337 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 337 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6326 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 337 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp73_, "cp.match (c3)");
#line 338 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp77_ = cp;
#line 338 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp78_ = c4;
#line 338 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp76_ = gxml_css_selector_parser_match (_tmp77_, _tmp78_, &_inner_error_);
#line 338 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 338 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 338 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 338 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 338 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 338 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 338 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 338 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 338 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 338 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 338 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6359 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 338 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp76_, "!cp.match (c4)");
#line 339 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp80_ = cp;
#line 339 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp81_ = c5;
#line 339 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp79_ = gxml_css_selector_parser_match (_tmp80_, _tmp81_, &_inner_error_);
#line 339 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 339 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 339 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 339 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 339 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 339 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 339 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 339 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 339 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 339 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 339 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6392 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 339 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp79_, "!cp.match (c5)");
#line 307 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c5);
#line 307 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 307 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 307 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 307 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 307 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 307 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 307 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (si);
#line 307 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 307 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 6417 "CssSelectorTest.c"
	}
	goto __finally9;
	__catch9_g_error:
	{
		GError* e = NULL;
		GError* _tmp82_;
		const gchar* _tmp83_;
		gchar* _tmp84_;
		gchar* _tmp85_;
#line 307 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		e = _inner_error_;
#line 307 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_inner_error_ = NULL;
#line 341 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp82_ = e;
#line 341 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp83_ = _tmp82_->message;
#line 341 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp84_ = g_strconcat ("ERROR: ", _tmp83_, NULL);
#line 341 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp85_ = _tmp84_;
#line 341 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:341: %s", _tmp85_);
#line 341 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_free0 (_tmp85_);
#line 307 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_error_free0 (e);
#line 6445 "CssSelectorTest.c"
	}
	__finally9:
#line 307 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 307 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 307 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_clear_error (&_inner_error_);
#line 307 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		return;
#line 6456 "CssSelectorTest.c"
	}
}


static void
___lambda293__gtest_func (void)
{
#line 306 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	__lambda293_ ();
#line 6466 "CssSelectorTest.c"
}


static void
__lambda294_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelectorData* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelectorData* _tmp11_;
		GXmlCssSelectorData* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelectorData* si = NULL;
		GXmlCssSelectorParser* _tmp15_;
		GeeList* _tmp16_;
		GeeList* _tmp17_;
		gpointer _tmp18_;
		GXmlCssSelectorData* _tmp19_;
		GXmlCssSelectorData* _tmp20_;
		GXmlCssSelectorType _tmp21_;
		GXmlCssSelectorType _tmp22_;
		GXmlCssSelectorData* sc = NULL;
		GXmlCssSelectorParser* _tmp23_;
		GeeList* _tmp24_;
		GeeList* _tmp25_;
		gpointer _tmp26_;
		GXmlCssSelectorData* _tmp27_;
		GXmlCssSelectorData* _tmp28_;
		GXmlCssSelectorType _tmp29_;
		GXmlCssSelectorType _tmp30_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp31_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlGomDocument* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomNode* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomElement* _tmp42_;
		GXmlDomNode* _tmp43_;
		GXmlDomNode* _tmp44_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomNode* _tmp50_;
		GXmlDomNode* _tmp51_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp52_;
		GXmlDomElement* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomElement* _tmp56_;
		GXmlDomNode* _tmp57_;
		GXmlDomNode* _tmp58_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp59_;
		GXmlDomElement* _tmp60_;
		GXmlDomElement* _tmp61_;
		GXmlDomElement* _tmp62_;
		GXmlDomElement* _tmp63_;
		GXmlDomNode* _tmp64_;
		GXmlDomNode* _tmp65_;
		GXmlDomElement* c5 = NULL;
		GXmlGomDocument* _tmp66_;
		GXmlDomElement* _tmp67_;
		GXmlDomElement* _tmp68_;
		GXmlDomElement* _tmp69_;
		GXmlDomNode* _tmp70_;
		GXmlDomNode* _tmp71_;
		gboolean _tmp72_ = FALSE;
		GXmlCssSelectorParser* _tmp73_;
		GXmlDomElement* _tmp74_;
		gboolean _tmp75_ = FALSE;
		GXmlCssSelectorParser* _tmp76_;
		GXmlDomElement* _tmp77_;
		gboolean _tmp78_ = FALSE;
		GXmlCssSelectorParser* _tmp79_;
		GXmlDomElement* _tmp80_;
		gboolean _tmp81_ = FALSE;
		GXmlCssSelectorParser* _tmp82_;
		GXmlDomElement* _tmp83_;
		gboolean _tmp84_ = FALSE;
		GXmlCssSelectorParser* _tmp85_;
		GXmlDomElement* _tmp86_;
		gboolean _tmp87_ = FALSE;
		GXmlCssSelectorParser* _tmp88_;
		GXmlDomElement* _tmp89_;
#line 346 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 346 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		cp = _tmp0_;
#line 347 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp1_ = cp;
#line 347 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "child.warning", &_inner_error_);
#line 347 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 347 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6588 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 348 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp2_ = cp;
#line 348 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 348 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 348 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 348 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 348 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 3, "cp.selectors.size == 3");
#line 349 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp7_ = cp;
#line 349 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 349 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 349 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 349 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		s = (GXmlCssSelectorData*) _tmp10_;
#line 350 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp11_ = s;
#line 350 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 351 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp12_ = s;
#line 351 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_data_get_selector_type (_tmp12_);
#line 351 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 351 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 352 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp15_ = cp;
#line 352 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_parser_get_selectors (_tmp15_);
#line 352 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 352 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp18_ = gee_list_get (_tmp17_, 1);
#line 352 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		si = (GXmlCssSelectorData*) _tmp18_;
#line 353 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp19_ = si;
#line 353 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp19_ != NULL, "si != null");
#line 354 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp20_ = si;
#line 354 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp21_ = gxml_css_selector_data_get_selector_type (_tmp20_);
#line 354 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp22_ = _tmp21_;
#line 354 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp22_ == GXML_CSS_SELECTOR_TYPE_INSIDE, "si.selector_type == CssSelectorType.INSIDE");
#line 355 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp23_ = cp;
#line 355 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_parser_get_selectors (_tmp23_);
#line 355 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 355 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp26_ = gee_list_get (_tmp25_, 2);
#line 355 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		sc = (GXmlCssSelectorData*) _tmp26_;
#line 356 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp27_ = sc;
#line 356 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp27_ != NULL, "sc != null");
#line 357 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp28_ = sc;
#line 357 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp29_ = gxml_css_selector_data_get_selector_type (_tmp28_);
#line 357 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp30_ = _tmp29_;
#line 357 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp30_ == GXML_CSS_SELECTOR_TYPE_CLASS, "sc.selector_type == CssSelectorType.CLASS");
#line 358 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp31_ = gxml_gom_document_new ();
#line 358 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		d = _tmp31_;
#line 359 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp32_ = d;
#line 359 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp33_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp32_, "root", &_inner_error_);
#line 359 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		r = _tmp33_;
#line 359 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 359 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 359 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 359 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 359 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 359 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6691 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 360 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp34_ = d;
#line 360 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp35_ = r;
#line 360 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp36_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp34_, (GXmlDomNode*) _tmp35_, &_inner_error_);
#line 360 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp37_ = _tmp36_;
#line 360 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp37_);
#line 360 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 360 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 360 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 360 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 360 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 360 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 360 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6718 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 361 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp38_ = d;
#line 361 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp39_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp38_, "children", &_inner_error_);
#line 361 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c1 = _tmp39_;
#line 361 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 361 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 361 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 361 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 361 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 361 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 361 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6741 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 362 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp40_ = c1;
#line 362 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp40_, "class", "error", &_inner_error_);
#line 362 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 362 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 362 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 362 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 362 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 362 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 362 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 362 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6764 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 363 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp41_ = r;
#line 363 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp42_ = c1;
#line 363 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp43_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp41_, (GXmlDomNode*) _tmp42_, &_inner_error_);
#line 363 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp44_ = _tmp43_;
#line 363 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp44_);
#line 363 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 363 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 363 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 363 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 363 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 363 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 363 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 363 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6793 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 364 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp45_ = d;
#line 364 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp46_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp45_, "child", &_inner_error_);
#line 364 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c2 = _tmp46_;
#line 364 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 364 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 364 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 364 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 364 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 364 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 364 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 364 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6818 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 365 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp47_ = c2;
#line 365 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp47_, "class", "warning", &_inner_error_);
#line 365 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 365 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 365 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 365 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 365 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 365 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 365 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 365 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 365 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6843 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 366 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp48_ = r;
#line 366 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp49_ = c2;
#line 366 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp50_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp48_, (GXmlDomNode*) _tmp49_, &_inner_error_);
#line 366 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp51_ = _tmp50_;
#line 366 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp51_);
#line 366 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 366 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 366 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 366 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 366 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 366 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 366 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 366 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 366 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6874 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 367 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp52_ = d;
#line 367 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp53_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp52_, "child", &_inner_error_);
#line 367 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c3 = _tmp53_;
#line 367 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 367 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 367 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 367 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 367 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 367 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 367 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 367 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 367 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6901 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 368 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp54_ = c3;
#line 368 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp54_, "class", "error warning", &_inner_error_);
#line 368 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 368 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 368 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 368 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 368 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 368 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 368 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 368 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 368 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 368 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6928 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 369 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp55_ = r;
#line 369 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp56_ = c3;
#line 369 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp57_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp55_, (GXmlDomNode*) _tmp56_, &_inner_error_);
#line 369 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp58_ = _tmp57_;
#line 369 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp58_);
#line 369 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 369 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 369 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 369 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 369 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 369 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 369 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 369 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 369 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 369 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6961 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 370 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp59_ = d;
#line 370 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp60_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp59_, "child", &_inner_error_);
#line 370 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c4 = _tmp60_;
#line 370 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 370 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 370 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 370 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 370 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 370 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 370 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 370 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 370 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 370 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6990 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 371 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp61_ = c4;
#line 371 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp61_, "class", "error calc", &_inner_error_);
#line 371 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 371 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 371 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 371 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 371 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 371 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 371 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 371 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 371 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 371 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 371 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7019 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 372 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp62_ = r;
#line 372 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp63_ = c4;
#line 372 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp64_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp62_, (GXmlDomNode*) _tmp63_, &_inner_error_);
#line 372 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp65_ = _tmp64_;
#line 372 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp65_);
#line 372 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 372 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 372 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 372 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 372 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 372 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 372 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 372 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 372 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 372 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 372 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7054 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 373 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp66_ = d;
#line 373 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp67_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp66_, "child", &_inner_error_);
#line 373 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c5 = _tmp67_;
#line 373 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 373 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 373 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 373 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 373 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 373 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 373 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 373 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 373 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 373 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 373 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7085 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 374 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp68_ = r;
#line 374 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp69_ = c5;
#line 374 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp70_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp68_, (GXmlDomNode*) _tmp69_, &_inner_error_);
#line 374 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp71_ = _tmp70_;
#line 374 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp71_);
#line 374 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 374 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 374 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 374 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 374 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 374 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 374 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 374 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 374 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 374 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 374 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 374 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7122 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 375 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp73_ = cp;
#line 375 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp74_ = r;
#line 375 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp72_ = gxml_css_selector_parser_match (_tmp73_, _tmp74_, &_inner_error_);
#line 375 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 375 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 375 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 375 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 375 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 375 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 375 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 375 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 375 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 375 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 375 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 375 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7155 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 375 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp72_, "!cp.match (r)");
#line 376 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp76_ = cp;
#line 376 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp77_ = c1;
#line 376 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp75_ = gxml_css_selector_parser_match (_tmp76_, _tmp77_, &_inner_error_);
#line 376 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 376 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 376 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 376 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 376 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 376 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 376 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 376 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 376 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 376 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 376 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 376 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7190 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 376 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp75_, "!cp.match (c1)");
#line 377 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp79_ = cp;
#line 377 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp80_ = c2;
#line 377 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp78_ = gxml_css_selector_parser_match (_tmp79_, _tmp80_, &_inner_error_);
#line 377 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 377 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 377 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 377 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 377 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 377 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 377 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 377 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 377 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 377 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 377 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 377 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7225 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 377 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp78_, "cp.match (c2)");
#line 378 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp82_ = cp;
#line 378 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp83_ = c3;
#line 378 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp81_ = gxml_css_selector_parser_match (_tmp82_, _tmp83_, &_inner_error_);
#line 378 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 378 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 378 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 378 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 378 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 378 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 378 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 378 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 378 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 378 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 378 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 378 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7260 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 378 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp81_, "cp.match (c3)");
#line 379 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp85_ = cp;
#line 379 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp86_ = c4;
#line 379 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp84_ = gxml_css_selector_parser_match (_tmp85_, _tmp86_, &_inner_error_);
#line 379 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 379 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 379 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 379 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 379 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 379 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 379 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 379 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 379 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 379 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 379 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 379 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7295 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 379 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp84_, "!cp.match (c4)");
#line 380 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp88_ = cp;
#line 380 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp89_ = c5;
#line 380 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp87_ = gxml_css_selector_parser_match (_tmp88_, _tmp89_, &_inner_error_);
#line 380 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 380 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 380 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 380 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 380 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 380 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 380 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 380 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 380 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 380 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 380 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 380 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7330 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 380 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp87_, "!cp.match (c5)");
#line 345 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c5);
#line 345 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 345 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 345 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 345 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 345 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 345 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 345 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (sc);
#line 345 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (si);
#line 345 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 345 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 7357 "CssSelectorTest.c"
	}
	goto __finally10;
	__catch10_g_error:
	{
		GError* e = NULL;
		GError* _tmp90_;
		const gchar* _tmp91_;
		gchar* _tmp92_;
		gchar* _tmp93_;
#line 345 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		e = _inner_error_;
#line 345 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_inner_error_ = NULL;
#line 382 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp90_ = e;
#line 382 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp91_ = _tmp90_->message;
#line 382 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp92_ = g_strconcat ("ERROR: ", _tmp91_, NULL);
#line 382 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp93_ = _tmp92_;
#line 382 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:382: %s", _tmp93_);
#line 382 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_free0 (_tmp93_);
#line 345 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_error_free0 (e);
#line 7385 "CssSelectorTest.c"
	}
	__finally10:
#line 345 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 345 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 345 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_clear_error (&_inner_error_);
#line 345 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		return;
#line 7396 "CssSelectorTest.c"
	}
}


static void
___lambda294__gtest_func (void)
{
#line 344 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	__lambda294_ ();
#line 7406 "CssSelectorTest.c"
}


static void
__lambda295_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelectorData* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelectorData* _tmp11_;
		GXmlCssSelectorData* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelectorData* si = NULL;
		GXmlCssSelectorParser* _tmp15_;
		GeeList* _tmp16_;
		GeeList* _tmp17_;
		gpointer _tmp18_;
		GXmlCssSelectorData* _tmp19_;
		GXmlCssSelectorData* _tmp20_;
		GXmlCssSelectorType _tmp21_;
		GXmlCssSelectorType _tmp22_;
		GXmlCssSelectorData* sa = NULL;
		GXmlCssSelectorParser* _tmp23_;
		GeeList* _tmp24_;
		GeeList* _tmp25_;
		gpointer _tmp26_;
		GXmlCssSelectorData* _tmp27_;
		GXmlCssSelectorData* _tmp28_;
		GXmlCssSelectorType _tmp29_;
		GXmlCssSelectorType _tmp30_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp31_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlGomDocument* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomNode* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomNode* _tmp42_;
		GXmlDomNode* _tmp43_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp44_;
		GXmlDomElement* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomNode* _tmp49_;
		GXmlDomNode* _tmp50_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp51_;
		GXmlDomElement* _tmp52_;
		GXmlDomElement* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomNode* _tmp56_;
		GXmlDomNode* _tmp57_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp58_;
		GXmlDomElement* _tmp59_;
		GXmlDomElement* _tmp60_;
		GXmlDomElement* _tmp61_;
		GXmlDomElement* _tmp62_;
		GXmlDomNode* _tmp63_;
		GXmlDomNode* _tmp64_;
		gboolean _tmp65_ = FALSE;
		GXmlCssSelectorParser* _tmp66_;
		GXmlDomElement* _tmp67_;
		gboolean _tmp68_ = FALSE;
		GXmlCssSelectorParser* _tmp69_;
		GXmlDomElement* _tmp70_;
		gboolean _tmp71_ = FALSE;
		GXmlCssSelectorParser* _tmp72_;
		GXmlDomElement* _tmp73_;
		gboolean _tmp74_ = FALSE;
		GXmlCssSelectorParser* _tmp75_;
		GXmlDomElement* _tmp76_;
		gboolean _tmp77_ = FALSE;
		GXmlCssSelectorParser* _tmp78_;
		GXmlDomElement* _tmp79_;
		GXmlDomDocument* d2 = NULL;
		GXmlGDocument* _tmp80_;
		GXmlDomDocument* _tmp81_;
		GXmlDomElement* r2 = NULL;
		GXmlDomDocument* _tmp82_;
		GXmlDomElement* _tmp83_;
		GXmlDomDocument* _tmp84_;
		GXmlDomElement* _tmp85_;
		GXmlDomNode* _tmp86_;
		GXmlDomNode* _tmp87_;
		GXmlDomElement* c1g = NULL;
		GXmlDomDocument* _tmp88_;
		GXmlDomElement* _tmp89_;
		GXmlDomElement* _tmp90_;
		GXmlDomElement* _tmp91_;
		GXmlDomNode* _tmp92_;
		GXmlDomNode* _tmp93_;
		GXmlDomElement* c2g = NULL;
		GXmlDomDocument* _tmp94_;
		GXmlDomElement* _tmp95_;
		GXmlDomElement* _tmp96_;
		GXmlDomElement* _tmp97_;
		GXmlDomElement* _tmp98_;
		GXmlDomNode* _tmp99_;
		GXmlDomNode* _tmp100_;
		GXmlDomElement* c3g = NULL;
		GXmlDomDocument* _tmp101_;
		GXmlDomElement* _tmp102_;
		GXmlDomElement* _tmp103_;
		GXmlDomElement* _tmp104_;
		GXmlDomElement* _tmp105_;
		GXmlDomNode* _tmp106_;
		GXmlDomNode* _tmp107_;
		GXmlDomElement* c4g = NULL;
		GXmlDomDocument* _tmp108_;
		GXmlDomElement* _tmp109_;
		GXmlDomElement* _tmp110_;
		GXmlDomElement* _tmp111_;
		GXmlDomElement* _tmp112_;
		GXmlDomNode* _tmp113_;
		GXmlDomNode* _tmp114_;
		gboolean _tmp115_ = FALSE;
		GXmlCssSelectorParser* _tmp116_;
		GXmlDomElement* _tmp117_;
		gboolean _tmp118_ = FALSE;
		GXmlCssSelectorParser* _tmp119_;
		GXmlDomElement* _tmp120_;
		gboolean _tmp121_ = FALSE;
		GXmlCssSelectorParser* _tmp122_;
		GXmlDomElement* _tmp123_;
		gboolean _tmp124_ = FALSE;
		GXmlCssSelectorParser* _tmp125_;
		GXmlDomElement* _tmp126_;
		gboolean _tmp127_ = FALSE;
		GXmlCssSelectorParser* _tmp128_;
		GXmlDomElement* _tmp129_;
#line 387 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 387 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		cp = _tmp0_;
#line 388 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp1_ = cp;
#line 388 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "toplevel:root", &_inner_error_);
#line 388 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 388 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7573 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 389 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp2_ = cp;
#line 389 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 389 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 389 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 389 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 389 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 3, "cp.selectors.size == 3");
#line 390 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp7_ = cp;
#line 390 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 390 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 390 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 390 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		s = (GXmlCssSelectorData*) _tmp10_;
#line 391 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp11_ = s;
#line 391 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 392 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp12_ = s;
#line 392 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_data_get_selector_type (_tmp12_);
#line 392 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 392 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 393 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp15_ = cp;
#line 393 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_parser_get_selectors (_tmp15_);
#line 393 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 393 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp18_ = gee_list_get (_tmp17_, 1);
#line 393 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		si = (GXmlCssSelectorData*) _tmp18_;
#line 394 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp19_ = si;
#line 394 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp19_ != NULL, "si != null");
#line 395 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp20_ = si;
#line 395 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp21_ = gxml_css_selector_data_get_selector_type (_tmp20_);
#line 395 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp22_ = _tmp21_;
#line 395 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp22_ == GXML_CSS_SELECTOR_TYPE_INSIDE, "si.selector_type == CssSelectorType.INSIDE");
#line 396 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp23_ = cp;
#line 396 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_parser_get_selectors (_tmp23_);
#line 396 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 396 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp26_ = gee_list_get (_tmp25_, 2);
#line 396 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		sa = (GXmlCssSelectorData*) _tmp26_;
#line 397 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp27_ = sa;
#line 397 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp27_ != NULL, "sa != null");
#line 398 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp28_ = sa;
#line 398 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp29_ = gxml_css_selector_data_get_selector_type (_tmp28_);
#line 398 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp30_ = _tmp29_;
#line 398 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp30_ == GXML_CSS_SELECTOR_TYPE_PSEUDO, "sa.selector_type == CssSelectorType.PSEUDO");
#line 399 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp31_ = gxml_gom_document_new ();
#line 399 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		d = _tmp31_;
#line 400 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp32_ = d;
#line 400 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp33_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp32_, "toplevel", &_inner_error_);
#line 400 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		r = _tmp33_;
#line 400 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 400 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 400 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 400 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 400 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 400 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7676 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 401 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp34_ = d;
#line 401 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp35_ = r;
#line 401 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp36_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp34_, (GXmlDomNode*) _tmp35_, &_inner_error_);
#line 401 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp37_ = _tmp36_;
#line 401 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp37_);
#line 401 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 401 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 401 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 401 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 401 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 401 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 401 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7703 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 402 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp38_ = d;
#line 402 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp39_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp38_, "child", &_inner_error_);
#line 402 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c1 = _tmp39_;
#line 402 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 402 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 402 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 402 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 402 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 402 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 402 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7726 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 403 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp40_ = r;
#line 403 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp41_ = c1;
#line 403 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp42_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp40_, (GXmlDomNode*) _tmp41_, &_inner_error_);
#line 403 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp43_ = _tmp42_;
#line 403 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp43_);
#line 403 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 403 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 403 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 403 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 403 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 403 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 403 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 403 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7755 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 404 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp44_ = d;
#line 404 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp45_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp44_, "child", &_inner_error_);
#line 404 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c2 = _tmp45_;
#line 404 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 404 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 404 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 404 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 404 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 404 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 404 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 404 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7780 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 405 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp46_ = c2;
#line 405 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp46_, "prop-name", "subval", &_inner_error_);
#line 405 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 405 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 405 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 405 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 405 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 405 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 405 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 405 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 405 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7805 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 406 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp47_ = r;
#line 406 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp48_ = c2;
#line 406 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp49_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp47_, (GXmlDomNode*) _tmp48_, &_inner_error_);
#line 406 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp50_ = _tmp49_;
#line 406 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp50_);
#line 406 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 406 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 406 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 406 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 406 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 406 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 406 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 406 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 406 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7836 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 407 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp51_ = d;
#line 407 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp52_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp51_, "child", &_inner_error_);
#line 407 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c3 = _tmp52_;
#line 407 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 407 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 407 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 407 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 407 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 407 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 407 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 407 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 407 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7863 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 408 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp53_ = c3;
#line 408 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp53_, "prop-name", "techval", &_inner_error_);
#line 408 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 408 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 408 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 408 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 408 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 408 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 408 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 408 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 408 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 408 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7890 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 409 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp54_ = r;
#line 409 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp55_ = c3;
#line 409 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp56_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp54_, (GXmlDomNode*) _tmp55_, &_inner_error_);
#line 409 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp57_ = _tmp56_;
#line 409 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp57_);
#line 409 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 409 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 409 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 409 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 409 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 409 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 409 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 409 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 409 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 409 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7923 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 410 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp58_ = d;
#line 410 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp59_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp58_, "child", &_inner_error_);
#line 410 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c4 = _tmp59_;
#line 410 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 410 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 410 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 410 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 410 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 410 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 410 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 410 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 410 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 410 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7952 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 411 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp60_ = c4;
#line 411 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp60_, "prop-name", "secondaryvalue", &_inner_error_);
#line 411 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 411 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 411 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 411 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 411 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 411 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 411 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 411 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 411 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 411 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 411 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7981 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 412 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp61_ = r;
#line 412 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp62_ = c4;
#line 412 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp63_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp61_, (GXmlDomNode*) _tmp62_, &_inner_error_);
#line 412 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp64_ = _tmp63_;
#line 412 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp64_);
#line 412 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 412 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 412 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 412 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 412 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 412 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 412 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 412 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 412 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 412 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 412 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8016 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 413 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp66_ = cp;
#line 413 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp67_ = r;
#line 413 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp65_ = gxml_css_selector_parser_match (_tmp66_, _tmp67_, &_inner_error_);
#line 413 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 413 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 413 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 413 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 413 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 413 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 413 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 413 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 413 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 413 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 413 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8047 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 413 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp65_, "cp.match (r)");
#line 414 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp69_ = cp;
#line 414 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp70_ = c1;
#line 414 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp68_ = gxml_css_selector_parser_match (_tmp69_, _tmp70_, &_inner_error_);
#line 414 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 414 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 414 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 414 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 414 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 414 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 414 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 414 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 414 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 414 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 414 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8080 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 414 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp68_, "!cp.match (c1)");
#line 415 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp72_ = cp;
#line 415 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp73_ = c2;
#line 415 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp71_ = gxml_css_selector_parser_match (_tmp72_, _tmp73_, &_inner_error_);
#line 415 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 415 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 415 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 415 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 415 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 415 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 415 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 415 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 415 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 415 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 415 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8113 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 415 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp71_, "!cp.match (c2)");
#line 416 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp75_ = cp;
#line 416 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp76_ = c3;
#line 416 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp74_ = gxml_css_selector_parser_match (_tmp75_, _tmp76_, &_inner_error_);
#line 416 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 416 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 416 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 416 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 416 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 416 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 416 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 416 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 416 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 416 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 416 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8146 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 416 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp74_, "!cp.match (c3)");
#line 417 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp78_ = cp;
#line 417 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp79_ = c4;
#line 417 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp77_ = gxml_css_selector_parser_match (_tmp78_, _tmp79_, &_inner_error_);
#line 417 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 417 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 417 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 417 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 417 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 417 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 417 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 417 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 417 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 417 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 417 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8179 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 417 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp77_, "!cp.match (c4)");
#line 418 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp80_ = gxml_gdocument_new ();
#line 418 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp81_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp80_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp80_) : NULL;
#line 418 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (_tmp81_ == NULL) {
#line 418 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (_tmp80_);
#line 8192 "CssSelectorTest.c"
		}
#line 418 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		d2 = _tmp81_;
#line 419 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp82_ = d2;
#line 419 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp83_ = gxml_dom_document_create_element (_tmp82_, "toplevel", &_inner_error_);
#line 419 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		r2 = _tmp83_;
#line 419 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 419 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 419 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 419 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 419 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 419 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 419 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 419 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 419 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 419 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 419 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 419 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8226 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 420 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp84_ = d2;
#line 420 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp85_ = r2;
#line 420 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp86_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp84_, (GXmlDomNode*) _tmp85_, &_inner_error_);
#line 420 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp87_ = _tmp86_;
#line 420 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp87_);
#line 420 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 420 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 420 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 420 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 420 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 420 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 420 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 420 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 420 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 420 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 420 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 420 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 420 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8265 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 421 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp88_ = d2;
#line 421 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp89_ = gxml_dom_document_create_element (_tmp88_, "child", &_inner_error_);
#line 421 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c1g = _tmp89_;
#line 421 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 421 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 421 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 421 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 421 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 421 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 421 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 421 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 421 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 421 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 421 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 421 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 421 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8300 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 422 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp90_ = r2;
#line 422 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp91_ = c1g;
#line 422 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp92_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp90_, (GXmlDomNode*) _tmp91_, &_inner_error_);
#line 422 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp93_ = _tmp92_;
#line 422 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp93_);
#line 422 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 422 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 422 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 422 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 422 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 422 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 422 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 422 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 422 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 422 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 422 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 422 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 422 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 422 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8341 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 423 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp94_ = d2;
#line 423 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp95_ = gxml_dom_document_create_element (_tmp94_, "child", &_inner_error_);
#line 423 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c2g = _tmp95_;
#line 423 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 423 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 423 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 423 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 423 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 423 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 423 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 423 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 423 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 423 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 423 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 423 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 423 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 423 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8378 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 424 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp96_ = c2g;
#line 424 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp96_, "prop-name", "subval", &_inner_error_);
#line 424 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 424 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 424 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 424 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 424 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 424 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 424 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 424 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 424 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 424 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 424 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 424 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 424 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 424 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 424 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8415 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 425 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp97_ = r2;
#line 425 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp98_ = c2g;
#line 425 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp99_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp97_, (GXmlDomNode*) _tmp98_, &_inner_error_);
#line 425 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp100_ = _tmp99_;
#line 425 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp100_);
#line 425 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 425 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 425 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 425 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 425 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 425 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 425 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 425 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 425 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 425 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 425 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 425 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 425 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 425 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 425 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8458 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 426 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp101_ = d2;
#line 426 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp102_ = gxml_dom_document_create_element (_tmp101_, "child", &_inner_error_);
#line 426 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c3g = _tmp102_;
#line 426 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 426 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 426 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 426 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 426 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 426 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 426 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 426 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 426 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 426 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 426 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 426 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 426 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 426 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 426 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8497 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 427 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp103_ = c3g;
#line 427 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp103_, "prop-name", "techval", &_inner_error_);
#line 427 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 427 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 427 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 427 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 427 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 427 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 427 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 427 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 427 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 427 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 427 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 427 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 427 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 427 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 427 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 427 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8536 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 428 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp104_ = r2;
#line 428 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp105_ = c3g;
#line 428 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp106_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp104_, (GXmlDomNode*) _tmp105_, &_inner_error_);
#line 428 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp107_ = _tmp106_;
#line 428 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp107_);
#line 428 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 428 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 428 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 428 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 428 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 428 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 428 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 428 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 428 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 428 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 428 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 428 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 428 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 428 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 428 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 428 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8581 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 429 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp108_ = d2;
#line 429 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp109_ = gxml_dom_document_create_element (_tmp108_, "child", &_inner_error_);
#line 429 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c4g = _tmp109_;
#line 429 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 429 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 429 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 429 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 429 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 429 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 429 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 429 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 429 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 429 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 429 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 429 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 429 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 429 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 429 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 429 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8622 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 430 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp110_ = c4g;
#line 430 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp110_, "prop-name", "secondaryvalue", &_inner_error_);
#line 430 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 430 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 430 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 430 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 430 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 430 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 430 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 430 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 430 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 430 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 430 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 430 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 430 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 430 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 430 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 430 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 430 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8663 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp111_ = r2;
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp112_ = c4g;
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp113_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp111_, (GXmlDomNode*) _tmp112_, &_inner_error_);
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp114_ = _tmp113_;
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp114_);
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 431 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8710 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 432 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp116_ = cp;
#line 432 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp117_ = r;
#line 432 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp115_ = gxml_css_selector_parser_match (_tmp116_, _tmp117_, &_inner_error_);
#line 432 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 432 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 432 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 432 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 432 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 432 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 432 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 432 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 432 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 432 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 432 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 432 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 432 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 432 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 432 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 432 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 432 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8753 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 432 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp115_, "cp.match (r)");
#line 433 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp119_ = cp;
#line 433 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp120_ = c1g;
#line 433 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp118_ = gxml_css_selector_parser_match (_tmp119_, _tmp120_, &_inner_error_);
#line 433 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 433 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 433 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 433 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 433 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 433 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 433 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 433 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 433 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 433 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 433 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 433 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 433 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 433 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 433 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 433 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 433 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8798 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 433 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp118_, "!cp.match (c1g)");
#line 434 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp122_ = cp;
#line 434 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp123_ = c2g;
#line 434 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp121_ = gxml_css_selector_parser_match (_tmp122_, _tmp123_, &_inner_error_);
#line 434 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 434 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 434 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 434 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 434 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 434 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 434 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 434 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 434 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 434 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 434 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 434 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 434 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 434 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 434 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 434 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 434 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8843 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 434 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp121_, "!cp.match (c2g)");
#line 435 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp125_ = cp;
#line 435 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp126_ = c3g;
#line 435 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp124_ = gxml_css_selector_parser_match (_tmp125_, _tmp126_, &_inner_error_);
#line 435 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 435 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 435 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 435 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 435 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 435 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 435 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 435 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 435 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 435 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 435 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 435 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 435 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 435 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 435 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 435 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 435 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8888 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 435 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp124_, "!cp.match (c3g)");
#line 436 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp128_ = cp;
#line 436 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp129_ = c4g;
#line 436 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp127_ = gxml_css_selector_parser_match (_tmp128_, _tmp129_, &_inner_error_);
#line 436 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 436 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 436 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 436 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 436 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 436 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 436 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 436 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 436 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 436 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 436 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 436 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 436 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 436 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 436 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 436 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 436 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8933 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 436 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp127_, "!cp.match (c4g)");
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c4g);
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c3g);
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c2g);
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c1g);
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (r2);
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (d2);
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (si);
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 8970 "CssSelectorTest.c"
	}
	goto __finally11;
	__catch11_g_error:
	{
		GError* e = NULL;
		GError* _tmp130_;
		const gchar* _tmp131_;
		gchar* _tmp132_;
		gchar* _tmp133_;
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		e = _inner_error_;
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_inner_error_ = NULL;
#line 438 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp130_ = e;
#line 438 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp131_ = _tmp130_->message;
#line 438 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp132_ = g_strconcat ("ERROR: ", _tmp131_, NULL);
#line 438 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp133_ = _tmp132_;
#line 438 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:438: %s", _tmp133_);
#line 438 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_free0 (_tmp133_);
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_error_free0 (e);
#line 8998 "CssSelectorTest.c"
	}
	__finally11:
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_clear_error (&_inner_error_);
#line 386 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		return;
#line 9009 "CssSelectorTest.c"
	}
}


static void
___lambda295__gtest_func (void)
{
#line 385 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	__lambda295_ ();
#line 9019 "CssSelectorTest.c"
}


static void
__lambda296_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelectorData* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelectorData* _tmp11_;
		GXmlCssSelectorData* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelectorData* si = NULL;
		GXmlCssSelectorParser* _tmp15_;
		GeeList* _tmp16_;
		GeeList* _tmp17_;
		gpointer _tmp18_;
		GXmlCssSelectorData* _tmp19_;
		GXmlCssSelectorData* _tmp20_;
		GXmlCssSelectorType _tmp21_;
		GXmlCssSelectorType _tmp22_;
		GXmlCssSelectorData* sa = NULL;
		GXmlCssSelectorParser* _tmp23_;
		GeeList* _tmp24_;
		GeeList* _tmp25_;
		gpointer _tmp26_;
		GXmlCssSelectorData* _tmp27_;
		GXmlCssSelectorData* _tmp28_;
		GXmlCssSelectorType _tmp29_;
		GXmlCssSelectorType _tmp30_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp31_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlGomDocument* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomNode* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomNode* _tmp42_;
		GXmlDomNode* _tmp43_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp44_;
		GXmlDomElement* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomNode* _tmp49_;
		GXmlDomNode* _tmp50_;
		gboolean _tmp51_ = FALSE;
		GXmlCssSelectorParser* _tmp52_;
		GXmlDomElement* _tmp53_;
		gboolean _tmp54_ = FALSE;
		GXmlCssSelectorParser* _tmp55_;
		GXmlDomElement* _tmp56_;
		gboolean _tmp57_ = FALSE;
		GXmlCssSelectorParser* _tmp58_;
		GXmlDomElement* _tmp59_;
#line 443 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 443 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		cp = _tmp0_;
#line 444 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp1_ = cp;
#line 444 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "radio[enable=\"true\"]", &_inner_error_);
#line 444 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 444 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9108 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 445 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp2_ = cp;
#line 445 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 445 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 445 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 445 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 445 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 3, "cp.selectors.size == 3");
#line 446 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp7_ = cp;
#line 446 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 446 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 446 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 446 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		s = (GXmlCssSelectorData*) _tmp10_;
#line 447 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp11_ = s;
#line 447 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 448 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp12_ = s;
#line 448 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_data_get_selector_type (_tmp12_);
#line 448 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 448 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 449 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp15_ = cp;
#line 449 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_parser_get_selectors (_tmp15_);
#line 449 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 449 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp18_ = gee_list_get (_tmp17_, 1);
#line 449 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		si = (GXmlCssSelectorData*) _tmp18_;
#line 450 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp19_ = si;
#line 450 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp19_ != NULL, "si != null");
#line 451 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp20_ = si;
#line 451 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp21_ = gxml_css_selector_data_get_selector_type (_tmp20_);
#line 451 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp22_ = _tmp21_;
#line 451 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp22_ == GXML_CSS_SELECTOR_TYPE_INSIDE, "si.selector_type == CssSelectorType.INSIDE");
#line 452 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp23_ = cp;
#line 452 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_parser_get_selectors (_tmp23_);
#line 452 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 452 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp26_ = gee_list_get (_tmp25_, 2);
#line 452 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		sa = (GXmlCssSelectorData*) _tmp26_;
#line 453 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp27_ = sa;
#line 453 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp27_ != NULL, "sa != null");
#line 454 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp28_ = sa;
#line 454 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp29_ = gxml_css_selector_data_get_selector_type (_tmp28_);
#line 454 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp30_ = _tmp29_;
#line 454 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp30_ == GXML_CSS_SELECTOR_TYPE_ATTRIBUTE_EQUAL, "sa.selector_type == CssSelectorType.ATTRIBUTE_EQUAL");
#line 455 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp31_ = gxml_gom_document_new ();
#line 455 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		d = _tmp31_;
#line 456 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp32_ = d;
#line 456 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp33_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp32_, "HTML", &_inner_error_);
#line 456 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		r = _tmp33_;
#line 456 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 456 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 456 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 456 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 456 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 456 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9211 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 457 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp34_ = d;
#line 457 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp35_ = r;
#line 457 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp36_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp34_, (GXmlDomNode*) _tmp35_, &_inner_error_);
#line 457 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp37_ = _tmp36_;
#line 457 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp37_);
#line 457 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 457 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 457 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 457 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 457 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 457 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 457 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9238 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 458 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp38_ = d;
#line 458 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp39_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp38_, "BODY", &_inner_error_);
#line 458 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c1 = _tmp39_;
#line 458 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 458 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 458 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 458 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 458 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 458 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 458 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9261 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 459 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp40_ = r;
#line 459 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp41_ = c1;
#line 459 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp42_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp40_, (GXmlDomNode*) _tmp41_, &_inner_error_);
#line 459 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp43_ = _tmp42_;
#line 459 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp43_);
#line 459 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 459 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 459 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 459 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 459 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 459 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 459 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 459 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9290 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 460 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp44_ = d;
#line 460 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp45_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp44_, "radio", &_inner_error_);
#line 460 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c2 = _tmp45_;
#line 460 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 460 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 460 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 460 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 460 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 460 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 460 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 460 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9315 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 461 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp46_ = c2;
#line 461 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp46_, "enable", "true", &_inner_error_);
#line 461 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 461 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 461 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 461 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 461 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 461 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 461 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 461 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 461 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9340 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 462 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp47_ = r;
#line 462 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp48_ = c2;
#line 462 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp49_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp47_, (GXmlDomNode*) _tmp48_, &_inner_error_);
#line 462 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp50_ = _tmp49_;
#line 462 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp50_);
#line 462 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 462 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 462 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 462 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 462 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 462 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 462 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 462 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 462 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9371 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 463 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp52_ = cp;
#line 463 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp53_ = r;
#line 463 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp51_ = gxml_css_selector_parser_match (_tmp52_, _tmp53_, &_inner_error_);
#line 463 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 463 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 463 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 463 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 463 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 463 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 463 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 463 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 463 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9398 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 463 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp51_, "!cp.match (r)");
#line 464 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp55_ = cp;
#line 464 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp56_ = c1;
#line 464 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp54_ = gxml_css_selector_parser_match (_tmp55_, _tmp56_, &_inner_error_);
#line 464 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 464 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 464 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 464 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 464 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 464 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 464 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 464 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 464 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9427 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 464 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp54_, "!cp.match (c1)");
#line 465 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp58_ = cp;
#line 465 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp59_ = c2;
#line 465 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp57_ = gxml_css_selector_parser_match (_tmp58_, _tmp59_, &_inner_error_);
#line 465 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 465 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 465 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 465 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 465 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 465 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 465 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 465 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 465 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9456 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 465 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp57_, "cp.match (c2)");
#line 442 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 442 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 442 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 442 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 442 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 442 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (si);
#line 442 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 442 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 9477 "CssSelectorTest.c"
	}
	goto __finally12;
	__catch12_g_error:
	{
		GError* e = NULL;
		GError* _tmp60_;
		const gchar* _tmp61_;
		gchar* _tmp62_;
		gchar* _tmp63_;
#line 442 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		e = _inner_error_;
#line 442 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_inner_error_ = NULL;
#line 467 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp60_ = e;
#line 467 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp61_ = _tmp60_->message;
#line 467 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp62_ = g_strconcat ("ERROR: ", _tmp61_, NULL);
#line 467 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp63_ = _tmp62_;
#line 467 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:467: %s", _tmp63_);
#line 467 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_free0 (_tmp63_);
#line 442 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_error_free0 (e);
#line 9505 "CssSelectorTest.c"
	}
	__finally12:
#line 442 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 442 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 442 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_clear_error (&_inner_error_);
#line 442 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		return;
#line 9516 "CssSelectorTest.c"
	}
}


static void
___lambda296__gtest_func (void)
{
#line 441 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	__lambda296_ ();
#line 9526 "CssSelectorTest.c"
}


static void
__lambda297_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelectorData* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelectorData* _tmp11_;
		GXmlCssSelectorData* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelectorData* si = NULL;
		GXmlCssSelectorParser* _tmp15_;
		GeeList* _tmp16_;
		GeeList* _tmp17_;
		gpointer _tmp18_;
		GXmlCssSelectorData* _tmp19_;
		GXmlCssSelectorData* _tmp20_;
		GXmlCssSelectorType _tmp21_;
		GXmlCssSelectorType _tmp22_;
		GXmlCssSelectorData* sa = NULL;
		GXmlCssSelectorParser* _tmp23_;
		GeeList* _tmp24_;
		GeeList* _tmp25_;
		gpointer _tmp26_;
		GXmlCssSelectorData* _tmp27_;
		GXmlCssSelectorData* _tmp28_;
		GXmlCssSelectorType _tmp29_;
		GXmlCssSelectorType _tmp30_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp31_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlGomDocument* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomNode* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomNode* _tmp42_;
		GXmlDomNode* _tmp43_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp44_;
		GXmlDomElement* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomNode* _tmp49_;
		GXmlDomNode* _tmp50_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp51_;
		GXmlDomElement* _tmp52_;
		GXmlDomElement* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomNode* _tmp56_;
		GXmlDomNode* _tmp57_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp58_;
		GXmlDomElement* _tmp59_;
		GXmlDomElement* _tmp60_;
		GXmlDomElement* _tmp61_;
		GXmlDomElement* _tmp62_;
		GXmlDomNode* _tmp63_;
		GXmlDomNode* _tmp64_;
		GXmlDomElement* c5 = NULL;
		GXmlGomDocument* _tmp65_;
		GXmlDomElement* _tmp66_;
		GXmlDomElement* _tmp67_;
		GXmlDomElement* _tmp68_;
		GXmlDomNode* _tmp69_;
		GXmlDomNode* _tmp70_;
		GXmlDomElement* _tmp71_;
		GXmlDomElement* _tmp72_;
		GXmlDomElement* _tmp73_;
		GXmlDomElement* _tmp74_;
		GXmlDomElement* _tmp75_;
		gboolean _tmp76_ = FALSE;
		GXmlCssSelectorParser* _tmp77_;
		GXmlDomElement* _tmp78_;
		gboolean _tmp79_ = FALSE;
		GXmlCssSelectorParser* _tmp80_;
		GXmlDomElement* _tmp81_;
		gboolean _tmp82_ = FALSE;
		GXmlCssSelectorParser* _tmp83_;
		GXmlDomElement* _tmp84_;
		gboolean _tmp85_ = FALSE;
		GXmlCssSelectorParser* _tmp86_;
		GXmlDomElement* _tmp87_;
		gboolean _tmp88_ = FALSE;
		GXmlCssSelectorParser* _tmp89_;
		GXmlDomElement* _tmp90_;
		gboolean _tmp91_ = FALSE;
		GXmlCssSelectorParser* _tmp92_;
		GXmlDomElement* _tmp93_;
		GXmlDomDocument* d2 = NULL;
		GXmlGDocument* _tmp94_;
		GXmlDomDocument* _tmp95_;
		GXmlDomElement* r2 = NULL;
		GXmlDomDocument* _tmp96_;
		GXmlDomElement* _tmp97_;
		GXmlDomDocument* _tmp98_;
		GXmlDomElement* _tmp99_;
		GXmlDomNode* _tmp100_;
		GXmlDomNode* _tmp101_;
		GXmlDomElement* c1g = NULL;
		GXmlDomDocument* _tmp102_;
		GXmlDomElement* _tmp103_;
		GXmlDomElement* _tmp104_;
		GXmlDomElement* _tmp105_;
		GXmlDomNode* _tmp106_;
		GXmlDomNode* _tmp107_;
		GXmlDomElement* c2g = NULL;
		GXmlDomDocument* _tmp108_;
		GXmlDomElement* _tmp109_;
		GXmlDomElement* _tmp110_;
		GXmlDomElement* _tmp111_;
		GXmlDomElement* _tmp112_;
		GXmlDomNode* _tmp113_;
		GXmlDomNode* _tmp114_;
		GXmlDomElement* c3g = NULL;
		GXmlDomDocument* _tmp115_;
		GXmlDomElement* _tmp116_;
		GXmlDomElement* _tmp117_;
		GXmlDomElement* _tmp118_;
		GXmlDomElement* _tmp119_;
		GXmlDomNode* _tmp120_;
		GXmlDomNode* _tmp121_;
		GXmlDomElement* c4g = NULL;
		GXmlDomDocument* _tmp122_;
		GXmlDomElement* _tmp123_;
		GXmlDomElement* _tmp124_;
		GXmlDomElement* _tmp125_;
		GXmlDomElement* _tmp126_;
		GXmlDomNode* _tmp127_;
		GXmlDomNode* _tmp128_;
		GXmlDomElement* c5g = NULL;
		GXmlDomDocument* _tmp129_;
		GXmlDomElement* _tmp130_;
		GXmlDomElement* _tmp131_;
		GXmlDomElement* _tmp132_;
		GXmlDomNode* _tmp133_;
		GXmlDomNode* _tmp134_;
		gboolean _tmp135_ = FALSE;
		GXmlCssSelectorParser* _tmp136_;
		GXmlDomElement* _tmp137_;
		gboolean _tmp138_ = FALSE;
		GXmlCssSelectorParser* _tmp139_;
		GXmlDomElement* _tmp140_;
		gboolean _tmp141_ = FALSE;
		GXmlCssSelectorParser* _tmp142_;
		GXmlDomElement* _tmp143_;
		gboolean _tmp144_ = FALSE;
		GXmlCssSelectorParser* _tmp145_;
		GXmlDomElement* _tmp146_;
		gboolean _tmp147_ = FALSE;
		GXmlCssSelectorParser* _tmp148_;
		GXmlDomElement* _tmp149_;
		gboolean _tmp150_ = FALSE;
		GXmlCssSelectorParser* _tmp151_;
		GXmlDomElement* _tmp152_;
#line 472 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 472 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		cp = _tmp0_;
#line 473 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp1_ = cp;
#line 473 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "child:empty", &_inner_error_);
#line 473 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 473 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9718 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 474 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp2_ = cp;
#line 474 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 474 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 474 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 474 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 474 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 3, "cp.selectors.size == 3");
#line 475 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp7_ = cp;
#line 475 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 475 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 475 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 475 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		s = (GXmlCssSelectorData*) _tmp10_;
#line 476 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp11_ = s;
#line 476 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 477 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp12_ = s;
#line 477 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_data_get_selector_type (_tmp12_);
#line 477 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 477 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 478 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp15_ = cp;
#line 478 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_parser_get_selectors (_tmp15_);
#line 478 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 478 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp18_ = gee_list_get (_tmp17_, 1);
#line 478 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		si = (GXmlCssSelectorData*) _tmp18_;
#line 479 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp19_ = si;
#line 479 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp19_ != NULL, "si != null");
#line 480 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp20_ = si;
#line 480 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp21_ = gxml_css_selector_data_get_selector_type (_tmp20_);
#line 480 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp22_ = _tmp21_;
#line 480 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp22_ == GXML_CSS_SELECTOR_TYPE_INSIDE, "si.selector_type == CssSelectorType.INSIDE");
#line 481 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp23_ = cp;
#line 481 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_parser_get_selectors (_tmp23_);
#line 481 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 481 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp26_ = gee_list_get (_tmp25_, 2);
#line 481 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		sa = (GXmlCssSelectorData*) _tmp26_;
#line 482 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp27_ = sa;
#line 482 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp27_ != NULL, "sa != null");
#line 483 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp28_ = sa;
#line 483 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp29_ = gxml_css_selector_data_get_selector_type (_tmp28_);
#line 483 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp30_ = _tmp29_;
#line 483 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp30_ == GXML_CSS_SELECTOR_TYPE_PSEUDO, "sa.selector_type == CssSelectorType.PSEUDO");
#line 484 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp31_ = gxml_gom_document_new ();
#line 484 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		d = _tmp31_;
#line 485 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp32_ = d;
#line 485 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp33_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp32_, "toplevel", &_inner_error_);
#line 485 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		r = _tmp33_;
#line 485 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 485 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 485 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 485 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 485 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 485 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9821 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 486 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp34_ = d;
#line 486 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp35_ = r;
#line 486 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp36_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp34_, (GXmlDomNode*) _tmp35_, &_inner_error_);
#line 486 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp37_ = _tmp36_;
#line 486 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp37_);
#line 486 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 486 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 486 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 486 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 486 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 486 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 486 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9848 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 487 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp38_ = d;
#line 487 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp39_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp38_, "child", &_inner_error_);
#line 487 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c1 = _tmp39_;
#line 487 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 487 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 487 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 487 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 487 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 487 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 487 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9871 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 488 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp40_ = r;
#line 488 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp41_ = c1;
#line 488 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp42_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp40_, (GXmlDomNode*) _tmp41_, &_inner_error_);
#line 488 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp43_ = _tmp42_;
#line 488 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp43_);
#line 488 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 488 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 488 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 488 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 488 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 488 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 488 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 488 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9900 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 489 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp44_ = d;
#line 489 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp45_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp44_, "child", &_inner_error_);
#line 489 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c2 = _tmp45_;
#line 489 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 489 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 489 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 489 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 489 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 489 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 489 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 489 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9925 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 490 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp46_ = c2;
#line 490 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp46_, "prop-name", "subval", &_inner_error_);
#line 490 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 490 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 490 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 490 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 490 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 490 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 490 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 490 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 490 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9950 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 491 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp47_ = r;
#line 491 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp48_ = c2;
#line 491 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp49_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp47_, (GXmlDomNode*) _tmp48_, &_inner_error_);
#line 491 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp50_ = _tmp49_;
#line 491 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp50_);
#line 491 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 491 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 491 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 491 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 491 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 491 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 491 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 491 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 491 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9981 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 492 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp51_ = d;
#line 492 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp52_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp51_, "child", &_inner_error_);
#line 492 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c3 = _tmp52_;
#line 492 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 492 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 492 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 492 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 492 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 492 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 492 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 492 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 492 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10008 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 493 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp53_ = c3;
#line 493 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp53_, "prop-name", "techval", &_inner_error_);
#line 493 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 493 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 493 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 493 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 493 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 493 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 493 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 493 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 493 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 493 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10035 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 494 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp54_ = r;
#line 494 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp55_ = c3;
#line 494 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp56_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp54_, (GXmlDomNode*) _tmp55_, &_inner_error_);
#line 494 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp57_ = _tmp56_;
#line 494 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp57_);
#line 494 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 494 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 494 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 494 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 494 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 494 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 494 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 494 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 494 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 494 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10068 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 495 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp58_ = d;
#line 495 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp59_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp58_, "child", &_inner_error_);
#line 495 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c4 = _tmp59_;
#line 495 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 495 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 495 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 495 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 495 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 495 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 495 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 495 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 495 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 495 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10097 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 496 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp60_ = c4;
#line 496 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp60_, "prop-name", "secondaryvalue", &_inner_error_);
#line 496 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 496 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 496 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 496 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 496 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 496 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 496 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 496 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 496 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 496 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 496 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10126 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 497 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp61_ = r;
#line 497 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp62_ = c4;
#line 497 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp63_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp61_, (GXmlDomNode*) _tmp62_, &_inner_error_);
#line 497 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp64_ = _tmp63_;
#line 497 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp64_);
#line 497 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 497 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 497 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 497 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 497 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 497 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 497 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 497 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 497 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 497 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 497 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10161 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 498 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp65_ = d;
#line 498 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp66_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp65_, "common", &_inner_error_);
#line 498 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c5 = _tmp66_;
#line 498 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 498 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 498 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 498 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 498 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 498 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 498 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 498 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 498 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 498 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 498 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10192 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 499 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp67_ = c4;
#line 499 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp68_ = c5;
#line 499 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp69_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp67_, (GXmlDomNode*) _tmp68_, &_inner_error_);
#line 499 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp70_ = _tmp69_;
#line 499 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp70_);
#line 499 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 499 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 499 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 499 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 499 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 499 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 499 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 499 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 499 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 499 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 499 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 499 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10229 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 500 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp71_ = c1;
#line 500 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!gxml_dom_node_has_child_nodes ((GXmlDomNode*) _tmp71_), "!c1.has_child_nodes ()");
#line 501 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp72_ = c2;
#line 501 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!gxml_dom_node_has_child_nodes ((GXmlDomNode*) _tmp72_), "!c2.has_child_nodes ()");
#line 502 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp73_ = c3;
#line 502 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!gxml_dom_node_has_child_nodes ((GXmlDomNode*) _tmp73_), "!c3.has_child_nodes ()");
#line 503 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp74_ = c4;
#line 503 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (gxml_dom_node_has_child_nodes ((GXmlDomNode*) _tmp74_), "c4.has_child_nodes ()");
#line 504 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp75_ = c5;
#line 504 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!gxml_dom_node_has_child_nodes ((GXmlDomNode*) _tmp75_), "!c5.has_child_nodes ()");
#line 505 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp77_ = cp;
#line 505 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp78_ = r;
#line 505 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp76_ = gxml_css_selector_parser_match (_tmp77_, _tmp78_, &_inner_error_);
#line 505 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 505 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 505 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 505 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 505 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 505 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 505 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 505 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 505 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 505 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 505 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 505 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10282 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 505 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp76_, "!cp.match (r)");
#line 506 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp80_ = cp;
#line 506 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp81_ = c1;
#line 506 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp79_ = gxml_css_selector_parser_match (_tmp80_, _tmp81_, &_inner_error_);
#line 506 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 506 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 506 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 506 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 506 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 506 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 506 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 506 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 506 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 506 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 506 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 506 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10317 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 506 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp79_, "cp.match (c1)");
#line 507 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp83_ = cp;
#line 507 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp84_ = c2;
#line 507 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp82_ = gxml_css_selector_parser_match (_tmp83_, _tmp84_, &_inner_error_);
#line 507 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 507 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 507 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 507 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 507 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 507 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 507 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 507 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 507 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 507 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 507 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 507 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10352 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 507 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp82_, "cp.match (c2)");
#line 508 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp86_ = cp;
#line 508 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp87_ = c3;
#line 508 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp85_ = gxml_css_selector_parser_match (_tmp86_, _tmp87_, &_inner_error_);
#line 508 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 508 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 508 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 508 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 508 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 508 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 508 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 508 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 508 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 508 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 508 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 508 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10387 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 508 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp85_, "cp.match (c3)");
#line 509 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp89_ = cp;
#line 509 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp90_ = c4;
#line 509 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp88_ = gxml_css_selector_parser_match (_tmp89_, _tmp90_, &_inner_error_);
#line 509 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 509 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 509 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 509 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 509 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 509 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 509 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 509 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 509 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 509 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 509 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 509 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10422 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 509 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp88_, "!cp.match (c4)");
#line 510 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp92_ = cp;
#line 510 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp93_ = c5;
#line 510 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp91_ = gxml_css_selector_parser_match (_tmp92_, _tmp93_, &_inner_error_);
#line 510 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 510 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 510 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 510 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 510 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 510 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 510 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 510 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 510 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 510 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 510 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 510 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10457 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 510 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp91_, "!cp.match (c5)");
#line 511 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp94_ = gxml_gdocument_new ();
#line 511 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp95_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp94_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp94_) : NULL;
#line 511 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (_tmp95_ == NULL) {
#line 511 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (_tmp94_);
#line 10470 "CssSelectorTest.c"
		}
#line 511 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		d2 = _tmp95_;
#line 512 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp96_ = d2;
#line 512 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp97_ = gxml_dom_document_create_element (_tmp96_, "toplevel", &_inner_error_);
#line 512 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		r2 = _tmp97_;
#line 512 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 512 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 512 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 512 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 512 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 512 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 512 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 512 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 512 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 512 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 512 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 512 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 512 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10506 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 513 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp98_ = d2;
#line 513 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp99_ = r2;
#line 513 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp100_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp98_, (GXmlDomNode*) _tmp99_, &_inner_error_);
#line 513 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp101_ = _tmp100_;
#line 513 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp101_);
#line 513 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 513 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 513 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 513 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 513 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 513 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 513 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 513 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 513 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 513 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 513 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 513 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 513 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 513 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10547 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 514 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp102_ = d2;
#line 514 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp103_ = gxml_dom_document_create_element (_tmp102_, "child", &_inner_error_);
#line 514 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c1g = _tmp103_;
#line 514 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 514 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 514 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 514 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 514 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 514 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 514 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 514 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 514 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 514 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 514 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 514 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 514 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 514 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10584 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 515 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp104_ = r2;
#line 515 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp105_ = c1g;
#line 515 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp106_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp104_, (GXmlDomNode*) _tmp105_, &_inner_error_);
#line 515 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp107_ = _tmp106_;
#line 515 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp107_);
#line 515 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 515 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 515 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 515 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 515 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 515 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 515 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 515 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 515 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 515 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 515 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 515 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 515 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 515 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 515 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10627 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 516 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp108_ = d2;
#line 516 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp109_ = gxml_dom_document_create_element (_tmp108_, "child", &_inner_error_);
#line 516 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c2g = _tmp109_;
#line 516 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 516 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 516 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 516 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 516 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 516 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 516 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 516 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 516 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 516 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 516 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 516 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 516 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 516 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 516 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10666 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 517 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp110_ = c2g;
#line 517 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp110_, "prop-name", "subval", &_inner_error_);
#line 517 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 517 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 517 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 517 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 517 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 517 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 517 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 517 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 517 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 517 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 517 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 517 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 517 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 517 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 517 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 517 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10705 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 518 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp111_ = r2;
#line 518 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp112_ = c2g;
#line 518 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp113_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp111_, (GXmlDomNode*) _tmp112_, &_inner_error_);
#line 518 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp114_ = _tmp113_;
#line 518 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp114_);
#line 518 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 518 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 518 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 518 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 518 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 518 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 518 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 518 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 518 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 518 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 518 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 518 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 518 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 518 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 518 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 518 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10750 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 519 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp115_ = d2;
#line 519 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp116_ = gxml_dom_document_create_element (_tmp115_, "child", &_inner_error_);
#line 519 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c3g = _tmp116_;
#line 519 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 519 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 519 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 519 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 519 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 519 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 519 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 519 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 519 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 519 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 519 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 519 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 519 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 519 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 519 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 519 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10791 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 520 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp117_ = c3g;
#line 520 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp117_, "prop-name", "techval", &_inner_error_);
#line 520 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 520 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 520 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 520 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 520 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 520 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 520 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 520 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 520 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 520 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 520 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 520 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 520 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 520 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 520 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 520 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 520 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10832 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp118_ = r2;
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp119_ = c3g;
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp120_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp118_, (GXmlDomNode*) _tmp119_, &_inner_error_);
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp121_ = _tmp120_;
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp121_);
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 521 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10879 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 522 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp122_ = d2;
#line 522 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp123_ = gxml_dom_document_create_element (_tmp122_, "child", &_inner_error_);
#line 522 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c4g = _tmp123_;
#line 522 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 522 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 522 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 522 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 522 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 522 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 522 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 522 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 522 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 522 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 522 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 522 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 522 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 522 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 522 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 522 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 522 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10922 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 523 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp124_ = c4g;
#line 523 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp124_, "prop-name", "secondaryvalue", &_inner_error_);
#line 523 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 523 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 523 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 523 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 523 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 523 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 523 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 523 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 523 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 523 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 523 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 523 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 523 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 523 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 523 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 523 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 523 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 523 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10965 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp125_ = r2;
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp126_ = c4g;
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp127_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp125_, (GXmlDomNode*) _tmp126_, &_inner_error_);
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp128_ = _tmp127_;
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp128_);
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 524 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11014 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 525 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp129_ = d2;
#line 525 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp130_ = gxml_dom_document_create_element (_tmp129_, "common", &_inner_error_);
#line 525 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c5g = _tmp130_;
#line 525 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 525 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 525 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 525 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 525 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 525 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 525 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 525 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 525 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 525 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 525 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 525 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 525 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 525 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 525 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 525 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 525 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 525 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11059 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp131_ = c4g;
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp132_ = c5g;
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp133_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp131_, (GXmlDomNode*) _tmp132_, &_inner_error_);
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp134_ = _tmp133_;
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp134_);
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 526 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11110 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp136_ = cp;
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp137_ = r;
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp135_ = gxml_css_selector_parser_match (_tmp136_, _tmp137_, &_inner_error_);
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11157 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 527 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp135_, "!cp.match (r)");
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp139_ = cp;
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp140_ = c1g;
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp138_ = gxml_css_selector_parser_match (_tmp139_, _tmp140_, &_inner_error_);
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11206 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 528 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp138_, "cp.match (c1g)");
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp142_ = cp;
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp143_ = c2g;
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp141_ = gxml_css_selector_parser_match (_tmp142_, _tmp143_, &_inner_error_);
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11255 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 529 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp141_, "cp.match (c2g)");
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp145_ = cp;
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp146_ = c3g;
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp144_ = gxml_css_selector_parser_match (_tmp145_, _tmp146_, &_inner_error_);
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11304 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 530 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp144_, "cp.match (c3g)");
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp148_ = cp;
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp149_ = c4g;
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp147_ = gxml_css_selector_parser_match (_tmp148_, _tmp149_, &_inner_error_);
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11353 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 531 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp147_, "!cp.match (c4g)");
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp151_ = cp;
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp152_ = c5g;
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp150_ = gxml_css_selector_parser_match (_tmp151_, _tmp152_, &_inner_error_);
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11402 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 532 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp150_, "!cp.match (c5g)");
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c5g);
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c4g);
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c3g);
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c2g);
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c1g);
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (r2);
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (d2);
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c5);
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (si);
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 11443 "CssSelectorTest.c"
	}
	goto __finally13;
	__catch13_g_error:
	{
		GError* e = NULL;
		GError* _tmp153_;
		const gchar* _tmp154_;
		gchar* _tmp155_;
		gchar* _tmp156_;
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		e = _inner_error_;
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_inner_error_ = NULL;
#line 534 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp153_ = e;
#line 534 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp154_ = _tmp153_->message;
#line 534 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp155_ = g_strconcat ("ERROR: ", _tmp154_, NULL);
#line 534 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp156_ = _tmp155_;
#line 534 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:534: %s", _tmp156_);
#line 534 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_free0 (_tmp156_);
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_error_free0 (e);
#line 11471 "CssSelectorTest.c"
	}
	__finally13:
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_clear_error (&_inner_error_);
#line 471 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		return;
#line 11482 "CssSelectorTest.c"
	}
}


static void
___lambda297__gtest_func (void)
{
#line 470 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	__lambda297_ ();
#line 11492 "CssSelectorTest.c"
}


static void
__lambda298_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelectorData* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelectorData* _tmp11_;
		GXmlCssSelectorData* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelectorData* si = NULL;
		GXmlCssSelectorParser* _tmp15_;
		GeeList* _tmp16_;
		GeeList* _tmp17_;
		gpointer _tmp18_;
		GXmlCssSelectorData* _tmp19_;
		GXmlCssSelectorData* _tmp20_;
		GXmlCssSelectorType _tmp21_;
		GXmlCssSelectorType _tmp22_;
		GXmlCssSelectorData* sa = NULL;
		GXmlCssSelectorParser* _tmp23_;
		GeeList* _tmp24_;
		GeeList* _tmp25_;
		gpointer _tmp26_;
		GXmlCssSelectorData* _tmp27_;
		GXmlCssSelectorData* _tmp28_;
		GXmlCssSelectorType _tmp29_;
		GXmlCssSelectorType _tmp30_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp31_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlGomDocument* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomNode* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomNode* _tmp42_;
		GXmlDomNode* _tmp43_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp44_;
		GXmlDomElement* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomNode* _tmp49_;
		GXmlDomNode* _tmp50_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp51_;
		GXmlDomElement* _tmp52_;
		GXmlDomElement* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomNode* _tmp56_;
		GXmlDomNode* _tmp57_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp58_;
		GXmlDomElement* _tmp59_;
		GXmlDomElement* _tmp60_;
		GXmlDomElement* _tmp61_;
		GXmlDomElement* _tmp62_;
		GXmlDomNode* _tmp63_;
		GXmlDomNode* _tmp64_;
		GXmlDomElement* c5 = NULL;
		GXmlGomDocument* _tmp65_;
		GXmlDomElement* _tmp66_;
		GXmlDomElement* _tmp67_;
		GXmlDomElement* _tmp68_;
		GXmlDomNode* _tmp69_;
		GXmlDomNode* _tmp70_;
		GXmlDomElement* c6 = NULL;
		GXmlGomDocument* _tmp71_;
		GXmlDomElement* _tmp72_;
		GXmlDomElement* _tmp73_;
		GXmlDomElement* _tmp74_;
		GXmlDomNode* _tmp75_;
		GXmlDomNode* _tmp76_;
		GXmlDomElement* _tmp77_;
		GXmlDomElement* _tmp78_;
		GXmlDomNode* _tmp79_;
		GXmlDomNode* _tmp80_;
		GXmlDomParentNode* _tmp81_;
		GXmlDomParentNode* _tmp82_;
		GXmlDomElement* _tmp83_;
		GXmlDomElement* _tmp84_;
		GXmlDomElement* _tmp85_;
		GXmlDomElement* _tmp86_;
		GXmlDomElement* _tmp87_;
		GXmlDomNode* _tmp88_;
		GXmlDomNode* _tmp89_;
		GXmlDomParentNode* _tmp90_;
		GXmlDomParentNode* _tmp91_;
		GXmlDomElement* _tmp92_;
		GXmlDomElement* _tmp93_;
		GXmlDomElement* _tmp94_;
		GXmlDomElement* _tmp95_;
		GXmlDomElement* _tmp96_;
		GXmlDomNode* _tmp97_;
		GXmlDomNode* _tmp98_;
		GXmlDomParentNode* _tmp99_;
		GXmlDomParentNode* _tmp100_;
		GXmlDomElement* _tmp101_;
		GXmlDomElement* _tmp102_;
		GXmlDomElement* _tmp103_;
		GXmlDomElement* _tmp104_;
		GXmlDomElement* _tmp105_;
		GXmlDomNode* _tmp106_;
		GXmlDomNode* _tmp107_;
		GXmlDomParentNode* _tmp108_;
		GXmlDomParentNode* _tmp109_;
		GXmlDomElement* _tmp110_;
		GXmlDomElement* _tmp111_;
		GXmlDomElement* _tmp112_;
		GXmlDomElement* _tmp113_;
		GXmlDomElement* _tmp114_;
		GXmlDomNode* _tmp115_;
		GXmlDomNode* _tmp116_;
		GXmlDomParentNode* _tmp117_;
		GXmlDomParentNode* _tmp118_;
		GXmlDomElement* _tmp119_;
		GXmlDomElement* _tmp120_;
		GXmlDomElement* _tmp121_;
		GXmlDomElement* _tmp122_;
		GXmlDomElement* _tmp123_;
		GXmlDomNode* _tmp124_;
		GXmlDomNode* _tmp125_;
		GXmlDomParentNode* _tmp126_;
		GXmlDomParentNode* _tmp127_;
		GXmlDomElement* _tmp128_;
		GXmlDomElement* _tmp129_;
		GXmlDomElement* _tmp130_;
		gboolean _tmp131_ = FALSE;
		GXmlCssSelectorParser* _tmp132_;
		GXmlDomElement* _tmp133_;
		gboolean _tmp134_ = FALSE;
		GXmlCssSelectorParser* _tmp135_;
		GXmlDomElement* _tmp136_;
		gboolean _tmp137_ = FALSE;
		GXmlCssSelectorParser* _tmp138_;
		GXmlDomElement* _tmp139_;
		gboolean _tmp140_ = FALSE;
		GXmlCssSelectorParser* _tmp141_;
		GXmlDomElement* _tmp142_;
		gboolean _tmp143_ = FALSE;
		GXmlCssSelectorParser* _tmp144_;
		GXmlDomElement* _tmp145_;
		gboolean _tmp146_ = FALSE;
		GXmlCssSelectorParser* _tmp147_;
		GXmlDomElement* _tmp148_;
		gboolean _tmp149_ = FALSE;
		GXmlCssSelectorParser* _tmp150_;
		GXmlDomElement* _tmp151_;
		GXmlDomDocument* d2 = NULL;
		GXmlGDocument* _tmp152_;
		GXmlDomDocument* _tmp153_;
		GXmlDomElement* r2 = NULL;
		GXmlDomDocument* _tmp154_;
		GXmlDomElement* _tmp155_;
		GXmlDomDocument* _tmp156_;
		GXmlDomElement* _tmp157_;
		GXmlDomNode* _tmp158_;
		GXmlDomNode* _tmp159_;
		GXmlDomElement* c1g = NULL;
		GXmlDomDocument* _tmp160_;
		GXmlDomElement* _tmp161_;
		GXmlDomElement* _tmp162_;
		GXmlDomElement* _tmp163_;
		GXmlDomNode* _tmp164_;
		GXmlDomNode* _tmp165_;
		GXmlDomElement* c2g = NULL;
		GXmlDomDocument* _tmp166_;
		GXmlDomElement* _tmp167_;
		GXmlDomElement* _tmp168_;
		GXmlDomElement* _tmp169_;
		GXmlDomElement* _tmp170_;
		GXmlDomNode* _tmp171_;
		GXmlDomNode* _tmp172_;
		GXmlDomElement* c3g = NULL;
		GXmlDomDocument* _tmp173_;
		GXmlDomElement* _tmp174_;
		GXmlDomElement* _tmp175_;
		GXmlDomElement* _tmp176_;
		GXmlDomElement* _tmp177_;
		GXmlDomNode* _tmp178_;
		GXmlDomNode* _tmp179_;
		GXmlDomElement* c4g = NULL;
		GXmlDomDocument* _tmp180_;
		GXmlDomElement* _tmp181_;
		GXmlDomElement* _tmp182_;
		GXmlDomElement* _tmp183_;
		GXmlDomElement* _tmp184_;
		GXmlDomNode* _tmp185_;
		GXmlDomNode* _tmp186_;
		GXmlDomElement* c5g = NULL;
		GXmlDomDocument* _tmp187_;
		GXmlDomElement* _tmp188_;
		GXmlDomElement* _tmp189_;
		GXmlDomElement* _tmp190_;
		GXmlDomNode* _tmp191_;
		GXmlDomNode* _tmp192_;
		GXmlDomElement* c6g = NULL;
		GXmlDomDocument* _tmp193_;
		GXmlDomElement* _tmp194_;
		GXmlDomElement* _tmp195_;
		GXmlDomElement* _tmp196_;
		GXmlDomNode* _tmp197_;
		GXmlDomNode* _tmp198_;
		gboolean _tmp199_ = FALSE;
		GXmlCssSelectorParser* _tmp200_;
		GXmlDomElement* _tmp201_;
		gboolean _tmp202_ = FALSE;
		GXmlCssSelectorParser* _tmp203_;
		GXmlDomElement* _tmp204_;
		gboolean _tmp205_ = FALSE;
		GXmlCssSelectorParser* _tmp206_;
		GXmlDomElement* _tmp207_;
		gboolean _tmp208_ = FALSE;
		GXmlCssSelectorParser* _tmp209_;
		GXmlDomElement* _tmp210_;
		gboolean _tmp211_ = FALSE;
		GXmlCssSelectorParser* _tmp212_;
		GXmlDomElement* _tmp213_;
		gboolean _tmp214_ = FALSE;
		GXmlCssSelectorParser* _tmp215_;
		GXmlDomElement* _tmp216_;
		gboolean _tmp217_ = FALSE;
		GXmlCssSelectorParser* _tmp218_;
		GXmlDomElement* _tmp219_;
#line 539 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 539 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		cp = _tmp0_;
#line 540 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp1_ = cp;
#line 540 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "second:first-child", &_inner_error_);
#line 540 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 540 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11753 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 541 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp2_ = cp;
#line 541 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 541 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 541 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 541 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 541 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 3, "cp.selectors.size == 3");
#line 542 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp7_ = cp;
#line 542 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 542 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 542 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 542 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		s = (GXmlCssSelectorData*) _tmp10_;
#line 543 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp11_ = s;
#line 543 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 544 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp12_ = s;
#line 544 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_data_get_selector_type (_tmp12_);
#line 544 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 544 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 545 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp15_ = cp;
#line 545 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_parser_get_selectors (_tmp15_);
#line 545 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 545 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp18_ = gee_list_get (_tmp17_, 1);
#line 545 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		si = (GXmlCssSelectorData*) _tmp18_;
#line 546 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp19_ = si;
#line 546 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp19_ != NULL, "si != null");
#line 547 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp20_ = si;
#line 547 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp21_ = gxml_css_selector_data_get_selector_type (_tmp20_);
#line 547 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp22_ = _tmp21_;
#line 547 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp22_ == GXML_CSS_SELECTOR_TYPE_INSIDE, "si.selector_type == CssSelectorType.INSIDE");
#line 548 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp23_ = cp;
#line 548 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_parser_get_selectors (_tmp23_);
#line 548 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 548 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp26_ = gee_list_get (_tmp25_, 2);
#line 548 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		sa = (GXmlCssSelectorData*) _tmp26_;
#line 549 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp27_ = sa;
#line 549 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp27_ != NULL, "sa != null");
#line 550 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp28_ = sa;
#line 550 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp29_ = gxml_css_selector_data_get_selector_type (_tmp28_);
#line 550 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp30_ = _tmp29_;
#line 550 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp30_ == GXML_CSS_SELECTOR_TYPE_PSEUDO, "sa.selector_type == CssSelectorType.PSEUDO");
#line 551 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp31_ = gxml_gom_document_new ();
#line 551 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		d = _tmp31_;
#line 552 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp32_ = d;
#line 552 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp33_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp32_, "toplevel", &_inner_error_);
#line 552 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		r = _tmp33_;
#line 552 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 552 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 552 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 552 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 552 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 552 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11856 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 553 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp34_ = d;
#line 553 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp35_ = r;
#line 553 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp36_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp34_, (GXmlDomNode*) _tmp35_, &_inner_error_);
#line 553 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp37_ = _tmp36_;
#line 553 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp37_);
#line 553 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 553 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 553 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 553 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 553 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 553 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 553 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11883 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 554 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp38_ = d;
#line 554 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp39_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp38_, "child", &_inner_error_);
#line 554 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c1 = _tmp39_;
#line 554 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 554 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 554 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 554 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 554 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 554 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 554 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11906 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 555 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp40_ = r;
#line 555 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp41_ = c1;
#line 555 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp42_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp40_, (GXmlDomNode*) _tmp41_, &_inner_error_);
#line 555 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp43_ = _tmp42_;
#line 555 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp43_);
#line 555 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 555 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 555 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 555 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 555 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 555 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 555 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 555 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11935 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 556 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp44_ = d;
#line 556 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp45_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp44_, "child", &_inner_error_);
#line 556 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c2 = _tmp45_;
#line 556 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 556 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 556 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 556 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 556 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 556 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 556 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 556 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11960 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 557 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp46_ = c2;
#line 557 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp46_, "prop-name", "subval", &_inner_error_);
#line 557 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 557 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 557 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 557 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 557 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 557 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 557 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 557 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 557 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11985 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 558 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp47_ = r;
#line 558 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp48_ = c2;
#line 558 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp49_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp47_, (GXmlDomNode*) _tmp48_, &_inner_error_);
#line 558 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp50_ = _tmp49_;
#line 558 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp50_);
#line 558 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 558 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 558 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 558 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 558 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 558 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 558 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 558 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 558 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12016 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 559 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp51_ = d;
#line 559 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp52_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp51_, "child", &_inner_error_);
#line 559 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c3 = _tmp52_;
#line 559 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 559 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 559 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 559 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 559 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 559 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 559 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 559 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 559 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12043 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 560 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp53_ = c3;
#line 560 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp53_, "prop-name", "techval", &_inner_error_);
#line 560 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 560 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 560 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 560 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 560 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 560 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 560 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 560 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 560 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 560 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12070 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 561 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp54_ = r;
#line 561 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp55_ = c3;
#line 561 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp56_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp54_, (GXmlDomNode*) _tmp55_, &_inner_error_);
#line 561 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp57_ = _tmp56_;
#line 561 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp57_);
#line 561 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 561 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 561 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 561 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 561 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 561 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 561 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 561 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 561 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 561 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12103 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 562 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp58_ = d;
#line 562 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp59_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp58_, "child", &_inner_error_);
#line 562 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c4 = _tmp59_;
#line 562 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 562 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 562 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 562 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 562 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 562 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 562 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 562 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 562 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 562 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12132 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 563 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp60_ = c4;
#line 563 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp60_, "prop-name", "secondaryvalue", &_inner_error_);
#line 563 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 563 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 563 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 563 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 563 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 563 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 563 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 563 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 563 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 563 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 563 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12161 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 564 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp61_ = r;
#line 564 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp62_ = c4;
#line 564 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp63_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp61_, (GXmlDomNode*) _tmp62_, &_inner_error_);
#line 564 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp64_ = _tmp63_;
#line 564 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp64_);
#line 564 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 564 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 564 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 564 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 564 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 564 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 564 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 564 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 564 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 564 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 564 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12196 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 565 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp65_ = d;
#line 565 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp66_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp65_, "second", &_inner_error_);
#line 565 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c5 = _tmp66_;
#line 565 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 565 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 565 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 565 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 565 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 565 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 565 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 565 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 565 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 565 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 565 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12227 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 566 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp67_ = c3;
#line 566 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp68_ = c5;
#line 566 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp69_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp67_, (GXmlDomNode*) _tmp68_, &_inner_error_);
#line 566 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp70_ = _tmp69_;
#line 566 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp70_);
#line 566 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 566 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 566 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 566 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 566 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 566 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 566 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 566 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 566 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 566 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 566 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 566 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12264 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 567 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp71_ = d;
#line 567 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp72_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp71_, "second", &_inner_error_);
#line 567 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c6 = _tmp72_;
#line 567 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 567 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 567 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 567 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 567 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 567 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 567 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 567 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 567 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 567 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 567 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 567 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12297 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 568 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp73_ = c4;
#line 568 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp74_ = c6;
#line 568 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp75_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp73_, (GXmlDomNode*) _tmp74_, &_inner_error_);
#line 568 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp76_ = _tmp75_;
#line 568 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp76_);
#line 568 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 568 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 568 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 568 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 568 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 568 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 568 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 568 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 568 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 568 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 568 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 568 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 568 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12336 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 569 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp77_ = c1;
#line 569 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp78_ = c1;
#line 569 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp79_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp78_);
#line 569 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp80_ = _tmp79_;
#line 569 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp81_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp80_, GXML_TYPE_DOM_PARENT_NODE) ? ((GXmlDomParentNode*) _tmp80_) : NULL;
#line 569 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (_tmp81_ == NULL) {
#line 569 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (_tmp80_);
#line 12353 "CssSelectorTest.c"
		}
#line 569 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp82_ = _tmp81_;
#line 569 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp83_ = gxml_dom_parent_node_get_first_element_child (_tmp82_);
#line 569 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp84_ = _tmp83_;
#line 569 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp85_ = _tmp84_;
#line 569 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp77_ == _tmp85_, "c1 == (c1.parent_node as DomParentNode).first_element_child");
#line 569 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp85_);
#line 569 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp82_);
#line 570 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp86_ = c2;
#line 570 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp87_ = c2;
#line 570 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp88_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp87_);
#line 570 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp89_ = _tmp88_;
#line 570 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp90_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp89_, GXML_TYPE_DOM_PARENT_NODE) ? ((GXmlDomParentNode*) _tmp89_) : NULL;
#line 570 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (_tmp90_ == NULL) {
#line 570 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (_tmp89_);
#line 12383 "CssSelectorTest.c"
		}
#line 570 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp91_ = _tmp90_;
#line 570 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp92_ = gxml_dom_parent_node_get_first_element_child (_tmp91_);
#line 570 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp93_ = _tmp92_;
#line 570 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp94_ = _tmp93_;
#line 570 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp86_ != _tmp94_, "c2 != (c2.parent_node as DomParentNode).first_element_child");
#line 570 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp94_);
#line 570 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp91_);
#line 571 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp95_ = c3;
#line 571 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp96_ = c3;
#line 571 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp97_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp96_);
#line 571 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp98_ = _tmp97_;
#line 571 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp99_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp98_, GXML_TYPE_DOM_PARENT_NODE) ? ((GXmlDomParentNode*) _tmp98_) : NULL;
#line 571 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (_tmp99_ == NULL) {
#line 571 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (_tmp98_);
#line 12413 "CssSelectorTest.c"
		}
#line 571 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp100_ = _tmp99_;
#line 571 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp101_ = gxml_dom_parent_node_get_first_element_child (_tmp100_);
#line 571 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp102_ = _tmp101_;
#line 571 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp103_ = _tmp102_;
#line 571 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp95_ != _tmp103_, "c3 != (c3.parent_node as DomParentNode).first_element_child");
#line 571 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp103_);
#line 571 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp100_);
#line 572 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp104_ = c4;
#line 572 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp105_ = c4;
#line 572 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp106_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp105_);
#line 572 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp107_ = _tmp106_;
#line 572 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp108_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp107_, GXML_TYPE_DOM_PARENT_NODE) ? ((GXmlDomParentNode*) _tmp107_) : NULL;
#line 572 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (_tmp108_ == NULL) {
#line 572 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (_tmp107_);
#line 12443 "CssSelectorTest.c"
		}
#line 572 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp109_ = _tmp108_;
#line 572 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp110_ = gxml_dom_parent_node_get_first_element_child (_tmp109_);
#line 572 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp111_ = _tmp110_;
#line 572 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp112_ = _tmp111_;
#line 572 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp104_ != _tmp112_, "c4 != (c4.parent_node as DomParentNode).first_element_child");
#line 572 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp112_);
#line 572 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp109_);
#line 573 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp113_ = c5;
#line 573 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp114_ = c5;
#line 573 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp115_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp114_);
#line 573 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp116_ = _tmp115_;
#line 573 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp117_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp116_, GXML_TYPE_DOM_PARENT_NODE) ? ((GXmlDomParentNode*) _tmp116_) : NULL;
#line 573 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (_tmp117_ == NULL) {
#line 573 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (_tmp116_);
#line 12473 "CssSelectorTest.c"
		}
#line 573 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp118_ = _tmp117_;
#line 573 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp119_ = gxml_dom_parent_node_get_first_element_child (_tmp118_);
#line 573 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp120_ = _tmp119_;
#line 573 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp121_ = _tmp120_;
#line 573 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp113_ == _tmp121_, "c5 == (c5.parent_node as DomParentNode).first_element_child");
#line 573 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp121_);
#line 573 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp118_);
#line 574 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp122_ = c6;
#line 574 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp123_ = c6;
#line 574 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp124_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp123_);
#line 574 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp125_ = _tmp124_;
#line 574 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp126_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp125_, GXML_TYPE_DOM_PARENT_NODE) ? ((GXmlDomParentNode*) _tmp125_) : NULL;
#line 574 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (_tmp126_ == NULL) {
#line 574 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (_tmp125_);
#line 12503 "CssSelectorTest.c"
		}
#line 574 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp127_ = _tmp126_;
#line 574 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp128_ = gxml_dom_parent_node_get_first_element_child (_tmp127_);
#line 574 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp129_ = _tmp128_;
#line 574 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp130_ = _tmp129_;
#line 574 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp122_ == _tmp130_, "c6 == (c6.parent_node as DomParentNode).first_element_child");
#line 574 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp130_);
#line 574 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp127_);
#line 575 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp132_ = cp;
#line 575 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp133_ = r;
#line 575 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp131_ = gxml_css_selector_parser_match (_tmp132_, _tmp133_, &_inner_error_);
#line 575 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 575 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 575 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 575 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 575 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 575 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 575 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 575 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 575 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 575 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 575 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 575 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 575 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12551 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 575 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp131_, "!cp.match (r)");
#line 576 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp135_ = cp;
#line 576 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp136_ = c1;
#line 576 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp134_ = gxml_css_selector_parser_match (_tmp135_, _tmp136_, &_inner_error_);
#line 576 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 576 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 576 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 576 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 576 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 576 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 576 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 576 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 576 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 576 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 576 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 576 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 576 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12588 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 576 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp134_, "!cp.match (c1)");
#line 577 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp138_ = cp;
#line 577 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp139_ = c2;
#line 577 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp137_ = gxml_css_selector_parser_match (_tmp138_, _tmp139_, &_inner_error_);
#line 577 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 577 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 577 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 577 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 577 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 577 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 577 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 577 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 577 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 577 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 577 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 577 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 577 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12625 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 577 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp137_, "!cp.match (c2)");
#line 578 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp141_ = cp;
#line 578 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp142_ = c3;
#line 578 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp140_ = gxml_css_selector_parser_match (_tmp141_, _tmp142_, &_inner_error_);
#line 578 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 578 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 578 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 578 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 578 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 578 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 578 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 578 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 578 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 578 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 578 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 578 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 578 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12662 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 578 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp140_, "!cp.match (c3)");
#line 579 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp144_ = cp;
#line 579 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp145_ = c4;
#line 579 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp143_ = gxml_css_selector_parser_match (_tmp144_, _tmp145_, &_inner_error_);
#line 579 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 579 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 579 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 579 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 579 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 579 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 579 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 579 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 579 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 579 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 579 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 579 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 579 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12699 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 579 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp143_, "!cp.match (c4)");
#line 580 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp147_ = cp;
#line 580 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp148_ = c5;
#line 580 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp146_ = gxml_css_selector_parser_match (_tmp147_, _tmp148_, &_inner_error_);
#line 580 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 580 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 580 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 580 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 580 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 580 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 580 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 580 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 580 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 580 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 580 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 580 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 580 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12736 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 580 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp146_, "cp.match (c5)");
#line 581 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp150_ = cp;
#line 581 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp151_ = c6;
#line 581 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp149_ = gxml_css_selector_parser_match (_tmp150_, _tmp151_, &_inner_error_);
#line 581 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 581 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 581 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 581 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 581 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 581 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 581 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 581 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 581 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 581 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 581 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 581 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 581 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12773 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 581 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp149_, "cp.match (c6)");
#line 582 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp152_ = gxml_gdocument_new ();
#line 582 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp153_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp152_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp152_) : NULL;
#line 582 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (_tmp153_ == NULL) {
#line 582 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (_tmp152_);
#line 12786 "CssSelectorTest.c"
		}
#line 582 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		d2 = _tmp153_;
#line 583 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp154_ = d2;
#line 583 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp155_ = gxml_dom_document_create_element (_tmp154_, "toplevel", &_inner_error_);
#line 583 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		r2 = _tmp155_;
#line 583 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 583 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 583 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 583 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 583 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 583 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 583 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 583 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 583 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 583 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 583 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 583 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 583 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 583 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12824 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 584 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp156_ = d2;
#line 584 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp157_ = r2;
#line 584 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp158_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp156_, (GXmlDomNode*) _tmp157_, &_inner_error_);
#line 584 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp159_ = _tmp158_;
#line 584 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp159_);
#line 584 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 584 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 584 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 584 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 584 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 584 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 584 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 584 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 584 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 584 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 584 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 584 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 584 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 584 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 584 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12867 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 585 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp160_ = d2;
#line 585 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp161_ = gxml_dom_document_create_element (_tmp160_, "child", &_inner_error_);
#line 585 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c1g = _tmp161_;
#line 585 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 585 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 585 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 585 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 585 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 585 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 585 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 585 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 585 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 585 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 585 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 585 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 585 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 585 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 585 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12906 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 586 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp162_ = r2;
#line 586 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp163_ = c1g;
#line 586 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp164_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp162_, (GXmlDomNode*) _tmp163_, &_inner_error_);
#line 586 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp165_ = _tmp164_;
#line 586 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp165_);
#line 586 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 586 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 586 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 586 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 586 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 586 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 586 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 586 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 586 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 586 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 586 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 586 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 586 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 586 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 586 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 586 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12951 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 587 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp166_ = d2;
#line 587 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp167_ = gxml_dom_document_create_element (_tmp166_, "child", &_inner_error_);
#line 587 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c2g = _tmp167_;
#line 587 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 587 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 587 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 587 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 587 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 587 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 587 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 587 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 587 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 587 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 587 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 587 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 587 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 587 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 587 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 587 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12992 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 588 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp168_ = c2g;
#line 588 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp168_, "prop-name", "subval", &_inner_error_);
#line 588 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 588 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 588 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 588 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 588 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 588 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 588 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 588 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 588 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 588 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 588 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 588 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 588 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 588 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 588 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 588 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 588 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13033 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp169_ = r2;
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp170_ = c2g;
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp171_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp169_, (GXmlDomNode*) _tmp170_, &_inner_error_);
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp172_ = _tmp171_;
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp172_);
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 589 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13080 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 590 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp173_ = d2;
#line 590 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp174_ = gxml_dom_document_create_element (_tmp173_, "child", &_inner_error_);
#line 590 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c3g = _tmp174_;
#line 590 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 590 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 590 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 590 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 590 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 590 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 590 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 590 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 590 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 590 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 590 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 590 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 590 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 590 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 590 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 590 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 590 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13123 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 591 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp175_ = c3g;
#line 591 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp175_, "prop-name", "techval", &_inner_error_);
#line 591 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 591 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 591 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 591 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 591 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 591 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 591 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 591 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 591 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 591 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 591 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 591 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 591 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 591 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 591 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 591 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 591 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 591 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13166 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp176_ = r2;
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp177_ = c3g;
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp178_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp176_, (GXmlDomNode*) _tmp177_, &_inner_error_);
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp179_ = _tmp178_;
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp179_);
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 592 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13215 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 593 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp180_ = d2;
#line 593 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp181_ = gxml_dom_document_create_element (_tmp180_, "child", &_inner_error_);
#line 593 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c4g = _tmp181_;
#line 593 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 593 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 593 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 593 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 593 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 593 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 593 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 593 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 593 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 593 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 593 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 593 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 593 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 593 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 593 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 593 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 593 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 593 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13260 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 594 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp182_ = c4g;
#line 594 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp182_, "prop-name", "secondaryvalue", &_inner_error_);
#line 594 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 594 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 594 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 594 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 594 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 594 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 594 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 594 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 594 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 594 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 594 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 594 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 594 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 594 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 594 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 594 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 594 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 594 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 594 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13305 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp183_ = r2;
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp184_ = c4g;
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp185_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp183_, (GXmlDomNode*) _tmp184_, &_inner_error_);
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp186_ = _tmp185_;
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp186_);
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 595 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13356 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp187_ = d2;
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp188_ = gxml_dom_document_create_element (_tmp187_, "second", &_inner_error_);
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c5g = _tmp188_;
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 596 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13403 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp189_ = c3g;
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp190_ = c5g;
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp191_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp189_, (GXmlDomNode*) _tmp190_, &_inner_error_);
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp192_ = _tmp191_;
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp192_);
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 597 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13456 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp193_ = d2;
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp194_ = gxml_dom_document_create_element (_tmp193_, "second", &_inner_error_);
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c6g = _tmp194_;
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 598 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13505 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp195_ = c4g;
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp196_ = c6g;
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp197_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp195_, (GXmlDomNode*) _tmp196_, &_inner_error_);
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp198_ = _tmp197_;
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp198_);
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 599 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13560 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp200_ = cp;
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp201_ = r;
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp199_ = gxml_css_selector_parser_match (_tmp200_, _tmp201_, &_inner_error_);
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13611 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 600 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp199_, "!cp.match (r)");
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp203_ = cp;
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp204_ = c1g;
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp202_ = gxml_css_selector_parser_match (_tmp203_, _tmp204_, &_inner_error_);
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13664 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 601 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp202_, "!cp.match (c1g)");
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp206_ = cp;
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp207_ = c2g;
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp205_ = gxml_css_selector_parser_match (_tmp206_, _tmp207_, &_inner_error_);
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13717 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 602 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp205_, "!cp.match (c2g)");
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp209_ = cp;
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp210_ = c3g;
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp208_ = gxml_css_selector_parser_match (_tmp209_, _tmp210_, &_inner_error_);
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13770 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 603 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp208_, "!cp.match (c3g)");
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp212_ = cp;
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp213_ = c4g;
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp211_ = gxml_css_selector_parser_match (_tmp212_, _tmp213_, &_inner_error_);
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13823 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 604 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp211_, "!cp.match (c4g)");
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp215_ = cp;
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp216_ = c5g;
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp214_ = gxml_css_selector_parser_match (_tmp215_, _tmp216_, &_inner_error_);
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13876 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 605 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp214_, "cp.match (c5g)");
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp218_ = cp;
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp219_ = c6g;
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp217_ = gxml_css_selector_parser_match (_tmp218_, _tmp219_, &_inner_error_);
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13929 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 606 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp217_, "cp.match (c6g)");
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c6g);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c5g);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c4g);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c3g);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c2g);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c1g);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (r2);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (d2);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c6);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c5);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (si);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 13974 "CssSelectorTest.c"
	}
	goto __finally14;
	__catch14_g_error:
	{
		GError* e = NULL;
		GError* _tmp220_;
		const gchar* _tmp221_;
		gchar* _tmp222_;
		gchar* _tmp223_;
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		e = _inner_error_;
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_inner_error_ = NULL;
#line 608 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp220_ = e;
#line 608 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp221_ = _tmp220_->message;
#line 608 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp222_ = g_strconcat ("ERROR: ", _tmp221_, NULL);
#line 608 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp223_ = _tmp222_;
#line 608 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:608: %s", _tmp223_);
#line 608 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_free0 (_tmp223_);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_error_free0 (e);
#line 14002 "CssSelectorTest.c"
	}
	__finally14:
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_clear_error (&_inner_error_);
#line 538 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		return;
#line 14013 "CssSelectorTest.c"
	}
}


static void
___lambda298__gtest_func (void)
{
#line 537 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	__lambda298_ ();
#line 14023 "CssSelectorTest.c"
}


static void
__lambda299_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelectorData* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelectorData* _tmp11_;
		GXmlCssSelectorData* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelectorData* si = NULL;
		GXmlCssSelectorParser* _tmp15_;
		GeeList* _tmp16_;
		GeeList* _tmp17_;
		gpointer _tmp18_;
		GXmlCssSelectorData* _tmp19_;
		GXmlCssSelectorData* _tmp20_;
		GXmlCssSelectorType _tmp21_;
		GXmlCssSelectorType _tmp22_;
		GXmlCssSelectorData* sa = NULL;
		GXmlCssSelectorParser* _tmp23_;
		GeeList* _tmp24_;
		GeeList* _tmp25_;
		gpointer _tmp26_;
		GXmlCssSelectorData* _tmp27_;
		GXmlCssSelectorData* _tmp28_;
		GXmlCssSelectorType _tmp29_;
		GXmlCssSelectorType _tmp30_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp31_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlGomDocument* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomNode* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomNode* _tmp42_;
		GXmlDomNode* _tmp43_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp44_;
		GXmlDomElement* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomNode* _tmp49_;
		GXmlDomNode* _tmp50_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp51_;
		GXmlDomElement* _tmp52_;
		GXmlDomElement* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomNode* _tmp56_;
		GXmlDomNode* _tmp57_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp58_;
		GXmlDomElement* _tmp59_;
		GXmlDomElement* _tmp60_;
		GXmlDomElement* _tmp61_;
		GXmlDomElement* _tmp62_;
		GXmlDomNode* _tmp63_;
		GXmlDomNode* _tmp64_;
		GXmlDomElement* c5 = NULL;
		GXmlGomDocument* _tmp65_;
		GXmlDomElement* _tmp66_;
		GXmlDomElement* _tmp67_;
		GXmlDomElement* _tmp68_;
		GXmlDomNode* _tmp69_;
		GXmlDomNode* _tmp70_;
		GXmlDomElement* c6 = NULL;
		GXmlGomDocument* _tmp71_;
		GXmlDomElement* _tmp72_;
		GXmlDomElement* _tmp73_;
		GXmlDomElement* _tmp74_;
		GXmlDomNode* _tmp75_;
		GXmlDomNode* _tmp76_;
		GXmlDomElement* c7 = NULL;
		GXmlGomDocument* _tmp77_;
		GXmlDomElement* _tmp78_;
		GXmlDomElement* _tmp79_;
		GXmlDomElement* _tmp80_;
		GXmlDomNode* _tmp81_;
		GXmlDomNode* _tmp82_;
		gboolean _tmp83_ = FALSE;
		GXmlCssSelectorParser* _tmp84_;
		GXmlDomElement* _tmp85_;
		gboolean _tmp86_ = FALSE;
		GXmlCssSelectorParser* _tmp87_;
		GXmlDomElement* _tmp88_;
		gboolean _tmp89_ = FALSE;
		GXmlCssSelectorParser* _tmp90_;
		GXmlDomElement* _tmp91_;
		gboolean _tmp92_ = FALSE;
		GXmlCssSelectorParser* _tmp93_;
		GXmlDomElement* _tmp94_;
		gboolean _tmp95_ = FALSE;
		GXmlCssSelectorParser* _tmp96_;
		GXmlDomElement* _tmp97_;
		gboolean _tmp98_ = FALSE;
		GXmlCssSelectorParser* _tmp99_;
		GXmlDomElement* _tmp100_;
		gboolean _tmp101_ = FALSE;
		GXmlCssSelectorParser* _tmp102_;
		GXmlDomElement* _tmp103_;
		gboolean _tmp104_ = FALSE;
		GXmlCssSelectorParser* _tmp105_;
		GXmlDomElement* _tmp106_;
		GXmlDomDocument* d2 = NULL;
		GXmlGDocument* _tmp107_;
		GXmlDomDocument* _tmp108_;
		GXmlDomElement* r2 = NULL;
		GXmlDomDocument* _tmp109_;
		GXmlDomElement* _tmp110_;
		GXmlDomDocument* _tmp111_;
		GXmlDomElement* _tmp112_;
		GXmlDomNode* _tmp113_;
		GXmlDomNode* _tmp114_;
		GXmlDomElement* c1g = NULL;
		GXmlDomDocument* _tmp115_;
		GXmlDomElement* _tmp116_;
		GXmlDomElement* _tmp117_;
		GXmlDomElement* _tmp118_;
		GXmlDomNode* _tmp119_;
		GXmlDomNode* _tmp120_;
		GXmlDomElement* c2g = NULL;
		GXmlDomDocument* _tmp121_;
		GXmlDomElement* _tmp122_;
		GXmlDomElement* _tmp123_;
		GXmlDomElement* _tmp124_;
		GXmlDomElement* _tmp125_;
		GXmlDomNode* _tmp126_;
		GXmlDomNode* _tmp127_;
		GXmlDomElement* c3g = NULL;
		GXmlDomDocument* _tmp128_;
		GXmlDomElement* _tmp129_;
		GXmlDomElement* _tmp130_;
		GXmlDomElement* _tmp131_;
		GXmlDomElement* _tmp132_;
		GXmlDomNode* _tmp133_;
		GXmlDomNode* _tmp134_;
		GXmlDomElement* c4g = NULL;
		GXmlDomDocument* _tmp135_;
		GXmlDomElement* _tmp136_;
		GXmlDomElement* _tmp137_;
		GXmlDomElement* _tmp138_;
		GXmlDomElement* _tmp139_;
		GXmlDomNode* _tmp140_;
		GXmlDomNode* _tmp141_;
		GXmlDomElement* c5g = NULL;
		GXmlDomDocument* _tmp142_;
		GXmlDomElement* _tmp143_;
		GXmlDomElement* _tmp144_;
		GXmlDomElement* _tmp145_;
		GXmlDomNode* _tmp146_;
		GXmlDomNode* _tmp147_;
		GXmlDomElement* c6g = NULL;
		GXmlDomDocument* _tmp148_;
		GXmlDomElement* _tmp149_;
		GXmlDomElement* _tmp150_;
		GXmlDomElement* _tmp151_;
		GXmlDomNode* _tmp152_;
		GXmlDomNode* _tmp153_;
		GXmlDomElement* c7g = NULL;
		GXmlDomDocument* _tmp154_;
		GXmlDomElement* _tmp155_;
		GXmlDomElement* _tmp156_;
		GXmlDomElement* _tmp157_;
		GXmlDomNode* _tmp158_;
		GXmlDomNode* _tmp159_;
		gboolean _tmp160_ = FALSE;
		GXmlCssSelectorParser* _tmp161_;
		GXmlDomElement* _tmp162_;
		gboolean _tmp163_ = FALSE;
		GXmlCssSelectorParser* _tmp164_;
		GXmlDomElement* _tmp165_;
		gboolean _tmp166_ = FALSE;
		GXmlCssSelectorParser* _tmp167_;
		GXmlDomElement* _tmp168_;
		gboolean _tmp169_ = FALSE;
		GXmlCssSelectorParser* _tmp170_;
		GXmlDomElement* _tmp171_;
		gboolean _tmp172_ = FALSE;
		GXmlCssSelectorParser* _tmp173_;
		GXmlDomElement* _tmp174_;
		gboolean _tmp175_ = FALSE;
		GXmlCssSelectorParser* _tmp176_;
		GXmlDomElement* _tmp177_;
		gboolean _tmp178_ = FALSE;
		GXmlCssSelectorParser* _tmp179_;
		GXmlDomElement* _tmp180_;
		gboolean _tmp181_ = FALSE;
		GXmlCssSelectorParser* _tmp182_;
		GXmlDomElement* _tmp183_;
#line 613 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 613 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		cp = _tmp0_;
#line 614 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp1_ = cp;
#line 614 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "second:last-child", &_inner_error_);
#line 614 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 614 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14250 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 615 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp2_ = cp;
#line 615 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 615 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 615 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 615 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 615 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 3, "cp.selectors.size == 3");
#line 616 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp7_ = cp;
#line 616 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 616 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 616 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 616 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		s = (GXmlCssSelectorData*) _tmp10_;
#line 617 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp11_ = s;
#line 617 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 618 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp12_ = s;
#line 618 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_data_get_selector_type (_tmp12_);
#line 618 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 618 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 619 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp15_ = cp;
#line 619 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_parser_get_selectors (_tmp15_);
#line 619 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 619 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp18_ = gee_list_get (_tmp17_, 1);
#line 619 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		si = (GXmlCssSelectorData*) _tmp18_;
#line 620 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp19_ = si;
#line 620 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp19_ != NULL, "si != null");
#line 621 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp20_ = si;
#line 621 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp21_ = gxml_css_selector_data_get_selector_type (_tmp20_);
#line 621 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp22_ = _tmp21_;
#line 621 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp22_ == GXML_CSS_SELECTOR_TYPE_INSIDE, "si.selector_type == CssSelectorType.INSIDE");
#line 622 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp23_ = cp;
#line 622 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_parser_get_selectors (_tmp23_);
#line 622 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 622 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp26_ = gee_list_get (_tmp25_, 2);
#line 622 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		sa = (GXmlCssSelectorData*) _tmp26_;
#line 623 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp27_ = sa;
#line 623 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp27_ != NULL, "sa != null");
#line 624 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp28_ = sa;
#line 624 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp29_ = gxml_css_selector_data_get_selector_type (_tmp28_);
#line 624 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp30_ = _tmp29_;
#line 624 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp30_ == GXML_CSS_SELECTOR_TYPE_PSEUDO, "sa.selector_type == CssSelectorType.PSEUDO");
#line 625 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp31_ = gxml_gom_document_new ();
#line 625 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		d = _tmp31_;
#line 626 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp32_ = d;
#line 626 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp33_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp32_, "toplevel", &_inner_error_);
#line 626 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		r = _tmp33_;
#line 626 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 626 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 626 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 626 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 626 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 626 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14353 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 627 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp34_ = d;
#line 627 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp35_ = r;
#line 627 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp36_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp34_, (GXmlDomNode*) _tmp35_, &_inner_error_);
#line 627 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp37_ = _tmp36_;
#line 627 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp37_);
#line 627 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 627 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 627 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 627 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 627 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 627 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 627 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14380 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 628 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp38_ = d;
#line 628 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp39_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp38_, "child", &_inner_error_);
#line 628 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c1 = _tmp39_;
#line 628 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 628 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 628 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 628 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 628 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 628 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 628 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14403 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 629 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp40_ = r;
#line 629 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp41_ = c1;
#line 629 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp42_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp40_, (GXmlDomNode*) _tmp41_, &_inner_error_);
#line 629 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp43_ = _tmp42_;
#line 629 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp43_);
#line 629 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 629 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 629 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 629 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 629 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 629 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 629 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 629 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14432 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 630 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp44_ = d;
#line 630 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp45_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp44_, "child", &_inner_error_);
#line 630 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c2 = _tmp45_;
#line 630 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 630 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 630 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 630 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 630 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 630 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 630 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 630 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14457 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 631 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp46_ = c2;
#line 631 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp46_, "prop-name", "subval", &_inner_error_);
#line 631 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 631 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 631 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 631 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 631 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 631 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 631 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 631 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 631 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14482 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 632 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp47_ = r;
#line 632 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp48_ = c2;
#line 632 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp49_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp47_, (GXmlDomNode*) _tmp48_, &_inner_error_);
#line 632 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp50_ = _tmp49_;
#line 632 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp50_);
#line 632 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 632 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 632 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 632 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 632 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 632 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 632 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 632 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 632 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14513 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 633 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp51_ = d;
#line 633 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp52_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp51_, "child", &_inner_error_);
#line 633 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c3 = _tmp52_;
#line 633 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 633 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 633 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 633 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 633 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 633 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 633 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 633 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 633 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14540 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 634 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp53_ = c3;
#line 634 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp53_, "prop-name", "techval", &_inner_error_);
#line 634 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 634 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 634 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 634 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 634 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 634 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 634 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 634 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 634 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 634 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14567 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 635 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp54_ = r;
#line 635 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp55_ = c3;
#line 635 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp56_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp54_, (GXmlDomNode*) _tmp55_, &_inner_error_);
#line 635 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp57_ = _tmp56_;
#line 635 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp57_);
#line 635 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 635 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 635 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 635 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 635 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 635 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 635 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 635 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 635 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 635 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14600 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 636 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp58_ = d;
#line 636 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp59_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp58_, "child", &_inner_error_);
#line 636 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c4 = _tmp59_;
#line 636 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 636 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 636 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 636 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 636 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 636 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 636 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 636 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 636 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 636 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14629 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 637 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp60_ = c4;
#line 637 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp60_, "prop-name", "secondaryvalue", &_inner_error_);
#line 637 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 637 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 637 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 637 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 637 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 637 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 637 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 637 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 637 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 637 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 637 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14658 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 638 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp61_ = r;
#line 638 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp62_ = c4;
#line 638 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp63_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp61_, (GXmlDomNode*) _tmp62_, &_inner_error_);
#line 638 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp64_ = _tmp63_;
#line 638 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp64_);
#line 638 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 638 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 638 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 638 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 638 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 638 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 638 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 638 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 638 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 638 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 638 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14693 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 639 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp65_ = d;
#line 639 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp66_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp65_, "second", &_inner_error_);
#line 639 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c5 = _tmp66_;
#line 639 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 639 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 639 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 639 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 639 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 639 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 639 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 639 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 639 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 639 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 639 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14724 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 640 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp67_ = c3;
#line 640 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp68_ = c5;
#line 640 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp69_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp67_, (GXmlDomNode*) _tmp68_, &_inner_error_);
#line 640 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp70_ = _tmp69_;
#line 640 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp70_);
#line 640 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 640 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 640 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 640 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 640 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 640 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 640 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 640 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 640 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 640 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 640 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 640 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14761 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 641 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp71_ = d;
#line 641 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp72_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp71_, "second", &_inner_error_);
#line 641 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c6 = _tmp72_;
#line 641 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 641 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 641 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 641 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 641 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 641 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 641 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 641 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 641 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 641 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 641 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 641 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14794 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 642 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp73_ = c4;
#line 642 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp74_ = c6;
#line 642 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp75_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp73_, (GXmlDomNode*) _tmp74_, &_inner_error_);
#line 642 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp76_ = _tmp75_;
#line 642 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp76_);
#line 642 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 642 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 642 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 642 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 642 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 642 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 642 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 642 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 642 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 642 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 642 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 642 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 642 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14833 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 643 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp77_ = d;
#line 643 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp78_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp77_, "second", &_inner_error_);
#line 643 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c7 = _tmp78_;
#line 643 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 643 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 643 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 643 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 643 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 643 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 643 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 643 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 643 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 643 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 643 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 643 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 643 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14868 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 644 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp79_ = c4;
#line 644 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp80_ = c7;
#line 644 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp81_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp79_, (GXmlDomNode*) _tmp80_, &_inner_error_);
#line 644 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp82_ = _tmp81_;
#line 644 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp82_);
#line 644 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 644 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 644 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 644 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 644 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 644 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 644 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 644 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 644 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 644 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 644 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 644 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 644 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 644 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14909 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 645 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp84_ = cp;
#line 645 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp85_ = r;
#line 645 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp83_ = gxml_css_selector_parser_match (_tmp84_, _tmp85_, &_inner_error_);
#line 645 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 645 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 645 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 645 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 645 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 645 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 645 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 645 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 645 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 645 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 645 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 645 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 645 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 645 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14946 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 645 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp83_, "!cp.match (r)");
#line 646 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp87_ = cp;
#line 646 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp88_ = c1;
#line 646 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp86_ = gxml_css_selector_parser_match (_tmp87_, _tmp88_, &_inner_error_);
#line 646 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 646 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 646 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 646 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 646 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 646 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 646 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 646 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 646 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 646 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 646 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 646 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 646 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 646 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14985 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 646 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp86_, "!cp.match (c1)");
#line 647 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp90_ = cp;
#line 647 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp91_ = c2;
#line 647 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp89_ = gxml_css_selector_parser_match (_tmp90_, _tmp91_, &_inner_error_);
#line 647 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 647 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 647 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 647 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 647 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 647 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 647 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 647 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 647 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 647 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 647 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 647 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 647 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 647 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15024 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 647 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp89_, "!cp.match (c2)");
#line 648 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp93_ = cp;
#line 648 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp94_ = c3;
#line 648 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp92_ = gxml_css_selector_parser_match (_tmp93_, _tmp94_, &_inner_error_);
#line 648 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 648 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 648 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 648 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 648 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 648 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 648 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 648 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 648 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 648 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 648 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 648 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 648 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 648 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15063 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 648 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp92_, "!cp.match (c3)");
#line 649 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp96_ = cp;
#line 649 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp97_ = c4;
#line 649 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp95_ = gxml_css_selector_parser_match (_tmp96_, _tmp97_, &_inner_error_);
#line 649 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 649 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 649 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 649 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 649 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 649 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 649 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 649 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 649 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 649 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 649 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 649 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 649 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 649 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15102 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 649 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp95_, "!cp.match (c4)");
#line 650 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp99_ = cp;
#line 650 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp100_ = c5;
#line 650 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp98_ = gxml_css_selector_parser_match (_tmp99_, _tmp100_, &_inner_error_);
#line 650 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 650 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 650 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 650 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 650 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 650 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 650 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 650 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 650 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 650 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 650 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 650 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 650 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 650 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15141 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 650 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp98_, "cp.match (c5)");
#line 651 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp102_ = cp;
#line 651 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp103_ = c6;
#line 651 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp101_ = gxml_css_selector_parser_match (_tmp102_, _tmp103_, &_inner_error_);
#line 651 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 651 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 651 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 651 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 651 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 651 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 651 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 651 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 651 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 651 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 651 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 651 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 651 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 651 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15180 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 651 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp101_, "!cp.match (c6)");
#line 652 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp105_ = cp;
#line 652 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp106_ = c7;
#line 652 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp104_ = gxml_css_selector_parser_match (_tmp105_, _tmp106_, &_inner_error_);
#line 652 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 652 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 652 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 652 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 652 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 652 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 652 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 652 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 652 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 652 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 652 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 652 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 652 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 652 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15219 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 652 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp104_, "cp.match (c7)");
#line 653 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp107_ = gxml_gdocument_new ();
#line 653 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp108_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp107_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp107_) : NULL;
#line 653 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (_tmp108_ == NULL) {
#line 653 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (_tmp107_);
#line 15232 "CssSelectorTest.c"
		}
#line 653 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		d2 = _tmp108_;
#line 654 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp109_ = d2;
#line 654 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp110_ = gxml_dom_document_create_element (_tmp109_, "toplevel", &_inner_error_);
#line 654 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		r2 = _tmp110_;
#line 654 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 654 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 654 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 654 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 654 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 654 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 654 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 654 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 654 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 654 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 654 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 654 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 654 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 654 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 654 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15272 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 655 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp111_ = d2;
#line 655 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp112_ = r2;
#line 655 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp113_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp111_, (GXmlDomNode*) _tmp112_, &_inner_error_);
#line 655 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp114_ = _tmp113_;
#line 655 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp114_);
#line 655 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 655 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 655 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 655 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 655 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 655 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 655 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 655 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 655 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 655 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 655 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 655 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 655 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 655 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 655 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 655 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15317 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 656 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp115_ = d2;
#line 656 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp116_ = gxml_dom_document_create_element (_tmp115_, "child", &_inner_error_);
#line 656 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c1g = _tmp116_;
#line 656 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 656 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 656 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 656 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 656 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 656 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 656 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 656 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 656 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 656 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 656 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 656 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 656 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 656 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 656 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 656 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15358 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp117_ = r2;
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp118_ = c1g;
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp119_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp117_, (GXmlDomNode*) _tmp118_, &_inner_error_);
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp120_ = _tmp119_;
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp120_);
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 657 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15405 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 658 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp121_ = d2;
#line 658 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp122_ = gxml_dom_document_create_element (_tmp121_, "child", &_inner_error_);
#line 658 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c2g = _tmp122_;
#line 658 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 658 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 658 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 658 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 658 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 658 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 658 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 658 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 658 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 658 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 658 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 658 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 658 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 658 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 658 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 658 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 658 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15448 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 659 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp123_ = c2g;
#line 659 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp123_, "prop-name", "subval", &_inner_error_);
#line 659 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 659 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 659 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 659 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 659 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 659 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 659 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 659 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 659 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 659 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 659 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 659 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 659 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 659 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 659 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 659 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 659 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 659 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15491 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp124_ = r2;
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp125_ = c2g;
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp126_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp124_, (GXmlDomNode*) _tmp125_, &_inner_error_);
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp127_ = _tmp126_;
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp127_);
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 660 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15540 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 661 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp128_ = d2;
#line 661 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp129_ = gxml_dom_document_create_element (_tmp128_, "child", &_inner_error_);
#line 661 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c3g = _tmp129_;
#line 661 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 661 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 661 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 661 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 661 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 661 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 661 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 661 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 661 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 661 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 661 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 661 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 661 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 661 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 661 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 661 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 661 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 661 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15585 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 662 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp130_ = c3g;
#line 662 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp130_, "prop-name", "techval", &_inner_error_);
#line 662 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 662 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 662 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 662 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 662 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 662 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 662 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 662 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 662 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 662 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 662 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 662 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 662 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 662 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 662 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 662 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 662 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 662 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 662 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15630 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp131_ = r2;
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp132_ = c3g;
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp133_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp131_, (GXmlDomNode*) _tmp132_, &_inner_error_);
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp134_ = _tmp133_;
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp134_);
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 663 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15681 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp135_ = d2;
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp136_ = gxml_dom_document_create_element (_tmp135_, "child", &_inner_error_);
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c4g = _tmp136_;
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 664 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15728 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp137_ = c4g;
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp137_, "prop-name", "secondaryvalue", &_inner_error_);
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 665 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15775 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp138_ = r2;
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp139_ = c4g;
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp140_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp138_, (GXmlDomNode*) _tmp139_, &_inner_error_);
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp141_ = _tmp140_;
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp141_);
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 666 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15828 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp142_ = d2;
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp143_ = gxml_dom_document_create_element (_tmp142_, "second", &_inner_error_);
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c5g = _tmp143_;
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 667 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15877 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp144_ = c3g;
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp145_ = c5g;
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp146_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp144_, (GXmlDomNode*) _tmp145_, &_inner_error_);
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp147_ = _tmp146_;
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp147_);
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 668 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15932 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp148_ = d2;
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp149_ = gxml_dom_document_create_element (_tmp148_, "second", &_inner_error_);
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c6g = _tmp149_;
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 669 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15983 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp150_ = c4g;
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp151_ = c6g;
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp152_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp150_, (GXmlDomNode*) _tmp151_, &_inner_error_);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp153_ = _tmp152_;
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp153_);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 670 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16040 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp154_ = d2;
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp155_ = gxml_dom_document_create_element (_tmp154_, "second", &_inner_error_);
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		c7g = _tmp155_;
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 671 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16093 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp156_ = c4g;
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp157_ = c7g;
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp158_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp156_, (GXmlDomNode*) _tmp157_, &_inner_error_);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp159_ = _tmp158_;
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (_tmp159_);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7g);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 672 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16152 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp161_ = cp;
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp162_ = r;
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp160_ = gxml_css_selector_parser_match (_tmp161_, _tmp162_, &_inner_error_);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7g);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16207 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 673 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp160_, "!cp.match (r)");
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp164_ = cp;
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp165_ = c1g;
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp163_ = gxml_css_selector_parser_match (_tmp164_, _tmp165_, &_inner_error_);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7g);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16264 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 674 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp163_, "!cp.match (c1g)");
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp167_ = cp;
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp168_ = c2g;
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp166_ = gxml_css_selector_parser_match (_tmp167_, _tmp168_, &_inner_error_);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7g);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16321 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 675 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp166_, "!cp.match (c2g)");
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp170_ = cp;
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp171_ = c3g;
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp169_ = gxml_css_selector_parser_match (_tmp170_, _tmp171_, &_inner_error_);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7g);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16378 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 676 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp169_, "!cp.match (c3g)");
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp173_ = cp;
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp174_ = c4g;
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp172_ = gxml_css_selector_parser_match (_tmp173_, _tmp174_, &_inner_error_);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7g);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16435 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 677 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp172_, "!cp.match (c4g)");
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp176_ = cp;
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp177_ = c5g;
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp175_ = gxml_css_selector_parser_match (_tmp176_, _tmp177_, &_inner_error_);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7g);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16492 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 678 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp175_, "cp.match (c5g)");
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp179_ = cp;
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp180_ = c6g;
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp178_ = gxml_css_selector_parser_match (_tmp179_, _tmp180_, &_inner_error_);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7g);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16549 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 679 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (!_tmp178_, "!cp.match (c6g)");
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp182_ = cp;
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp183_ = c7g;
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp181_ = gxml_css_selector_parser_match (_tmp182_, _tmp183_, &_inner_error_);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7g);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16606 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 680 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_vala_assert (_tmp181_, "cp.match (c7g)");
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c7g);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c6g);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c5g);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c4g);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c3g);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c2g);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c1g);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (r2);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (d2);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c7);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c6);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c5);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (si);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 16655 "CssSelectorTest.c"
	}
	goto __finally15;
	__catch15_g_error:
	{
		GError* e = NULL;
		GError* _tmp184_;
		const gchar* _tmp185_;
		gchar* _tmp186_;
		gchar* _tmp187_;
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		e = _inner_error_;
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_inner_error_ = NULL;
#line 682 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp184_ = e;
#line 682 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp185_ = _tmp184_->message;
#line 682 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp186_ = g_strconcat ("ERROR: ", _tmp185_, NULL);
#line 682 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_tmp187_ = _tmp186_;
#line 682 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:682: %s", _tmp187_);
#line 682 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_free0 (_tmp187_);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		_g_error_free0 (e);
#line 16683 "CssSelectorTest.c"
	}
	__finally15:
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		g_clear_error (&_inner_error_);
#line 612 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
		return;
#line 16694 "CssSelectorTest.c"
	}
}


static void
___lambda299__gtest_func (void)
{
#line 611 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	__lambda299_ ();
#line 16704 "CssSelectorTest.c"
}


void
css_selector_test_add_tests (void)
{
#line 27 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/all", ___lambda284__gtest_func);
#line 46 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element/node", ___lambda285__gtest_func);
#line 65 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element/attribute/value", ___lambda286__gtest_func);
#line 94 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element/attribute/contains", ___lambda287__gtest_func);
#line 131 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element/attribute/starts_with", ___lambda288__gtest_func);
#line 168 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element/attribute/starts_with_hyphen", ___lambda289__gtest_func);
#line 205 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element/attribute/ends_with", ___lambda290__gtest_func);
#line 242 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element/attribute-value-unquoted", ___lambda291__gtest_func);
#line 274 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element/attribute-value", ___lambda292__gtest_func);
#line 306 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element/class-only", ___lambda293__gtest_func);
#line 344 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element/class-element", ___lambda294__gtest_func);
#line 385 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/pseudo/root", ___lambda295__gtest_func);
#line 441 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/pseudo/non-hmtl/enable-disable-checked", ___lambda296__gtest_func);
#line 470 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/pseudo/empty", ___lambda297__gtest_func);
#line 537 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/pseudo/first-child", ___lambda298__gtest_func);
#line 611 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/pseudo/last-child", ___lambda299__gtest_func);
#line 16743 "CssSelectorTest.c"
}


CssSelectorTest*
css_selector_test_construct (GType object_type)
{
	CssSelectorTest* self = NULL;
#line 25 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	self = (CssSelectorTest*) gxml_test_construct (object_type);
#line 25 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	return self;
#line 16755 "CssSelectorTest.c"
}


CssSelectorTest*
css_selector_test_new (void)
{
#line 25 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	return css_selector_test_construct (TYPE_CSS_SELECTOR_TEST);
#line 16764 "CssSelectorTest.c"
}


static void
css_selector_test_class_init (CssSelectorTestClass * klass)
{
#line 25 "/home/despinosa/Proyectos/gxml/test/CssSelectorTest.vala"
	css_selector_test_parent_class = g_type_class_peek_parent (klass);
#line 16773 "CssSelectorTest.c"
}


static void
css_selector_test_instance_init (CssSelectorTest * self)
{
}


GType
css_selector_test_get_type (void)
{
	static volatile gsize css_selector_test_type_id__volatile = 0;
	if (g_once_init_enter (&css_selector_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (CssSelectorTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) css_selector_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (CssSelectorTest), 0, (GInstanceInitFunc) css_selector_test_instance_init, NULL };
		GType css_selector_test_type_id;
		css_selector_test_type_id = g_type_register_static (TYPE_GXML_TEST, "CssSelectorTest", &g_define_type_info, 0);
		g_once_init_leave (&css_selector_test_type_id__volatile, css_selector_test_type_id);
	}
	return css_selector_test_type_id__volatile;
}



