/* GomElementTest.c generated by valac 0.39.3.9-ecb8a, the Vala compiler
 * generated from GomElementTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* Notation.vala
 *
 * Copyright (C) 2016  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <gxml/gxml.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gio/gio.h>


#define TYPE_NO_INSTANTIATABLE (no_instantiatable_get_type ())
#define NO_INSTANTIATABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NO_INSTANTIATABLE, NoInstantiatable))
#define IS_NO_INSTANTIATABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NO_INSTANTIATABLE))
#define NO_INSTANTIATABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_NO_INSTANTIATABLE, NoInstantiatableIface))

typedef struct _NoInstantiatable NoInstantiatable;
typedef struct _NoInstantiatableIface NoInstantiatableIface;

#define TYPE_PROPERTY (property_get_type ())
#define PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PROPERTY, Property))
#define IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PROPERTY))
#define PROPERTY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_PROPERTY, PropertyIface))

typedef struct _Property Property;
typedef struct _PropertyIface PropertyIface;

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_GOM_ELEMENT_TEST (gom_element_test_get_type ())
#define GOM_ELEMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_ELEMENT_TEST, GomElementTest))
#define GOM_ELEMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_ELEMENT_TEST, GomElementTestClass))
#define IS_GOM_ELEMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_ELEMENT_TEST))
#define IS_GOM_ELEMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_ELEMENT_TEST))
#define GOM_ELEMENT_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_ELEMENT_TEST, GomElementTestClass))

typedef struct _GomElementTest GomElementTest;
typedef struct _GomElementTestClass GomElementTestClass;
typedef struct _GomElementTestPrivate GomElementTestPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define GOM_ELEMENT_TEST_TYPE_POTION (gom_element_test_potion_get_type ())
#define GOM_ELEMENT_TEST_POTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotion))
#define GOM_ELEMENT_TEST_POTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotionClass))
#define GOM_ELEMENT_TEST_IS_POTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_POTION))
#define GOM_ELEMENT_TEST_IS_POTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_POTION))
#define GOM_ELEMENT_TEST_POTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotionClass))

typedef struct _GomElementTestPotion GomElementTestPotion;
typedef struct _GomElementTestPotionClass GomElementTestPotionClass;

#define GOM_ELEMENT_TEST_TYPE_INGREDIENT (gom_element_test_ingredient_get_type ())
#define GOM_ELEMENT_TEST_INGREDIENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredient))
#define GOM_ELEMENT_TEST_INGREDIENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredientClass))
#define GOM_ELEMENT_TEST_IS_INGREDIENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_INGREDIENT))
#define GOM_ELEMENT_TEST_IS_INGREDIENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_INGREDIENT))
#define GOM_ELEMENT_TEST_INGREDIENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredientClass))

typedef struct _GomElementTestIngredient GomElementTestIngredient;
typedef struct _GomElementTestIngredientClass GomElementTestIngredientClass;

#define GOM_ELEMENT_TEST_METHOD_TYPE_MAP (gom_element_test_method_map_get_type ())
#define GOM_ELEMENT_TEST_METHOD_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_METHOD_TYPE_MAP, GomElementTestMethodMap))
#define GOM_ELEMENT_TEST_METHOD_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_METHOD_TYPE_MAP, GomElementTestMethodMapClass))
#define GOM_ELEMENT_TEST_METHOD_IS_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_METHOD_TYPE_MAP))
#define GOM_ELEMENT_TEST_METHOD_IS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_METHOD_TYPE_MAP))
#define GOM_ELEMENT_TEST_METHOD_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_METHOD_TYPE_MAP, GomElementTestMethodMapClass))

typedef struct _GomElementTestMethodMap GomElementTestMethodMap;
typedef struct _GomElementTestMethodMapClass GomElementTestMethodMapClass;

#define GOM_ELEMENT_TEST_TYPE_METHOD (gom_element_test_method_get_type ())
#define GOM_ELEMENT_TEST_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethod))
#define GOM_ELEMENT_TEST_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethodClass))
#define GOM_ELEMENT_TEST_IS_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_METHOD))
#define GOM_ELEMENT_TEST_IS_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_METHOD))
#define GOM_ELEMENT_TEST_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethodClass))

typedef struct _GomElementTestMethod GomElementTestMethod;
typedef struct _GomElementTestMethodClass GomElementTestMethodClass;

#define GOM_ELEMENT_TEST_TYPE_REPOSITORY (gom_element_test_repository_get_type ())
#define GOM_ELEMENT_TEST_REPOSITORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepository))
#define GOM_ELEMENT_TEST_REPOSITORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepositoryClass))
#define GOM_ELEMENT_TEST_IS_REPOSITORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_REPOSITORY))
#define GOM_ELEMENT_TEST_IS_REPOSITORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_REPOSITORY))
#define GOM_ELEMENT_TEST_REPOSITORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepositoryClass))

typedef struct _GomElementTestRepository GomElementTestRepository;
typedef struct _GomElementTestRepositoryClass GomElementTestRepositoryClass;

#define GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED (gom_element_test_parsed_delayed_get_type ())
#define GOM_ELEMENT_TEST_PARSED_DELAYED(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED, GomElementTestParsedDelayed))
#define GOM_ELEMENT_TEST_PARSED_DELAYED_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED, GomElementTestParsedDelayedClass))
#define GOM_ELEMENT_TEST_IS_PARSED_DELAYED(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED))
#define GOM_ELEMENT_TEST_IS_PARSED_DELAYED_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED))
#define GOM_ELEMENT_TEST_PARSED_DELAYED_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED, GomElementTestParsedDelayedClass))

typedef struct _GomElementTestParsedDelayed GomElementTestParsedDelayed;
typedef struct _GomElementTestParsedDelayedClass GomElementTestParsedDelayedClass;

#define GOM_ELEMENT_TEST_TYPE_TOP (gom_element_test_top_get_type ())
#define GOM_ELEMENT_TEST_TOP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTop))
#define GOM_ELEMENT_TEST_TOP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTopClass))
#define GOM_ELEMENT_TEST_IS_TOP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_TOP))
#define GOM_ELEMENT_TEST_IS_TOP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_TOP))
#define GOM_ELEMENT_TEST_TOP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTopClass))

typedef struct _GomElementTestTop GomElementTestTop;
typedef struct _GomElementTestTopClass GomElementTestTopClass;

#define GOM_ELEMENT_TEST_TYPE_GTOP (gom_element_test_gtop_get_type ())
#define GOM_ELEMENT_TEST_GTOP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTop))
#define GOM_ELEMENT_TEST_GTOP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTopClass))
#define GOM_ELEMENT_TEST_IS_GTOP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_GTOP))
#define GOM_ELEMENT_TEST_IS_GTOP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_GTOP))
#define GOM_ELEMENT_TEST_GTOP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTopClass))

typedef struct _GomElementTestGTop GomElementTestGTop;
typedef struct _GomElementTestGTopClass GomElementTestGTopClass;
typedef struct _GomElementTestParsedDelayedPrivate GomElementTestParsedDelayedPrivate;
enum  {
	GOM_ELEMENT_TEST_PARSED_DELAYED_0_PROPERTY,
	GOM_ELEMENT_TEST_PARSED_DELAYED_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_parsed_delayed_properties[GOM_ELEMENT_TEST_PARSED_DELAYED_NUM_PROPERTIES];

#define GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE (gom_element_test_instantiatable_get_type ())
#define GOM_ELEMENT_TEST_INSTANTIATABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatable))
#define GOM_ELEMENT_TEST_INSTANTIATABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatableClass))
#define GOM_ELEMENT_TEST_IS_INSTANTIATABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE))
#define GOM_ELEMENT_TEST_IS_INSTANTIATABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE))
#define GOM_ELEMENT_TEST_INSTANTIATABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatableClass))

typedef struct _GomElementTestInstantiatable GomElementTestInstantiatable;
typedef struct _GomElementTestInstantiatableClass GomElementTestInstantiatableClass;
typedef struct _GomElementTestInstantiatablePrivate GomElementTestInstantiatablePrivate;
enum  {
	GOM_ELEMENT_TEST_INSTANTIATABLE_0_PROPERTY,
	GOM_ELEMENT_TEST_INSTANTIATABLE_NAME_PROPERTY,
	GOM_ELEMENT_TEST_INSTANTIATABLE_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_instantiatable_properties[GOM_ELEMENT_TEST_INSTANTIATABLE_NUM_PROPERTIES];
typedef struct _GomElementTestTopPrivate GomElementTestTopPrivate;
enum  {
	GOM_ELEMENT_TEST_TOP_0_PROPERTY,
	GOM_ELEMENT_TEST_TOP_INST_PROPERTY,
	GOM_ELEMENT_TEST_TOP_INST_I_PROPERTY,
	GOM_ELEMENT_TEST_TOP_PQ_PROPERTY,
	GOM_ELEMENT_TEST_TOP_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_top_properties[GOM_ELEMENT_TEST_TOP_NUM_PROPERTIES];

#define GOM_ELEMENT_TEST_TYPE_GPROPERTY (gom_element_test_gproperty_get_type ())
#define GOM_ELEMENT_TEST_GPROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_GPROPERTY, GomElementTestGProperty))
#define GOM_ELEMENT_TEST_GPROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_GPROPERTY, GomElementTestGPropertyClass))
#define GOM_ELEMENT_TEST_IS_GPROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_GPROPERTY))
#define GOM_ELEMENT_TEST_IS_GPROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_GPROPERTY))
#define GOM_ELEMENT_TEST_GPROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_GPROPERTY, GomElementTestGPropertyClass))

typedef struct _GomElementTestGProperty GomElementTestGProperty;
typedef struct _GomElementTestGPropertyClass GomElementTestGPropertyClass;
typedef struct _GomElementTestGPropertyPrivate GomElementTestGPropertyPrivate;
enum  {
	GOM_ELEMENT_TEST_GPROPERTY_0_PROPERTY,
	GOM_ELEMENT_TEST_GPROPERTY_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_gproperty_properties[GOM_ELEMENT_TEST_GPROPERTY_NUM_PROPERTIES];
typedef struct _GomElementTestGTopPrivate GomElementTestGTopPrivate;
enum  {
	GOM_ELEMENT_TEST_GTOP_0_PROPERTY,
	GOM_ELEMENT_TEST_GTOP_INST_PROPERTY,
	GOM_ELEMENT_TEST_GTOP_INST_I_PROPERTY,
	GOM_ELEMENT_TEST_GTOP_GPQ_PROPERTY,
	GOM_ELEMENT_TEST_GTOP_PQ_PROPERTY,
	GOM_ELEMENT_TEST_GTOP_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_gtop_properties[GOM_ELEMENT_TEST_GTOP_NUM_PROPERTIES];
typedef struct _GomElementTestPotionPrivate GomElementTestPotionPrivate;
enum  {
	GOM_ELEMENT_TEST_POTION_0_PROPERTY,
	GOM_ELEMENT_TEST_POTION_CNAME_PROPERTY,
	GOM_ELEMENT_TEST_POTION_INGREDIENT_PROPERTY,
	GOM_ELEMENT_TEST_POTION_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_potion_properties[GOM_ELEMENT_TEST_POTION_NUM_PROPERTIES];
typedef struct _GomElementTestIngredientPrivate GomElementTestIngredientPrivate;
enum  {
	GOM_ELEMENT_TEST_INGREDIENT_0_PROPERTY,
	GOM_ELEMENT_TEST_INGREDIENT_CNAME_PROPERTY,
	GOM_ELEMENT_TEST_INGREDIENT_METHODS_PROPERTY,
	GOM_ELEMENT_TEST_INGREDIENT_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_ingredient_properties[GOM_ELEMENT_TEST_INGREDIENT_NUM_PROPERTIES];

#define GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP (gom_element_test_ingredient_map_get_type ())
#define GOM_ELEMENT_TEST_INGREDIENT_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP, GomElementTestIngredientMap))
#define GOM_ELEMENT_TEST_INGREDIENT_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP, GomElementTestIngredientMapClass))
#define GOM_ELEMENT_TEST_INGREDIENT_IS_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP))
#define GOM_ELEMENT_TEST_INGREDIENT_IS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP))
#define GOM_ELEMENT_TEST_INGREDIENT_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP, GomElementTestIngredientMapClass))

typedef struct _GomElementTestIngredientMap GomElementTestIngredientMap;
typedef struct _GomElementTestIngredientMapClass GomElementTestIngredientMapClass;
typedef struct _GomElementTestIngredientMapPrivate GomElementTestIngredientMapPrivate;
enum  {
	GOM_ELEMENT_TEST_INGREDIENT_MAP_0_PROPERTY,
	GOM_ELEMENT_TEST_INGREDIENT_MAP_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_ingredient_map_properties[GOM_ELEMENT_TEST_INGREDIENT_MAP_NUM_PROPERTIES];
typedef struct _GomElementTestMethodPrivate GomElementTestMethodPrivate;
enum  {
	GOM_ELEMENT_TEST_METHOD_0_PROPERTY,
	GOM_ELEMENT_TEST_METHOD_CNAME_PROPERTY,
	GOM_ELEMENT_TEST_METHOD_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_method_properties[GOM_ELEMENT_TEST_METHOD_NUM_PROPERTIES];
typedef struct _GomElementTestMethodMapPrivate GomElementTestMethodMapPrivate;
enum  {
	GOM_ELEMENT_TEST_METHOD_MAP_0_PROPERTY,
	GOM_ELEMENT_TEST_METHOD_MAP_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_method_map_properties[GOM_ELEMENT_TEST_METHOD_MAP_NUM_PROPERTIES];
typedef struct _GomElementTestRepositoryPrivate GomElementTestRepositoryPrivate;

#define GOM_ELEMENT_TEST_TYPE_NAMESPACE (gom_element_test_namespace_get_type ())
#define GOM_ELEMENT_TEST_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespace))
#define GOM_ELEMENT_TEST_NAMESPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespaceClass))
#define GOM_ELEMENT_TEST_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_NAMESPACE))
#define GOM_ELEMENT_TEST_IS_NAMESPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_NAMESPACE))
#define GOM_ELEMENT_TEST_NAMESPACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespaceClass))

typedef struct _GomElementTestNamespace GomElementTestNamespace;
typedef struct _GomElementTestNamespaceClass GomElementTestNamespaceClass;
enum  {
	GOM_ELEMENT_TEST_REPOSITORY_0_PROPERTY,
	GOM_ELEMENT_TEST_REPOSITORY_VERSION_PROPERTY,
	GOM_ELEMENT_TEST_REPOSITORY_NS_PROPERTY,
	GOM_ELEMENT_TEST_REPOSITORY_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_repository_properties[GOM_ELEMENT_TEST_REPOSITORY_NUM_PROPERTIES];
typedef struct _GomElementTestNamespacePrivate GomElementTestNamespacePrivate;

#define GOM_ELEMENT_TEST_TCLASS_TYPE_MAP (gom_element_test_tclass_map_get_type ())
#define GOM_ELEMENT_TEST_TCLASS_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TCLASS_TYPE_MAP, GomElementTestTClassMap))
#define GOM_ELEMENT_TEST_TCLASS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TCLASS_TYPE_MAP, GomElementTestTClassMapClass))
#define GOM_ELEMENT_TEST_TCLASS_IS_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TCLASS_TYPE_MAP))
#define GOM_ELEMENT_TEST_TCLASS_IS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TCLASS_TYPE_MAP))
#define GOM_ELEMENT_TEST_TCLASS_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TCLASS_TYPE_MAP, GomElementTestTClassMapClass))

typedef struct _GomElementTestTClassMap GomElementTestTClassMap;
typedef struct _GomElementTestTClassMapClass GomElementTestTClassMapClass;
enum  {
	GOM_ELEMENT_TEST_NAMESPACE_0_PROPERTY,
	GOM_ELEMENT_TEST_NAMESPACE_NAME_PROPERTY,
	GOM_ELEMENT_TEST_NAMESPACE_VERSION_PROPERTY,
	GOM_ELEMENT_TEST_NAMESPACE_CPREFIX_PROPERTY,
	GOM_ELEMENT_TEST_NAMESPACE_CLASSES_PROPERTY,
	GOM_ELEMENT_TEST_NAMESPACE_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_namespace_properties[GOM_ELEMENT_TEST_NAMESPACE_NUM_PROPERTIES];

#define GOM_ELEMENT_TEST_TYPE_TCLASS (gom_element_test_tclass_get_type ())
#define GOM_ELEMENT_TEST_TCLASS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClass))
#define GOM_ELEMENT_TEST_TCLASS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClassClass))
#define GOM_ELEMENT_TEST_IS_TCLASS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_TCLASS))
#define GOM_ELEMENT_TEST_IS_TCLASS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_TCLASS))
#define GOM_ELEMENT_TEST_TCLASS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClassClass))

typedef struct _GomElementTestTClass GomElementTestTClass;
typedef struct _GomElementTestTClassClass GomElementTestTClassClass;
typedef struct _GomElementTestTClassPrivate GomElementTestTClassPrivate;
enum  {
	GOM_ELEMENT_TEST_TCLASS_0_PROPERTY,
	GOM_ELEMENT_TEST_TCLASS_NAME_PROPERTY,
	GOM_ELEMENT_TEST_TCLASS_VERSION_PROPERTY,
	GOM_ELEMENT_TEST_TCLASS_CPREFIX_PROPERTY,
	GOM_ELEMENT_TEST_TCLASS_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_tclass_properties[GOM_ELEMENT_TEST_TCLASS_NUM_PROPERTIES];
typedef struct _GomElementTestTClassMapPrivate GomElementTestTClassMapPrivate;
enum  {
	GOM_ELEMENT_TEST_TCLASS_MAP_0_PROPERTY,
	GOM_ELEMENT_TEST_TCLASS_MAP_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_tclass_map_properties[GOM_ELEMENT_TEST_TCLASS_MAP_NUM_PROPERTIES];
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _NoInstantiatableIface {
	GTypeInterface parent_iface;
	const gchar* (*get_name) (NoInstantiatable* self);
	void (*set_name) (NoInstantiatable* self, const gchar* value);
};

struct _PropertyIface {
	GTypeInterface parent_iface;
};

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _GomElementTest {
	GXmlTest parent_instance;
	GomElementTestPrivate * priv;
};

struct _GomElementTestClass {
	GXmlTestClass parent_class;
};

struct _GomElementTestParsedDelayed {
	GXmlGomElement parent_instance;
	GomElementTestParsedDelayedPrivate * priv;
};

struct _GomElementTestParsedDelayedClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestInstantiatable {
	GXmlGomElement parent_instance;
	GomElementTestInstantiatablePrivate * priv;
};

struct _GomElementTestInstantiatableClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestInstantiatablePrivate {
	gchar* _name;
};

struct _GomElementTestTop {
	GXmlGomElement parent_instance;
	GomElementTestTopPrivate * priv;
};

struct _GomElementTestTopClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestTopPrivate {
	GomElementTestInstantiatable* _inst_i;
	Property* _pq;
};

struct _GomElementTestGProperty {
	GXmlGomString parent_instance;
	GomElementTestGPropertyPrivate * priv;
};

struct _GomElementTestGPropertyClass {
	GXmlGomStringClass parent_class;
};

struct _GomElementTestGTop {
	GXmlGomElement parent_instance;
	GomElementTestGTopPrivate * priv;
};

struct _GomElementTestGTopClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestGTopPrivate {
	NoInstantiatable* _inst;
	Property* _pq;
};

struct _GomElementTestPotion {
	GXmlGomElement parent_instance;
	GomElementTestPotionPrivate * priv;
};

struct _GomElementTestPotionClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestPotionPrivate {
	gchar* _cname;
	GomElementTestIngredient* _ingredient;
};

struct _GomElementTestIngredient {
	GXmlGomElement parent_instance;
	GomElementTestIngredientPrivate * priv;
};

struct _GomElementTestIngredientClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestIngredientPrivate {
	gchar* _cname;
	GomElementTestMethodMap* _methods;
};

struct _GomElementTestIngredientMap {
	GXmlGomHashMap parent_instance;
	GomElementTestIngredientMapPrivate * priv;
};

struct _GomElementTestIngredientMapClass {
	GXmlGomHashMapClass parent_class;
};

struct _GomElementTestMethod {
	GXmlGomElement parent_instance;
	GomElementTestMethodPrivate * priv;
};

struct _GomElementTestMethodClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestMethodPrivate {
	gchar* _cname;
};

struct _GomElementTestMethodMap {
	GXmlGomHashMap parent_instance;
	GomElementTestMethodMapPrivate * priv;
};

struct _GomElementTestMethodMapClass {
	GXmlGomHashMapClass parent_class;
};

struct _GomElementTestRepository {
	GXmlGomElement parent_instance;
	GomElementTestRepositoryPrivate * priv;
};

struct _GomElementTestRepositoryClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestRepositoryPrivate {
	gchar* _version;
	GomElementTestNamespace* _ns;
};

struct _GomElementTestNamespace {
	GXmlGomElement parent_instance;
	GomElementTestNamespacePrivate * priv;
};

struct _GomElementTestNamespaceClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestNamespacePrivate {
	GomElementTestTClassMap* _classes;
	gchar* _name;
	gchar* _version;
	gchar* _cprefix;
};

struct _GomElementTestTClass {
	GXmlGomElement parent_instance;
	GomElementTestTClassPrivate * priv;
};

struct _GomElementTestTClassClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestTClassPrivate {
	gchar* _name;
	gchar* _version;
	gchar* _cprefix;
};

struct _GomElementTestTClassMap {
	GXmlGomHashMap parent_instance;
	GomElementTestTClassMapPrivate * priv;
};

struct _GomElementTestTClassMapClass {
	GXmlGomHashMapClass parent_class;
};


static gpointer gom_element_test_parent_class = NULL;
static gpointer gom_element_test_parsed_delayed_parent_class = NULL;
static gpointer gom_element_test_instantiatable_parent_class = NULL;
static NoInstantiatableIface * gom_element_test_instantiatable_no_instantiatable_parent_iface = NULL;
static gpointer gom_element_test_top_parent_class = NULL;
static gpointer gom_element_test_gproperty_parent_class = NULL;
static PropertyIface * gom_element_test_gproperty_property_parent_iface = NULL;
static gpointer gom_element_test_gtop_parent_class = NULL;
static gpointer gom_element_test_potion_parent_class = NULL;
static gpointer gom_element_test_ingredient_parent_class = NULL;
static gpointer gom_element_test_ingredient_map_parent_class = NULL;
static GXmlMappeableElementIface * gom_element_test_ingredient_gxml_mappeable_element_parent_iface = NULL;
static gpointer gom_element_test_method_parent_class = NULL;
static gpointer gom_element_test_method_map_parent_class = NULL;
static GXmlMappeableElementIface * gom_element_test_method_gxml_mappeable_element_parent_iface = NULL;
static gpointer gom_element_test_repository_parent_class = NULL;
static gpointer gom_element_test_namespace_parent_class = NULL;
static gpointer gom_element_test_tclass_parent_class = NULL;
static gpointer gom_element_test_tclass_map_parent_class = NULL;
static GXmlMappeableElementIface * gom_element_test_tclass_gxml_mappeable_element_parent_iface = NULL;

GType no_instantiatable_get_type (void) G_GNUC_CONST;
const gchar* no_instantiatable_get_name (NoInstantiatable* self);
void no_instantiatable_set_name (NoInstantiatable* self, 
                                 const gchar* value);
GType property_get_type (void) G_GNUC_CONST;
gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name, 
                                  const gchar* nick, 
                                  const gchar* blurb, 
                                  GType object_type, 
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value, 
                          gpointer v_object);
void value_take_gxml_test (GValue* value, 
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType gom_element_test_get_type (void) G_GNUC_CONST;
void gom_element_test_add_tests (void);
static void __lambda241_ (void);
static void ___lambda241__gtest_func (void);
static void __lambda242_ (void);
static void ___lambda242__gtest_func (void);
static void __lambda243_ (void);
static void ___lambda243__gtest_func (void);
static void __lambda244_ (void);
static void ___lambda244__gtest_func (void);
static void __lambda245_ (void);
GType gom_element_test_potion_get_type (void) G_GNUC_CONST;
GomElementTestPotion* gom_element_test_potion_new (void);
GomElementTestPotion* gom_element_test_potion_construct (GType object_type);
const gchar* gom_element_test_potion_get_cname (GomElementTestPotion* self);
GType gom_element_test_ingredient_get_type (void) G_GNUC_CONST;
GomElementTestIngredient* gom_element_test_potion_get_ingredient (GomElementTestPotion* self);
const gchar* gom_element_test_ingredient_get_cname (GomElementTestIngredient* self);
GType gom_element_test_method_map_get_type (void) G_GNUC_CONST;
GomElementTestMethodMap* gom_element_test_ingredient_get_methods (GomElementTestIngredient* self);
GType gom_element_test_method_get_type (void) G_GNUC_CONST;
const gchar* gom_element_test_method_get_cname (GomElementTestMethod* self);
static void ___lambda245__gtest_func (void);
static void __lambda246_ (void);
GType gom_element_test_repository_get_type (void) G_GNUC_CONST;
GomElementTestRepository* gom_element_test_repository_new (void);
GomElementTestRepository* gom_element_test_repository_construct (GType object_type);
static void ___lambda246__gtest_func (void);
static void __lambda247_ (void);
static void ___lambda247__gtest_func (void);
static void __lambda248_ (void);
static void ___lambda248__gtest_func (void);
static void __lambda249_ (void);
static void ___lambda249__gtest_func (void);
static void __lambda250_ (void);
static void ___lambda250__gtest_func (void);
static void __lambda251_ (void);
static void ___lambda251__gtest_func (void);
static void __lambda252_ (void);
GType gom_element_test_parsed_delayed_get_type (void) G_GNUC_CONST;
GomElementTestParsedDelayed* gom_element_test_parsed_delayed_new (void);
GomElementTestParsedDelayed* gom_element_test_parsed_delayed_construct (GType object_type);
static void ___lambda252__gtest_func (void);
static void __lambda253_ (void);
static void ___lambda253__gtest_func (void);
static void __lambda254_ (void);
static void ___lambda254__gtest_func (void);
static void __lambda255_ (void);
static void ___lambda255__gtest_func (void);
static void __lambda256_ (void);
static void ___lambda256__gtest_func (void);
static void __lambda257_ (void);
static void ___lambda257__gtest_func (void);
static void __lambda258_ (void);
GType gom_element_test_top_get_type (void) G_GNUC_CONST;
GomElementTestTop* gom_element_test_top_new (void);
GomElementTestTop* gom_element_test_top_construct (GType object_type);
NoInstantiatable* gom_element_test_top_get_inst (GomElementTestTop* self);
static void ___lambda258__gtest_func (void);
static void __lambda259_ (void);
GType gom_element_test_gtop_get_type (void) G_GNUC_CONST;
GomElementTestGTop* gom_element_test_gtop_new (void);
GomElementTestGTop* gom_element_test_gtop_construct (GType object_type);
NoInstantiatable* gom_element_test_gtop_get_inst (GomElementTestGTop* self);
Property* gom_element_test_gtop_get_pq (GomElementTestGTop* self);
static void ___lambda259__gtest_func (void);
GomElementTest* gom_element_test_new (void);
GomElementTest* gom_element_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static GObject * gom_element_test_parsed_delayed_constructor (GType type, 
                                                       guint n_construct_properties, 
                                                       GObjectConstructParam * construct_properties);
GType gom_element_test_instantiatable_get_type (void) G_GNUC_CONST;
#define GOM_ELEMENT_TEST_INSTANTIATABLE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatablePrivate))
GomElementTestInstantiatable* gom_element_test_instantiatable_new (void);
GomElementTestInstantiatable* gom_element_test_instantiatable_construct (GType object_type);
static GObject * gom_element_test_instantiatable_constructor (GType type, 
                                                       guint n_construct_properties, 
                                                       GObjectConstructParam * construct_properties);
static void gom_element_test_instantiatable_finalize (GObject * obj);
static void _vala_gom_element_test_instantiatable_get_property (GObject * object, 
                                                         guint property_id, 
                                                         GValue * value, 
                                                         GParamSpec * pspec);
static void _vala_gom_element_test_instantiatable_set_property (GObject * object, 
                                                         guint property_id, 
                                                         const GValue * value, 
                                                         GParamSpec * pspec);
#define GOM_ELEMENT_TEST_TOP_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTopPrivate))
GomElementTestInstantiatable* gom_element_test_top_get_inst_i (GomElementTestTop* self);
void gom_element_test_top_set_inst (GomElementTestTop* self, 
                                    NoInstantiatable* value);
void gom_element_test_top_set_inst_i (GomElementTestTop* self, 
                                      GomElementTestInstantiatable* value);
Property* gom_element_test_top_get_pq (GomElementTestTop* self);
void gom_element_test_top_set_pq (GomElementTestTop* self, 
                                  Property* value);
static GObject * gom_element_test_top_constructor (GType type, 
                                            guint n_construct_properties, 
                                            GObjectConstructParam * construct_properties);
static void gom_element_test_top_finalize (GObject * obj);
static void _vala_gom_element_test_top_get_property (GObject * object, 
                                              guint property_id, 
                                              GValue * value, 
                                              GParamSpec * pspec);
static void _vala_gom_element_test_top_set_property (GObject * object, 
                                              guint property_id, 
                                              const GValue * value, 
                                              GParamSpec * pspec);
GType gom_element_test_gproperty_get_type (void) G_GNUC_CONST;
GomElementTestGProperty* gom_element_test_gproperty_new (void);
GomElementTestGProperty* gom_element_test_gproperty_construct (GType object_type);
#define GOM_ELEMENT_TEST_GTOP_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTopPrivate))
void gom_element_test_gtop_set_inst (GomElementTestGTop* self, 
                                     NoInstantiatable* value);
GomElementTestInstantiatable* gom_element_test_gtop_get_inst_i (GomElementTestGTop* self);
void gom_element_test_gtop_set_inst_i (GomElementTestGTop* self, 
                                       GomElementTestInstantiatable* value);
GomElementTestGProperty* gom_element_test_gtop_get_gpq (GomElementTestGTop* self);
void gom_element_test_gtop_set_gpq (GomElementTestGTop* self, 
                                    GomElementTestGProperty* value);
void gom_element_test_gtop_set_pq (GomElementTestGTop* self, 
                                   Property* value);
static GObject * gom_element_test_gtop_constructor (GType type, 
                                             guint n_construct_properties, 
                                             GObjectConstructParam * construct_properties);
static void gom_element_test_gtop_finalize (GObject * obj);
static void _vala_gom_element_test_gtop_get_property (GObject * object, 
                                               guint property_id, 
                                               GValue * value, 
                                               GParamSpec * pspec);
static void _vala_gom_element_test_gtop_set_property (GObject * object, 
                                               guint property_id, 
                                               const GValue * value, 
                                               GParamSpec * pspec);
#define GOM_ELEMENT_TEST_POTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotionPrivate))
void gom_element_test_potion_set_cname (GomElementTestPotion* self, 
                                        const gchar* value);
void gom_element_test_potion_set_ingredient (GomElementTestPotion* self, 
                                             GomElementTestIngredient* value);
static GObject * gom_element_test_potion_constructor (GType type, 
                                               guint n_construct_properties, 
                                               GObjectConstructParam * construct_properties);
static void gom_element_test_potion_finalize (GObject * obj);
static void _vala_gom_element_test_potion_get_property (GObject * object, 
                                                 guint property_id, 
                                                 GValue * value, 
                                                 GParamSpec * pspec);
static void _vala_gom_element_test_potion_set_property (GObject * object, 
                                                 guint property_id, 
                                                 const GValue * value, 
                                                 GParamSpec * pspec);
#define GOM_ELEMENT_TEST_INGREDIENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredientPrivate))
static gchar* gom_element_test_ingredient_real_get_map_key (GXmlMappeableElement* base);
GomElementTestIngredient* gom_element_test_ingredient_new (void);
GomElementTestIngredient* gom_element_test_ingredient_construct (GType object_type);
void gom_element_test_ingredient_set_cname (GomElementTestIngredient* self, 
                                            const gchar* value);
void gom_element_test_ingredient_set_methods (GomElementTestIngredient* self, 
                                              GomElementTestMethodMap* value);
static GObject * gom_element_test_ingredient_constructor (GType type, 
                                                   guint n_construct_properties, 
                                                   GObjectConstructParam * construct_properties);
GType gom_element_test_ingredient_map_get_type (void) G_GNUC_CONST;
GomElementTestIngredientMap* gom_element_test_ingredient_map_new (void);
GomElementTestIngredientMap* gom_element_test_ingredient_map_construct (GType object_type);
static GObject * gom_element_test_ingredient_map_constructor (GType type, 
                                                       guint n_construct_properties, 
                                                       GObjectConstructParam * construct_properties);
static void gom_element_test_ingredient_finalize (GObject * obj);
static void _vala_gom_element_test_ingredient_get_property (GObject * object, 
                                                     guint property_id, 
                                                     GValue * value, 
                                                     GParamSpec * pspec);
static void _vala_gom_element_test_ingredient_set_property (GObject * object, 
                                                     guint property_id, 
                                                     const GValue * value, 
                                                     GParamSpec * pspec);
#define GOM_ELEMENT_TEST_METHOD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethodPrivate))
static gchar* gom_element_test_method_real_get_map_key (GXmlMappeableElement* base);
GomElementTestMethod* gom_element_test_method_new (void);
GomElementTestMethod* gom_element_test_method_construct (GType object_type);
void gom_element_test_method_set_cname (GomElementTestMethod* self, 
                                        const gchar* value);
static GObject * gom_element_test_method_constructor (GType type, 
                                               guint n_construct_properties, 
                                               GObjectConstructParam * construct_properties);
GomElementTestMethodMap* gom_element_test_method_map_new (void);
GomElementTestMethodMap* gom_element_test_method_map_construct (GType object_type);
static GObject * gom_element_test_method_map_constructor (GType type, 
                                                   guint n_construct_properties, 
                                                   GObjectConstructParam * construct_properties);
static void gom_element_test_method_finalize (GObject * obj);
static void _vala_gom_element_test_method_get_property (GObject * object, 
                                                 guint property_id, 
                                                 GValue * value, 
                                                 GParamSpec * pspec);
static void _vala_gom_element_test_method_set_property (GObject * object, 
                                                 guint property_id, 
                                                 const GValue * value, 
                                                 GParamSpec * pspec);
GType gom_element_test_namespace_get_type (void) G_GNUC_CONST;
#define GOM_ELEMENT_TEST_REPOSITORY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepositoryPrivate))
const gchar* gom_element_test_repository_get_version (GomElementTestRepository* self);
void gom_element_test_repository_set_version (GomElementTestRepository* self, 
                                              const gchar* value);
GomElementTestNamespace* gom_element_test_repository_get_ns (GomElementTestRepository* self);
void gom_element_test_repository_set_ns (GomElementTestRepository* self, 
                                         GomElementTestNamespace* value);
static GObject * gom_element_test_repository_constructor (GType type, 
                                                   guint n_construct_properties, 
                                                   GObjectConstructParam * construct_properties);
static void gom_element_test_repository_finalize (GObject * obj);
static void _vala_gom_element_test_repository_get_property (GObject * object, 
                                                     guint property_id, 
                                                     GValue * value, 
                                                     GParamSpec * pspec);
static void _vala_gom_element_test_repository_set_property (GObject * object, 
                                                     guint property_id, 
                                                     const GValue * value, 
                                                     GParamSpec * pspec);
GType gom_element_test_tclass_map_get_type (void) G_GNUC_CONST;
#define GOM_ELEMENT_TEST_NAMESPACE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespacePrivate))
GomElementTestNamespace* gom_element_test_namespace_new (void);
GomElementTestNamespace* gom_element_test_namespace_construct (GType object_type);
const gchar* gom_element_test_namespace_get_name (GomElementTestNamespace* self);
void gom_element_test_namespace_set_name (GomElementTestNamespace* self, 
                                          const gchar* value);
const gchar* gom_element_test_namespace_get_version (GomElementTestNamespace* self);
void gom_element_test_namespace_set_version (GomElementTestNamespace* self, 
                                             const gchar* value);
const gchar* gom_element_test_namespace_get_cprefix (GomElementTestNamespace* self);
void gom_element_test_namespace_set_cprefix (GomElementTestNamespace* self, 
                                             const gchar* value);
GomElementTestTClassMap* gom_element_test_namespace_get_classes (GomElementTestNamespace* self);
void gom_element_test_namespace_set_classes (GomElementTestNamespace* self, 
                                             GomElementTestTClassMap* value);
static GObject * gom_element_test_namespace_constructor (GType type, 
                                                  guint n_construct_properties, 
                                                  GObjectConstructParam * construct_properties);
GomElementTestTClassMap* gom_element_test_tclass_map_new (void);
GomElementTestTClassMap* gom_element_test_tclass_map_construct (GType object_type);
static void gom_element_test_namespace_finalize (GObject * obj);
static void _vala_gom_element_test_namespace_get_property (GObject * object, 
                                                    guint property_id, 
                                                    GValue * value, 
                                                    GParamSpec * pspec);
static void _vala_gom_element_test_namespace_set_property (GObject * object, 
                                                    guint property_id, 
                                                    const GValue * value, 
                                                    GParamSpec * pspec);
GType gom_element_test_tclass_get_type (void) G_GNUC_CONST;
#define GOM_ELEMENT_TEST_TCLASS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClassPrivate))
static gchar* gom_element_test_tclass_real_get_map_key (GXmlMappeableElement* base);
const gchar* gom_element_test_tclass_get_name (GomElementTestTClass* self);
GomElementTestTClass* gom_element_test_tclass_new (void);
GomElementTestTClass* gom_element_test_tclass_construct (GType object_type);
void gom_element_test_tclass_set_name (GomElementTestTClass* self, 
                                       const gchar* value);
const gchar* gom_element_test_tclass_get_version (GomElementTestTClass* self);
void gom_element_test_tclass_set_version (GomElementTestTClass* self, 
                                          const gchar* value);
const gchar* gom_element_test_tclass_get_cprefix (GomElementTestTClass* self);
void gom_element_test_tclass_set_cprefix (GomElementTestTClass* self, 
                                          const gchar* value);
static GObject * gom_element_test_tclass_constructor (GType type, 
                                               guint n_construct_properties, 
                                               GObjectConstructParam * construct_properties);
static GObject * gom_element_test_tclass_map_constructor (GType type, 
                                                   guint n_construct_properties, 
                                                   GObjectConstructParam * construct_properties);
static void gom_element_test_tclass_finalize (GObject * obj);
static void _vala_gom_element_test_tclass_get_property (GObject * object, 
                                                 guint property_id, 
                                                 GValue * value, 
                                                 GParamSpec * pspec);
static void _vala_gom_element_test_tclass_set_property (GObject * object, 
                                                 guint property_id, 
                                                 const GValue * value, 
                                                 GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, 
                          gint array_length, 
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, 
                       gint array_length, 
                       GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


const gchar*
no_instantiatable_get_name (NoInstantiatable* self)
{
#line 26 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 26 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return NO_INSTANTIATABLE_GET_INTERFACE (self)->get_name (self);
#line 866 "GomElementTest.c"
}


void
no_instantiatable_set_name (NoInstantiatable* self, 
                            const gchar* value)
{
#line 26 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 26 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	NO_INSTANTIATABLE_GET_INTERFACE (self)->set_name (self, value);
#line 878 "GomElementTest.c"
}


static void
no_instantiatable_base_init (NoInstantiatableIface * iface)
{
#line 25 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	static gboolean initialized = FALSE;
#line 25 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (!initialized) {
#line 25 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		initialized = TRUE;
#line 25 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_object_interface_install_property (iface, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 893 "GomElementTest.c"
	}
}


GType
no_instantiatable_get_type (void)
{
	static volatile gsize no_instantiatable_type_id__volatile = 0;
	if (g_once_init_enter (&no_instantiatable_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (NoInstantiatableIface), (GBaseInitFunc) no_instantiatable_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType no_instantiatable_type_id;
		no_instantiatable_type_id = g_type_register_static (G_TYPE_INTERFACE, "NoInstantiatable", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (no_instantiatable_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (no_instantiatable_type_id, GXML_TYPE_GOM_OBJECT);
		g_once_init_leave (&no_instantiatable_type_id__volatile, no_instantiatable_type_id);
	}
	return no_instantiatable_type_id__volatile;
}


static void
property_base_init (PropertyIface * iface)
{
#line 28 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	static gboolean initialized = FALSE;
#line 28 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (!initialized) {
#line 28 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		initialized = TRUE;
#line 923 "GomElementTest.c"
	}
}


GType
property_get_type (void)
{
	static volatile gsize property_type_id__volatile = 0;
	if (g_once_init_enter (&property_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PropertyIface), (GBaseInitFunc) property_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType property_type_id;
		property_type_id = g_type_register_static (G_TYPE_INTERFACE, "Property", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (property_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (property_type_id, GXML_TYPE_GOM_PROPERTY);
		g_once_init_leave (&property_type_id__volatile, property_type_id);
	}
	return property_type_id__volatile;
}


static void
__lambda241_ (void)
{
	GXmlDomDocument* doc = NULL;
	GError * _inner_error_ = NULL;
#line 183 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	doc = NULL;
#line 951 "GomElementTest.c"
	{
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_;
		GXmlGomDocument* _tmp2_;
		GXmlGomNode* root = NULL;
		GXmlDomDocument* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomElement* _tmp5_;
		GXmlGomNode* _tmp6_;
		GXmlGomNode* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		GXmlGomNode* node = NULL;
		GXmlGomNode* _tmp11_;
		GXmlDomNodeList* _tmp12_;
		GXmlDomNodeList* _tmp13_;
		GXmlDomNodeList* _tmp14_;
		gpointer _tmp15_;
		GXmlGomNode* _tmp16_;
		GXmlGomNode* _tmp17_;
		GXmlGomNode* _tmp18_;
		GXmlGomNode* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
		GXmlGomNode* _tmp23_;
		gchar* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		GXmlGomNode* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_;
		GXmlGomNode* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
		GXmlGomNode* _tmp35_;
		GXmlDomNamedNodeMap* _tmp36_;
		GXmlDomNamedNodeMap* _tmp37_;
		GXmlDomNamedNodeMap* _tmp38_;
		gint _tmp39_;
		gint _tmp40_;
		GXmlGomNode* _tmp41_;
		GXmlDomNamedNodeMap* _tmp42_;
		GXmlDomNamedNodeMap* _tmp43_;
		GXmlDomNamedNodeMap* _tmp44_;
		gint _tmp45_;
		gint _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
		gchar* _tmp49_;
		gchar* _tmp50_;
		GXmlGomNode* _tmp51_;
		gchar* _tmp52_;
		gchar* _tmp53_;
		GXmlGomNode* _tmp54_;
		gchar* _tmp55_;
		gchar* _tmp56_;
		GXmlGomNode* _tmp57_;
		gchar* _tmp58_;
		gchar* _tmp59_;
		GXmlGomNode* _tmp60_;
		gchar* _tmp61_;
		gchar* _tmp62_;
		GXmlGomNode* _tmp63_;
		gchar* _tmp64_;
		gchar* _tmp65_;
		GXmlGomNode* _tmp66_;
		gchar* _tmp67_;
		gchar* _tmp68_;
		GXmlGomNode* _tmp69_;
#line 185 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = gxml_gom_document_new_from_string ("<Potions><magic:Potion xmlns:magic=\"http://hogwarts.co.uk/magic\" xml" \
"ns:products=\"http://diagonalley.co.uk/products\"><ingredient products" \
":name=\"spider\"/></magic:Potion></Potions>", &_inner_error_);
#line 185 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = _tmp1_;
#line 185 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1031 "GomElementTest.c"
			goto __catch251_g_error;
		}
#line 185 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = _tmp0_;
#line 185 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = NULL;
#line 185 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 185 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = (GXmlDomDocument*) _tmp2_;
#line 186 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = doc;
#line 186 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = gxml_dom_document_get_document_element (_tmp3_);
#line 186 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 186 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		root = G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GXML_TYPE_GOM_NODE, GXmlGomNode);
#line 187 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = root;
#line 187 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp6_ != NULL, "root != null");
#line 188 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = root;
#line 188 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp7_);
#line 188 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = _tmp8_;
#line 188 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 188 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp10_, "Potions") == 0, "root.node_name == \"Potions\"");
#line 188 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp10_);
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = root;
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp11_);
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = _tmp12_;
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = gee_list_get ((GeeList*) _tmp14_, 0);
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomNode*) _tmp15_, GXML_TYPE_GOM_NODE, GXmlGomNode);
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp14_);
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		node = _tmp16_;
#line 190 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = node;
#line 190 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp17_ != NULL, "node != null");
#line 191 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = node;
#line 191 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, GXML_TYPE_DOM_ELEMENT), "node is DomElement");
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = node;
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = gxml_dom_element_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp19_) : NULL);
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = _tmp20_;
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = _tmp21_;
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp22_, "Potion") == 0, "(node as DomElement).local_name == \"Potion\"");
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp22_);
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = node;
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp23_);
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp26_, "magic:Potion") == 0, "node.node_name == \"magic:Potion\"");
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp26_);
#line 194 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = node;
#line 194 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = gxml_dom_element_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp27_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp27_) : NULL);
#line 194 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = _tmp28_;
#line 194 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = _tmp29_;
#line 194 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp30_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).namespace_uri == \"http://hogwarts.co.uk/magic\"");
#line 194 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp30_);
#line 195 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = node;
#line 195 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = gxml_dom_element_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp31_) : NULL);
#line 195 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 195 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 195 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "magic") == 0, "(node as DomElement).prefix == \"magic\"");
#line 195 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp34_);
#line 196 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = node;
#line 196 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = gxml_dom_element_get_attributes (G_TYPE_CHECK_INSTANCE_TYPE (_tmp35_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp35_) : NULL);
#line 196 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = _tmp36_;
#line 196 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = _tmp37_;
#line 196 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = gee_map_get_size ((GeeMap*) _tmp38_);
#line 196 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = _tmp39_;
#line 196 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp40_ == 2, "(node as DomElement).attributes.size == 2");
#line 196 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp38_);
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = node;
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = gxml_dom_element_get_attributes (G_TYPE_CHECK_INSTANCE_TYPE (_tmp41_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp41_) : NULL);
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = _tmp42_;
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = _tmp43_;
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = gee_map_get_size ((GeeMap*) _tmp44_);
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = _tmp45_;
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = g_strdup_printf ("%i", _tmp46_);
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = _tmp47_;
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = g_strconcat ("Attributes: ", _tmp48_, NULL);
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = _tmp49_;
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:197: %s", _tmp50_);
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp50_);
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp48_);
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp44_);
#line 198 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp51_ = node;
#line 198 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp52_ = gxml_dom_element_get_attribute (G_TYPE_CHECK_INSTANCE_TYPE (_tmp51_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp51_) : NULL, "xmlns:magic");
#line 198 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp53_ = _tmp52_;
#line 198 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp53_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).get_attribute (\"xmlns:magic\") == \"http://hogwarts.co.uk/magic\"");
#line 198 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp53_);
#line 199 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp54_ = node;
#line 199 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp55_ = gxml_dom_element_get_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (_tmp54_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp54_) : NULL, "http://www.w3.org/2000/xmlns/", "magic");
#line 199 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp56_ = _tmp55_;
#line 199 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp56_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).get_attribute_ns (\"http://www.w3.org/2000/xmlns/\", \"magic\") == \"http://hogwarts.co.uk/magic\"");
#line 199 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp56_);
#line 200 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp57_ = node;
#line 200 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp58_ = gxml_dom_element_get_attribute (G_TYPE_CHECK_INSTANCE_TYPE (_tmp57_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp57_) : NULL, "xmlns:products");
#line 200 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp59_ = _tmp58_;
#line 200 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp59_, "http://diagonalley.co.uk/products") == 0, "(node as DomElement).get_attribute (\"xmlns:products\") == \"http://diagonalley.co.uk/products\"");
#line 200 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp59_);
#line 201 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp60_ = node;
#line 201 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp61_ = gxml_dom_element_get_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (_tmp60_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp60_) : NULL, "http://www.w3.org/2000/xmlns/", "products");
#line 201 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp62_ = _tmp61_;
#line 201 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp62_, "http://diagonalley.co.uk/products") == 0, "(node as DomElement).get_attribute_ns (\"http://www.w3.org/2000/xmlns/\",\"products\") == \"http://diagonalley.co.uk/products\"");
#line 201 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp62_);
#line 202 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp63_ = node;
#line 202 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp64_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp63_, "http://diagonalley.co.uk/products");
#line 202 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp65_ = _tmp64_;
#line 202 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp65_, "products") == 0, "node.lookup_prefix (\"http://diagonalley.co.uk/products\") == \"products\"");
#line 202 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp65_);
#line 203 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp66_ = node;
#line 203 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp67_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp66_, "products");
#line 203 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp68_ = _tmp67_;
#line 203 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp68_, "http://diagonalley.co.uk/products") == 0, "node.lookup_namespace_uri (\"products\") == \"http://diagonalley.co.uk/products\"");
#line 203 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp68_);
#line 204 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp69_ = node;
#line 204 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (_tmp69_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp69_) : NULL, "http://www.w3.org/2000/xmlns", "xmlns:gxmlt", "http://org.gnome.org/GXmlTest/", &_inner_error_);
#line 204 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 204 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (node);
#line 204 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 204 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp0_);
#line 1254 "GomElementTest.c"
			goto __catch251_g_error;
		}
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (node);
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (root);
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp0_);
#line 1263 "GomElementTest.c"
	}
	goto __finally251;
	__catch251_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp70_;
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 206 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp70_ = e->message;
#line 206 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:206: %s", _tmp70_);
#line 207 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 1282 "GomElementTest.c"
	}
	__finally251:
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 1295 "GomElementTest.c"
	}
#line 182 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (doc);
#line 1299 "GomElementTest.c"
}


static void
___lambda241__gtest_func (void)
{
#line 182 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda241_ ();
#line 1308 "GomElementTest.c"
}


static void
__lambda242_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlGomNode* root = NULL;
		GXmlGomDocument* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlGomNode* _tmp4_;
		GXmlGomNode* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		GXmlGomNode* node = NULL;
		GXmlGomNode* _tmp9_;
		GXmlDomNodeList* _tmp10_;
		GXmlDomNodeList* _tmp11_;
		GXmlDomNodeList* _tmp12_;
		gpointer _tmp13_;
		GXmlGomNode* _tmp14_;
		GXmlGomNode* _tmp15_;
		GXmlGomNode* _tmp16_;
		GXmlGomNode* _tmp17_;
		gchar* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		GXmlGomNode* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
		GXmlGomNode* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		GXmlGomNode* _tmp29_;
		gchar* _tmp30_;
		gchar* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_ = NULL;
		GXmlGomNode* _tmp34_;
		gchar* _tmp35_;
		GXmlGomNode* _tmp36_;
		GXmlDomNamedNodeMap* _tmp37_;
		GXmlDomNamedNodeMap* _tmp38_;
		GXmlDomNamedNodeMap* _tmp39_;
		gint _tmp40_;
		gint _tmp41_;
		GXmlGomNode* _tmp42_;
		gchar* _tmp43_;
		gchar* _tmp44_;
		GXmlGomNode* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
		GXmlGomNode* _tmp48_;
		gchar* _tmp49_;
		gchar* _tmp50_;
		GXmlGomNode* _tmp51_;
		gchar* _tmp52_;
		gchar* _tmp53_;
		GXmlGomNode* _tmp54_;
		gchar* _tmp55_;
		gchar* _tmp56_;
		GXmlGomNode* _tmp57_;
		gchar* _tmp58_;
		gchar* _tmp59_;
#line 212 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<Potions><magic:Potion xmlns:magic=\"http://hogwarts.co.uk/magic\" xml" \
"ns:products=\"http://diagonalley.co.uk/products\"/></Potions>", &_inner_error_);
#line 212 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = _tmp0_;
#line 212 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1386 "GomElementTest.c"
			goto __catch252_g_error;
		}
#line 213 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = doc;
#line 213 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp1_);
#line 213 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 213 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		root = G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GXML_TYPE_GOM_NODE, GXmlGomNode);
#line 214 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = root;
#line 214 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp4_ != NULL, "root != null");
#line 215 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = root;
#line 215 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp5_);
#line 215 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 215 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 215 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp8_, "Potions") == 0, "root.node_name == \"Potions\"");
#line 215 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp8_);
#line 216 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = root;
#line 216 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp9_);
#line 216 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 216 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 216 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = gee_list_get ((GeeList*) _tmp12_, 0);
#line 216 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomNode*) _tmp13_, GXML_TYPE_GOM_NODE, GXmlGomNode);
#line 216 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 216 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		node = _tmp14_;
#line 217 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = node;
#line 217 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp15_ != NULL, "node != null");
#line 218 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = node;
#line 218 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp16_, GXML_TYPE_DOM_ELEMENT), "node is DomElement");
#line 219 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = node;
#line 219 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = gxml_dom_element_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp17_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp17_) : NULL);
#line 219 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = _tmp18_;
#line 219 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 219 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp20_, "Potion") == 0, "(node as DomElement).local_name == \"Potion\"");
#line 219 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp20_);
#line 220 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = node;
#line 220 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp21_);
#line 220 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = _tmp22_;
#line 220 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = _tmp23_;
#line 220 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp24_, "magic:Potion") == 0, "node.node_name == \"magic:Potion\"");
#line 220 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp24_);
#line 221 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = node;
#line 221 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = gxml_dom_element_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp25_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp25_) : NULL);
#line 221 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = _tmp26_;
#line 221 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = _tmp27_;
#line 221 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp28_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).namespace_uri == \"http://hogwarts.co.uk/magic\"");
#line 221 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp28_);
#line 222 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = node;
#line 222 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = gxml_dom_element_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp29_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp29_) : NULL);
#line 222 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = _tmp30_;
#line 222 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = _tmp31_;
#line 222 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp32_, "magic") == 0, "(node as DomElement).prefix == \"magic\"");
#line 222 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp32_);
#line 232 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = node;
#line 232 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = gxml_gom_element_write_string (G_TYPE_CHECK_INSTANCE_TYPE (_tmp34_, GXML_TYPE_GOM_ELEMENT) ? ((GXmlGomElement*) _tmp34_) : NULL, &_inner_error_);
#line 232 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = _tmp35_;
#line 232 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 232 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (node);
#line 232 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 232 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 1499 "GomElementTest.c"
			goto __catch252_g_error;
		}
#line 232 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:232: %s", _tmp33_);
#line 233 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = node;
#line 233 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = gxml_dom_element_get_attributes (G_TYPE_CHECK_INSTANCE_TYPE (_tmp36_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp36_) : NULL);
#line 233 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = _tmp37_;
#line 233 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = _tmp38_;
#line 233 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = gxml_dom_named_node_map_get_length (_tmp39_);
#line 233 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = _tmp40_;
#line 233 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp41_ == 2, "(node as DomElement).attributes.length == 2");
#line 233 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp39_);
#line 234 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = node;
#line 234 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = gxml_dom_element_get_attribute (G_TYPE_CHECK_INSTANCE_TYPE (_tmp42_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp42_) : NULL, "xmlns:magic");
#line 234 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = _tmp43_;
#line 234 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp44_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).get_attribute (\"xmlns:magic\") == \"http://hogwarts.co.uk/magic\"");
#line 234 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp44_);
#line 235 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = node;
#line 235 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = gxml_dom_element_get_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (_tmp45_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp45_) : NULL, "http://www.w3.org/2000/xmlns/", "magic");
#line 235 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = _tmp46_;
#line 235 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp47_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).get_attribute_ns (\"http://www.w3.org/2000/xmlns/\", \"magic\") == \"http://hogwarts.co.uk/magic\"");
#line 235 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp47_);
#line 236 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = node;
#line 236 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = gxml_dom_element_get_attribute (G_TYPE_CHECK_INSTANCE_TYPE (_tmp48_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp48_) : NULL, "xmlns:products");
#line 236 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = _tmp49_;
#line 236 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp50_, "http://diagonalley.co.uk/products") == 0, "(node as DomElement).get_attribute (\"xmlns:products\") == \"http://diagonalley.co.uk/products\"");
#line 236 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp50_);
#line 237 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp51_ = node;
#line 237 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp52_ = gxml_dom_element_get_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (_tmp51_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp51_) : NULL, "http://www.w3.org/2000/xmlns/", "products");
#line 237 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp53_ = _tmp52_;
#line 237 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp53_, "http://diagonalley.co.uk/products") == 0, "(node as DomElement).get_attribute_ns (\"http://www.w3.org/2000/xmlns/\",\"products\") == \"http://diagonalley.co.uk/products\"");
#line 237 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp53_);
#line 238 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp54_ = node;
#line 238 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp55_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp54_, "http://diagonalley.co.uk/products");
#line 238 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp56_ = _tmp55_;
#line 238 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp56_, "products") == 0, "node.lookup_prefix (\"http://diagonalley.co.uk/products\") == \"products\"");
#line 238 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp56_);
#line 239 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp57_ = node;
#line 239 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp58_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp57_, "products");
#line 239 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp59_ = _tmp58_;
#line 239 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp59_, "http://diagonalley.co.uk/products") == 0, "node.lookup_namespace_uri (\"products\") == \"http://diagonalley.co.uk/products\"");
#line 239 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp59_);
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp33_);
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (node);
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (root);
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 1588 "GomElementTest.c"
	}
	goto __finally252;
	__catch252_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp60_;
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 241 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp60_ = e->message;
#line 241 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:241: %s", _tmp60_);
#line 242 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 1607 "GomElementTest.c"
	}
	__finally252:
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 1618 "GomElementTest.c"
	}
}


static void
___lambda242__gtest_func (void)
{
#line 210 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda242_ ();
#line 1628 "GomElementTest.c"
}


static void
__lambda243_ (void)
{
	GXmlDomDocument* doc = NULL;
	GError * _inner_error_ = NULL;
#line 245 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	doc = NULL;
#line 1639 "GomElementTest.c"
	{
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_;
		GXmlGomDocument* _tmp2_;
		GXmlDomElement* r = NULL;
		GXmlDomDocument* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomElement* _tmp5_;
		GXmlDomElement* _tmp6_;
		GXmlDomElement* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		GXmlDomElement* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		GXmlDomElement* _tmp14_;
		gchar* _tmp15_;
		gchar* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlDomNodeList* _tmp18_;
		GXmlDomNodeList* _tmp19_;
		GXmlDomNodeList* _tmp20_;
		gint _tmp21_;
		gint _tmp22_;
		GXmlDomNode* n1 = NULL;
		GXmlDomElement* _tmp23_;
		GXmlDomNodeList* _tmp24_;
		GXmlDomNodeList* _tmp25_;
		GXmlDomNodeList* _tmp26_;
		GXmlDomNode* _tmp27_;
		GXmlDomNode* _tmp28_;
		GXmlDomNode* _tmp29_;
		GXmlDomNode* _tmp30_;
		GXmlDomNode* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
		GXmlDomNode* _tmp35_;
		gchar* _tmp36_;
		gchar* _tmp37_;
		gchar* _tmp38_;
		GXmlDomNode* _tmp39_;
		gchar* _tmp40_;
		gchar* _tmp41_;
		gchar* _tmp42_;
		GXmlDomNode* n2 = NULL;
		GXmlDomElement* _tmp43_;
		GXmlDomNodeList* _tmp44_;
		GXmlDomNodeList* _tmp45_;
		GXmlDomNodeList* _tmp46_;
		GXmlDomNode* _tmp47_;
		GXmlDomNode* _tmp48_;
		GXmlDomNode* _tmp49_;
		GXmlDomNode* _tmp50_;
		GXmlDomNode* _tmp51_;
		gchar* _tmp52_;
		gchar* _tmp53_;
		gchar* _tmp54_;
		GXmlDomNode* _tmp55_;
		gchar* _tmp56_;
		gchar* _tmp57_;
		gchar* _tmp58_;
		GXmlDomNode* _tmp59_;
		gchar* _tmp60_;
		gchar* _tmp61_;
		gchar* _tmp62_;
#line 247 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = gxml_gom_document_new_from_string ("<magic:Potion xmlns:magic=\"http://hogwarts.co.uk/magic\" xmlns:produc" \
"ts=\"http://hogwarts.co.uk/magic\"><magic:Arc/><products:Diamond/></ma" \
"gic:Potion>", &_inner_error_);
#line 247 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = _tmp1_;
#line 247 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1713 "GomElementTest.c"
			goto __catch253_g_error;
		}
#line 247 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = _tmp0_;
#line 247 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = NULL;
#line 247 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 247 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = (GXmlDomDocument*) _tmp2_;
#line 248 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = doc;
#line 248 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = gxml_dom_document_get_document_element (_tmp3_);
#line 248 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 248 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		r = _tmp5_;
#line 249 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = r;
#line 249 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp6_ != NULL, "r != null");
#line 250 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = r;
#line 250 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = gxml_dom_element_get_local_name (_tmp7_);
#line 250 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = _tmp8_;
#line 250 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 250 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp10_, "Potion") == 0, "r.local_name == \"Potion\"");
#line 250 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp10_);
#line 251 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = r;
#line 251 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = gxml_dom_element_get_attribute_ns (_tmp11_, "http://www.w3.org/2000/xmlns/", "magic");
#line 251 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = _tmp12_;
#line 251 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp13_, "http://hogwarts.co.uk/magic") == 0, "r.get_attribute_ns (\"http://www.w3.org/2000/xmlns/\", \"magic\") == \"http://hogwarts.co.uk/magic\"");
#line 251 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp13_);
#line 252 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = r;
#line 252 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = gxml_dom_element_get_attribute_ns (_tmp14_, "http://www.w3.org/2000/xmlns/", "products");
#line 252 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = _tmp15_;
#line 252 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp16_, "http://hogwarts.co.uk/magic") == 0, "r.get_attribute_ns (\"http://www.w3.org/2000/xmlns/\", \"products\") == \"http://hogwarts.co.uk/magic\"");
#line 252 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp16_);
#line 253 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = r;
#line 253 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp17_);
#line 253 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = _tmp18_;
#line 253 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 253 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = gxml_dom_node_list_get_length (_tmp20_);
#line 253 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = _tmp21_;
#line 253 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp22_ == 2, "r.child_nodes.length == 2");
#line 253 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp20_);
#line 254 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = r;
#line 254 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp23_);
#line 254 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 254 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 254 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = gxml_dom_node_list_item (_tmp26_, 0);
#line 254 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = _tmp27_;
#line 254 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 254 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n1 = _tmp28_;
#line 255 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = n1;
#line 255 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp29_ != NULL, "n1 != null");
#line 256 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = n1;
#line 256 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, GXML_TYPE_DOM_ELEMENT), "n1 is DomElement");
#line 257 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = n1;
#line 257 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = gxml_dom_element_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp31_) : NULL);
#line 257 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 257 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 257 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "Arc") == 0, "(n1 as DomElement).local_name == \"Arc\"");
#line 257 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp34_);
#line 258 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = n1;
#line 258 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = gxml_dom_element_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp35_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp35_) : NULL);
#line 258 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = _tmp36_;
#line 258 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = _tmp37_;
#line 258 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp38_, "magic") == 0, "(n1 as DomElement).prefix == \"magic\"");
#line 258 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp38_);
#line 259 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = n1;
#line 259 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = gxml_dom_element_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp39_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp39_) : NULL);
#line 259 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = _tmp40_;
#line 259 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = _tmp41_;
#line 259 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp42_, "http://hogwarts.co.uk/magic") == 0, "(n1 as DomElement).namespace_uri == \"http://hogwarts.co.uk/magic\"");
#line 259 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp42_);
#line 260 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = r;
#line 260 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp43_);
#line 260 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = _tmp44_;
#line 260 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = _tmp45_;
#line 260 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = gxml_dom_node_list_item (_tmp46_, 1);
#line 260 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = _tmp47_;
#line 260 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp46_);
#line 260 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n2 = _tmp48_;
#line 261 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = n2;
#line 261 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp49_ != NULL, "n2 != null");
#line 262 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = n2;
#line 262 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp50_, GXML_TYPE_DOM_ELEMENT), "n2 is DomElement");
#line 263 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp51_ = n2;
#line 263 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp52_ = gxml_dom_element_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp51_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp51_) : NULL);
#line 263 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp53_ = _tmp52_;
#line 263 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp54_ = _tmp53_;
#line 263 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp54_, "Diamond") == 0, "(n2 as DomElement).local_name == \"Diamond\"");
#line 263 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp54_);
#line 264 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp55_ = n2;
#line 264 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp56_ = gxml_dom_element_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp55_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp55_) : NULL);
#line 264 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp57_ = _tmp56_;
#line 264 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp58_ = _tmp57_;
#line 264 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp58_, "products") == 0, "(n2 as DomElement).prefix == \"products\"");
#line 264 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp58_);
#line 265 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp59_ = n2;
#line 265 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp60_ = gxml_dom_element_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp59_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp59_) : NULL);
#line 265 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp61_ = _tmp60_;
#line 265 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp62_ = _tmp61_;
#line 265 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp62_, "http://hogwarts.co.uk/magic") == 0, "(n2 as DomElement).namespace_uri == \"http://hogwarts.co.uk/magic\"");
#line 265 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp62_);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n2);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n1);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (r);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp0_);
#line 1912 "GomElementTest.c"
	}
	goto __finally253;
	__catch253_g_error:
	{
		GError* e = NULL;
		GError* _tmp63_;
		const gchar* _tmp64_;
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 267 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp63_ = e;
#line 267 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp64_ = _tmp63_->message;
#line 267 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_warning ("GomElementTest.vala:267: %s", _tmp64_);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 1932 "GomElementTest.c"
	}
	__finally253:
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 1945 "GomElementTest.c"
	}
#line 244 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (doc);
#line 1949 "GomElementTest.c"
}


static void
___lambda243__gtest_func (void)
{
#line 244 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda243_ ();
#line 1958 "GomElementTest.c"
}


static gpointer
_g_object_ref0 (gpointer self)
{
#line 274 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 1967 "GomElementTest.c"
}


static gboolean
string_contains (const gchar* self, 
                 const gchar* needle)
{
	gboolean result = FALSE;
	gchar* _tmp0_;
#line 1417 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1417 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1418 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp0_ = strstr ((gchar*) self, (gchar*) needle);
#line 1418 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	result = _tmp0_ != NULL;
#line 1418 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	return result;
#line 1987 "GomElementTest.c"
}


static void
__lambda244_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlGomDocument* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomElement* _tmp5_ = NULL;
		GXmlGomDocument* _tmp6_;
		GXmlDomElement* _tmp7_;
		GXmlGomElement* elem = NULL;
		GXmlGomElement* _tmp8_;
		GXmlGomDocument* _tmp9_;
		GXmlDomElement* _tmp10_;
		GXmlDomElement* _tmp11_;
		GXmlDomElement* _tmp12_;
		GXmlDomNodeList* _tmp13_;
		GXmlDomNodeList* _tmp14_;
		GXmlDomNodeList* _tmp15_;
		GXmlGomElement* _tmp16_;
		GXmlGomElement* _tmp17_;
		GXmlDomNamedNodeMap* _tmp18_;
		GXmlDomNamedNodeMap* _tmp19_;
		GXmlDomNamedNodeMap* _tmp20_;
		GXmlGomElement* _tmp21_;
		GXmlDomNamedNodeMap* _tmp22_;
		GXmlDomNamedNodeMap* _tmp23_;
		GXmlDomNamedNodeMap* _tmp24_;
		gint _tmp25_;
		gint _tmp26_;
		GXmlGomElement* _tmp27_;
		GXmlGomElement* _tmp28_;
		GXmlGomElement* _tmp29_;
		GXmlDomNamedNodeMap* _tmp30_;
		GXmlDomNamedNodeMap* _tmp31_;
		GXmlDomNamedNodeMap* _tmp32_;
		gint _tmp33_;
		gint _tmp34_;
		GXmlXParser* parser = NULL;
		GXmlGomDocument* _tmp35_;
		GXmlXParser* _tmp36_;
		gchar* _tmp37_ = NULL;
		GXmlXParser* _tmp38_;
		gchar* _tmp39_;
		gchar* _tmp40_;
		gchar* _tmp41_;
		GXmlGomElement* _tmp42_;
		GXmlDomNamedNodeMap* _tmp43_;
		GXmlDomNamedNodeMap* _tmp44_;
		GXmlDomNamedNodeMap* _tmp45_;
		GXmlDomNode* _tmp46_;
		GXmlDomNode* _tmp47_;
		gchar* _tmp48_;
		gchar* _tmp49_;
		gchar* _tmp50_;
		GXmlGomElement* _tmp51_;
		GXmlDomNamedNodeMap* _tmp52_;
		GXmlDomNamedNodeMap* _tmp53_;
		GXmlDomNamedNodeMap* _tmp54_;
		GXmlDomNode* _tmp55_;
		GXmlDomNode* _tmp56_;
		gchar* _tmp57_;
		gchar* _tmp58_;
		gchar* _tmp59_;
		GXmlGomElement* _tmp60_;
		GXmlGomAttr* attr = NULL;
		GXmlGomElement* _tmp61_;
		GXmlDomNamedNodeMap* _tmp62_;
		GXmlDomNamedNodeMap* _tmp63_;
		GXmlDomNamedNodeMap* _tmp64_;
		GXmlDomNode* _tmp65_;
		GXmlGomAttr* _tmp66_;
		GXmlGomAttr* _tmp67_;
		GXmlGomAttr* _tmp68_;
		GXmlGomAttr* _tmp69_;
		gchar* _tmp70_;
		gchar* _tmp71_;
		gchar* _tmp72_;
		GXmlGomElement* _tmp73_;
		GXmlDomNamedNodeMap* _tmp74_;
		GXmlDomNamedNodeMap* _tmp75_;
		GXmlDomNamedNodeMap* _tmp76_;
		gint _tmp77_;
		gint _tmp78_;
		GXmlGomElement* _tmp79_;
		gchar* _tmp80_;
		gchar* _tmp81_;
		GXmlGomElement* _tmp82_;
		GXmlDomNamedNodeMap* _tmp83_;
		GXmlDomNamedNodeMap* _tmp84_;
		GXmlDomNamedNodeMap* _tmp85_;
		GXmlDomNode* _tmp86_;
		GXmlDomNode* _tmp87_;
		GXmlGomElement* _tmp88_;
		gchar* _tmp89_;
		gchar* _tmp90_;
		GXmlGomElement* _tmp91_;
		GXmlDomNamedNodeMap* _tmp92_;
		GXmlDomNamedNodeMap* _tmp93_;
		GXmlDomNamedNodeMap* _tmp94_;
		gint _tmp95_;
		gint _tmp96_;
		GXmlGomElement* _tmp97_;
		GXmlGomElement* _tmp98_;
		GXmlDomNamedNodeMap* _tmp99_;
		GXmlDomNamedNodeMap* _tmp100_;
		GXmlDomNamedNodeMap* _tmp101_;
		gint _tmp102_;
		gint _tmp103_;
		GXmlGomElement* _tmp104_;
		GXmlGomElement* _tmp105_;
		GXmlDomNamedNodeMap* _tmp106_;
		GXmlDomNamedNodeMap* _tmp107_;
		GXmlDomNamedNodeMap* _tmp108_;
		gint _tmp109_;
		gint _tmp110_;
		GXmlGomElement* _tmp111_;
		GXmlGomElement* _tmp112_;
		GXmlDomNamedNodeMap* _tmp113_;
		GXmlDomNamedNodeMap* _tmp114_;
		GXmlDomNamedNodeMap* _tmp115_;
		gint _tmp116_;
		gint _tmp117_;
		GXmlGomElement* _tmp118_;
		gchar* _tmp119_;
		gchar* _tmp120_;
		GXmlGomElement* _tmp121_;
		GXmlGomElement* _tmp122_;
		gchar* _tmp123_;
		gchar* _tmp124_;
		GXmlGomElement* _tmp125_;
		gchar* _tmp126_;
		gchar* _tmp127_;
		GXmlGomElement* _tmp128_;
		GXmlDomNamedNodeMap* _tmp129_;
		GXmlDomNamedNodeMap* _tmp130_;
		GXmlDomNamedNodeMap* _tmp131_;
		gint _tmp132_;
		gint _tmp133_;
		GXmlGomElement* _tmp134_;
		gchar* _tmp135_ = NULL;
		GXmlGomElement* _tmp136_;
		gchar* _tmp137_;
		GXmlGomElement* _tmp138_;
		gchar* _tmp139_;
		gchar* _tmp140_;
		gchar* _tmp141_;
		GXmlGomElement* _tmp147_;
		GXmlGomElement* _tmp148_;
		GXmlDomNamedNodeMap* _tmp149_;
		GXmlDomNamedNodeMap* _tmp150_;
		GXmlDomNamedNodeMap* _tmp151_;
		GXmlGomElement* _tmp152_;
		GXmlDomNamedNodeMap* _tmp153_;
		GXmlDomNamedNodeMap* _tmp154_;
		GXmlDomNamedNodeMap* _tmp155_;
		gint _tmp156_;
		gint _tmp157_;
		GXmlDomElement* n = NULL;
		GXmlGomDocument* _tmp158_;
		GXmlDomElement* _tmp159_;
		GXmlGomElement* _tmp160_;
		GXmlDomElement* _tmp161_;
		GXmlDomNode* _tmp162_;
		GXmlDomNode* _tmp163_;
		GXmlDomElement* child = NULL;
		GXmlGomDocument* _tmp164_;
		GXmlDomElement* _tmp165_;
		GXmlDomElement* _tmp166_;
		GXmlDomElement* _tmp167_;
		GXmlDomNode* _tmp168_;
		GXmlDomNode* _tmp169_;
		GXmlGomElement* _tmp170_;
		GXmlGomElement* _tmp171_;
		gchar* _tmp172_;
		gchar* _tmp173_;
		GXmlDomElement* _tmp174_;
		gchar* _tmp175_;
		gchar* _tmp176_;
		GXmlDomElement* _tmp177_;
		gchar* _tmp178_;
		gchar* _tmp179_;
		GXmlGomElement* _tmp180_;
		gchar* _tmp181_;
		gchar* _tmp182_;
		GXmlDomElement* _tmp183_;
		gchar* _tmp184_;
		gchar* _tmp185_;
		GXmlDomElement* _tmp186_;
		gchar* _tmp187_;
		gchar* _tmp188_;
		gchar* _tmp189_ = NULL;
		GXmlGomElement* _tmp190_;
		gchar* _tmp191_;
		GXmlDomElement* _tmp192_;
		GXmlGomElement* _tmp193_;
		gchar* _tmp194_;
		gchar* _tmp195_;
		GXmlGomElement* _tmp196_;
		gchar* _tmp197_;
		gchar* _tmp198_;
		GXmlDomElement* _tmp199_;
		gchar* _tmp200_;
		gchar* _tmp201_;
#line 272 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<root />", &_inner_error_);
#line 272 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = _tmp0_;
#line 272 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2205 "GomElementTest.c"
			goto __catch254_g_error;
		}
#line 273 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = doc;
#line 273 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp1_);
#line 273 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 273 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = _tmp3_;
#line 273 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp4_ != NULL, "doc.document_element != null");
#line 273 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp4_);
#line 274 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = doc;
#line 274 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp6_, "alphanumeric", &_inner_error_);
#line 274 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp7_;
#line 274 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 274 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2230 "GomElementTest.c"
			goto __catch254_g_error;
		}
#line 274 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GXML_TYPE_GOM_ELEMENT, GXmlGomElement));
#line 274 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		elem = _tmp8_;
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = doc;
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp9_);
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp12_);
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = _tmp14_;
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = elem;
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp15_, (GXmlDomNode*) _tmp16_);
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp15_);
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 276 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = elem;
#line 276 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp17_);
#line 276 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = _tmp18_;
#line 276 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 276 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp20_ != NULL, "elem.attributes != null");
#line 276 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp20_);
#line 277 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = elem;
#line 277 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp21_);
#line 277 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = _tmp22_;
#line 277 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = _tmp23_;
#line 277 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = gee_map_get_size ((GeeMap*) _tmp24_);
#line 277 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 277 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp26_ == 0, "elem.attributes.size == 0");
#line 277 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp24_);
#line 278 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = elem;
#line 278 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp27_, "alley", "Diagon", &_inner_error_);
#line 278 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 278 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 278 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 278 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2299 "GomElementTest.c"
			goto __catch254_g_error;
		}
#line 279 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = elem;
#line 279 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp28_, "train", "Hogwarts Express", &_inner_error_);
#line 279 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 279 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 279 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 279 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2314 "GomElementTest.c"
			goto __catch254_g_error;
		}
#line 280 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = elem;
#line 280 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp29_);
#line 280 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = _tmp30_;
#line 280 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = _tmp31_;
#line 280 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = gee_map_get_size ((GeeMap*) _tmp32_);
#line 280 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 280 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp34_ == 2, "elem.attributes.size == 2");
#line 280 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp32_);
#line 281 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = doc;
#line 281 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = gxml_xparser_new ((GXmlDomNode*) _tmp35_);
#line 281 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		parser = _tmp36_;
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = parser;
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = gxml_parser_write_string ((GXmlParser*) _tmp38_, &_inner_error_);
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = _tmp39_;
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2355 "GomElementTest.c"
			goto __catch254_g_error;
		}
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = g_strconcat ("Getting attributes value alley... Node: ", _tmp37_, NULL);
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = _tmp40_;
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_test_message ("%s", _tmp41_);
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp41_);
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = elem;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp42_);
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = _tmp43_;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = _tmp44_;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = gxml_dom_named_node_map_get_named_item (_tmp45_, "alley");
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = _tmp46_;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = gxml_dom_node_get_node_value (_tmp47_);
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = _tmp48_;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = _tmp49_;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp50_, "Diagon") == 0, "elem.attributes.get_named_item (\"alley\").node_value == \"Diagon\"");
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp50_);
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp47_);
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp45_);
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp51_ = elem;
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp52_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp51_);
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp53_ = _tmp52_;
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp54_ = _tmp53_;
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp55_ = gxml_dom_named_node_map_get_named_item (_tmp54_, "train");
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp56_ = _tmp55_;
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp57_ = gxml_dom_node_get_node_value (_tmp56_);
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp58_ = _tmp57_;
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp59_ = _tmp58_;
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp59_, "Hogwarts Express") == 0, "elem.attributes.get_named_item (\"train\").node_value == \"Hogwarts Express\"");
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp59_);
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp56_);
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp54_);
#line 286 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp60_ = elem;
#line 286 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp60_, "owl", "Hedwig", &_inner_error_);
#line 286 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 286 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 286 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 286 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 286 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 286 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2434 "GomElementTest.c"
			goto __catch254_g_error;
		}
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp61_ = elem;
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp62_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp61_);
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp63_ = _tmp62_;
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp64_ = _tmp63_;
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp65_ = gxml_dom_named_node_map_get_named_item (_tmp64_, "owl");
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp66_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp65_, GXML_TYPE_GOM_ATTR) ? ((GXmlGomAttr*) _tmp65_) : NULL;
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (_tmp66_ == NULL) {
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp65_);
#line 2453 "GomElementTest.c"
		}
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp67_ = _tmp66_;
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp64_);
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		attr = _tmp67_;
#line 288 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp68_ = attr;
#line 288 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp68_ != NULL, "attr != null");
#line 289 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp69_ = attr;
#line 289 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp70_ = gxml_dom_node_get_node_value ((GXmlDomNode*) _tmp69_);
#line 289 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp71_ = _tmp70_;
#line 289 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp72_ = _tmp71_;
#line 289 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp72_, "Hedwig") == 0, "attr.node_value == \"Hedwig\"");
#line 289 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp72_);
#line 291 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp73_ = elem;
#line 291 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp74_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp73_);
#line 291 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp75_ = _tmp74_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp76_ = _tmp75_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp77_ = gee_map_get_size ((GeeMap*) _tmp76_);
#line 291 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp78_ = _tmp77_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp78_ == 3, "elem.attributes.size == 3");
#line 291 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp76_);
#line 292 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp79_ = elem;
#line 292 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp80_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp79_, "owl");
#line 292 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp81_ = _tmp80_;
#line 292 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp81_, "Hedwig") == 0, "elem.get_attribute (\"owl\") == \"Hedwig\"");
#line 292 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp81_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp82_ = elem;
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp83_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp82_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp84_ = _tmp83_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp85_ = _tmp84_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp86_ = gxml_dom_named_node_map_remove_named_item (_tmp85_, "alley", &_inner_error_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp87_ = _tmp86_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp87_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp85_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2533 "GomElementTest.c"
			goto __catch254_g_error;
		}
#line 296 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp88_ = elem;
#line 296 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp89_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp88_, "alley");
#line 296 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp90_ = _tmp89_;
#line 296 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp90_ == NULL, "elem.get_attribute (\"alley\") == null");
#line 296 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp90_);
#line 297 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp91_ = elem;
#line 297 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp92_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp91_);
#line 297 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp93_ = _tmp92_;
#line 297 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp94_ = _tmp93_;
#line 297 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp95_ = gee_map_get_size ((GeeMap*) _tmp94_);
#line 297 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp96_ = _tmp95_;
#line 297 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp96_ == 2, "elem.attributes.size == 2");
#line 297 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp94_);
#line 298 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp97_ = elem;
#line 298 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_remove_attribute ((GXmlDomElement*) _tmp97_, "owl");
#line 299 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp98_ = elem;
#line 299 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp99_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp98_);
#line 299 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp100_ = _tmp99_;
#line 299 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp101_ = _tmp100_;
#line 299 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp102_ = gee_map_get_size ((GeeMap*) _tmp101_);
#line 299 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp103_ = _tmp102_;
#line 299 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp103_ == 1, "elem.attributes.size == 1");
#line 299 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp101_);
#line 301 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp104_ = elem;
#line 301 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp104_, "http://www.w3.org/2000/xmlns/", "xmlns:gxml", "http://www.gnome.org/GXml", &_inner_error_);
#line 301 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 301 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 301 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 301 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 301 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 301 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 301 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2600 "GomElementTest.c"
			goto __catch254_g_error;
		}
#line 303 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp105_ = elem;
#line 303 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp106_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp105_);
#line 303 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp107_ = _tmp106_;
#line 303 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp108_ = _tmp107_;
#line 303 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp109_ = gee_map_get_size ((GeeMap*) _tmp108_);
#line 303 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp110_ = _tmp109_;
#line 303 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp110_ == 2, "elem.attributes.size == 2");
#line 303 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp108_);
#line 304 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp111_ = elem;
#line 304 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp111_, "http://www.gnome.org/GXml", "gxml:xola", "Mexico", &_inner_error_);
#line 304 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 304 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 304 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 304 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 304 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 304 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 304 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2637 "GomElementTest.c"
			goto __catch254_g_error;
		}
#line 305 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp112_ = elem;
#line 305 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp113_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp112_);
#line 305 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp114_ = _tmp113_;
#line 305 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp115_ = _tmp114_;
#line 305 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp116_ = gee_map_get_size ((GeeMap*) _tmp115_);
#line 305 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp117_ = _tmp116_;
#line 305 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp117_ == 3, "elem.attributes.size == 3");
#line 305 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp115_);
#line 306 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp118_ = elem;
#line 306 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp119_ = gxml_dom_element_get_attribute_ns ((GXmlDomElement*) _tmp118_, "http://www.gnome.org/GXml", "xola");
#line 306 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp120_ = _tmp119_;
#line 306 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp120_, "Mexico") == 0, "elem.get_attribute_ns (\"http://www.gnome.org/GXml\", \"xola\") == \"Mexico\"");
#line 306 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp120_);
#line 307 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp121_ = elem;
#line 307 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_remove_attribute_ns ((GXmlDomElement*) _tmp121_, "http://www.gnome.org/GXml", "xola");
#line 308 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp122_ = elem;
#line 308 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp123_ = gxml_dom_element_get_attribute_ns ((GXmlDomElement*) _tmp122_, "http://www.gnome.org/GXml", "xola");
#line 308 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp124_ = _tmp123_;
#line 308 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp124_ == NULL, "elem.get_attribute_ns (\"http://www.gnome.org/GXml\", \"xola\") == null");
#line 308 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp124_);
#line 309 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp125_ = elem;
#line 309 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp126_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp125_, "xola");
#line 309 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp127_ = _tmp126_;
#line 309 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp127_ == NULL, "elem.get_attribute (\"xola\") == null");
#line 309 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp127_);
#line 310 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp128_ = elem;
#line 310 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp129_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp128_);
#line 310 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp130_ = _tmp129_;
#line 310 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp131_ = _tmp130_;
#line 310 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp132_ = gee_map_get_size ((GeeMap*) _tmp131_);
#line 310 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp133_ = _tmp132_;
#line 310 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp133_ == 2, "elem.attributes.size == 2");
#line 310 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp131_);
#line 311 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp134_ = elem;
#line 311 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_id ((GXmlDomElement*) _tmp134_, "idnode");
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp136_ = elem;
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp137_ = gxml_gom_element_write_string (_tmp136_, &_inner_error_);
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp135_ = _tmp137_;
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2730 "GomElementTest.c"
			goto __catch254_g_error;
		}
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (string_contains (_tmp135_, "id=\"idnode\""), "\"id=\\\"idnode\\\"\" in elem.write_string ()");
#line 313 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp138_ = elem;
#line 313 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp139_ = gxml_dom_element_get_id ((GXmlDomElement*) _tmp138_);
#line 313 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp140_ = _tmp139_;
#line 313 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp141_ = _tmp140_;
#line 313 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp141_, "idnode") == 0, "elem.id == \"idnode\"");
#line 313 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp141_);
#line 2747 "GomElementTest.c"
		{
			GXmlGomElement* _tmp142_;
#line 315 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp142_ = elem;
#line 315 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp142_, "http://www.gnome.org/GXml", "gxml2:xola", "Mexico", &_inner_error_);
#line 315 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2756 "GomElementTest.c"
				goto __catch255_g_error;
			}
#line 316 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			g_assert_not_reached ();
#line 2761 "GomElementTest.c"
		}
		goto __finally255;
		__catch255_g_error:
		{
			GError* e = NULL;
			GError* _tmp143_;
			const gchar* _tmp144_;
			gchar* _tmp145_;
			gchar* _tmp146_;
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			e = _inner_error_;
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_inner_error_ = NULL;
#line 318 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp143_ = e;
#line 318 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp144_ = _tmp143_->message;
#line 318 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp145_ = g_strconcat ("Correctly Cough Error:", _tmp144_, NULL);
#line 318 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp146_ = _tmp145_;
#line 318 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			g_message ("GomElementTest.vala:318: %s", _tmp146_);
#line 318 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp146_);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_error_free0 (e);
#line 2789 "GomElementTest.c"
		}
		__finally255:
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2808 "GomElementTest.c"
			goto __catch254_g_error;
		}
#line 320 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp147_ = elem;
#line 320 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp147_ != NULL, "elem != null");
#line 321 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp148_ = elem;
#line 321 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp149_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp148_);
#line 321 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp150_ = _tmp149_;
#line 321 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp151_ = _tmp150_;
#line 321 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp151_ != NULL, "elem.attributes != null");
#line 321 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp151_);
#line 322 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp152_ = elem;
#line 322 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp153_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp152_);
#line 322 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp154_ = _tmp153_;
#line 322 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp155_ = _tmp154_;
#line 322 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp156_ = gee_map_get_size ((GeeMap*) _tmp155_);
#line 322 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp157_ = _tmp156_;
#line 322 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp157_ == 2, "elem.attributes.size == 2");
#line 322 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp155_);
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp158_ = doc;
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp159_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp158_, "node", &_inner_error_);
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n = _tmp159_;
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2865 "GomElementTest.c"
			goto __catch254_g_error;
		}
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp160_ = elem;
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp161_ = n;
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp162_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp160_, (GXmlDomNode*) _tmp161_, &_inner_error_);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp163_ = _tmp162_;
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp163_);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2896 "GomElementTest.c"
			goto __catch254_g_error;
		}
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp164_ = doc;
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp165_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp164_, "child", &_inner_error_);
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		child = _tmp165_;
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2923 "GomElementTest.c"
			goto __catch254_g_error;
		}
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp166_ = n;
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp167_ = child;
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp168_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp166_, (GXmlDomNode*) _tmp167_, &_inner_error_);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp169_ = _tmp168_;
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp169_);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (child);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2956 "GomElementTest.c"
			goto __catch254_g_error;
		}
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp170_ = elem;
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp170_, "http://www.w3.org/2000/xmlns", "xmlns:xtest", "http://www.w3c.org/test", &_inner_error_);
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (child);
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2983 "GomElementTest.c"
			goto __catch254_g_error;
		}
#line 328 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp171_ = elem;
#line 328 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp172_ = gxml_gom_element_lookup_prefix (_tmp171_, "http://www.w3c.org/test");
#line 328 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp173_ = _tmp172_;
#line 328 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp173_, "xtest") == 0, "elem.lookup_prefix (\"http://www.w3c.org/test\") == \"xtest\"");
#line 328 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp173_);
#line 329 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp174_ = n;
#line 329 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp175_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp174_, "http://www.w3c.org/test");
#line 329 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp176_ = _tmp175_;
#line 329 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp176_, "xtest") == 0, "n.lookup_prefix (\"http://www.w3c.org/test\") == \"xtest\"");
#line 329 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp176_);
#line 330 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp177_ = child;
#line 330 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp178_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp177_, "http://www.w3c.org/test");
#line 330 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp179_ = _tmp178_;
#line 330 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp179_, "xtest") == 0, "child.lookup_prefix (\"http://www.w3c.org/test\") == \"xtest\"");
#line 330 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp179_);
#line 331 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp180_ = elem;
#line 331 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp181_ = gxml_gom_element_lookup_namespace_uri (_tmp180_, "xtest");
#line 331 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp182_ = _tmp181_;
#line 331 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp182_, "http://www.w3c.org/test") == 0, "elem.lookup_namespace_uri (\"xtest\") == \"http://www.w3c.org/test\"");
#line 331 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp182_);
#line 332 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp183_ = n;
#line 332 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp184_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp183_, "xtest");
#line 332 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp185_ = _tmp184_;
#line 332 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp185_, "http://www.w3c.org/test") == 0, "n.lookup_namespace_uri (\"xtest\") == \"http://www.w3c.org/test\"");
#line 332 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp185_);
#line 333 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp186_ = child;
#line 333 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp187_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp186_, "xtest");
#line 333 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp188_ = _tmp187_;
#line 333 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp188_, "http://www.w3c.org/test") == 0, "child.lookup_namespace_uri (\"xtest\") == \"http://www.w3c.org/test\"");
#line 333 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp188_);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp190_ = elem;
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp191_ = gxml_gom_element_write_string (G_TYPE_CHECK_INSTANCE_TYPE (_tmp190_, GXML_TYPE_GOM_ELEMENT) ? ((GXmlGomElement*) _tmp190_) : NULL, &_inner_error_);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp189_ = _tmp191_;
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (child);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3072 "GomElementTest.c"
			goto __catch254_g_error;
		}
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:334: %s", _tmp189_);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp192_ = child;
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns (_tmp192_, "http://www.w3c.org/test", "xtest:val", "Value", &_inner_error_);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp189_);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (child);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3103 "GomElementTest.c"
			goto __catch254_g_error;
		}
#line 336 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp193_ = elem;
#line 336 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp194_ = gxml_dom_element_get_attribute_ns ((GXmlDomElement*) _tmp193_, "http://www.w3.org/2000/xmlns/", "xtest");
#line 336 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp195_ = _tmp194_;
#line 336 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp195_, "http://www.w3c.org/test") == 0, "elem.get_attribute_ns (\"http://www.w3.org/2000/xmlns/\",\"xtest\") == \"http://www.w3c.org/test\"");
#line 336 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp195_);
#line 337 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp196_ = elem;
#line 337 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp197_ = gxml_dom_element_get_attribute_ns ((GXmlDomElement*) _tmp196_, "http://www.w3.org/2000/xmlns", "xtest");
#line 337 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp198_ = _tmp197_;
#line 337 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp198_, "http://www.w3c.org/test") == 0, "elem.get_attribute_ns (\"http://www.w3.org/2000/xmlns\",\"xtest\") == \"http://www.w3c.org/test\"");
#line 337 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp198_);
#line 338 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp199_ = child;
#line 338 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp200_ = gxml_dom_element_get_attribute_ns (_tmp199_, "http://www.w3c.org/test", "val");
#line 338 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp201_ = _tmp200_;
#line 338 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp201_, "Value") == 0, "child.get_attribute_ns (\"http://www.w3c.org/test\",\"val\") == \"Value\"");
#line 338 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp201_);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp189_);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (child);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp135_);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (attr);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp37_);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (parser);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (elem);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp5_);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 3156 "GomElementTest.c"
	}
	goto __finally254;
	__catch254_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp202_;
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 340 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp202_ = e->message;
#line 340 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:340: %s", _tmp202_);
#line 341 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 3175 "GomElementTest.c"
	}
	__finally254:
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 3186 "GomElementTest.c"
	}
}


static void
___lambda244__gtest_func (void)
{
#line 270 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda244_ ();
#line 3196 "GomElementTest.c"
}


static void
__lambda245_ (void)
{
	GError * _inner_error_ = NULL;
	{
		gchar* str = NULL;
		gchar* _tmp0_;
		GomElementTestPotion* p = NULL;
		GomElementTestPotion* _tmp1_;
		GomElementTestPotion* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		GomElementTestPotion* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp8_;
		GomElementTestPotion* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		GomElementTestPotion* _tmp12_;
		const gchar* _tmp13_;
		gchar* _tmp14_ = NULL;
		GomElementTestPotion* _tmp15_;
		gchar* _tmp16_;
		GomElementTestPotion* _tmp17_;
		const gchar* _tmp18_;
		const gchar* _tmp19_;
		GomElementTestPotion* _tmp20_;
		GomElementTestIngredient* _tmp21_;
		GomElementTestIngredient* _tmp22_;
		GomElementTestPotion* _tmp23_;
		GomElementTestIngredient* _tmp24_;
		GomElementTestIngredient* _tmp25_;
		const gchar* _tmp26_;
		const gchar* _tmp27_;
		GomElementTestPotion* _tmp28_;
		GomElementTestIngredient* _tmp29_;
		GomElementTestIngredient* _tmp30_;
		GomElementTestMethodMap* _tmp31_;
		GomElementTestMethodMap* _tmp32_;
		GomElementTestPotion* _tmp33_;
		GomElementTestIngredient* _tmp34_;
		GomElementTestIngredient* _tmp35_;
		GomElementTestMethodMap* _tmp36_;
		GomElementTestMethodMap* _tmp37_;
		gint _tmp38_;
		gint _tmp39_;
		GXmlDomElement* _tmp40_ = NULL;
		GomElementTestPotion* _tmp41_;
		GomElementTestIngredient* _tmp42_;
		GomElementTestIngredient* _tmp43_;
		GomElementTestMethodMap* _tmp44_;
		GomElementTestMethodMap* _tmp45_;
		GXmlDomElement* _tmp46_;
		GomElementTestMethod* m = NULL;
		GomElementTestMethod* _tmp47_;
		const gchar* _tmp48_;
		const gchar* _tmp49_;
#line 346 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = g_strdup ("<Potion xmlns:c=\"http://c.org/1.0\" c:name=\"edumor\"><ingredient c:n" \
"ame=\"spider\"><child/><method c:name=\"move\"/></ingredient></Potion>");
#line 346 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		str = _tmp0_;
#line 347 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = gom_element_test_potion_new ();
#line 347 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		p = _tmp1_;
#line 348 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = p;
#line 348 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp2_);
#line 348 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = _tmp3_;
#line 348 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 348 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp5_, "Potion") == 0, "p.node_name == \"Potion\"");
#line 348 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp5_);
#line 349 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = p;
#line 349 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = gom_element_test_potion_get_cname (_tmp6_);
#line 349 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 349 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp8_ == NULL, "p.cname == null");
#line 350 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = p;
#line 350 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = gxml_dom_element_get_attribute_ns ((GXmlDomElement*) _tmp9_, "http://www.w3.org/2000/xmlns", "c");
#line 350 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 350 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp11_, "http://c.org/1.0") == 0, "p.get_attribute_ns (\"http://www.w3.org/2000/xmlns\", \"c\") == \"http://c.org/1.0\"");
#line 350 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp11_);
#line 351 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = p;
#line 351 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = str;
#line 351 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_read_from_string ((GXmlGomElement*) _tmp12_, _tmp13_, &_inner_error_);
#line 351 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 351 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (p);
#line 351 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (str);
#line 3308 "GomElementTest.c"
			goto __catch256_g_error;
		}
#line 352 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = p;
#line 352 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = gxml_gom_element_write_string ((GXmlGomElement*) _tmp15_, &_inner_error_);
#line 352 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = _tmp16_;
#line 352 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 352 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (p);
#line 352 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (str);
#line 3323 "GomElementTest.c"
			goto __catch256_g_error;
		}
#line 352 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:352: %s", _tmp14_);
#line 353 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = p;
#line 353 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = gom_element_test_potion_get_cname (_tmp17_);
#line 353 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = _tmp18_;
#line 353 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp19_, "edumor") == 0, "p.cname == \"edumor\"");
#line 354 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = p;
#line 354 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = gom_element_test_potion_get_ingredient (_tmp20_);
#line 354 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = _tmp21_;
#line 354 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp22_ != NULL, "p.ingredient != null");
#line 355 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = p;
#line 355 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = gom_element_test_potion_get_ingredient (_tmp23_);
#line 355 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 355 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = gom_element_test_ingredient_get_cname (_tmp25_);
#line 355 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = _tmp26_;
#line 355 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp27_, "spider") == 0, "p.ingredient.cname == \"spider\"");
#line 356 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = p;
#line 356 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = gom_element_test_potion_get_ingredient (_tmp28_);
#line 356 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = _tmp29_;
#line 356 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = gom_element_test_ingredient_get_methods (_tmp30_);
#line 356 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = _tmp31_;
#line 356 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp32_ != NULL, "p.ingredient.methods != null");
#line 357 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = p;
#line 357 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = gom_element_test_potion_get_ingredient (_tmp33_);
#line 357 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = _tmp34_;
#line 357 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = gom_element_test_ingredient_get_methods (_tmp35_);
#line 357 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = _tmp36_;
#line 357 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = gxml_gom_collection_get_length ((GXmlGomCollection*) _tmp37_);
#line 357 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = _tmp38_;
#line 357 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp39_ == 1, "p.ingredient.methods.length == 1");
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = p;
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = gom_element_test_potion_get_ingredient (_tmp41_);
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = _tmp42_;
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = gom_element_test_ingredient_get_methods (_tmp43_);
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = _tmp44_;
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp45_, 0, &_inner_error_);
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = _tmp46_;
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp14_);
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (p);
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (str);
#line 3406 "GomElementTest.c"
			goto __catch256_g_error;
		}
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp40_, GOM_ELEMENT_TEST_TYPE_METHOD) ? ((GomElementTestMethod*) _tmp40_) : NULL);
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		m = _tmp47_;
#line 359 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = gom_element_test_method_get_cname (m);
#line 359 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = _tmp48_;
#line 359 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp49_, "move") == 0, "m.cname == \"move\"");
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (m);
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp40_);
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp14_);
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (p);
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (str);
#line 3429 "GomElementTest.c"
	}
	goto __finally256;
	__catch256_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp50_;
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 361 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = e->message;
#line 361 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:361: %s", _tmp50_);
#line 362 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 3448 "GomElementTest.c"
	}
	__finally256:
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 3459 "GomElementTest.c"
	}
}


static void
___lambda245__gtest_func (void)
{
#line 344 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda245_ ();
#line 3469 "GomElementTest.c"
}


static void
__lambda246_ (void)
{
	GError * _inner_error_ = NULL;
	{
		gchar* str = NULL;
		gchar* _tmp0_;
		GomElementTestRepository* r = NULL;
		GomElementTestRepository* _tmp1_;
#line 367 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = g_strdup ("<?xml version=\"1.0\"?>\n" \
"<repository version=\"1.2\" xmlns=\"http://www.gtk.org/introspection/c" \
"ore/1.0\" xmlns:c=\"http://www.gtk.org/introspection/c/1.0\" xmlns:gli" \
"b=\"http://www.gtk.org/introspection/glib/1.0\">\n" \
"<include name=\"GXml\" version=\"0.16\"/>\n" \
"<package name=\"girp-0.2\"/>\n" \
"<c:include name=\"girp.h\"/>\n" \
"<namespace name=\"Girp\" version=\"0.2\" c:prefix=\"Girp\">\n" \
"\t<attribute name=\"ccode.gir-version\" value=\"0.2\"/>\n" \
"\t<attribute name=\"ccode.cheader-filename\" value=\"girp.h\"/>\n" \
"\t<attribute name=\"ccode.gir-namespace\" value=\"Girp\"/>\n" \
"\t<class name=\"Repository\" c:type=\"GirpRepository\" glib:type-name=" \
"\"GirpRepository\" glib:get-type=\"girp_repository_get_type\" glib:typ" \
"e-struct=\"RepositoryClass\" parent=\"GXml.GomElement\">\n" \
"\t</class>\n" \
"</namespace>\n" \
"</repository>");
#line 367 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		str = _tmp0_;
#line 380 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = gom_element_test_repository_new ();
#line 380 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		r = _tmp1_;
#line 381 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_read_from_string ((GXmlGomElement*) r, str, &_inner_error_);
#line 381 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 381 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 381 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (str);
#line 3498 "GomElementTest.c"
			goto __catch257_g_error;
		}
#line 366 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (r);
#line 366 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (str);
#line 3505 "GomElementTest.c"
	}
	goto __finally257;
	__catch257_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp2_;
#line 366 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 366 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 383 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = e->message;
#line 383 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:383: %s", _tmp2_);
#line 384 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 366 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 3524 "GomElementTest.c"
	}
	__finally257:
#line 366 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 366 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 366 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 366 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 3535 "GomElementTest.c"
	}
}


static void
___lambda246__gtest_func (void)
{
#line 365 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda246_ ();
#line 3545 "GomElementTest.c"
}


static void
__lambda247_ (void)
{
	GError * _inner_error_ = NULL;
	{
		gchar* str = NULL;
		gchar* _tmp0_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlDomElement* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		GXmlDomHTMLCollection* lt = NULL;
		GXmlDomElement* _tmp8_;
		GXmlDomElement* _tmp9_;
		GXmlDomElement* _tmp10_;
		GXmlDomHTMLCollection* _tmp11_;
		GXmlDomHTMLCollection* _tmp12_;
		gint _tmp13_;
		gint _tmp14_;
		GXmlDomElement* n = NULL;
		gpointer _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
#line 389 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = g_strdup ("<?xml version=\"1.0\"?>\n" \
"<repository version=\"1.2\" xmlns=\"http://www.gtk.org/introspection/c" \
"ore/1.0\" xmlns:c=\"http://www.gtk.org/introspection/c/1.0\" xmlns:gli" \
"b=\"http://www.gtk.org/introspection/glib/1.0\">\n" \
"<include name=\"GXml\" version=\"0.16\"/>\n" \
"<package name=\"girp-0.2\"/>\n" \
"<c:include name=\"girp.h\"/>\n" \
"<namespace name=\"Girp\" version=\"0.2\" c:prefix=\"Girp\">\n" \
"\t<attribute name=\"ccode.gir-version\" value=\"0.2\"/>\n" \
"\t<attribute name=\"ccode.cheader-filename\" value=\"girp.h\"/>\n" \
"\t<attribute name=\"ccode.gir-namespace\" value=\"Girp\"/>\n" \
"\t<class name=\"Repository\" c:type=\"GirpRepository\" glib:type-name=" \
"\"GirpRepository\" glib:get-type=\"girp_repository_get_type\" glib:typ" \
"e-struct=\"RepositoryClass\" parent=\"GXml.GomElement\">\n" \
"\t</class>\n" \
"</namespace>\n" \
"</repository>");
#line 389 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		str = _tmp0_;
#line 402 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = gxml_gom_document_new_from_string (str, &_inner_error_);
#line 402 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		d = _tmp1_;
#line 402 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 402 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (str);
#line 3593 "GomElementTest.c"
			goto __catch258_g_error;
		}
#line 403 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 403 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = _tmp3_;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp4_);
#line 403 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = _tmp5_;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "repository") == 0, "d.document_element.node_name == \"repository\"");
#line 403 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp7_);
#line 403 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp4_);
#line 404 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 404 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = _tmp8_;
#line 404 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 404 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = gxml_dom_element_get_elements_by_tag_name (_tmp10_, "class");
#line 404 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 404 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp10_);
#line 404 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		lt = _tmp12_;
#line 405 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = gxml_dom_html_collection_get_length (lt);
#line 405 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 405 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp14_ == 1, "lt.length == 1");
#line 406 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = gee_list_get ((GeeList*) lt, 0);
#line 406 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n = (GXmlDomElement*) _tmp15_;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = gxml_dom_node_get_node_name ((GXmlDomNode*) n);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = _tmp17_;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp18_, "class") == 0, "n.node_name == \"class\"");
#line 407 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp18_);
#line 408 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) n, "c");
#line 408 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 408 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp20_, "http://www.gtk.org/introspection/c/1.0") == 0, "n.lookup_namespace_uri (\"c\") == \"http://www.gtk.org/introspection/c/1.0\"");
#line 408 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp20_);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) n, "http://www.gtk.org/introspection/c/1.0");
#line 409 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = _tmp21_;
#line 409 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp22_, "c") == 0, "n.lookup_prefix (\"http://www.gtk.org/introspection/c/1.0\") == \"c\"");
#line 409 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp22_);
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n);
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (lt);
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (d);
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (str);
#line 3672 "GomElementTest.c"
	}
	goto __finally258;
	__catch258_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp23_;
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 411 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = e->message;
#line 411 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:411: %s", _tmp23_);
#line 412 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 3691 "GomElementTest.c"
	}
	__finally258:
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 3702 "GomElementTest.c"
	}
}


static void
___lambda247__gtest_func (void)
{
#line 387 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda247_ ();
#line 3712 "GomElementTest.c"
}


static void
__lambda248_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomElement* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlGomElement* root = NULL;
		GXmlGomElement* _tmp4_;
		GXmlGomDocument* _tmp5_;
		GXmlDomNodeList* _tmp6_;
		GXmlDomNodeList* _tmp7_;
		GXmlDomNodeList* _tmp8_;
		GXmlGomElement* _tmp9_;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlGomDocument* _tmp11_;
		GXmlDomElement* _tmp12_;
		GXmlGomElement* n = NULL;
		GXmlGomElement* _tmp13_;
		GXmlGomElement* _tmp14_;
		GXmlDomNodeList* _tmp15_;
		GXmlDomNodeList* _tmp16_;
		GXmlDomNodeList* _tmp17_;
		GXmlGomElement* _tmp18_;
		GXmlDomText* t = NULL;
		GXmlGomDocument* _tmp19_;
		GXmlDomText* _tmp20_;
		GXmlGomElement* _tmp21_;
		GXmlDomNodeList* _tmp22_;
		GXmlDomNodeList* _tmp23_;
		GXmlDomNodeList* _tmp24_;
		GXmlDomText* _tmp25_;
		GXmlXParser* parser = NULL;
		GXmlGomDocument* _tmp26_;
		GXmlXParser* _tmp27_;
		gchar* _tmp28_ = NULL;
		GXmlXParser* _tmp29_;
		gchar* _tmp30_;
		gchar* s = NULL;
		gchar** _tmp31_;
		gchar** _tmp32_;
		gchar** _tmp33_;
		gint _tmp33__length1;
		const gchar* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
#line 417 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 417 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = _tmp0_;
#line 418 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = doc;
#line 418 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp2_, "root", &_inner_error_);
#line 418 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = _tmp3_;
#line 418 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 418 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3779 "GomElementTest.c"
			goto __catch259_g_error;
		}
#line 418 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_GOM_ELEMENT, GXmlGomElement));
#line 418 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		root = _tmp4_;
#line 419 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = doc;
#line 419 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp5_);
#line 419 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 419 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 419 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = root;
#line 419 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp8_, (GXmlDomNode*) _tmp9_);
#line 419 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp8_);
#line 420 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = doc;
#line 420 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp11_, "child", &_inner_error_);
#line 420 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = _tmp12_;
#line 420 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 420 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 420 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 420 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3814 "GomElementTest.c"
			goto __catch259_g_error;
		}
#line 420 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GXML_TYPE_GOM_ELEMENT, GXmlGomElement));
#line 420 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n = _tmp13_;
#line 421 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = root;
#line 421 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp14_);
#line 421 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = _tmp15_;
#line 421 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 421 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = n;
#line 421 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp17_, (GXmlDomNode*) _tmp18_);
#line 421 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp17_);
#line 422 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = doc;
#line 422 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = gxml_dom_document_create_text_node ((GXmlDomDocument*) _tmp19_, "TEXT1", &_inner_error_);
#line 422 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		t = _tmp20_;
#line 422 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 422 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 422 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp10_);
#line 422 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 422 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 422 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3853 "GomElementTest.c"
			goto __catch259_g_error;
		}
#line 423 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = root;
#line 423 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp21_);
#line 423 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = _tmp22_;
#line 423 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = _tmp23_;
#line 423 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = t;
#line 423 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp24_, (GXmlDomNode*) _tmp25_);
#line 423 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp24_);
#line 424 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = doc;
#line 424 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = gxml_xparser_new ((GXmlDomNode*) _tmp26_);
#line 424 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		parser = _tmp27_;
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = parser;
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = gxml_parser_write_string ((GXmlParser*) _tmp29_, &_inner_error_);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = _tmp30_;
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (t);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp10_);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3898 "GomElementTest.c"
			goto __catch259_g_error;
		}
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = _tmp31_ = g_strsplit (_tmp28_, "\n", 0);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33__length1 = _vala_array_length (_tmp31_);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp33_[1];
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = g_strdup (_tmp34_);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = _tmp35_;
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = (_vala_array_free (_tmp33_, _tmp33__length1, (GDestroyNotify) g_free), NULL);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		s = _tmp36_;
#line 426 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (s, "<root><child/>TEXT1</root>") == 0, "s == \"<root><child/>TEXT1</root>\"");
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (s);
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp28_);
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (parser);
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (t);
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n);
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp10_);
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (root);
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp1_);
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 3937 "GomElementTest.c"
	}
	goto __finally259;
	__catch259_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp37_;
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 428 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = e->message;
#line 428 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_test_message ("%s", _tmp37_);
#line 429 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 3956 "GomElementTest.c"
	}
	__finally259:
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 3967 "GomElementTest.c"
	}
}


static void
___lambda248__gtest_func (void)
{
#line 415 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda248_ ();
#line 3977 "GomElementTest.c"
}


static void
__lambda249_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomElement* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlGomElement* root = NULL;
		GXmlGomElement* _tmp4_;
		GXmlGomDocument* _tmp5_;
		GXmlDomNodeList* _tmp6_;
		GXmlDomNodeList* _tmp7_;
		GXmlDomNodeList* _tmp8_;
		GXmlGomElement* _tmp9_;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlGomDocument* _tmp11_;
		GXmlDomElement* _tmp12_;
		GXmlGomElement* n = NULL;
		GXmlGomElement* _tmp13_;
		GXmlGomElement* _tmp14_;
		GXmlDomNodeList* _tmp15_;
		GXmlDomNodeList* _tmp16_;
		GXmlDomNodeList* _tmp17_;
		GXmlGomElement* _tmp18_;
		GXmlDomText* _tmp19_ = NULL;
		GXmlGomDocument* _tmp20_;
		GXmlDomText* _tmp21_;
		GXmlDomText* t = NULL;
		GXmlDomText* _tmp22_;
		GXmlGomElement* _tmp23_;
		GXmlDomNodeList* _tmp24_;
		GXmlDomNodeList* _tmp25_;
		GXmlDomNodeList* _tmp26_;
		GXmlDomText* _tmp27_;
		GXmlXParser* parser = NULL;
		GXmlGomDocument* _tmp28_;
		GXmlXParser* _tmp29_;
		gchar* _tmp30_ = NULL;
		GXmlXParser* _tmp31_;
		gchar* _tmp32_;
		gchar* s = NULL;
		gchar** _tmp33_;
		gchar** _tmp34_;
		gchar** _tmp35_;
		gint _tmp35__length1;
		const gchar* _tmp36_;
		gchar* _tmp37_;
		gchar* _tmp38_;
#line 434 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 434 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = _tmp0_;
#line 435 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = doc;
#line 435 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp2_, "root", &_inner_error_);
#line 435 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = _tmp3_;
#line 435 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 435 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 4046 "GomElementTest.c"
			goto __catch260_g_error;
		}
#line 435 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_GOM_ELEMENT, GXmlGomElement));
#line 435 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		root = _tmp4_;
#line 436 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = doc;
#line 436 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp5_);
#line 436 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 436 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 436 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = root;
#line 436 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp8_, (GXmlDomNode*) _tmp9_);
#line 436 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp8_);
#line 437 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = doc;
#line 437 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp11_, "child", &_inner_error_);
#line 437 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = _tmp12_;
#line 437 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 437 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 437 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 437 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 4081 "GomElementTest.c"
			goto __catch260_g_error;
		}
#line 437 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GXML_TYPE_GOM_ELEMENT, GXmlGomElement));
#line 437 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n = _tmp13_;
#line 438 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = root;
#line 438 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp14_);
#line 438 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = _tmp15_;
#line 438 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 438 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = n;
#line 438 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp17_, (GXmlDomNode*) _tmp18_);
#line 438 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp17_);
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = doc;
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = gxml_dom_document_create_text_node ((GXmlDomDocument*) _tmp20_, "TEXT1", &_inner_error_);
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = _tmp21_;
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp10_);
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 4120 "GomElementTest.c"
			goto __catch260_g_error;
		}
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, GXML_TYPE_DOM_TEXT) ? ((GXmlDomText*) _tmp19_) : NULL);
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		t = _tmp22_;
#line 440 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = root;
#line 440 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp23_);
#line 440 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 440 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 440 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = t;
#line 440 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp26_, (GXmlDomNode*) _tmp27_);
#line 440 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 441 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = doc;
#line 441 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = gxml_xparser_new ((GXmlDomNode*) _tmp28_);
#line 441 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		parser = _tmp29_;
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = parser;
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = gxml_parser_write_string ((GXmlParser*) _tmp31_, &_inner_error_);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = _tmp32_;
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (t);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp19_);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp10_);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 4171 "GomElementTest.c"
			goto __catch260_g_error;
		}
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp33_ = g_strsplit (_tmp30_, "\n", 0);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = _tmp34_;
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35__length1 = _vala_array_length (_tmp33_);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = _tmp35_[1];
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = g_strdup (_tmp36_);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = _tmp37_;
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = (_vala_array_free (_tmp35_, _tmp35__length1, (GDestroyNotify) g_free), NULL);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		s = _tmp38_;
#line 443 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (s, "<root><child/>TEXT1</root>") == 0, "s == \"<root><child/>TEXT1</root>\"");
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (s);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp30_);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (parser);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (t);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp19_);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp10_);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (root);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp1_);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 4212 "GomElementTest.c"
	}
	goto __finally260;
	__catch260_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp39_;
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 445 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = e->message;
#line 445 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_test_message ("%s", _tmp39_);
#line 446 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 4231 "GomElementTest.c"
	}
	__finally260:
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 4242 "GomElementTest.c"
	}
}


static void
___lambda249__gtest_func (void)
{
#line 432 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda249_ ();
#line 4252 "GomElementTest.c"
}


static void
__lambda250_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomElement* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomElement* _tmp5_;
		GXmlDomElement* _tmp6_;
		GXmlDomNode* _tmp7_;
		GXmlDomNode* _tmp8_;
		GXmlDomNode* _tmp9_;
		GXmlDomElement* _tmp10_;
		GXmlDomElement* _tmp11_;
		GXmlDomElement* _tmp12_;
		GXmlDomNode* _tmp13_;
		GXmlDomNode* _tmp14_;
		GXmlDomNode* _tmp15_;
		GXmlDomElement* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlDomElement* _tmp18_;
		GXmlDomNodeList* _tmp19_;
		GXmlDomNodeList* _tmp20_;
		GXmlDomNodeList* _tmp21_;
		gpointer _tmp22_;
		GXmlDomNode* _tmp23_;
		GXmlDomElement* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlDomElement* _tmp26_;
		GXmlDomNodeList* _tmp27_;
		GXmlDomNodeList* _tmp28_;
		GXmlDomNodeList* _tmp29_;
		gpointer _tmp30_;
		GXmlDomNode* _tmp31_;
		GXmlDomNode* _tmp32_;
		GXmlDomNode* _tmp33_;
		GXmlDomNode* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomElement* _tmp37_;
		GXmlDomNodeList* _tmp38_;
		GXmlDomNodeList* _tmp39_;
		GXmlDomNodeList* _tmp40_;
		gpointer _tmp41_;
		GXmlDomNode* _tmp42_;
		GXmlDomNode* _tmp43_;
		GXmlDomNode* _tmp44_;
		GXmlDomNode* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
#line 451 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<root><child/></root>", &_inner_error_);
#line 451 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = _tmp0_;
#line 451 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4317 "GomElementTest.c"
			goto __catch261_g_error;
		}
#line 452 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 452 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = _tmp1_;
#line 452 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 452 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp3_ != NULL, "doc.document_element != null");
#line 452 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp3_);
#line 453 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 453 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 453 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = _tmp5_;
#line 453 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp6_);
#line 453 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 453 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = _tmp8_;
#line 453 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_DOM_NODE), "doc.document_element.parent_node is GXml.DomNode");
#line 453 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp9_);
#line 453 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp6_);
#line 454 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 454 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 454 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 454 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp12_);
#line 454 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 454 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = _tmp14_;
#line 454 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_DOM_DOCUMENT), "doc.document_element.parent_node is GXml.DomDocument");
#line 454 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp15_);
#line 454 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = _tmp17_;
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp18_);
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = _tmp20_;
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = gee_list_get ((GeeList*) _tmp21_, 0);
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = (GXmlDomNode*) _tmp22_;
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp23_ != NULL, "doc.document_element.child_nodes[0] != null");
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp23_);
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp21_);
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp18_);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp26_);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = _tmp27_;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = _tmp28_;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = gee_list_get ((GeeList*) _tmp29_, 0);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = (GXmlDomNode*) _tmp30_;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = gxml_dom_node_get_parent_node (_tmp31_);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp34_ != NULL, "doc.document_element.child_nodes[0].parent_node != null");
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp34_);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp31_);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp29_);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = _tmp35_;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = _tmp36_;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp37_);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = _tmp38_;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = _tmp39_;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = gee_list_get ((GeeList*) _tmp40_, 0);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = (GXmlDomNode*) _tmp41_;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = gxml_dom_node_get_parent_node (_tmp42_);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = _tmp43_;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = _tmp44_;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = gxml_dom_node_get_node_name (_tmp45_);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = _tmp46_;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = _tmp47_;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp48_, "root") == 0, "doc.document_element.child_nodes[0].parent_node.node_name == \"root\"");
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp48_);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp45_);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp42_);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp40_);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp37_);
#line 450 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 4464 "GomElementTest.c"
	}
	goto __finally261;
	__catch261_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp49_;
		gchar* _tmp50_;
		gchar* _tmp51_;
#line 450 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 450 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 459 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = e->message;
#line 459 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = g_strconcat ("Error: ", _tmp49_, NULL);
#line 459 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp51_ = _tmp50_;
#line 459 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:459: %s", _tmp51_);
#line 459 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp51_);
#line 460 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 450 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 4491 "GomElementTest.c"
	}
	__finally261:
#line 450 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 450 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 450 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 450 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 4502 "GomElementTest.c"
	}
}


static void
___lambda250__gtest_func (void)
{
#line 449 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda250_ ();
#line 4512 "GomElementTest.c"
}


static void
__lambda251_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlGomDocument* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlGomDocument* _tmp5_;
		GXmlDomElement* _tmp6_;
		GXmlDomElement* _tmp7_;
		GXmlDomElement* _tmp8_;
		GXmlDomNode* _tmp9_;
		GXmlDomNode* _tmp10_;
		GXmlDomNode* _tmp11_;
		GXmlGomDocument* _tmp12_;
		GXmlDomElement* _tmp13_;
		GXmlDomElement* _tmp14_;
		GXmlDomElement* _tmp15_;
		GXmlDomNode* _tmp16_;
		GXmlDomNode* _tmp17_;
		GXmlDomNode* _tmp18_;
		GXmlGomDocument* _tmp19_;
		GXmlDomElement* _tmp20_;
		GXmlDomElement* _tmp21_;
		GXmlDomElement* _tmp22_;
		GXmlDomNodeList* _tmp23_;
		GXmlDomNodeList* _tmp24_;
		GXmlDomNodeList* _tmp25_;
		gint _tmp26_;
		gint _tmp27_;
		GXmlGomDocument* _tmp28_;
		GXmlDomElement* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomElement* _tmp31_;
		GXmlDomNodeList* _tmp32_;
		GXmlDomNodeList* _tmp33_;
		GXmlDomNodeList* _tmp34_;
		gpointer _tmp35_;
		GXmlDomNode* _tmp36_;
		GXmlGomDocument* _tmp37_;
		GXmlDomElement* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomNodeList* _tmp41_;
		GXmlDomNodeList* _tmp42_;
		GXmlDomNodeList* _tmp43_;
		gpointer _tmp44_;
		GXmlDomNode* _tmp45_;
		GXmlDomChildNode* _tmp46_;
		GXmlDomChildNode* _tmp47_;
		GXmlGomDocument* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomElement* _tmp51_;
		GXmlDomNodeList* _tmp52_;
		GXmlDomNodeList* _tmp53_;
		GXmlDomNodeList* _tmp54_;
		gint _tmp55_;
		gint _tmp56_;
		gchar* _tmp57_ = NULL;
		GXmlGomDocument* _tmp58_;
		gchar* _tmp59_;
#line 465 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<root><child/></root>", &_inner_error_);
#line 465 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = _tmp0_;
#line 465 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4588 "GomElementTest.c"
			goto __catch262_g_error;
		}
#line 466 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = doc;
#line 466 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp1_);
#line 466 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 466 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = _tmp3_;
#line 466 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp4_ != NULL, "doc.document_element != null");
#line 466 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp4_);
#line 467 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = doc;
#line 467 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp5_);
#line 467 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 467 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 467 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp8_);
#line 467 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 467 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 467 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, GXML_TYPE_DOM_NODE), "doc.document_element.parent_node is GXml.DomNode");
#line 467 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp11_);
#line 467 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp8_);
#line 468 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = doc;
#line 468 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp12_);
#line 468 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 468 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = _tmp14_;
#line 468 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp15_);
#line 468 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 468 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = _tmp17_;
#line 468 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, GXML_TYPE_DOM_DOCUMENT), "doc.document_element.parent_node is GXml.DomDocument");
#line 468 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp18_);
#line 468 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp15_);
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = doc;
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp19_);
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = _tmp20_;
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = _tmp21_;
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp22_);
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = _tmp23_;
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = gxml_dom_node_list_get_length (_tmp25_);
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = _tmp26_;
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp27_ == 1, "doc.document_element.child_nodes.length == 1");
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp25_);
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp22_);
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = doc;
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp28_);
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = _tmp29_;
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = _tmp30_;
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp31_);
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = gee_list_get ((GeeList*) _tmp34_, 0);
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = (GXmlDomNode*) _tmp35_;
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp36_, GXML_TYPE_DOM_CHILD_NODE), "doc.document_element.child_nodes[0] is DomChildNode");
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp36_);
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp34_);
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp31_);
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = doc;
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp37_);
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = _tmp38_;
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = _tmp39_;
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp40_);
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = _tmp41_;
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = _tmp42_;
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = gee_list_get ((GeeList*) _tmp43_, 0);
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = (GXmlDomNode*) _tmp44_;
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp45_, GXML_TYPE_DOM_CHILD_NODE) ? ((GXmlDomChildNode*) _tmp45_) : NULL;
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (_tmp46_ == NULL) {
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp45_);
#line 4717 "GomElementTest.c"
		}
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = _tmp46_;
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_child_node_remove (_tmp47_);
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp47_);
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp43_);
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp40_);
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = doc;
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp48_);
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = _tmp49_;
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp51_ = _tmp50_;
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp52_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp51_);
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp53_ = _tmp52_;
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp54_ = _tmp53_;
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp55_ = gxml_dom_node_list_get_length (_tmp54_);
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp56_ = _tmp55_;
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp56_ == 0, "doc.document_element.child_nodes.length == 0");
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp54_);
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp51_);
#line 473 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp58_ = doc;
#line 473 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp59_ = gxml_gom_document_write_string (_tmp58_, &_inner_error_);
#line 473 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp57_ = _tmp59_;
#line 473 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 473 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 4763 "GomElementTest.c"
			goto __catch262_g_error;
		}
#line 473 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (string_contains (_tmp57_, "<root/>"), "\"<root/>\" in  doc.write_string ()");
#line 464 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp57_);
#line 464 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 4772 "GomElementTest.c"
	}
	goto __finally262;
	__catch262_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp60_;
		gchar* _tmp61_;
		gchar* _tmp62_;
#line 464 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 464 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 475 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp60_ = e->message;
#line 475 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp61_ = g_strconcat ("Error: ", _tmp60_, NULL);
#line 475 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp62_ = _tmp61_;
#line 475 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:475: %s", _tmp62_);
#line 475 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp62_);
#line 476 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 464 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 4799 "GomElementTest.c"
	}
	__finally262:
#line 464 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 464 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 464 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 464 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 4810 "GomElementTest.c"
	}
}


static void
___lambda251__gtest_func (void)
{
#line 463 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda251_ ();
#line 4820 "GomElementTest.c"
}


static void
__lambda252_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GomElementTestParsedDelayed* n = NULL;
		GomElementTestParsedDelayed* _tmp0_;
		GomElementTestParsedDelayed* _tmp1_;
		GomElementTestParsedDelayed* _tmp2_;
		const gchar* _tmp3_;
		const gchar* _tmp4_;
		GomElementTestParsedDelayed* _tmp5_;
		const gchar* _tmp6_;
		const gchar* _tmp7_;
		GomElementTestParsedDelayed* _tmp8_;
		GomElementTestParsedDelayed* _tmp9_;
		GXmlDomNodeList* _tmp10_;
		GXmlDomNodeList* _tmp11_;
		GXmlDomNodeList* _tmp12_;
		gint _tmp13_;
		gint _tmp14_;
		GomElementTestParsedDelayed* _tmp15_;
		GomElementTestParsedDelayed* _tmp16_;
		GomElementTestParsedDelayed* _tmp17_;
		GXmlDomNodeList* _tmp18_;
		GXmlDomNodeList* _tmp19_;
		GXmlDomNodeList* _tmp20_;
		gint _tmp21_;
		gint _tmp22_;
		GomElementTestParsedDelayed* _tmp23_;
		const gchar* _tmp24_;
		const gchar* _tmp25_;
#line 481 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gom_element_test_parsed_delayed_new ();
#line 481 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n = _tmp0_;
#line 482 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = n;
#line 482 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_read_from_string ((GXmlGomElement*) _tmp1_, "<root><child p1=\"Value1\" p2=\"Value2\"><child2/></child></root>", &_inner_error_);
#line 482 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 482 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 4868 "GomElementTest.c"
			goto __catch263_g_error;
		}
#line 483 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = n;
#line 483 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = gxml_gom_element_get_unparsed ((GXmlGomElement*) _tmp2_);
#line 483 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = _tmp3_;
#line 483 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp4_ != NULL, "n.unparsed != null");
#line 484 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = n;
#line 484 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = gxml_gom_element_get_unparsed ((GXmlGomElement*) _tmp5_);
#line 484 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 484 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "<child p1=\"Value1\" p2=\"Value2\"><child2/></child>") == 0, "n.unparsed == \"<child p1=\\\"Value1\\\" p2=\\\"Value2\\\"><child2/></child>\"");
#line 485 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = n;
#line 485 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (!gxml_dom_node_has_child_nodes ((GXmlDomNode*) _tmp8_), "!n.has_child_nodes ()");
#line 486 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = n;
#line 486 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp9_);
#line 486 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 486 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 486 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = gxml_dom_node_list_get_length (_tmp12_);
#line 486 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 486 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp14_ == 0, "n.child_nodes.length == 0");
#line 486 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 487 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = n;
#line 487 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_read_unparsed ((GXmlGomElement*) _tmp15_, &_inner_error_);
#line 487 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 487 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 4915 "GomElementTest.c"
			goto __catch263_g_error;
		}
#line 488 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = n;
#line 488 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (gxml_dom_node_has_child_nodes ((GXmlDomNode*) _tmp16_), "n.has_child_nodes ()");
#line 489 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = n;
#line 489 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp17_);
#line 489 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = _tmp18_;
#line 489 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 489 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = gxml_dom_node_list_get_length (_tmp20_);
#line 489 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = _tmp21_;
#line 489 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp22_ == 1, "n.child_nodes.length == 1");
#line 489 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp20_);
#line 490 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = n;
#line 490 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = gxml_gom_element_get_unparsed ((GXmlGomElement*) _tmp23_);
#line 490 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 490 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp25_ == NULL, "n.unparsed == null");
#line 480 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n);
#line 4948 "GomElementTest.c"
	}
	goto __finally263;
	__catch263_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
#line 480 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 480 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 492 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = e->message;
#line 492 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = g_strconcat ("Error: ", _tmp26_, NULL);
#line 492 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = _tmp27_;
#line 492 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:492: %s", _tmp28_);
#line 492 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp28_);
#line 493 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 480 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 4975 "GomElementTest.c"
	}
	__finally263:
#line 480 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 480 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 480 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 480 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 4986 "GomElementTest.c"
	}
}


static void
___lambda252__gtest_func (void)
{
#line 479 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda252_ ();
#line 4996 "GomElementTest.c"
}


static void
__lambda253_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlGomElement* n = NULL;
		GXmlGomElement* _tmp0_;
		GXmlGomElement* _tmp1_;
		GXmlGomElement* _tmp2_;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlGomElement* _tmp4_;
		GXmlDomDocument* _tmp5_;
		GXmlDomDocument* _tmp6_;
		GXmlDomElement* _tmp7_;
		GXmlGomElement* n2 = NULL;
		GXmlGomElement* _tmp8_;
		GXmlGomElement* _tmp9_;
		GXmlGomElement* _tmp10_;
		GXmlDomNode* _tmp11_;
		GXmlDomNode* _tmp12_;
		gchar* str = NULL;
		GXmlGomElement* _tmp13_;
		gchar* _tmp14_;
		const gchar* _tmp15_;
		const gchar* _tmp16_;
		gchar* _tmp17_ = NULL;
		GXmlGomElement* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		const gchar* _tmp21_;
		const gchar* _tmp22_;
#line 498 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_element_new ();
#line 498 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n = _tmp0_;
#line 499 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = n;
#line 499 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_initialize (_tmp1_, "Node");
#line 500 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = n;
#line 500 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp2_, "name", "value", &_inner_error_);
#line 500 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 500 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 5047 "GomElementTest.c"
			goto __catch264_g_error;
		}
#line 501 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = n;
#line 501 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp4_);
#line 501 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = _tmp5_;
#line 501 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = gxml_dom_document_create_element (_tmp6_, "Node2", &_inner_error_);
#line 501 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp7_;
#line 501 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 501 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 5064 "GomElementTest.c"
			goto __catch264_g_error;
		}
#line 501 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_GOM_ELEMENT) ? ((GXmlGomElement*) _tmp3_) : NULL);
#line 501 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n2 = _tmp8_;
#line 502 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = n;
#line 502 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = n2;
#line 502 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp9_, (GXmlDomNode*) _tmp10_, &_inner_error_);
#line 502 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 502 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 502 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 502 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 502 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp3_);
#line 502 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 5089 "GomElementTest.c"
			goto __catch264_g_error;
		}
#line 503 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = n;
#line 503 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = gxml_gom_element_write_string (_tmp13_, &_inner_error_);
#line 503 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		str = _tmp14_;
#line 503 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 503 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 503 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp3_);
#line 503 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 5106 "GomElementTest.c"
			goto __catch264_g_error;
		}
#line 504 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = str;
#line 504 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (string_contains (_tmp15_, "<Node"), "\"<Node\" in str");
#line 505 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = str;
#line 505 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (string_contains (_tmp16_, "<Node name=\"value\"><Node2/></Node>"), "\"<Node name=\\\"value\\\"><Node2/></Node>\" in str");
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = n2;
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = gxml_gom_element_write_string (_tmp18_, &_inner_error_);
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = _tmp19_;
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (str);
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp3_);
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 5133 "GomElementTest.c"
			goto __catch264_g_error;
		}
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = _tmp17_;
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = NULL;
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (str);
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		str = _tmp20_;
#line 507 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = str;
#line 507 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (string_contains (_tmp21_, "<Node2/>"), "\"<Node2/>\" in str");
#line 508 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = str;
#line 508 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (!string_contains (_tmp22_, "<Node name=\"value\"><Node2/></Node>"), "!(\"<Node name=\\\"value\\\"><Node2/></Node>\" in str)");
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp17_);
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (str);
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n2);
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp3_);
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n);
#line 5162 "GomElementTest.c"
	}
	goto __finally264;
	__catch264_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp23_;
		gchar* _tmp24_;
		gchar* _tmp25_;
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 510 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = e->message;
#line 510 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = g_strconcat ("Error: ", _tmp23_, NULL);
#line 510 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 510 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:510: %s", _tmp25_);
#line 510 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp25_);
#line 511 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 5189 "GomElementTest.c"
	}
	__finally264:
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 5200 "GomElementTest.c"
	}
}


static void
___lambda253__gtest_func (void)
{
#line 496 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda253_ ();
#line 5210 "GomElementTest.c"
}


static void
__lambda254_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlGomElement* n = NULL;
		GXmlGomElement* _tmp0_;
		GXmlGomElement* _tmp1_;
		GXmlGomElement* _tmp2_;
		GMemoryOutputStream* ostream = NULL;
		GMemoryOutputStream* _tmp3_;
		GXmlGomElement* _tmp4_;
		GMemoryOutputStream* _tmp5_;
		gchar* str = NULL;
		GMemoryOutputStream* _tmp6_;
		void* _tmp7_;
		void* _tmp8_;
		gchar* _tmp9_;
#line 516 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_element_new ();
#line 516 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n = _tmp0_;
#line 517 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = n;
#line 517 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_initialize (_tmp1_, "Node");
#line 518 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = n;
#line 518 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp2_, "name", "value", &_inner_error_);
#line 518 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 518 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 5248 "GomElementTest.c"
			goto __catch265_g_error;
		}
#line 519 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = (GMemoryOutputStream*) g_memory_output_stream_new_resizable ();
#line 519 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		ostream = _tmp3_;
#line 520 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = n;
#line 520 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = ostream;
#line 520 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_write_stream (_tmp4_, (GOutputStream*) _tmp5_, &_inner_error_);
#line 520 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 520 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (ostream);
#line 520 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 5267 "GomElementTest.c"
			goto __catch265_g_error;
		}
#line 521 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = ostream;
#line 521 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = g_memory_output_stream_get_data (_tmp6_);
#line 521 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 521 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = g_strdup ((const gchar*) _tmp8_);
#line 521 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		str = _tmp9_;
#line 522 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (string_contains (str, "<Node"), "\"<Node\" in str");
#line 523 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (string_contains (str, "<Node name=\"value\"/>"), "\"<Node name=\\\"value\\\"/>\" in str");
#line 515 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (str);
#line 515 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (ostream);
#line 515 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n);
#line 5290 "GomElementTest.c"
	}
	goto __finally265;
	__catch265_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
#line 515 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 515 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 525 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = e->message;
#line 525 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = g_strconcat ("Error: ", _tmp10_, NULL);
#line 525 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 525 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:525: %s", _tmp12_);
#line 525 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp12_);
#line 526 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 515 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 5317 "GomElementTest.c"
	}
	__finally265:
#line 515 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 515 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 515 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 515 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 5328 "GomElementTest.c"
	}
}


static void
___lambda254__gtest_func (void)
{
#line 514 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda254_ ();
#line 5338 "GomElementTest.c"
}


static void
__lambda255_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlGomElement* n = NULL;
		GXmlGomElement* _tmp0_;
		GXmlGomElement* _tmp1_;
		GXmlGomElement* _tmp2_;
		GMemoryOutputStream* ostream = NULL;
		GMemoryOutputStream* _tmp3_;
		GInputStream* istream = NULL;
		GXmlGomElement* _tmp4_;
		GInputStream* _tmp5_;
		GMemoryOutputStream* _tmp6_;
		GInputStream* _tmp7_;
		gchar* str = NULL;
		GMemoryOutputStream* _tmp8_;
		void* _tmp9_;
		void* _tmp10_;
		gchar* _tmp11_;
#line 531 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_element_new ();
#line 531 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n = _tmp0_;
#line 532 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = n;
#line 532 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_initialize (_tmp1_, "Node");
#line 533 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = n;
#line 533 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp2_, "name", "value", &_inner_error_);
#line 533 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 533 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 5379 "GomElementTest.c"
			goto __catch266_g_error;
		}
#line 534 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = (GMemoryOutputStream*) g_memory_output_stream_new_resizable ();
#line 534 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		ostream = _tmp3_;
#line 535 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = n;
#line 535 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = gxml_gom_element_create_stream (_tmp4_, &_inner_error_);
#line 535 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		istream = _tmp5_;
#line 535 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 535 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (ostream);
#line 535 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 5398 "GomElementTest.c"
			goto __catch266_g_error;
		}
#line 536 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = ostream;
#line 536 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = istream;
#line 536 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_output_stream_splice ((GOutputStream*) _tmp6_, _tmp7_, G_OUTPUT_STREAM_SPLICE_NONE, NULL, &_inner_error_);
#line 536 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 536 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (istream);
#line 536 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (ostream);
#line 536 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 5415 "GomElementTest.c"
			goto __catch266_g_error;
		}
#line 537 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = ostream;
#line 537 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = g_memory_output_stream_get_data (_tmp8_);
#line 537 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 537 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = g_strdup ((const gchar*) _tmp10_);
#line 537 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		str = _tmp11_;
#line 538 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (string_contains (str, "<Node"), "\"<Node\" in str");
#line 539 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (string_contains (str, "<Node name=\"value\"/>"), "\"<Node name=\\\"value\\\"/>\" in str");
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (str);
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (istream);
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (ostream);
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n);
#line 5440 "GomElementTest.c"
	}
	goto __finally266;
	__catch266_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 541 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = e->message;
#line 541 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = g_strconcat ("Error: ", _tmp12_, NULL);
#line 541 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 541 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:541: %s", _tmp14_);
#line 541 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp14_);
#line 542 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 5467 "GomElementTest.c"
	}
	__finally266:
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 5478 "GomElementTest.c"
	}
}


static void
___lambda255__gtest_func (void)
{
#line 529 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda255_ ();
#line 5488 "GomElementTest.c"
}


static void
__lambda256_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomElement* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomElement* _tmp5_;
		GXmlDomElement* _tmp6_;
		GXmlDomNode* _tmp7_;
		GXmlDomNode* _tmp8_;
		GXmlDomNode* _tmp9_;
		GXmlDomElement* _tmp10_;
		GXmlDomElement* _tmp11_;
		GXmlDomElement* _tmp12_;
		GXmlDomNode* _tmp13_;
		GXmlDomNode* _tmp14_;
		GXmlDomNode* _tmp15_;
		GXmlDomElement* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlDomElement* _tmp18_;
		GXmlDomNodeList* _tmp19_;
		GXmlDomNodeList* _tmp20_;
		GXmlDomNodeList* _tmp21_;
		gpointer _tmp22_;
		GXmlDomNode* _tmp23_;
		GXmlDomElement* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlDomElement* _tmp26_;
		GXmlDomNodeList* _tmp27_;
		GXmlDomNodeList* _tmp28_;
		GXmlDomNodeList* _tmp29_;
		gpointer _tmp30_;
		GXmlDomNode* _tmp31_;
		GXmlDomNode* _tmp32_;
		GXmlDomNode* _tmp33_;
		GXmlDomNode* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomElement* _tmp37_;
		GXmlDomNodeList* _tmp38_;
		GXmlDomNodeList* _tmp39_;
		GXmlDomNodeList* _tmp40_;
		gpointer _tmp41_;
		GXmlDomNode* _tmp42_;
		GXmlDomNode* _tmp43_;
		GXmlDomNode* _tmp44_;
		GXmlDomNode* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomElement* _tmp51_;
		GXmlDomNodeList* _tmp52_;
		GXmlDomNodeList* _tmp53_;
		GXmlDomNodeList* _tmp54_;
		gpointer _tmp55_;
		GXmlDomNode* _tmp56_;
		GXmlDomElement* _tmp57_;
		GXmlDomElement* _tmp58_;
		GXmlDomElement* _tmp59_;
		GXmlDomNodeList* _tmp60_;
		GXmlDomNodeList* _tmp61_;
		GXmlDomNodeList* _tmp62_;
		gpointer _tmp63_;
		GXmlDomNode* _tmp64_;
		GXmlDomElement* _tmp65_;
		GXmlDomElement* _tmp66_;
		GXmlDomElement* _tmp67_;
		GXmlDomNodeList* _tmp68_;
		GXmlDomNodeList* _tmp69_;
		GXmlDomNodeList* _tmp70_;
		gpointer _tmp71_;
		GXmlDomNode* _tmp72_;
		GXmlDomElement* _tmp73_;
		GXmlDomElement* _tmp74_;
		GXmlDomElement* _tmp75_;
		GXmlDomNodeList* _tmp76_;
		GXmlDomNodeList* _tmp77_;
		GXmlDomNodeList* _tmp78_;
		gpointer _tmp79_;
		GXmlDomNode* _tmp80_;
		gchar* _tmp81_;
		gchar* _tmp82_;
		gchar* _tmp83_;
		GXmlDomElement* _tmp84_;
		GXmlDomElement* _tmp85_;
		GXmlDomElement* _tmp86_;
		GXmlDomNodeList* _tmp87_;
		GXmlDomNodeList* _tmp88_;
		GXmlDomNodeList* _tmp89_;
		gpointer _tmp90_;
		GXmlDomNode* _tmp91_;
		GXmlDomElement* _tmp92_;
		GXmlDomElement* _tmp93_;
		GXmlDomElement* _tmp94_;
		GXmlDomElement* _tmp95_;
		GXmlDomElement* _tmp96_;
		GXmlDomElement* _tmp97_;
		GXmlDomElement* _tmp98_;
		GXmlDomElement* _tmp99_;
		GXmlDomNodeList* _tmp100_;
		GXmlDomNodeList* _tmp101_;
		GXmlDomNodeList* _tmp102_;
		gpointer _tmp103_;
		GXmlDomNode* _tmp104_;
		GXmlDomElement* _tmp105_;
		GXmlDomElement* _tmp106_;
		GXmlDomElement* _tmp107_;
		GXmlDomElement* _tmp108_;
		GXmlDomElement* _tmp109_;
		GXmlDomElement* _tmp110_;
		GXmlDomElement* _tmp111_;
		GXmlDomElement* _tmp112_;
		GXmlDomNodeList* _tmp113_;
		GXmlDomNodeList* _tmp114_;
		GXmlDomNodeList* _tmp115_;
		gpointer _tmp116_;
		GXmlDomNode* _tmp117_;
		GXmlDomElement* _tmp118_;
		GXmlDomElement* _tmp119_;
		GXmlDomElement* _tmp120_;
		GXmlDomElement* _tmp121_;
		GXmlDomElement* _tmp122_;
		gchar* _tmp123_;
		gchar* _tmp124_;
		gchar* _tmp125_;
		GXmlDomElement* _tmp126_;
		GXmlDomElement* _tmp127_;
		GXmlDomElement* _tmp128_;
		GXmlDomNodeList* _tmp129_;
		GXmlDomNodeList* _tmp130_;
		GXmlDomNodeList* _tmp131_;
		gpointer _tmp132_;
		GXmlDomNode* _tmp133_;
		GXmlDomElement* _tmp134_;
		GXmlDomElement* _tmp135_;
		GXmlDomElement* _tmp136_;
		GXmlDomNodeList* _tmp137_;
		GXmlDomNodeList* _tmp138_;
		GXmlDomNodeList* _tmp139_;
		gpointer _tmp140_;
		GXmlDomNode* _tmp141_;
		GXmlDomNode* _tmp142_;
		GXmlDomNode* _tmp143_;
		GXmlDomNode* _tmp144_;
		GXmlDomElement* _tmp145_;
		GXmlDomElement* _tmp146_;
		GXmlDomElement* _tmp147_;
		GXmlDomNodeList* _tmp148_;
		GXmlDomNodeList* _tmp149_;
		GXmlDomNodeList* _tmp150_;
		gpointer _tmp151_;
		GXmlDomNode* _tmp152_;
		GXmlDomNode* _tmp153_;
		GXmlDomNode* _tmp154_;
		GXmlDomNode* _tmp155_;
		gchar* _tmp156_;
		gchar* _tmp157_;
		gchar* _tmp158_;
		GXmlDomElement* _tmp159_;
		GXmlDomElement* _tmp160_;
		GXmlDomElement* _tmp161_;
		GXmlDomNodeList* _tmp162_;
		GXmlDomNodeList* _tmp163_;
		GXmlDomNodeList* _tmp164_;
		gpointer _tmp165_;
		GXmlDomNode* _tmp166_;
		GXmlDomElement* _tmp167_;
		GXmlDomElement* _tmp168_;
		GXmlDomElement* _tmp169_;
		GXmlDomNodeList* _tmp170_;
		GXmlDomNodeList* _tmp171_;
		GXmlDomNodeList* _tmp172_;
		gpointer _tmp173_;
		GXmlDomNode* _tmp174_;
		GXmlDomElement* _tmp175_;
		GXmlDomElement* _tmp176_;
		GXmlDomElement* _tmp177_;
		GXmlDomNodeList* _tmp178_;
		GXmlDomNodeList* _tmp179_;
		GXmlDomNodeList* _tmp180_;
		gpointer _tmp181_;
		GXmlDomNode* _tmp182_;
		GXmlDomElement* _tmp183_;
		GXmlDomElement* _tmp184_;
		GXmlDomElement* _tmp185_;
		GXmlDomNodeList* _tmp186_;
		GXmlDomNodeList* _tmp187_;
		GXmlDomNodeList* _tmp188_;
		gpointer _tmp189_;
		GXmlDomNode* _tmp190_;
		gchar* _tmp191_;
		gchar* _tmp192_;
		gchar* _tmp193_;
		GXmlDomElement* _tmp194_;
		GXmlDomElement* _tmp195_;
		GXmlDomElement* _tmp196_;
		GXmlDomNodeList* _tmp197_;
		GXmlDomNodeList* _tmp198_;
		GXmlDomNodeList* _tmp199_;
		gpointer _tmp200_;
		GXmlDomNode* _tmp201_;
		GXmlDomElement* _tmp202_;
		GXmlDomElement* _tmp203_;
		GXmlDomElement* _tmp204_;
		GXmlDomElement* _tmp205_;
		GXmlDomElement* _tmp206_;
		GXmlDomElement* _tmp207_;
		GXmlDomElement* _tmp208_;
		GXmlDomElement* _tmp209_;
		GXmlDomNodeList* _tmp210_;
		GXmlDomNodeList* _tmp211_;
		GXmlDomNodeList* _tmp212_;
		gpointer _tmp213_;
		GXmlDomNode* _tmp214_;
		GXmlDomElement* _tmp215_;
		GXmlDomElement* _tmp216_;
		GXmlDomElement* _tmp217_;
		GXmlDomElement* _tmp218_;
		GXmlDomElement* _tmp219_;
		GXmlDomElement* _tmp220_;
		GXmlDomElement* _tmp221_;
		GXmlDomElement* _tmp222_;
		GXmlDomNodeList* _tmp223_;
		GXmlDomNodeList* _tmp224_;
		GXmlDomNodeList* _tmp225_;
		gpointer _tmp226_;
		GXmlDomNode* _tmp227_;
		GXmlDomElement* _tmp228_;
		GXmlDomElement* _tmp229_;
		GXmlDomElement* _tmp230_;
		GXmlDomElement* _tmp231_;
		GXmlDomElement* _tmp232_;
		gchar* _tmp233_;
		gchar* _tmp234_;
		gchar* _tmp235_;
#line 547 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<root> <child/> <child/></root>", &_inner_error_);
#line 547 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = _tmp0_;
#line 547 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5740 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 548 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 548 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = _tmp1_;
#line 548 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 548 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp3_ != NULL, "doc.document_element != null");
#line 548 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp3_);
#line 549 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 549 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 549 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = _tmp5_;
#line 549 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp6_);
#line 549 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 549 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = _tmp8_;
#line 549 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_DOM_NODE), "doc.document_element.parent_node is GXml.DomNode");
#line 549 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp9_);
#line 549 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp6_);
#line 550 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 550 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 550 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 550 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp12_);
#line 550 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 550 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = _tmp14_;
#line 550 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_DOM_DOCUMENT), "doc.document_element.parent_node is GXml.DomDocument");
#line 550 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp15_);
#line 550 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = _tmp17_;
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp18_);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = _tmp20_;
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = gee_list_get ((GeeList*) _tmp21_, 0);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = (GXmlDomNode*) _tmp22_;
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp23_ != NULL, "doc.document_element.child_nodes[0] != null");
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp23_);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp21_);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp18_);
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp26_);
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = _tmp27_;
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = _tmp28_;
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = gee_list_get ((GeeList*) _tmp29_, 0);
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = (GXmlDomNode*) _tmp30_;
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = gxml_dom_node_get_parent_node (_tmp31_);
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp34_ != NULL, "doc.document_element.child_nodes[0].parent_node != null");
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp34_);
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp31_);
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp29_);
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = _tmp35_;
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = _tmp36_;
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp37_);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = _tmp38_;
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = _tmp39_;
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = gee_list_get ((GeeList*) _tmp40_, 0);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = (GXmlDomNode*) _tmp41_;
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = gxml_dom_node_get_parent_node (_tmp42_);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = _tmp43_;
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = _tmp44_;
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = gxml_dom_node_get_node_name (_tmp45_);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = _tmp46_;
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = _tmp47_;
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp48_, "root") == 0, "doc.document_element.child_nodes[0].parent_node.node_name == \"root\"");
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp48_);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp45_);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp42_);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp40_);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp37_);
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = _tmp49_;
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp51_ = _tmp50_;
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp52_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp51_);
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp53_ = _tmp52_;
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp54_ = _tmp53_;
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp55_ = gee_list_get ((GeeList*) _tmp54_, 0);
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp56_ = (GXmlDomNode*) _tmp55_;
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp56_, GXML_TYPE_DOM_TEXT), "doc.document_element.child_nodes[0] is DomText");
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp56_);
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp54_);
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp51_);
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp57_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp58_ = _tmp57_;
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp59_ = _tmp58_;
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp60_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp59_);
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp61_ = _tmp60_;
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp62_ = _tmp61_;
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp63_ = gee_list_get ((GeeList*) _tmp62_, 1);
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp64_ = (GXmlDomNode*) _tmp63_;
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp64_ != NULL, "doc.document_element.child_nodes[1] != null");
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp64_);
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp62_);
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp59_);
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp65_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp66_ = _tmp65_;
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp67_ = _tmp66_;
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp68_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp67_);
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp69_ = _tmp68_;
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp70_ = _tmp69_;
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp71_ = gee_list_get ((GeeList*) _tmp70_, 1);
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp72_ = (GXmlDomNode*) _tmp71_;
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp72_, GXML_TYPE_DOM_ELEMENT), "doc.document_element.child_nodes[1] is DomElement");
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp72_);
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp70_);
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp67_);
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp73_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp74_ = _tmp73_;
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp75_ = _tmp74_;
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp76_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp75_);
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp77_ = _tmp76_;
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp78_ = _tmp77_;
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp79_ = gee_list_get ((GeeList*) _tmp78_, 1);
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp80_ = (GXmlDomNode*) _tmp79_;
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp81_ = gxml_dom_node_get_node_name (_tmp80_);
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp82_ = _tmp81_;
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp83_ = _tmp82_;
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp83_, "child") == 0, "doc.document_element.child_nodes[1].node_name == \"child\"");
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp83_);
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp80_);
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp78_);
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp75_);
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp84_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp85_ = _tmp84_;
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp86_ = _tmp85_;
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp87_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp86_);
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp88_ = _tmp87_;
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp89_ = _tmp88_;
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp90_ = gee_list_get ((GeeList*) _tmp89_, 1);
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp91_ = (GXmlDomNode*) _tmp90_;
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp92_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp91_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp91_) : NULL;
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (_tmp92_ == NULL) {
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp91_);
#line 6011 "GomElementTest.c"
		}
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp93_ = _tmp92_;
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp94_ = gxml_dom_non_document_type_child_node_get_next_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp93_);
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp95_ = _tmp94_;
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp96_ = _tmp95_;
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp96_ != NULL, "(doc.document_element.child_nodes[1] as DomElement).next_element_sibling != null");
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp96_);
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp93_);
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp89_);
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp86_);
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp97_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp98_ = _tmp97_;
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp99_ = _tmp98_;
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp100_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp99_);
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp101_ = _tmp100_;
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp102_ = _tmp101_;
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp103_ = gee_list_get ((GeeList*) _tmp102_, 1);
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp104_ = (GXmlDomNode*) _tmp103_;
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp105_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp104_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp104_) : NULL;
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (_tmp105_ == NULL) {
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp104_);
#line 6053 "GomElementTest.c"
		}
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp106_ = _tmp105_;
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp107_ = gxml_dom_non_document_type_child_node_get_next_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp106_);
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp108_ = _tmp107_;
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp109_ = _tmp108_;
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp109_, GXML_TYPE_DOM_ELEMENT), "(doc.document_element.child_nodes[1] as DomElement).next_element_sibling is DomElement");
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp109_);
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp106_);
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp102_);
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp99_);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp110_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp111_ = _tmp110_;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp112_ = _tmp111_;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp113_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp112_);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp114_ = _tmp113_;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp115_ = _tmp114_;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp116_ = gee_list_get ((GeeList*) _tmp115_, 1);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp117_ = (GXmlDomNode*) _tmp116_;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp118_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp117_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp117_) : NULL;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (_tmp118_ == NULL) {
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp117_);
#line 6095 "GomElementTest.c"
		}
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp119_ = _tmp118_;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp120_ = gxml_dom_non_document_type_child_node_get_next_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp119_);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp121_ = _tmp120_;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp122_ = _tmp121_;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp123_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp122_);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp124_ = _tmp123_;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp125_ = _tmp124_;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp125_, "child") == 0, "(doc.document_element.child_nodes[1] as DomElement).next_element_sibling.node_name == \"child\"");
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp125_);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp122_);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp119_);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp115_);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp112_);
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp126_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp127_ = _tmp126_;
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp128_ = _tmp127_;
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp129_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp128_);
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp130_ = _tmp129_;
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp131_ = _tmp130_;
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp132_ = gee_list_get ((GeeList*) _tmp131_, 2);
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp133_ = (GXmlDomNode*) _tmp132_;
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp133_ != NULL, "doc.document_element.child_nodes[2] != null");
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp133_);
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp131_);
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp128_);
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp134_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp135_ = _tmp134_;
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp136_ = _tmp135_;
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp137_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp136_);
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp138_ = _tmp137_;
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp139_ = _tmp138_;
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp140_ = gee_list_get ((GeeList*) _tmp139_, 2);
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp141_ = (GXmlDomNode*) _tmp140_;
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp142_ = gxml_dom_node_get_parent_node (_tmp141_);
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp143_ = _tmp142_;
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp144_ = _tmp143_;
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp144_ != NULL, "doc.document_element.child_nodes[2].parent_node != null");
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp144_);
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp141_);
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp139_);
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp136_);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp145_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp146_ = _tmp145_;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp147_ = _tmp146_;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp148_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp147_);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp149_ = _tmp148_;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp150_ = _tmp149_;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp151_ = gee_list_get ((GeeList*) _tmp150_, 2);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp152_ = (GXmlDomNode*) _tmp151_;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp153_ = gxml_dom_node_get_parent_node (_tmp152_);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp154_ = _tmp153_;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp155_ = _tmp154_;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp156_ = gxml_dom_node_get_node_name (_tmp155_);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp157_ = _tmp156_;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp158_ = _tmp157_;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp158_, "root") == 0, "doc.document_element.child_nodes[2].parent_node.node_name == \"root\"");
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp158_);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp155_);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp152_);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp150_);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp147_);
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp159_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp160_ = _tmp159_;
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp161_ = _tmp160_;
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp162_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp161_);
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp163_ = _tmp162_;
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp164_ = _tmp163_;
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp165_ = gee_list_get ((GeeList*) _tmp164_, 2);
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp166_ = (GXmlDomNode*) _tmp165_;
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp166_, GXML_TYPE_DOM_TEXT), "doc.document_element.child_nodes[2] is DomText");
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp166_);
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp164_);
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp161_);
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp167_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp168_ = _tmp167_;
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp169_ = _tmp168_;
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp170_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp169_);
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp171_ = _tmp170_;
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp172_ = _tmp171_;
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp173_ = gee_list_get ((GeeList*) _tmp172_, 3);
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp174_ = (GXmlDomNode*) _tmp173_;
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp174_ != NULL, "doc.document_element.child_nodes[3] != null");
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp174_);
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp172_);
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp169_);
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp175_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp176_ = _tmp175_;
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp177_ = _tmp176_;
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp178_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp177_);
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp179_ = _tmp178_;
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp180_ = _tmp179_;
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp181_ = gee_list_get ((GeeList*) _tmp180_, 3);
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp182_ = (GXmlDomNode*) _tmp181_;
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp182_, GXML_TYPE_DOM_ELEMENT), "doc.document_element.child_nodes[3] is DomElement");
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp182_);
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp180_);
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp177_);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp183_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp184_ = _tmp183_;
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp185_ = _tmp184_;
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp186_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp185_);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp187_ = _tmp186_;
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp188_ = _tmp187_;
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp189_ = gee_list_get ((GeeList*) _tmp188_, 3);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp190_ = (GXmlDomNode*) _tmp189_;
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp191_ = gxml_dom_node_get_node_name (_tmp190_);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp192_ = _tmp191_;
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp193_ = _tmp192_;
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp193_, "child") == 0, "doc.document_element.child_nodes[3].node_name == \"child\"");
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp193_);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp190_);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp188_);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp185_);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp194_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp195_ = _tmp194_;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp196_ = _tmp195_;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp197_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp196_);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp198_ = _tmp197_;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp199_ = _tmp198_;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp200_ = gee_list_get ((GeeList*) _tmp199_, 3);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp201_ = (GXmlDomNode*) _tmp200_;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp202_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp201_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp201_) : NULL;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (_tmp202_ == NULL) {
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp201_);
#line 6345 "GomElementTest.c"
		}
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp203_ = _tmp202_;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp204_ = gxml_dom_non_document_type_child_node_get_previous_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp203_);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp205_ = _tmp204_;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp206_ = _tmp205_;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp206_ != NULL, "(doc.document_element.child_nodes[3] as DomElement).previous_element_sibling != null");
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp206_);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp203_);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp199_);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp196_);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp207_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp208_ = _tmp207_;
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp209_ = _tmp208_;
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp210_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp209_);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp211_ = _tmp210_;
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp212_ = _tmp211_;
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp213_ = gee_list_get ((GeeList*) _tmp212_, 3);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp214_ = (GXmlDomNode*) _tmp213_;
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp215_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp214_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp214_) : NULL;
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (_tmp215_ == NULL) {
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp214_);
#line 6387 "GomElementTest.c"
		}
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp216_ = _tmp215_;
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp217_ = gxml_dom_non_document_type_child_node_get_previous_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp216_);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp218_ = _tmp217_;
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp219_ = _tmp218_;
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp219_, GXML_TYPE_DOM_ELEMENT), "(doc.document_element.child_nodes[3] as DomElement).previous_element_sibling is DomElement");
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp219_);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp216_);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp212_);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp209_);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp220_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp221_ = _tmp220_;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp222_ = _tmp221_;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp223_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp222_);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp224_ = _tmp223_;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp225_ = _tmp224_;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp226_ = gee_list_get ((GeeList*) _tmp225_, 3);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp227_ = (GXmlDomNode*) _tmp226_;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp228_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp227_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp227_) : NULL;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (_tmp228_ == NULL) {
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp227_);
#line 6429 "GomElementTest.c"
		}
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp229_ = _tmp228_;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp230_ = gxml_dom_non_document_type_child_node_get_previous_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp229_);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp231_ = _tmp230_;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp232_ = _tmp231_;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp233_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp232_);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp234_ = _tmp233_;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp235_ = _tmp234_;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp235_, "child") == 0, "(doc.document_element.child_nodes[3] as DomElement).previous_element_sibling.node_name == \"child\"");
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp235_);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp232_);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp229_);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp225_);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp222_);
#line 546 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 6459 "GomElementTest.c"
	}
	goto __finally267;
	__catch267_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp236_;
#line 546 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 546 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 572 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp236_ = e->message;
#line 572 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_test_message ("%s", _tmp236_);
#line 573 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 546 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 6478 "GomElementTest.c"
	}
	__finally267:
#line 546 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 546 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 546 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 546 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 6489 "GomElementTest.c"
	}
}


static void
___lambda256__gtest_func (void)
{
#line 545 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda256_ ();
#line 6499 "GomElementTest.c"
}


static void
__lambda257_ (void)
{
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlGomDocument* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomNode* _tmp5_;
		GXmlDomNode* _tmp6_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp7_;
		GXmlDomElement* _tmp8_;
		GXmlDomElement* _tmp9_;
		GXmlDomElement* _tmp10_;
		GXmlDomElement* _tmp11_;
		GXmlDomNode* _tmp12_;
		GXmlDomNode* _tmp13_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp14_;
		GXmlDomElement* _tmp15_;
		GXmlDomElement* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlDomElement* _tmp18_;
		GXmlDomNode* _tmp19_;
		GXmlDomNode* _tmp20_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp21_;
		GXmlDomElement* _tmp22_;
		GXmlDomElement* _tmp23_;
		GXmlDomElement* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlDomNode* _tmp26_;
		GXmlDomNode* _tmp27_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp28_;
		GXmlDomElement* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomElement* _tmp31_;
		GXmlDomElement* _tmp32_;
		GXmlDomNode* _tmp33_;
		GXmlDomNode* _tmp34_;
		GXmlDomElement* c5 = NULL;
		GXmlGomDocument* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomElement* _tmp37_;
		GXmlDomElement* _tmp38_;
		GXmlDomNode* _tmp39_;
		GXmlDomNode* _tmp40_;
		GXmlDomElement* n1 = NULL;
		GXmlDomElement* _tmp41_;
		GXmlDomElement* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomElement* _tmp44_;
		gchar* _tmp45_;
		gchar* _tmp46_;
		GXmlDomElement* n2 = NULL;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		gchar* _tmp51_;
		gchar* _tmp52_;
		GXmlDomElement* n3 = NULL;
		GXmlDomElement* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomElement* _tmp56_;
		gchar* _tmp57_;
		gchar* _tmp58_;
		GXmlDomElement* n4 = NULL;
		GXmlDomElement* _tmp59_;
		GXmlDomElement* _tmp60_;
		GXmlDomElement* _tmp61_;
		GXmlDomElement* _tmp62_;
		gchar* _tmp63_;
		gchar* _tmp64_;
		GXmlDomNodeList* l1 = NULL;
		GXmlDomElement* _tmp65_;
		GXmlDomNodeList* _tmp66_;
		GXmlDomNodeList* _tmp67_;
		GXmlDomNodeList* _tmp68_;
		gint _tmp69_;
		gint _tmp70_;
		gchar* _tmp71_;
		gchar* _tmp72_;
		GXmlDomNodeList* _tmp73_;
		gint _tmp74_;
		gint _tmp75_;
		GXmlDomNodeList* _tmp76_;
		GXmlDomNode* _tmp77_;
		GXmlDomNode* _tmp78_;
		gchar* _tmp79_;
		gchar* _tmp80_;
		gchar* _tmp81_;
		GXmlDomNodeList* l2 = NULL;
		GXmlDomElement* _tmp82_;
		GXmlDomNodeList* _tmp83_;
		GXmlDomNodeList* _tmp84_;
		GXmlDomNodeList* _tmp85_;
		gint _tmp86_;
		gint _tmp87_;
		GXmlDomNodeList* _tmp88_;
		GXmlDomNode* _tmp89_;
		GXmlDomNode* _tmp90_;
		gchar* _tmp91_;
		gchar* _tmp92_;
		gchar* _tmp93_;
		GXmlDomNodeList* l3 = NULL;
		GXmlDomElement* _tmp94_;
		GXmlDomNodeList* _tmp95_;
		GXmlDomNodeList* _tmp96_;
		GXmlDomNodeList* _tmp97_;
		gint _tmp98_;
		gint _tmp99_;
		GXmlDomNodeList* _tmp100_;
		GXmlDomNode* _tmp101_;
		GXmlDomNode* _tmp102_;
		gchar* _tmp103_;
		gchar* _tmp104_;
		gchar* _tmp105_;
		GXmlDomElement* c6 = NULL;
		GXmlGomDocument* _tmp106_;
		GXmlDomElement* _tmp107_;
		GXmlDomElement* _tmp108_;
		GXmlDomElement* _tmp109_;
		GXmlDomElement* _tmp110_;
		GXmlDomNode* _tmp111_;
		GXmlDomNode* _tmp112_;
		GXmlDomElement* c7 = NULL;
		GXmlGomDocument* _tmp113_;
		GXmlDomElement* _tmp114_;
		GXmlDomElement* _tmp115_;
		GXmlDomElement* _tmp116_;
		GXmlDomElement* _tmp117_;
		GXmlDomNode* _tmp118_;
		GXmlDomNode* _tmp119_;
		GXmlDomNodeList* l4 = NULL;
		GXmlDomElement* _tmp120_;
		GXmlDomNodeList* _tmp121_;
		GXmlDomNodeList* _tmp122_;
		GXmlDomNodeList* _tmp123_;
		gint _tmp124_;
		gint _tmp125_;
		GXmlDomNodeList* _tmp126_;
		GXmlDomNode* _tmp127_;
		GXmlDomNode* _tmp128_;
		gchar* _tmp129_;
		gchar* _tmp130_;
		gchar* _tmp131_;
#line 578 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 578 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		d = _tmp0_;
#line 579 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = d;
#line 579 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp1_, "root", &_inner_error_);
#line 579 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		r = _tmp2_;
#line 579 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 579 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6671 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 580 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = d;
#line 580 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = r;
#line 580 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp3_, (GXmlDomNode*) _tmp4_, &_inner_error_);
#line 580 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = _tmp5_;
#line 580 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp6_);
#line 580 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 580 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 580 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6690 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 581 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = d;
#line 581 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp7_, "child", &_inner_error_);
#line 581 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		c1 = _tmp8_;
#line 581 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 581 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 581 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6705 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 582 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = c1;
#line 582 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute (_tmp9_, "class", "error", &_inner_error_);
#line 582 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 582 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 582 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 582 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6720 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 583 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = r;
#line 583 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = c1;
#line 583 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp10_, (GXmlDomNode*) _tmp11_, &_inner_error_);
#line 583 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = _tmp12_;
#line 583 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp13_);
#line 583 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 583 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 583 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 583 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6741 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 584 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = d;
#line 584 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp14_, "child", &_inner_error_);
#line 584 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		c2 = _tmp15_;
#line 584 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 584 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 584 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 584 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6758 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 585 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = c2;
#line 585 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute (_tmp16_, "class", "warning", &_inner_error_);
#line 585 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 585 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 585 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 585 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 585 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6775 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 586 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = r;
#line 586 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = c2;
#line 586 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp17_, (GXmlDomNode*) _tmp18_, &_inner_error_);
#line 586 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 586 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp20_);
#line 586 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 586 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 586 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 586 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 586 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6798 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 587 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = d;
#line 587 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp21_, "child", &_inner_error_);
#line 587 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		c3 = _tmp22_;
#line 587 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 587 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 587 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 587 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 587 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6817 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 588 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = c3;
#line 588 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute (_tmp23_, "class", "error warning", &_inner_error_);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 588 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6836 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = r;
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = c3;
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp24_, (GXmlDomNode*) _tmp25_, &_inner_error_);
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = _tmp26_;
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp27_);
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6861 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 590 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = d;
#line 590 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp28_, "child", &_inner_error_);
#line 590 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		c4 = _tmp29_;
#line 590 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 590 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 590 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 590 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 590 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 590 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6882 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 591 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = c4;
#line 591 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute (_tmp30_, "class", "error calc", &_inner_error_);
#line 591 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 591 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 591 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 591 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 591 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 591 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 591 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6903 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = r;
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = c4;
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp31_, (GXmlDomNode*) _tmp32_, &_inner_error_);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp34_);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6930 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 593 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = d;
#line 593 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp35_, "child", &_inner_error_);
#line 593 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		c5 = _tmp36_;
#line 593 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 593 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 593 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 593 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 593 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 593 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 593 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6953 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = r;
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = c5;
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp37_, (GXmlDomNode*) _tmp38_, &_inner_error_);
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = _tmp39_;
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp40_);
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6982 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = r;
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp41_, "child", &_inner_error_);
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n1 = _tmp42_;
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7007 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 596 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = n1;
#line 596 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp43_ != NULL, "n1 != null");
#line 597 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = n1;
#line 597 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = gxml_dom_element_get_attribute (_tmp44_, "class");
#line 597 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = _tmp45_;
#line 597 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp46_, "error") == 0, "n1.get_attribute (\"class\") == \"error\"");
#line 597 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp46_);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = r;
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp47_, "child.warning", &_inner_error_);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n2 = _tmp48_;
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7048 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 599 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = n2;
#line 599 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp49_ != NULL, "n2 != null");
#line 600 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = n2;
#line 600 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp51_ = gxml_dom_element_get_attribute (_tmp50_, "class");
#line 600 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp52_ = _tmp51_;
#line 600 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp52_, "warning") == 0, "n2.get_attribute (\"class\") == \"warning\"");
#line 600 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp52_);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp53_ = r;
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp54_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp53_, "child[class]", &_inner_error_);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n3 = _tmp54_;
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7091 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 602 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp55_ = n3;
#line 602 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp55_ != NULL, "n3 != null");
#line 603 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp56_ = n3;
#line 603 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp57_ = gxml_dom_element_get_attribute (_tmp56_, "class");
#line 603 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp58_ = _tmp57_;
#line 603 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp58_, "error") == 0, "n3.get_attribute (\"class\") == \"error\"");
#line 603 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp58_);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp59_ = r;
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp60_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp59_, "child[class=\"error calc\"]", &_inner_error_);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n4 = _tmp60_;
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7136 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 605 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp61_ = n4;
#line 605 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp61_ != NULL, "n4 != null");
#line 606 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp62_ = n4;
#line 606 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp63_ = gxml_dom_element_get_attribute (_tmp62_, "class");
#line 606 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp64_ = _tmp63_;
#line 606 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp64_, "error calc") == 0, "n4.get_attribute (\"class\") == \"error calc\"");
#line 606 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp64_);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp65_ = r;
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp66_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp65_, "child", &_inner_error_);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		l1 = _tmp66_;
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n4);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7183 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 608 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp67_ = l1;
#line 608 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp67_ != NULL, "l1 != null");
#line 609 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp68_ = l1;
#line 609 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp69_ = gxml_dom_node_list_get_length (_tmp68_);
#line 609 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp70_ = _tmp69_;
#line 609 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp71_ = g_strdup_printf ("%i", _tmp70_);
#line 609 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp72_ = _tmp71_;
#line 609 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:609: %s", _tmp72_);
#line 609 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp72_);
#line 610 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp73_ = l1;
#line 610 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp74_ = gxml_dom_node_list_get_length (_tmp73_);
#line 610 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp75_ = _tmp74_;
#line 610 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp75_ == 5, "l1.length == 5");
#line 611 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp76_ = l1;
#line 611 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp77_ = gxml_dom_node_list_item (_tmp76_, 4);
#line 611 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp78_ = _tmp77_;
#line 611 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp79_ = gxml_dom_node_get_node_name (_tmp78_);
#line 611 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp80_ = _tmp79_;
#line 611 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp81_ = _tmp80_;
#line 611 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp81_, "child") == 0, "l1.item (4).node_name == \"child\"");
#line 611 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp81_);
#line 611 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp78_);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp82_ = r;
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp83_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp82_, "child[class]", &_inner_error_);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		l2 = _tmp83_;
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l1);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n4);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7262 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 613 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp84_ = l2;
#line 613 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp84_ != NULL, "l2 != null");
#line 614 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp85_ = l2;
#line 614 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp86_ = gxml_dom_node_list_get_length (_tmp85_);
#line 614 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp87_ = _tmp86_;
#line 614 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp87_ == 4, "l2.length == 4");
#line 615 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp88_ = l2;
#line 615 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp89_ = gxml_dom_node_list_item (_tmp88_, 3);
#line 615 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp90_ = _tmp89_;
#line 615 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp91_ = gxml_dom_node_get_node_name (_tmp90_);
#line 615 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp92_ = _tmp91_;
#line 615 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp93_ = _tmp92_;
#line 615 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp93_, "child") == 0, "l2.item (3).node_name == \"child\"");
#line 615 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp93_);
#line 615 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp90_);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp94_ = r;
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp95_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp94_, "child[class=\"error\"]", &_inner_error_);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		l3 = _tmp95_;
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l2);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l1);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n4);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7329 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 617 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp96_ = l3;
#line 617 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp96_ != NULL, "l3 != null");
#line 618 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp97_ = l3;
#line 618 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp98_ = gxml_dom_node_list_get_length (_tmp97_);
#line 618 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp99_ = _tmp98_;
#line 618 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp99_ == 1, "l3.length == 1");
#line 619 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp100_ = l3;
#line 619 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp101_ = gxml_dom_node_list_item (_tmp100_, 0);
#line 619 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp102_ = _tmp101_;
#line 619 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp103_ = gxml_dom_node_get_node_name (_tmp102_);
#line 619 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp104_ = _tmp103_;
#line 619 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp105_ = _tmp104_;
#line 619 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp105_, "child") == 0, "l3.item (0).node_name == \"child\"");
#line 619 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp105_);
#line 619 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp102_);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp106_ = d;
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp107_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp106_, "child", &_inner_error_);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		c6 = _tmp107_;
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l3);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l2);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l1);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n4);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7398 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp108_ = c6;
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute (_tmp108_, "prop", "val1", &_inner_error_);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c6);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l3);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l2);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l1);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n4);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7437 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp109_ = r;
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp110_ = c6;
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp111_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp109_, (GXmlDomNode*) _tmp110_, &_inner_error_);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp112_ = _tmp111_;
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp112_);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c6);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l3);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l2);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l1);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n4);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7482 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp113_ = d;
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp114_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp113_, "child", &_inner_error_);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		c7 = _tmp114_;
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c6);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l3);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l2);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l1);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n4);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7523 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp115_ = c7;
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute (_tmp115_, "prop", "val1", &_inner_error_);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c7);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c6);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l3);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l2);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l1);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n4);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7564 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp116_ = r;
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp117_ = c7;
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp118_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp116_, (GXmlDomNode*) _tmp117_, &_inner_error_);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp119_ = _tmp118_;
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp119_);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c7);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c6);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l3);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l2);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l1);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n4);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7611 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp120_ = r;
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp121_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp120_, "child[prop=\"val1\"]", &_inner_error_);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		l4 = _tmp121_;
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c7);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c6);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l3);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l2);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l1);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n4);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7654 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 627 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp122_ = l4;
#line 627 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp122_ != NULL, "l4 != null");
#line 628 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp123_ = l4;
#line 628 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp124_ = gxml_dom_node_list_get_length (_tmp123_);
#line 628 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp125_ = _tmp124_;
#line 628 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp125_ == 2, "l4.length == 2");
#line 629 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp126_ = l4;
#line 629 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp127_ = gxml_dom_node_list_item (_tmp126_, 0);
#line 629 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp128_ = _tmp127_;
#line 629 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp129_ = gxml_dom_node_get_node_name (_tmp128_);
#line 629 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp130_ = _tmp129_;
#line 629 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp131_ = _tmp130_;
#line 629 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp131_, "child") == 0, "l4.item (0).node_name == \"child\"");
#line 629 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp131_);
#line 629 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp128_);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (l4);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (c7);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (c6);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (l3);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (l2);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (l1);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n4);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n3);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n2);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n1);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (c5);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (c4);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (c3);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (c2);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (c1);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (r);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (d);
#line 7721 "GomElementTest.c"
	}
	goto __finally268;
	__catch268_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp132_;
		gchar* _tmp133_;
		gchar* _tmp134_;
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 631 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp132_ = e->message;
#line 631 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp133_ = g_strconcat ("Error: ", _tmp132_, NULL);
#line 631 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp134_ = _tmp133_;
#line 631 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:631: %s", _tmp134_);
#line 631 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp134_);
#line 632 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 7748 "GomElementTest.c"
	}
	__finally268:
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 7759 "GomElementTest.c"
	}
}


static void
___lambda257__gtest_func (void)
{
#line 576 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda257_ ();
#line 7769 "GomElementTest.c"
}


static void
__lambda258_ (void)
{
	GError * _inner_error_ = NULL;
	{
		gchar* str = NULL;
		gchar* _tmp0_;
		GomElementTestTop* t = NULL;
		GomElementTestTop* _tmp1_;
		NoInstantiatable* _tmp2_;
		NoInstantiatable* _tmp3_;
		NoInstantiatable* _tmp4_;
		NoInstantiatable* _tmp5_;
		const gchar* _tmp6_;
		const gchar* _tmp7_;
#line 637 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = g_strdup ("<Top pq=\"Qlt\"><Instantiatable name=\"Nop\"/></Top>");
#line 637 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		str = _tmp0_;
#line 638 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = gom_element_test_top_new ();
#line 638 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		t = _tmp1_;
#line 639 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_read_from_string ((GXmlGomElement*) t, str, &_inner_error_);
#line 639 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 639 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (t);
#line 639 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (str);
#line 7804 "GomElementTest.c"
			goto __catch269_g_error;
		}
#line 640 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = gom_element_test_top_get_inst (t);
#line 640 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 640 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp3_ != NULL, "t.inst != null");
#line 641 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = gom_element_test_top_get_inst (t);
#line 641 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 641 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = no_instantiatable_get_name (_tmp5_);
#line 641 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 641 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "Nop") == 0, "t.inst.name == \"Nop\"");
#line 636 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (t);
#line 636 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (str);
#line 7827 "GomElementTest.c"
	}
	goto __finally269;
	__catch269_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
#line 636 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 636 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 643 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = e->message;
#line 643 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = g_strconcat ("Error: ", _tmp8_, NULL);
#line 643 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 643 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:643: %s", _tmp10_);
#line 643 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp10_);
#line 644 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 636 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 7854 "GomElementTest.c"
	}
	__finally269:
#line 636 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 636 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 636 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 636 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 7865 "GomElementTest.c"
	}
}


static void
___lambda258__gtest_func (void)
{
#line 635 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda258_ ();
#line 7875 "GomElementTest.c"
}


static void
__lambda259_ (void)
{
	GError * _inner_error_ = NULL;
	{
		gchar* str = NULL;
		gchar* _tmp0_;
		GomElementTestGTop* t = NULL;
		GomElementTestGTop* _tmp1_;
		NoInstantiatable* _tmp2_;
		NoInstantiatable* _tmp3_;
		NoInstantiatable* _tmp4_;
		NoInstantiatable* _tmp5_;
		const gchar* _tmp6_;
		const gchar* _tmp7_;
		Property* _tmp8_;
		Property* _tmp9_;
		Property* _tmp10_;
		Property* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
#line 649 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = g_strdup ("<Top pq=\"Qlt\"><Instantiatable name=\"Nop\"/></Top>");
#line 649 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		str = _tmp0_;
#line 650 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = gom_element_test_gtop_new ();
#line 650 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		t = _tmp1_;
#line 651 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_read_from_string ((GXmlGomElement*) t, str, &_inner_error_);
#line 651 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 651 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (t);
#line 651 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (str);
#line 7917 "GomElementTest.c"
			goto __catch270_g_error;
		}
#line 652 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = gom_element_test_gtop_get_inst (t);
#line 652 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 652 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp3_ != NULL, "t.inst != null");
#line 653 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = gom_element_test_gtop_get_inst (t);
#line 653 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 653 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = no_instantiatable_get_name (_tmp5_);
#line 653 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 653 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "Nop") == 0, "t.inst.name == \"Nop\"");
#line 654 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = gom_element_test_gtop_get_pq (t);
#line 654 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = _tmp8_;
#line 654 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp9_ != NULL, "t.pq != null");
#line 655 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = gom_element_test_gtop_get_pq (t);
#line 655 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 655 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = gxml_gom_property_get_value ((GXmlGomProperty*) _tmp11_);
#line 655 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = _tmp12_;
#line 655 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 655 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp14_, "Qlt") == 0, "t.pq.value == \"Qlt\"");
#line 655 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp14_);
#line 648 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (t);
#line 648 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (str);
#line 7960 "GomElementTest.c"
	}
	goto __finally270;
	__catch270_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
#line 648 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 648 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 657 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = e->message;
#line 657 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = g_strconcat ("Error: ", _tmp15_, NULL);
#line 657 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 657 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:657: %s", _tmp17_);
#line 657 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp17_);
#line 658 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 648 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 7987 "GomElementTest.c"
	}
	__finally270:
#line 648 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 648 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 648 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 648 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 7998 "GomElementTest.c"
	}
}


static void
___lambda259__gtest_func (void)
{
#line 647 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda259_ ();
#line 8008 "GomElementTest.c"
}


void
gom_element_test_add_tests (void)
{
#line 182 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/read/namespace_uri", ___lambda241__gtest_func);
#line 210 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/namespace_uri", ___lambda242__gtest_func);
#line 244 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/read/namespace/redefinition", ___lambda243__gtest_func);
#line 270 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/attributes", ___lambda244__gtest_func);
#line 344 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/attributes/property-ns", ___lambda245__gtest_func);
#line 365 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/attribute-ns/collection", ___lambda246__gtest_func);
#line 387 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/lookup-prefix", ___lambda247__gtest_func);
#line 415 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/content/add_aside_child_nodes", ___lambda248__gtest_func);
#line 432 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/content/keep_child_nodes", ___lambda249__gtest_func);
#line 449 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/parent", ___lambda250__gtest_func);
#line 463 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/remove", ___lambda251__gtest_func);
#line 479 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/parsed-delayed", ___lambda252__gtest_func);
#line 496 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/write/string", ___lambda253__gtest_func);
#line 514 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/write/stream", ___lambda254__gtest_func);
#line 529 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/write/input_stream", ___lambda255__gtest_func);
#line 545 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/previous_element_sibling", ___lambda256__gtest_func);
#line 576 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/css-selector", ___lambda257__gtest_func);
#line 635 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/no-instantiatable/avoid", ___lambda258__gtest_func);
#line 647 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/no-instantiatable/set", ___lambda259__gtest_func);
#line 8053 "GomElementTest.c"
}


GomElementTest*
gom_element_test_construct (GType object_type)
{
	GomElementTest* self = NULL;
#line 30 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTest*) gxml_test_construct (object_type);
#line 30 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 8065 "GomElementTest.c"
}


GomElementTest*
gom_element_test_new (void)
{
#line 30 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_construct (TYPE_GOM_ELEMENT_TEST);
#line 8074 "GomElementTest.c"
}


GomElementTestParsedDelayed*
gom_element_test_parsed_delayed_construct (GType object_type)
{
	GomElementTestParsedDelayed * self = NULL;
#line 31 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestParsedDelayed*) gxml_gom_element_construct (object_type);
#line 31 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 8086 "GomElementTest.c"
}


GomElementTestParsedDelayed*
gom_element_test_parsed_delayed_new (void)
{
#line 31 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_parsed_delayed_construct (GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED);
#line 8095 "GomElementTest.c"
}


static GObject *
gom_element_test_parsed_delayed_constructor (GType type, 
                                             guint n_construct_properties, 
                                             GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestParsedDelayed * self;
	GError * _inner_error_ = NULL;
#line 32 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_parsed_delayed_parent_class);
#line 32 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 32 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED, GomElementTestParsedDelayed);
#line 8114 "GomElementTest.c"
	{
#line 33 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "root");
#line 8118 "GomElementTest.c"
	}
	goto __finally271;
	__catch271_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 33 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 33 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 34 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = e;
#line 34 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = _tmp0_->message;
#line 34 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 34 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 34 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_warning ("GomElementTest.vala:34: %s", _tmp3_);
#line 34 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp3_);
#line 33 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 8146 "GomElementTest.c"
	}
	__finally271:
#line 33 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 33 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 33 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 8155 "GomElementTest.c"
	}
#line 35 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gxml_gom_element_set_parse_children ((GXmlGomElement*) self, FALSE);
#line 32 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 8161 "GomElementTest.c"
}


static void
gom_element_test_parsed_delayed_class_init (GomElementTestParsedDelayedClass * klass)
{
#line 31 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_parsed_delayed_parent_class = g_type_class_peek_parent (klass);
#line 31 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_parsed_delayed_constructor;
#line 8172 "GomElementTest.c"
}


static void
gom_element_test_parsed_delayed_instance_init (GomElementTestParsedDelayed * self)
{
}


GType
gom_element_test_parsed_delayed_get_type (void)
{
	static volatile gsize gom_element_test_parsed_delayed_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_parsed_delayed_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestParsedDelayedClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_parsed_delayed_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestParsedDelayed), 0, (GInstanceInitFunc) gom_element_test_parsed_delayed_instance_init, NULL };
		GType gom_element_test_parsed_delayed_type_id;
		gom_element_test_parsed_delayed_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestParsedDelayed", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_parsed_delayed_type_id__volatile, gom_element_test_parsed_delayed_type_id);
	}
	return gom_element_test_parsed_delayed_type_id__volatile;
}


GomElementTestInstantiatable*
gom_element_test_instantiatable_construct (GType object_type)
{
	GomElementTestInstantiatable * self = NULL;
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestInstantiatable*) gxml_gom_element_construct (object_type);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 8204 "GomElementTest.c"
}


GomElementTestInstantiatable*
gom_element_test_instantiatable_new (void)
{
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_instantiatable_construct (GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE);
#line 8213 "GomElementTest.c"
}


static const gchar*
gom_element_test_instantiatable_real_get_name (NoInstantiatable* base)
{
	const gchar* result;
	GomElementTestInstantiatable* self;
	const gchar* _tmp0_;
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestInstantiatable*) base;
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_name;
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 8231 "GomElementTest.c"
}


static void
gom_element_test_instantiatable_real_set_name (NoInstantiatable* base, 
                                               const gchar* value)
{
	GomElementTestInstantiatable* self;
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestInstantiatable*) base;
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_instantiatable_real_get_name (base)) != 0) {
#line 8244 "GomElementTest.c"
		gchar* _tmp0_;
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (self->priv->_name);
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		self->priv->_name = _tmp0_;
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_instantiatable_properties[GOM_ELEMENT_TEST_INSTANTIATABLE_NAME_PROPERTY]);
#line 8254 "GomElementTest.c"
	}
}


static GObject *
gom_element_test_instantiatable_constructor (GType type, 
                                             guint n_construct_properties, 
                                             GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestInstantiatable * self;
#line 41 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_instantiatable_parent_class);
#line 41 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 41 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatable);
#line 41 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "Instantiatable");
#line 41 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 8277 "GomElementTest.c"
}


static void
gom_element_test_instantiatable_class_init (GomElementTestInstantiatableClass * klass)
{
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_instantiatable_parent_class = g_type_class_peek_parent (klass);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_type_class_add_private (klass, sizeof (GomElementTestInstantiatablePrivate));
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_instantiatable_get_property;
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_instantiatable_set_property;
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_instantiatable_constructor;
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_instantiatable_finalize;
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_INSTANTIATABLE_NAME_PROPERTY, gom_element_test_instantiatable_properties[GOM_ELEMENT_TEST_INSTANTIATABLE_NAME_PROPERTY] = g_param_spec_string ("name", "::name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 8298 "GomElementTest.c"
}


static void
gom_element_test_instantiatable_no_instantiatable_interface_init (NoInstantiatableIface * iface)
{
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_instantiatable_no_instantiatable_parent_iface = g_type_interface_peek_parent (iface);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	iface->get_name = gom_element_test_instantiatable_real_get_name;
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	iface->set_name = gom_element_test_instantiatable_real_set_name;
#line 8311 "GomElementTest.c"
}


static void
gom_element_test_instantiatable_instance_init (GomElementTestInstantiatable * self)
{
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv = GOM_ELEMENT_TEST_INSTANTIATABLE_GET_PRIVATE (self);
#line 8320 "GomElementTest.c"
}


static void
gom_element_test_instantiatable_finalize (GObject * obj)
{
	GomElementTestInstantiatable * self;
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatable);
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_name);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_instantiatable_parent_class)->finalize (obj);
#line 8334 "GomElementTest.c"
}


GType
gom_element_test_instantiatable_get_type (void)
{
	static volatile gsize gom_element_test_instantiatable_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_instantiatable_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestInstantiatableClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_instantiatable_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestInstantiatable), 0, (GInstanceInitFunc) gom_element_test_instantiatable_instance_init, NULL };
		static const GInterfaceInfo no_instantiatable_info = { (GInterfaceInitFunc) gom_element_test_instantiatable_no_instantiatable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gom_element_test_instantiatable_type_id;
		gom_element_test_instantiatable_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestInstantiatable", &g_define_type_info, 0);
		g_type_add_interface_static (gom_element_test_instantiatable_type_id, TYPE_NO_INSTANTIATABLE, &no_instantiatable_info);
		g_once_init_leave (&gom_element_test_instantiatable_type_id__volatile, gom_element_test_instantiatable_type_id);
	}
	return gom_element_test_instantiatable_type_id__volatile;
}


static void
_vala_gom_element_test_instantiatable_get_property (GObject * object, 
                                                    guint property_id, 
                                                    GValue * value, 
                                                    GParamSpec * pspec)
{
	GomElementTestInstantiatable * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatable);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_INSTANTIATABLE_NAME_PROPERTY:
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, no_instantiatable_get_name ((NoInstantiatable*) self));
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 8370 "GomElementTest.c"
		default:
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 8376 "GomElementTest.c"
	}
}


static void
_vala_gom_element_test_instantiatable_set_property (GObject * object, 
                                                    guint property_id, 
                                                    const GValue * value, 
                                                    GParamSpec * pspec)
{
	GomElementTestInstantiatable * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatable);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_INSTANTIATABLE_NAME_PROPERTY:
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		no_instantiatable_set_name ((NoInstantiatable*) self, g_value_get_string (value));
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 8397 "GomElementTest.c"
		default:
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 8403 "GomElementTest.c"
	}
}


GomElementTestTop*
gom_element_test_top_construct (GType object_type)
{
	GomElementTestTop * self = NULL;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestTop*) gxml_gom_element_construct (object_type);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 8416 "GomElementTest.c"
}


GomElementTestTop*
gom_element_test_top_new (void)
{
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_top_construct (GOM_ELEMENT_TEST_TYPE_TOP);
#line 8425 "GomElementTest.c"
}


NoInstantiatable*
gom_element_test_top_get_inst (GomElementTestTop* self)
{
	NoInstantiatable* result;
	GomElementTestInstantiatable* _tmp0_;
#line 45 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 45 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_inst_i;
#line 45 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = (NoInstantiatable*) _tmp0_;
#line 45 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 8442 "GomElementTest.c"
}


void
gom_element_test_top_set_inst (GomElementTestTop* self, 
                               NoInstantiatable* value)
{
#line 45 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 45 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_top_set_inst_i (self, G_TYPE_CHECK_INSTANCE_TYPE (value, GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE) ? ((GomElementTestInstantiatable*) value) : NULL);
#line 45 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify_by_pspec ((GObject *) self, gom_element_test_top_properties[GOM_ELEMENT_TEST_TOP_INST_PROPERTY]);
#line 8456 "GomElementTest.c"
}


GomElementTestInstantiatable*
gom_element_test_top_get_inst_i (GomElementTestTop* self)
{
	GomElementTestInstantiatable* result;
	GomElementTestInstantiatable* _tmp0_;
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_inst_i;
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 8473 "GomElementTest.c"
}


void
gom_element_test_top_set_inst_i (GomElementTestTop* self, 
                                 GomElementTestInstantiatable* value)
{
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (gom_element_test_top_get_inst_i (self) != value) {
#line 8485 "GomElementTest.c"
		GomElementTestInstantiatable* _tmp0_;
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (self->priv->_inst_i);
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		self->priv->_inst_i = _tmp0_;
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_top_properties[GOM_ELEMENT_TEST_TOP_INST_I_PROPERTY]);
#line 8495 "GomElementTest.c"
	}
}


Property*
gom_element_test_top_get_pq (GomElementTestTop* self)
{
	Property* result;
	Property* _tmp0_;
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_pq;
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 8513 "GomElementTest.c"
}


void
gom_element_test_top_set_pq (GomElementTestTop* self, 
                             Property* value)
{
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (gom_element_test_top_get_pq (self) != value) {
#line 8525 "GomElementTest.c"
		Property* _tmp0_;
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (self->priv->_pq);
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		self->priv->_pq = _tmp0_;
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_top_properties[GOM_ELEMENT_TEST_TOP_PQ_PROPERTY]);
#line 8535 "GomElementTest.c"
	}
}


static GObject *
gom_element_test_top_constructor (GType type, 
                                  guint n_construct_properties, 
                                  GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestTop * self;
#line 50 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_top_parent_class);
#line 50 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 50 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTop);
#line 50 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "Top");
#line 50 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 8558 "GomElementTest.c"
}


static void
gom_element_test_top_class_init (GomElementTestTopClass * klass)
{
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_top_parent_class = g_type_class_peek_parent (klass);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_type_class_add_private (klass, sizeof (GomElementTestTopPrivate));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_top_get_property;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_top_set_property;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_top_constructor;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_top_finalize;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_TOP_INST_PROPERTY, gom_element_test_top_properties[GOM_ELEMENT_TEST_TOP_INST_PROPERTY] = g_param_spec_object ("inst", "inst", "inst", TYPE_NO_INSTANTIATABLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_TOP_INST_I_PROPERTY, gom_element_test_top_properties[GOM_ELEMENT_TEST_TOP_INST_I_PROPERTY] = g_param_spec_object ("inst-i", "inst-i", "inst-i", GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_TOP_PQ_PROPERTY, gom_element_test_top_properties[GOM_ELEMENT_TEST_TOP_PQ_PROPERTY] = g_param_spec_object ("pq", "::pq", "pq", TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 8583 "GomElementTest.c"
}


static void
gom_element_test_top_instance_init (GomElementTestTop * self)
{
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv = GOM_ELEMENT_TEST_TOP_GET_PRIVATE (self);
#line 8592 "GomElementTest.c"
}


static void
gom_element_test_top_finalize (GObject * obj)
{
	GomElementTestTop * self;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTop);
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_inst_i);
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_pq);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_top_parent_class)->finalize (obj);
#line 8608 "GomElementTest.c"
}


GType
gom_element_test_top_get_type (void)
{
	static volatile gsize gom_element_test_top_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_top_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestTopClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_top_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestTop), 0, (GInstanceInitFunc) gom_element_test_top_instance_init, NULL };
		GType gom_element_test_top_type_id;
		gom_element_test_top_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestTop", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_top_type_id__volatile, gom_element_test_top_type_id);
	}
	return gom_element_test_top_type_id__volatile;
}


static void
_vala_gom_element_test_top_get_property (GObject * object, 
                                         guint property_id, 
                                         GValue * value, 
                                         GParamSpec * pspec)
{
	GomElementTestTop * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTop);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TOP_INST_PROPERTY:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_top_get_inst (self));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TOP_INST_I_PROPERTY:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_top_get_inst_i (self));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TOP_PQ_PROPERTY:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_top_get_pq (self));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 8654 "GomElementTest.c"
		default:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 8660 "GomElementTest.c"
	}
}


static void
_vala_gom_element_test_top_set_property (GObject * object, 
                                         guint property_id, 
                                         const GValue * value, 
                                         GParamSpec * pspec)
{
	GomElementTestTop * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTop);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TOP_INST_PROPERTY:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_top_set_inst (self, g_value_get_object (value));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TOP_INST_I_PROPERTY:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_top_set_inst_i (self, g_value_get_object (value));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TOP_PQ_PROPERTY:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_top_set_pq (self, g_value_get_object (value));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 8693 "GomElementTest.c"
		default:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 8699 "GomElementTest.c"
	}
}


GomElementTestGProperty*
gom_element_test_gproperty_construct (GType object_type)
{
	GomElementTestGProperty * self = NULL;
#line 52 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestGProperty*) gxml_gom_string_construct (object_type);
#line 52 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 8712 "GomElementTest.c"
}


GomElementTestGProperty*
gom_element_test_gproperty_new (void)
{
#line 52 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_gproperty_construct (GOM_ELEMENT_TEST_TYPE_GPROPERTY);
#line 8721 "GomElementTest.c"
}


static void
gom_element_test_gproperty_class_init (GomElementTestGPropertyClass * klass)
{
#line 52 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_gproperty_parent_class = g_type_class_peek_parent (klass);
#line 8730 "GomElementTest.c"
}


static void
gom_element_test_gproperty_property_interface_init (PropertyIface * iface)
{
#line 52 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_gproperty_property_parent_iface = g_type_interface_peek_parent (iface);
#line 8739 "GomElementTest.c"
}


static void
gom_element_test_gproperty_instance_init (GomElementTestGProperty * self)
{
}


GType
gom_element_test_gproperty_get_type (void)
{
	static volatile gsize gom_element_test_gproperty_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_gproperty_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestGPropertyClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_gproperty_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestGProperty), 0, (GInstanceInitFunc) gom_element_test_gproperty_instance_init, NULL };
		static const GInterfaceInfo property_info = { (GInterfaceInitFunc) gom_element_test_gproperty_property_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gom_element_test_gproperty_type_id;
		gom_element_test_gproperty_type_id = g_type_register_static (GXML_TYPE_GOM_STRING, "GomElementTestGProperty", &g_define_type_info, 0);
		g_type_add_interface_static (gom_element_test_gproperty_type_id, TYPE_PROPERTY, &property_info);
		g_once_init_leave (&gom_element_test_gproperty_type_id__volatile, gom_element_test_gproperty_type_id);
	}
	return gom_element_test_gproperty_type_id__volatile;
}


GomElementTestGTop*
gom_element_test_gtop_construct (GType object_type)
{
	GomElementTestGTop * self = NULL;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestGTop*) gxml_gom_element_construct (object_type);
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 8773 "GomElementTest.c"
}


GomElementTestGTop*
gom_element_test_gtop_new (void)
{
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_gtop_construct (GOM_ELEMENT_TEST_TYPE_GTOP);
#line 8782 "GomElementTest.c"
}


NoInstantiatable*
gom_element_test_gtop_get_inst (GomElementTestGTop* self)
{
	NoInstantiatable* result;
	NoInstantiatable* _tmp0_;
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_inst;
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 8799 "GomElementTest.c"
}


void
gom_element_test_gtop_set_inst (GomElementTestGTop* self, 
                                NoInstantiatable* value)
{
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (gom_element_test_gtop_get_inst (self) != value) {
#line 8811 "GomElementTest.c"
		NoInstantiatable* _tmp0_;
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (self->priv->_inst);
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		self->priv->_inst = _tmp0_;
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_gtop_properties[GOM_ELEMENT_TEST_GTOP_INST_PROPERTY]);
#line 8821 "GomElementTest.c"
	}
}


GomElementTestInstantiatable*
gom_element_test_gtop_get_inst_i (GomElementTestGTop* self)
{
	GomElementTestInstantiatable* result;
	NoInstantiatable* _tmp0_;
#line 56 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 56 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_inst;
#line 56 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE) ? ((GomElementTestInstantiatable*) _tmp0_) : NULL;
#line 56 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 8839 "GomElementTest.c"
}


void
gom_element_test_gtop_set_inst_i (GomElementTestGTop* self, 
                                  GomElementTestInstantiatable* value)
{
#line 57 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 57 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_gtop_set_inst (self, G_TYPE_CHECK_INSTANCE_TYPE (value, TYPE_NO_INSTANTIATABLE) ? ((NoInstantiatable*) value) : NULL);
#line 57 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify_by_pspec ((GObject *) self, gom_element_test_gtop_properties[GOM_ELEMENT_TEST_GTOP_INST_I_PROPERTY]);
#line 8853 "GomElementTest.c"
}


GomElementTestGProperty*
gom_element_test_gtop_get_gpq (GomElementTestGTop* self)
{
	GomElementTestGProperty* result;
	Property* _tmp0_;
#line 62 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 62 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_pq;
#line 62 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GOM_ELEMENT_TEST_TYPE_GPROPERTY) ? ((GomElementTestGProperty*) _tmp0_) : NULL;
#line 62 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 8870 "GomElementTest.c"
}


void
gom_element_test_gtop_set_gpq (GomElementTestGTop* self, 
                               GomElementTestGProperty* value)
{
#line 63 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 63 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_gtop_set_pq (self, G_TYPE_CHECK_INSTANCE_TYPE (value, TYPE_PROPERTY) ? ((Property*) value) : NULL);
#line 63 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify_by_pspec ((GObject *) self, gom_element_test_gtop_properties[GOM_ELEMENT_TEST_GTOP_GPQ_PROPERTY]);
#line 8884 "GomElementTest.c"
}


Property*
gom_element_test_gtop_get_pq (GomElementTestGTop* self)
{
	Property* result;
	Property* _tmp0_;
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_pq;
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 8901 "GomElementTest.c"
}


void
gom_element_test_gtop_set_pq (GomElementTestGTop* self, 
                              Property* value)
{
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (gom_element_test_gtop_get_pq (self) != value) {
#line 8913 "GomElementTest.c"
		Property* _tmp0_;
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (self->priv->_pq);
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		self->priv->_pq = _tmp0_;
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_gtop_properties[GOM_ELEMENT_TEST_GTOP_PQ_PROPERTY]);
#line 8923 "GomElementTest.c"
	}
}


static GObject *
gom_element_test_gtop_constructor (GType type, 
                                   guint n_construct_properties, 
                                   GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestGTop * self;
#line 70 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_gtop_parent_class);
#line 70 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 70 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTop);
#line 70 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "Top");
#line 70 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 8946 "GomElementTest.c"
}


static void
gom_element_test_gtop_class_init (GomElementTestGTopClass * klass)
{
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_gtop_parent_class = g_type_class_peek_parent (klass);
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_type_class_add_private (klass, sizeof (GomElementTestGTopPrivate));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_gtop_get_property;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_gtop_set_property;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_gtop_constructor;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_gtop_finalize;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_GTOP_INST_PROPERTY, gom_element_test_gtop_properties[GOM_ELEMENT_TEST_GTOP_INST_PROPERTY] = g_param_spec_object ("inst", "inst", "inst", TYPE_NO_INSTANTIATABLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_GTOP_INST_I_PROPERTY, gom_element_test_gtop_properties[GOM_ELEMENT_TEST_GTOP_INST_I_PROPERTY] = g_param_spec_object ("inst-i", "inst-i", "inst-i", GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_GTOP_GPQ_PROPERTY, gom_element_test_gtop_properties[GOM_ELEMENT_TEST_GTOP_GPQ_PROPERTY] = g_param_spec_object ("gpq", "::pq", "gpq", GOM_ELEMENT_TEST_TYPE_GPROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_GTOP_PQ_PROPERTY, gom_element_test_gtop_properties[GOM_ELEMENT_TEST_GTOP_PQ_PROPERTY] = g_param_spec_object ("pq", "::pq", "pq", TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 8973 "GomElementTest.c"
}


static void
gom_element_test_gtop_instance_init (GomElementTestGTop * self)
{
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv = GOM_ELEMENT_TEST_GTOP_GET_PRIVATE (self);
#line 8982 "GomElementTest.c"
}


static void
gom_element_test_gtop_finalize (GObject * obj)
{
	GomElementTestGTop * self;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTop);
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_inst);
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_pq);
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_gtop_parent_class)->finalize (obj);
#line 8998 "GomElementTest.c"
}


GType
gom_element_test_gtop_get_type (void)
{
	static volatile gsize gom_element_test_gtop_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_gtop_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestGTopClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_gtop_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestGTop), 0, (GInstanceInitFunc) gom_element_test_gtop_instance_init, NULL };
		GType gom_element_test_gtop_type_id;
		gom_element_test_gtop_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestGTop", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_gtop_type_id__volatile, gom_element_test_gtop_type_id);
	}
	return gom_element_test_gtop_type_id__volatile;
}


static void
_vala_gom_element_test_gtop_get_property (GObject * object, 
                                          guint property_id, 
                                          GValue * value, 
                                          GParamSpec * pspec)
{
	GomElementTestGTop * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTop);
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_INST_PROPERTY:
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_gtop_get_inst (self));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_INST_I_PROPERTY:
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_gtop_get_inst_i (self));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_GPQ_PROPERTY:
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_gtop_get_gpq (self));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_PQ_PROPERTY:
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_gtop_get_pq (self));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 9050 "GomElementTest.c"
		default:
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 9056 "GomElementTest.c"
	}
}


static void
_vala_gom_element_test_gtop_set_property (GObject * object, 
                                          guint property_id, 
                                          const GValue * value, 
                                          GParamSpec * pspec)
{
	GomElementTestGTop * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTop);
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_INST_PROPERTY:
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_gtop_set_inst (self, g_value_get_object (value));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_INST_I_PROPERTY:
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_gtop_set_inst_i (self, g_value_get_object (value));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_GPQ_PROPERTY:
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_gtop_set_gpq (self, g_value_get_object (value));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_PQ_PROPERTY:
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_gtop_set_pq (self, g_value_get_object (value));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 9095 "GomElementTest.c"
		default:
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 9101 "GomElementTest.c"
	}
}


GomElementTestPotion*
gom_element_test_potion_construct (GType object_type)
{
	GomElementTestPotion * self = NULL;
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestPotion*) gxml_gom_element_construct (object_type);
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 9114 "GomElementTest.c"
}


GomElementTestPotion*
gom_element_test_potion_new (void)
{
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_potion_construct (GOM_ELEMENT_TEST_TYPE_POTION);
#line 9123 "GomElementTest.c"
}


const gchar*
gom_element_test_potion_get_cname (GomElementTestPotion* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_cname;
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 9140 "GomElementTest.c"
}


void
gom_element_test_potion_set_cname (GomElementTestPotion* self, 
                                   const gchar* value)
{
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_potion_get_cname (self)) != 0) {
#line 9152 "GomElementTest.c"
		gchar* _tmp0_;
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (self->priv->_cname);
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		self->priv->_cname = _tmp0_;
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_potion_properties[GOM_ELEMENT_TEST_POTION_CNAME_PROPERTY]);
#line 9162 "GomElementTest.c"
	}
}


GomElementTestIngredient*
gom_element_test_potion_get_ingredient (GomElementTestPotion* self)
{
	GomElementTestIngredient* result;
	GomElementTestIngredient* _tmp0_;
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_ingredient;
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 9180 "GomElementTest.c"
}


void
gom_element_test_potion_set_ingredient (GomElementTestPotion* self, 
                                        GomElementTestIngredient* value)
{
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (gom_element_test_potion_get_ingredient (self) != value) {
#line 9192 "GomElementTest.c"
		GomElementTestIngredient* _tmp0_;
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (self->priv->_ingredient);
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		self->priv->_ingredient = _tmp0_;
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_potion_properties[GOM_ELEMENT_TEST_POTION_INGREDIENT_PROPERTY]);
#line 9202 "GomElementTest.c"
	}
}


static GObject *
gom_element_test_potion_constructor (GType type, 
                                     guint n_construct_properties, 
                                     GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestPotion * self;
	GError * _inner_error_ = NULL;
#line 76 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_potion_parent_class);
#line 76 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 76 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotion);
#line 77 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "Potion");
#line 9224 "GomElementTest.c"
	{
#line 79 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) self, "http://www.w3.org/2000/xmlns", "xmlns:c", "http://c.org/1.0", &_inner_error_);
#line 79 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 9230 "GomElementTest.c"
			goto __catch272_g_error;
		}
	}
	goto __finally272;
	__catch272_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 78 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 78 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 80 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = e;
#line 80 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = _tmp0_->message;
#line 80 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 80 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 80 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_warning ("GomElementTest.vala:80: %s", _tmp3_);
#line 80 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp3_);
#line 78 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 9260 "GomElementTest.c"
	}
	__finally272:
#line 78 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 78 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 78 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 9269 "GomElementTest.c"
	}
#line 76 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 9273 "GomElementTest.c"
}


static void
gom_element_test_potion_class_init (GomElementTestPotionClass * klass)
{
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_potion_parent_class = g_type_class_peek_parent (klass);
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_type_class_add_private (klass, sizeof (GomElementTestPotionPrivate));
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_potion_get_property;
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_potion_set_property;
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_potion_constructor;
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_potion_finalize;
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_POTION_CNAME_PROPERTY, gom_element_test_potion_properties[GOM_ELEMENT_TEST_POTION_CNAME_PROPERTY] = g_param_spec_string ("cname", "::c:name", "cname", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_POTION_INGREDIENT_PROPERTY, gom_element_test_potion_properties[GOM_ELEMENT_TEST_POTION_INGREDIENT_PROPERTY] = g_param_spec_object ("ingredient", "ingredient", "ingredient", GOM_ELEMENT_TEST_TYPE_INGREDIENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 9296 "GomElementTest.c"
}


static void
gom_element_test_potion_instance_init (GomElementTestPotion * self)
{
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv = GOM_ELEMENT_TEST_POTION_GET_PRIVATE (self);
#line 9305 "GomElementTest.c"
}


static void
gom_element_test_potion_finalize (GObject * obj)
{
	GomElementTestPotion * self;
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotion);
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_cname);
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_ingredient);
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_potion_parent_class)->finalize (obj);
#line 9321 "GomElementTest.c"
}


GType
gom_element_test_potion_get_type (void)
{
	static volatile gsize gom_element_test_potion_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_potion_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestPotionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_potion_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestPotion), 0, (GInstanceInitFunc) gom_element_test_potion_instance_init, NULL };
		GType gom_element_test_potion_type_id;
		gom_element_test_potion_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestPotion", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_potion_type_id__volatile, gom_element_test_potion_type_id);
	}
	return gom_element_test_potion_type_id__volatile;
}


static void
_vala_gom_element_test_potion_get_property (GObject * object, 
                                            guint property_id, 
                                            GValue * value, 
                                            GParamSpec * pspec)
{
	GomElementTestPotion * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotion);
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_POTION_CNAME_PROPERTY:
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, gom_element_test_potion_get_cname (self));
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_POTION_INGREDIENT_PROPERTY:
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_potion_get_ingredient (self));
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 9361 "GomElementTest.c"
		default:
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 9367 "GomElementTest.c"
	}
}


static void
_vala_gom_element_test_potion_set_property (GObject * object, 
                                            guint property_id, 
                                            const GValue * value, 
                                            GParamSpec * pspec)
{
	GomElementTestPotion * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotion);
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_POTION_CNAME_PROPERTY:
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_potion_set_cname (self, g_value_get_string (value));
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_POTION_INGREDIENT_PROPERTY:
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_potion_set_ingredient (self, g_value_get_object (value));
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 9394 "GomElementTest.c"
		default:
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 9400 "GomElementTest.c"
	}
}


static gchar*
gom_element_test_ingredient_real_get_map_key (GXmlMappeableElement* base)
{
	GomElementTestIngredient * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 88 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestIngredient*) base;
#line 88 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_cname;
#line 88 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 88 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp1_;
#line 88 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 9422 "GomElementTest.c"
}


GomElementTestIngredient*
gom_element_test_ingredient_construct (GType object_type)
{
	GomElementTestIngredient * self = NULL;
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestIngredient*) gxml_gom_element_construct (object_type);
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 9434 "GomElementTest.c"
}


GomElementTestIngredient*
gom_element_test_ingredient_new (void)
{
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_ingredient_construct (GOM_ELEMENT_TEST_TYPE_INGREDIENT);
#line 9443 "GomElementTest.c"
}


const gchar*
gom_element_test_ingredient_get_cname (GomElementTestIngredient* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_cname;
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 9460 "GomElementTest.c"
}


void
gom_element_test_ingredient_set_cname (GomElementTestIngredient* self, 
                                       const gchar* value)
{
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_ingredient_get_cname (self)) != 0) {
#line 9472 "GomElementTest.c"
		gchar* _tmp0_;
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (self->priv->_cname);
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		self->priv->_cname = _tmp0_;
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_ingredient_properties[GOM_ELEMENT_TEST_INGREDIENT_CNAME_PROPERTY]);
#line 9482 "GomElementTest.c"
	}
}


GomElementTestMethodMap*
gom_element_test_ingredient_get_methods (GomElementTestIngredient* self)
{
	GomElementTestMethodMap* result;
	GomElementTestMethodMap* _tmp0_;
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_methods;
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 9500 "GomElementTest.c"
}


void
gom_element_test_ingredient_set_methods (GomElementTestIngredient* self, 
                                         GomElementTestMethodMap* value)
{
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (gom_element_test_ingredient_get_methods (self) != value) {
#line 9512 "GomElementTest.c"
		GomElementTestMethodMap* _tmp0_;
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (self->priv->_methods);
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		self->priv->_methods = _tmp0_;
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_ingredient_properties[GOM_ELEMENT_TEST_INGREDIENT_METHODS_PROPERTY]);
#line 9522 "GomElementTest.c"
	}
}


static GObject *
gom_element_test_ingredient_constructor (GType type, 
                                         guint n_construct_properties, 
                                         GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestIngredient * self;
#line 87 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_ingredient_parent_class);
#line 87 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 87 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredient);
#line 87 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "ingredient");
#line 87 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 9545 "GomElementTest.c"
}


GomElementTestIngredientMap*
gom_element_test_ingredient_map_construct (GType object_type)
{
	GomElementTestIngredientMap * self = NULL;
#line 89 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestIngredientMap*) gxml_gom_hash_map_construct (object_type);
#line 89 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 9557 "GomElementTest.c"
}


GomElementTestIngredientMap*
gom_element_test_ingredient_map_new (void)
{
#line 89 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_ingredient_map_construct (GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP);
#line 9566 "GomElementTest.c"
}


static GObject *
gom_element_test_ingredient_map_constructor (GType type, 
                                             guint n_construct_properties, 
                                             GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestIngredientMap * self;
	GError * _inner_error_ = NULL;
#line 90 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_ingredient_map_parent_class);
#line 90 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 90 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP, GomElementTestIngredientMap);
#line 9585 "GomElementTest.c"
	{
#line 92 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_collection_initialize ((GXmlGomCollection*) self, GOM_ELEMENT_TEST_TYPE_INGREDIENT, &_inner_error_);
#line 92 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 9591 "GomElementTest.c"
			goto __catch273_g_error;
		}
	}
	goto __finally273;
	__catch273_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 91 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 91 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 93 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = e;
#line 93 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = _tmp0_->message;
#line 93 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 93 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 93 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_warning ("GomElementTest.vala:93: %s", _tmp3_);
#line 93 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp3_);
#line 91 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 9621 "GomElementTest.c"
	}
	__finally273:
#line 91 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 91 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 91 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 9630 "GomElementTest.c"
	}
#line 90 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 9634 "GomElementTest.c"
}


static void
gom_element_test_ingredient_map_class_init (GomElementTestIngredientMapClass * klass)
{
#line 89 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_ingredient_map_parent_class = g_type_class_peek_parent (klass);
#line 89 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_ingredient_map_constructor;
#line 9645 "GomElementTest.c"
}


static void
gom_element_test_ingredient_map_instance_init (GomElementTestIngredientMap * self)
{
}


GType
gom_element_test_ingredient_map_get_type (void)
{
	static volatile gsize gom_element_test_ingredient_map_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_ingredient_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestIngredientMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_ingredient_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestIngredientMap), 0, (GInstanceInitFunc) gom_element_test_ingredient_map_instance_init, NULL };
		GType gom_element_test_ingredient_map_type_id;
		gom_element_test_ingredient_map_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_MAP, "GomElementTestIngredientMap", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_ingredient_map_type_id__volatile, gom_element_test_ingredient_map_type_id);
	}
	return gom_element_test_ingredient_map_type_id__volatile;
}


static void
gom_element_test_ingredient_class_init (GomElementTestIngredientClass * klass)
{
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_ingredient_parent_class = g_type_class_peek_parent (klass);
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_type_class_add_private (klass, sizeof (GomElementTestIngredientPrivate));
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_ingredient_get_property;
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_ingredient_set_property;
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_ingredient_constructor;
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_ingredient_finalize;
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_INGREDIENT_CNAME_PROPERTY, gom_element_test_ingredient_properties[GOM_ELEMENT_TEST_INGREDIENT_CNAME_PROPERTY] = g_param_spec_string ("cname", "::c:name", "cname", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_INGREDIENT_METHODS_PROPERTY, gom_element_test_ingredient_properties[GOM_ELEMENT_TEST_INGREDIENT_METHODS_PROPERTY] = g_param_spec_object ("methods", "methods", "methods", GOM_ELEMENT_TEST_METHOD_TYPE_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 9688 "GomElementTest.c"
}


static void
gom_element_test_ingredient_gxml_mappeable_element_interface_init (GXmlMappeableElementIface * iface)
{
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_ingredient_gxml_mappeable_element_parent_iface = g_type_interface_peek_parent (iface);
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	iface->get_map_key = (gchar* (*) (GXmlMappeableElement *)) gom_element_test_ingredient_real_get_map_key;
#line 9699 "GomElementTest.c"
}


static void
gom_element_test_ingredient_instance_init (GomElementTestIngredient * self)
{
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv = GOM_ELEMENT_TEST_INGREDIENT_GET_PRIVATE (self);
#line 9708 "GomElementTest.c"
}


static void
gom_element_test_ingredient_finalize (GObject * obj)
{
	GomElementTestIngredient * self;
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredient);
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_cname);
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_methods);
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_ingredient_parent_class)->finalize (obj);
#line 9724 "GomElementTest.c"
}


GType
gom_element_test_ingredient_get_type (void)
{
	static volatile gsize gom_element_test_ingredient_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_ingredient_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestIngredientClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_ingredient_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestIngredient), 0, (GInstanceInitFunc) gom_element_test_ingredient_instance_init, NULL };
		static const GInterfaceInfo gxml_mappeable_element_info = { (GInterfaceInitFunc) gom_element_test_ingredient_gxml_mappeable_element_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gom_element_test_ingredient_type_id;
		gom_element_test_ingredient_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestIngredient", &g_define_type_info, 0);
		g_type_add_interface_static (gom_element_test_ingredient_type_id, GXML_TYPE_MAPPEABLE_ELEMENT, &gxml_mappeable_element_info);
		g_once_init_leave (&gom_element_test_ingredient_type_id__volatile, gom_element_test_ingredient_type_id);
	}
	return gom_element_test_ingredient_type_id__volatile;
}


static void
_vala_gom_element_test_ingredient_get_property (GObject * object, 
                                                guint property_id, 
                                                GValue * value, 
                                                GParamSpec * pspec)
{
	GomElementTestIngredient * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredient);
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_INGREDIENT_CNAME_PROPERTY:
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, gom_element_test_ingredient_get_cname (self));
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_INGREDIENT_METHODS_PROPERTY:
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_ingredient_get_methods (self));
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 9766 "GomElementTest.c"
		default:
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 9772 "GomElementTest.c"
	}
}


static void
_vala_gom_element_test_ingredient_set_property (GObject * object, 
                                                guint property_id, 
                                                const GValue * value, 
                                                GParamSpec * pspec)
{
	GomElementTestIngredient * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredient);
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_INGREDIENT_CNAME_PROPERTY:
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_ingredient_set_cname (self, g_value_get_string (value));
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_INGREDIENT_METHODS_PROPERTY:
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_ingredient_set_methods (self, g_value_get_object (value));
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 9799 "GomElementTest.c"
		default:
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 9805 "GomElementTest.c"
	}
}


static gchar*
gom_element_test_method_real_get_map_key (GXmlMappeableElement* base)
{
	GomElementTestMethod * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 101 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestMethod*) base;
#line 101 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_cname;
#line 101 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 101 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp1_;
#line 101 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 9827 "GomElementTest.c"
}


GomElementTestMethod*
gom_element_test_method_construct (GType object_type)
{
	GomElementTestMethod * self = NULL;
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestMethod*) gxml_gom_element_construct (object_type);
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 9839 "GomElementTest.c"
}


GomElementTestMethod*
gom_element_test_method_new (void)
{
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_method_construct (GOM_ELEMENT_TEST_TYPE_METHOD);
#line 9848 "GomElementTest.c"
}


const gchar*
gom_element_test_method_get_cname (GomElementTestMethod* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_cname;
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 9865 "GomElementTest.c"
}


void
gom_element_test_method_set_cname (GomElementTestMethod* self, 
                                   const gchar* value)
{
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_method_get_cname (self)) != 0) {
#line 9877 "GomElementTest.c"
		gchar* _tmp0_;
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (self->priv->_cname);
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		self->priv->_cname = _tmp0_;
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_method_properties[GOM_ELEMENT_TEST_METHOD_CNAME_PROPERTY]);
#line 9887 "GomElementTest.c"
	}
}


static GObject *
gom_element_test_method_constructor (GType type, 
                                     guint n_construct_properties, 
                                     GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestMethod * self;
#line 100 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_method_parent_class);
#line 100 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 100 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethod);
#line 100 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "method");
#line 100 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 9910 "GomElementTest.c"
}


GomElementTestMethodMap*
gom_element_test_method_map_construct (GType object_type)
{
	GomElementTestMethodMap * self = NULL;
#line 102 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestMethodMap*) gxml_gom_hash_map_construct (object_type);
#line 102 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 9922 "GomElementTest.c"
}


GomElementTestMethodMap*
gom_element_test_method_map_new (void)
{
#line 102 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_method_map_construct (GOM_ELEMENT_TEST_METHOD_TYPE_MAP);
#line 9931 "GomElementTest.c"
}


static GObject *
gom_element_test_method_map_constructor (GType type, 
                                         guint n_construct_properties, 
                                         GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestMethodMap * self;
	GError * _inner_error_ = NULL;
#line 103 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_method_map_parent_class);
#line 103 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 103 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_METHOD_TYPE_MAP, GomElementTestMethodMap);
#line 9950 "GomElementTest.c"
	{
#line 105 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_collection_initialize ((GXmlGomCollection*) self, GOM_ELEMENT_TEST_TYPE_METHOD, &_inner_error_);
#line 105 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 9956 "GomElementTest.c"
			goto __catch274_g_error;
		}
	}
	goto __finally274;
	__catch274_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 104 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 104 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = e;
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = _tmp0_->message;
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_warning ("GomElementTest.vala:106: %s", _tmp3_);
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp3_);
#line 104 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 9986 "GomElementTest.c"
	}
	__finally274:
#line 104 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 104 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 104 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 9995 "GomElementTest.c"
	}
#line 103 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 9999 "GomElementTest.c"
}


static void
gom_element_test_method_map_class_init (GomElementTestMethodMapClass * klass)
{
#line 102 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_method_map_parent_class = g_type_class_peek_parent (klass);
#line 102 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_method_map_constructor;
#line 10010 "GomElementTest.c"
}


static void
gom_element_test_method_map_instance_init (GomElementTestMethodMap * self)
{
}


GType
gom_element_test_method_map_get_type (void)
{
	static volatile gsize gom_element_test_method_map_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_method_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestMethodMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_method_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestMethodMap), 0, (GInstanceInitFunc) gom_element_test_method_map_instance_init, NULL };
		GType gom_element_test_method_map_type_id;
		gom_element_test_method_map_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_MAP, "GomElementTestMethodMap", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_method_map_type_id__volatile, gom_element_test_method_map_type_id);
	}
	return gom_element_test_method_map_type_id__volatile;
}


static void
gom_element_test_method_class_init (GomElementTestMethodClass * klass)
{
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_method_parent_class = g_type_class_peek_parent (klass);
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_type_class_add_private (klass, sizeof (GomElementTestMethodPrivate));
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_method_get_property;
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_method_set_property;
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_method_constructor;
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_method_finalize;
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_METHOD_CNAME_PROPERTY, gom_element_test_method_properties[GOM_ELEMENT_TEST_METHOD_CNAME_PROPERTY] = g_param_spec_string ("cname", "::c:name", "cname", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 10051 "GomElementTest.c"
}


static void
gom_element_test_method_gxml_mappeable_element_interface_init (GXmlMappeableElementIface * iface)
{
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_method_gxml_mappeable_element_parent_iface = g_type_interface_peek_parent (iface);
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	iface->get_map_key = (gchar* (*) (GXmlMappeableElement *)) gom_element_test_method_real_get_map_key;
#line 10062 "GomElementTest.c"
}


static void
gom_element_test_method_instance_init (GomElementTestMethod * self)
{
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv = GOM_ELEMENT_TEST_METHOD_GET_PRIVATE (self);
#line 10071 "GomElementTest.c"
}


static void
gom_element_test_method_finalize (GObject * obj)
{
	GomElementTestMethod * self;
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethod);
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_cname);
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_method_parent_class)->finalize (obj);
#line 10085 "GomElementTest.c"
}


GType
gom_element_test_method_get_type (void)
{
	static volatile gsize gom_element_test_method_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_method_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestMethod), 0, (GInstanceInitFunc) gom_element_test_method_instance_init, NULL };
		static const GInterfaceInfo gxml_mappeable_element_info = { (GInterfaceInitFunc) gom_element_test_method_gxml_mappeable_element_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gom_element_test_method_type_id;
		gom_element_test_method_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestMethod", &g_define_type_info, 0);
		g_type_add_interface_static (gom_element_test_method_type_id, GXML_TYPE_MAPPEABLE_ELEMENT, &gxml_mappeable_element_info);
		g_once_init_leave (&gom_element_test_method_type_id__volatile, gom_element_test_method_type_id);
	}
	return gom_element_test_method_type_id__volatile;
}


static void
_vala_gom_element_test_method_get_property (GObject * object, 
                                            guint property_id, 
                                            GValue * value, 
                                            GParamSpec * pspec)
{
	GomElementTestMethod * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethod);
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_METHOD_CNAME_PROPERTY:
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, gom_element_test_method_get_cname (self));
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10121 "GomElementTest.c"
		default:
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10127 "GomElementTest.c"
	}
}


static void
_vala_gom_element_test_method_set_property (GObject * object, 
                                            guint property_id, 
                                            const GValue * value, 
                                            GParamSpec * pspec)
{
	GomElementTestMethod * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethod);
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_METHOD_CNAME_PROPERTY:
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_method_set_cname (self, g_value_get_string (value));
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10148 "GomElementTest.c"
		default:
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10154 "GomElementTest.c"
	}
}


GomElementTestRepository*
gom_element_test_repository_construct (GType object_type)
{
	GomElementTestRepository * self = NULL;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestRepository*) gxml_gom_element_construct (object_type);
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 10167 "GomElementTest.c"
}


GomElementTestRepository*
gom_element_test_repository_new (void)
{
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_repository_construct (GOM_ELEMENT_TEST_TYPE_REPOSITORY);
#line 10176 "GomElementTest.c"
}


const gchar*
gom_element_test_repository_get_version (GomElementTestRepository* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_version;
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 10193 "GomElementTest.c"
}


void
gom_element_test_repository_set_version (GomElementTestRepository* self, 
                                         const gchar* value)
{
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_repository_get_version (self)) != 0) {
#line 10205 "GomElementTest.c"
		gchar* _tmp0_;
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (self->priv->_version);
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		self->priv->_version = _tmp0_;
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_repository_properties[GOM_ELEMENT_TEST_REPOSITORY_VERSION_PROPERTY]);
#line 10215 "GomElementTest.c"
	}
}


GomElementTestNamespace*
gom_element_test_repository_get_ns (GomElementTestRepository* self)
{
	GomElementTestNamespace* result;
	GomElementTestNamespace* _tmp0_;
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_ns;
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 10233 "GomElementTest.c"
}


void
gom_element_test_repository_set_ns (GomElementTestRepository* self, 
                                    GomElementTestNamespace* value)
{
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (gom_element_test_repository_get_ns (self) != value) {
#line 10245 "GomElementTest.c"
		GomElementTestNamespace* _tmp0_;
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (self->priv->_ns);
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		self->priv->_ns = _tmp0_;
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_repository_properties[GOM_ELEMENT_TEST_REPOSITORY_NS_PROPERTY]);
#line 10255 "GomElementTest.c"
	}
}


static GObject *
gom_element_test_repository_constructor (GType type, 
                                         guint n_construct_properties, 
                                         GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestRepository * self;
	GError * _inner_error_ = NULL;
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_repository_parent_class);
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepository);
#line 118 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "repository");
#line 10277 "GomElementTest.c"
	{
#line 120 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) self, "http://www.w3.org/2000/xmlns", "xmlns", "http://www.gtk.org/introspection/core/1.0", &_inner_error_);
#line 120 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 10283 "GomElementTest.c"
			goto __catch275_g_error;
		}
#line 122 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) self, "http://www.w3.org/2000/xmlns", "xmlns:c", "http://www.gtk.org/introspection/c/1.0", &_inner_error_);
#line 122 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 10290 "GomElementTest.c"
			goto __catch275_g_error;
		}
#line 124 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) self, "http://www.w3.org/2000/xmlns", "xmlns:glib", "http://www.gtk.org/introspection/glib/1.0", &_inner_error_);
#line 124 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 10297 "GomElementTest.c"
			goto __catch275_g_error;
		}
	}
	goto __finally275;
	__catch275_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 119 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 119 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 126 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = e;
#line 126 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = _tmp0_->message;
#line 126 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 126 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 126 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_warning ("GomElementTest.vala:126: %s", _tmp3_);
#line 126 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp3_);
#line 119 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 10327 "GomElementTest.c"
	}
	__finally275:
#line 119 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 119 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 119 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 10336 "GomElementTest.c"
	}
#line 127 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_repository_set_version (self, "1.2");
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 10342 "GomElementTest.c"
}


static void
gom_element_test_repository_class_init (GomElementTestRepositoryClass * klass)
{
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_repository_parent_class = g_type_class_peek_parent (klass);
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_type_class_add_private (klass, sizeof (GomElementTestRepositoryPrivate));
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_repository_get_property;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_repository_set_property;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_repository_constructor;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_repository_finalize;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_REPOSITORY_VERSION_PROPERTY, gom_element_test_repository_properties[GOM_ELEMENT_TEST_REPOSITORY_VERSION_PROPERTY] = g_param_spec_string ("version", "::version", "version", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_REPOSITORY_NS_PROPERTY, gom_element_test_repository_properties[GOM_ELEMENT_TEST_REPOSITORY_NS_PROPERTY] = g_param_spec_object ("ns", "ns", "ns", GOM_ELEMENT_TEST_TYPE_NAMESPACE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 10365 "GomElementTest.c"
}


static void
gom_element_test_repository_instance_init (GomElementTestRepository * self)
{
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv = GOM_ELEMENT_TEST_REPOSITORY_GET_PRIVATE (self);
#line 10374 "GomElementTest.c"
}


static void
gom_element_test_repository_finalize (GObject * obj)
{
	GomElementTestRepository * self;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepository);
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_version);
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_ns);
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_repository_parent_class)->finalize (obj);
#line 10390 "GomElementTest.c"
}


GType
gom_element_test_repository_get_type (void)
{
	static volatile gsize gom_element_test_repository_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_repository_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestRepositoryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_repository_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestRepository), 0, (GInstanceInitFunc) gom_element_test_repository_instance_init, NULL };
		GType gom_element_test_repository_type_id;
		gom_element_test_repository_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestRepository", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_repository_type_id__volatile, gom_element_test_repository_type_id);
	}
	return gom_element_test_repository_type_id__volatile;
}


static void
_vala_gom_element_test_repository_get_property (GObject * object, 
                                                guint property_id, 
                                                GValue * value, 
                                                GParamSpec * pspec)
{
	GomElementTestRepository * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepository);
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_REPOSITORY_VERSION_PROPERTY:
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, gom_element_test_repository_get_version (self));
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_REPOSITORY_NS_PROPERTY:
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_repository_get_ns (self));
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10430 "GomElementTest.c"
		default:
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10436 "GomElementTest.c"
	}
}


static void
_vala_gom_element_test_repository_set_property (GObject * object, 
                                                guint property_id, 
                                                const GValue * value, 
                                                GParamSpec * pspec)
{
	GomElementTestRepository * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepository);
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_REPOSITORY_VERSION_PROPERTY:
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_repository_set_version (self, g_value_get_string (value));
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_REPOSITORY_NS_PROPERTY:
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_repository_set_ns (self, g_value_get_object (value));
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10463 "GomElementTest.c"
		default:
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10469 "GomElementTest.c"
	}
}


GomElementTestNamespace*
gom_element_test_namespace_construct (GType object_type)
{
	GomElementTestNamespace * self = NULL;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestNamespace*) gxml_gom_element_construct (object_type);
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 10482 "GomElementTest.c"
}


GomElementTestNamespace*
gom_element_test_namespace_new (void)
{
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_namespace_construct (GOM_ELEMENT_TEST_TYPE_NAMESPACE);
#line 10491 "GomElementTest.c"
}


const gchar*
gom_element_test_namespace_get_name (GomElementTestNamespace* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_name;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 10508 "GomElementTest.c"
}


void
gom_element_test_namespace_set_name (GomElementTestNamespace* self, 
                                     const gchar* value)
{
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_namespace_get_name (self)) != 0) {
#line 10520 "GomElementTest.c"
		gchar* _tmp0_;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (self->priv->_name);
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		self->priv->_name = _tmp0_;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_namespace_properties[GOM_ELEMENT_TEST_NAMESPACE_NAME_PROPERTY]);
#line 10530 "GomElementTest.c"
	}
}


const gchar*
gom_element_test_namespace_get_version (GomElementTestNamespace* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_version;
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 10548 "GomElementTest.c"
}


void
gom_element_test_namespace_set_version (GomElementTestNamespace* self, 
                                        const gchar* value)
{
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_namespace_get_version (self)) != 0) {
#line 10560 "GomElementTest.c"
		gchar* _tmp0_;
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (self->priv->_version);
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		self->priv->_version = _tmp0_;
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_namespace_properties[GOM_ELEMENT_TEST_NAMESPACE_VERSION_PROPERTY]);
#line 10570 "GomElementTest.c"
	}
}


const gchar*
gom_element_test_namespace_get_cprefix (GomElementTestNamespace* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_cprefix;
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 10588 "GomElementTest.c"
}


void
gom_element_test_namespace_set_cprefix (GomElementTestNamespace* self, 
                                        const gchar* value)
{
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_namespace_get_cprefix (self)) != 0) {
#line 10600 "GomElementTest.c"
		gchar* _tmp0_;
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (self->priv->_cprefix);
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		self->priv->_cprefix = _tmp0_;
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_namespace_properties[GOM_ELEMENT_TEST_NAMESPACE_CPREFIX_PROPERTY]);
#line 10610 "GomElementTest.c"
	}
}


GomElementTestTClassMap*
gom_element_test_namespace_get_classes (GomElementTestNamespace* self)
{
	GomElementTestTClassMap* result;
	GomElementTestTClassMap* _tmp0_;
	GomElementTestTClassMap* _tmp1_;
#line 140 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 141 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_classes;
#line 141 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (_tmp0_ == NULL) {
#line 142 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_object_set_instance_property ((GXmlGomObject*) self, "classes");
#line 10629 "GomElementTest.c"
	}
#line 143 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = self->priv->_classes;
#line 143 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp1_;
#line 143 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 10637 "GomElementTest.c"
}


void
gom_element_test_namespace_set_classes (GomElementTestNamespace* self, 
                                        GomElementTestTClassMap* value)
{
	GomElementTestTClassMap* _tmp0_;
	GomElementTestTClassMap* _tmp5_;
	GError * _inner_error_ = NULL;
#line 145 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 146 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_classes;
#line 146 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (_tmp0_ != NULL) {
#line 10654 "GomElementTest.c"
		{
#line 147 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			gxml_gom_object_clean_property_elements ((GXmlGomObject*) self, "classes", &_inner_error_);
#line 147 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 10660 "GomElementTest.c"
				goto __catch276_g_error;
			}
		}
		goto __finally276;
		__catch276_g_error:
		{
			GError* e = NULL;
			GError* _tmp1_;
			const gchar* _tmp2_;
			gchar* _tmp3_;
			gchar* _tmp4_;
#line 147 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			e = _inner_error_;
#line 147 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_inner_error_ = NULL;
#line 148 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp1_ = e;
#line 148 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp2_ = _tmp1_->message;
#line 148 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp3_ = g_strconcat ("Error: ", _tmp2_, NULL);
#line 148 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp4_ = _tmp3_;
#line 148 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			g_warning ("GomElementTest.vala:148: %s", _tmp4_);
#line 148 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp4_);
#line 147 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_error_free0 (e);
#line 10690 "GomElementTest.c"
		}
		__finally276:
#line 147 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 147 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 147 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			g_clear_error (&_inner_error_);
#line 147 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			return;
#line 10701 "GomElementTest.c"
		}
	}
#line 150 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp5_ = _g_object_ref0 (value);
#line 150 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_classes);
#line 150 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_classes = _tmp5_;
#line 145 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify_by_pspec ((GObject *) self, gom_element_test_namespace_properties[GOM_ELEMENT_TEST_NAMESPACE_CLASSES_PROPERTY]);
#line 10712 "GomElementTest.c"
}


static GObject *
gom_element_test_namespace_constructor (GType type, 
                                        guint n_construct_properties, 
                                        GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestNamespace * self;
	GomElementTestTClassMap* _tmp0_;
	GError * _inner_error_ = NULL;
#line 153 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_namespace_parent_class);
#line 153 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 153 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespace);
#line 154 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "namespace");
#line 155 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = gom_element_test_tclass_map_new ();
#line 155 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_classes);
#line 155 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_classes = _tmp0_;
#line 10740 "GomElementTest.c"
	{
		GomElementTestTClassMap* _tmp1_;
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = self->priv->_classes;
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_base_collection_initialize_element ((GXmlBaseCollection*) _tmp1_, (GXmlGomElement*) self, &_inner_error_);
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 10749 "GomElementTest.c"
			goto __catch277_g_error;
		}
	}
	goto __finally277;
	__catch277_g_error:
	{
		GError* e = NULL;
		GError* _tmp2_;
		const gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 157 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = e;
#line 157 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_->message;
#line 157 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = g_strconcat ("Error: ", _tmp3_, NULL);
#line 157 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 157 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_warning ("GomElementTest.vala:157: %s", _tmp5_);
#line 157 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp5_);
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 10779 "GomElementTest.c"
	}
	__finally277:
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 10788 "GomElementTest.c"
	}
#line 153 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 10792 "GomElementTest.c"
}


static void
gom_element_test_namespace_class_init (GomElementTestNamespaceClass * klass)
{
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_namespace_parent_class = g_type_class_peek_parent (klass);
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_type_class_add_private (klass, sizeof (GomElementTestNamespacePrivate));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_namespace_get_property;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_namespace_set_property;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_namespace_constructor;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_namespace_finalize;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_NAMESPACE_NAME_PROPERTY, gom_element_test_namespace_properties[GOM_ELEMENT_TEST_NAMESPACE_NAME_PROPERTY] = g_param_spec_string ("name", "::name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_NAMESPACE_VERSION_PROPERTY, gom_element_test_namespace_properties[GOM_ELEMENT_TEST_NAMESPACE_VERSION_PROPERTY] = g_param_spec_string ("version", "::version", "version", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_NAMESPACE_CPREFIX_PROPERTY, gom_element_test_namespace_properties[GOM_ELEMENT_TEST_NAMESPACE_CPREFIX_PROPERTY] = g_param_spec_string ("cprefix", "::c:prefix", "cprefix", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_NAMESPACE_CLASSES_PROPERTY, gom_element_test_namespace_properties[GOM_ELEMENT_TEST_NAMESPACE_CLASSES_PROPERTY] = g_param_spec_object ("classes", "classes", "classes", GOM_ELEMENT_TEST_TCLASS_TYPE_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 10819 "GomElementTest.c"
}


static void
gom_element_test_namespace_instance_init (GomElementTestNamespace * self)
{
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv = GOM_ELEMENT_TEST_NAMESPACE_GET_PRIVATE (self);
#line 10828 "GomElementTest.c"
}


static void
gom_element_test_namespace_finalize (GObject * obj)
{
	GomElementTestNamespace * self;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespace);
#line 132 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_classes);
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_name);
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_version);
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_cprefix);
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_namespace_parent_class)->finalize (obj);
#line 10848 "GomElementTest.c"
}


GType
gom_element_test_namespace_get_type (void)
{
	static volatile gsize gom_element_test_namespace_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_namespace_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestNamespaceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_namespace_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestNamespace), 0, (GInstanceInitFunc) gom_element_test_namespace_instance_init, NULL };
		GType gom_element_test_namespace_type_id;
		gom_element_test_namespace_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestNamespace", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_namespace_type_id__volatile, gom_element_test_namespace_type_id);
	}
	return gom_element_test_namespace_type_id__volatile;
}


static void
_vala_gom_element_test_namespace_get_property (GObject * object, 
                                               guint property_id, 
                                               GValue * value, 
                                               GParamSpec * pspec)
{
	GomElementTestNamespace * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespace);
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_NAME_PROPERTY:
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, gom_element_test_namespace_get_name (self));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_VERSION_PROPERTY:
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, gom_element_test_namespace_get_version (self));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_CPREFIX_PROPERTY:
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, gom_element_test_namespace_get_cprefix (self));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_CLASSES_PROPERTY:
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_namespace_get_classes (self));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10900 "GomElementTest.c"
		default:
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10906 "GomElementTest.c"
	}
}


static void
_vala_gom_element_test_namespace_set_property (GObject * object, 
                                               guint property_id, 
                                               const GValue * value, 
                                               GParamSpec * pspec)
{
	GomElementTestNamespace * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespace);
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_NAME_PROPERTY:
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_namespace_set_name (self, g_value_get_string (value));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_VERSION_PROPERTY:
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_namespace_set_version (self, g_value_get_string (value));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_CPREFIX_PROPERTY:
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_namespace_set_cprefix (self, g_value_get_string (value));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_CLASSES_PROPERTY:
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_namespace_set_classes (self, g_value_get_object (value));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10945 "GomElementTest.c"
		default:
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10951 "GomElementTest.c"
	}
}


static gchar*
gom_element_test_tclass_real_get_map_key (GXmlMappeableElement* base)
{
	GomElementTestTClass * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 173 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestTClass*) base;
#line 173 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_name;
#line 173 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 173 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp1_;
#line 173 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 10973 "GomElementTest.c"
}


GomElementTestTClass*
gom_element_test_tclass_construct (GType object_type)
{
	GomElementTestTClass * self = NULL;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestTClass*) gxml_gom_element_construct (object_type);
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 10985 "GomElementTest.c"
}


GomElementTestTClass*
gom_element_test_tclass_new (void)
{
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_tclass_construct (GOM_ELEMENT_TEST_TYPE_TCLASS);
#line 10994 "GomElementTest.c"
}


const gchar*
gom_element_test_tclass_get_name (GomElementTestTClass* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_name;
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 11011 "GomElementTest.c"
}


void
gom_element_test_tclass_set_name (GomElementTestTClass* self, 
                                  const gchar* value)
{
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_tclass_get_name (self)) != 0) {
#line 11023 "GomElementTest.c"
		gchar* _tmp0_;
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (self->priv->_name);
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		self->priv->_name = _tmp0_;
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_tclass_properties[GOM_ELEMENT_TEST_TCLASS_NAME_PROPERTY]);
#line 11033 "GomElementTest.c"
	}
}


const gchar*
gom_element_test_tclass_get_version (GomElementTestTClass* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_version;
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 11051 "GomElementTest.c"
}


void
gom_element_test_tclass_set_version (GomElementTestTClass* self, 
                                     const gchar* value)
{
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_tclass_get_version (self)) != 0) {
#line 11063 "GomElementTest.c"
		gchar* _tmp0_;
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (self->priv->_version);
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		self->priv->_version = _tmp0_;
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_tclass_properties[GOM_ELEMENT_TEST_TCLASS_VERSION_PROPERTY]);
#line 11073 "GomElementTest.c"
	}
}


const gchar*
gom_element_test_tclass_get_cprefix (GomElementTestTClass* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_cprefix;
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 11091 "GomElementTest.c"
}


void
gom_element_test_tclass_set_cprefix (GomElementTestTClass* self, 
                                     const gchar* value)
{
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_tclass_get_cprefix (self)) != 0) {
#line 11103 "GomElementTest.c"
		gchar* _tmp0_;
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (self->priv->_cprefix);
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		self->priv->_cprefix = _tmp0_;
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_tclass_properties[GOM_ELEMENT_TEST_TCLASS_CPREFIX_PROPERTY]);
#line 11113 "GomElementTest.c"
	}
}


static GObject *
gom_element_test_tclass_constructor (GType type, 
                                     guint n_construct_properties, 
                                     GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestTClass * self;
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_tclass_parent_class);
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClass);
#line 170 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "class");
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 11136 "GomElementTest.c"
}


GomElementTestTClassMap*
gom_element_test_tclass_map_construct (GType object_type)
{
	GomElementTestTClassMap * self = NULL;
#line 174 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestTClassMap*) gxml_gom_hash_map_construct (object_type);
#line 174 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 11148 "GomElementTest.c"
}


GomElementTestTClassMap*
gom_element_test_tclass_map_new (void)
{
#line 174 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_tclass_map_construct (GOM_ELEMENT_TEST_TCLASS_TYPE_MAP);
#line 11157 "GomElementTest.c"
}


static GObject *
gom_element_test_tclass_map_constructor (GType type, 
                                         guint n_construct_properties, 
                                         GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestTClassMap * self;
	GError * _inner_error_ = NULL;
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_tclass_map_parent_class);
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TCLASS_TYPE_MAP, GomElementTestTClassMap);
#line 11176 "GomElementTest.c"
	{
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_collection_initialize ((GXmlGomCollection*) self, GOM_ELEMENT_TEST_TYPE_TCLASS, &_inner_error_);
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 11182 "GomElementTest.c"
			goto __catch278_g_error;
		}
	}
	goto __finally278;
	__catch278_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 177 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = e;
#line 177 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = _tmp0_->message;
#line 177 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 177 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 177 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_warning ("GomElementTest.vala:177: %s", _tmp3_);
#line 177 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp3_);
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 11212 "GomElementTest.c"
	}
	__finally278:
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 11221 "GomElementTest.c"
	}
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 11225 "GomElementTest.c"
}


static void
gom_element_test_tclass_map_class_init (GomElementTestTClassMapClass * klass)
{
#line 174 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_tclass_map_parent_class = g_type_class_peek_parent (klass);
#line 174 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_tclass_map_constructor;
#line 11236 "GomElementTest.c"
}


static void
gom_element_test_tclass_map_instance_init (GomElementTestTClassMap * self)
{
}


GType
gom_element_test_tclass_map_get_type (void)
{
	static volatile gsize gom_element_test_tclass_map_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_tclass_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestTClassMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_tclass_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestTClassMap), 0, (GInstanceInitFunc) gom_element_test_tclass_map_instance_init, NULL };
		GType gom_element_test_tclass_map_type_id;
		gom_element_test_tclass_map_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_MAP, "GomElementTestTClassMap", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_tclass_map_type_id__volatile, gom_element_test_tclass_map_type_id);
	}
	return gom_element_test_tclass_map_type_id__volatile;
}


static void
gom_element_test_tclass_class_init (GomElementTestTClassClass * klass)
{
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_tclass_parent_class = g_type_class_peek_parent (klass);
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_type_class_add_private (klass, sizeof (GomElementTestTClassPrivate));
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_tclass_get_property;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_tclass_set_property;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_tclass_constructor;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_tclass_finalize;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_TCLASS_NAME_PROPERTY, gom_element_test_tclass_properties[GOM_ELEMENT_TEST_TCLASS_NAME_PROPERTY] = g_param_spec_string ("name", "::name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_TCLASS_VERSION_PROPERTY, gom_element_test_tclass_properties[GOM_ELEMENT_TEST_TCLASS_VERSION_PROPERTY] = g_param_spec_string ("version", "::version", "version", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_TCLASS_CPREFIX_PROPERTY, gom_element_test_tclass_properties[GOM_ELEMENT_TEST_TCLASS_CPREFIX_PROPERTY] = g_param_spec_string ("cprefix", "::c:prefix", "cprefix", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 11281 "GomElementTest.c"
}


static void
gom_element_test_tclass_gxml_mappeable_element_interface_init (GXmlMappeableElementIface * iface)
{
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_tclass_gxml_mappeable_element_parent_iface = g_type_interface_peek_parent (iface);
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	iface->get_map_key = (gchar* (*) (GXmlMappeableElement *)) gom_element_test_tclass_real_get_map_key;
#line 11292 "GomElementTest.c"
}


static void
gom_element_test_tclass_instance_init (GomElementTestTClass * self)
{
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv = GOM_ELEMENT_TEST_TCLASS_GET_PRIVATE (self);
#line 11301 "GomElementTest.c"
}


static void
gom_element_test_tclass_finalize (GObject * obj)
{
	GomElementTestTClass * self;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClass);
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_name);
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_version);
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_cprefix);
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_tclass_parent_class)->finalize (obj);
#line 11319 "GomElementTest.c"
}


GType
gom_element_test_tclass_get_type (void)
{
	static volatile gsize gom_element_test_tclass_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_tclass_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestTClassClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_tclass_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestTClass), 0, (GInstanceInitFunc) gom_element_test_tclass_instance_init, NULL };
		static const GInterfaceInfo gxml_mappeable_element_info = { (GInterfaceInitFunc) gom_element_test_tclass_gxml_mappeable_element_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gom_element_test_tclass_type_id;
		gom_element_test_tclass_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestTClass", &g_define_type_info, 0);
		g_type_add_interface_static (gom_element_test_tclass_type_id, GXML_TYPE_MAPPEABLE_ELEMENT, &gxml_mappeable_element_info);
		g_once_init_leave (&gom_element_test_tclass_type_id__volatile, gom_element_test_tclass_type_id);
	}
	return gom_element_test_tclass_type_id__volatile;
}


static void
_vala_gom_element_test_tclass_get_property (GObject * object, 
                                            guint property_id, 
                                            GValue * value, 
                                            GParamSpec * pspec)
{
	GomElementTestTClass * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClass);
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TCLASS_NAME_PROPERTY:
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, gom_element_test_tclass_get_name (self));
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TCLASS_VERSION_PROPERTY:
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, gom_element_test_tclass_get_version (self));
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TCLASS_CPREFIX_PROPERTY:
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, gom_element_test_tclass_get_cprefix (self));
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 11367 "GomElementTest.c"
		default:
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 11373 "GomElementTest.c"
	}
}


static void
_vala_gom_element_test_tclass_set_property (GObject * object, 
                                            guint property_id, 
                                            const GValue * value, 
                                            GParamSpec * pspec)
{
	GomElementTestTClass * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClass);
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TCLASS_NAME_PROPERTY:
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_tclass_set_name (self, g_value_get_string (value));
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TCLASS_VERSION_PROPERTY:
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_tclass_set_version (self, g_value_get_string (value));
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TCLASS_CPREFIX_PROPERTY:
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_tclass_set_cprefix (self, g_value_get_string (value));
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 11406 "GomElementTest.c"
		default:
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 11412 "GomElementTest.c"
	}
}


static void
gom_element_test_class_init (GomElementTestClass * klass)
{
#line 30 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_parent_class = g_type_class_peek_parent (klass);
#line 11422 "GomElementTest.c"
}


static void
gom_element_test_instance_init (GomElementTest * self)
{
}


GType
gom_element_test_get_type (void)
{
	static volatile gsize gom_element_test_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTest), 0, (GInstanceInitFunc) gom_element_test_instance_init, NULL };
		GType gom_element_test_type_id;
		gom_element_test_type_id = g_type_register_static (TYPE_GXML_TEST, "GomElementTest", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_type_id__volatile, gom_element_test_type_id);
	}
	return gom_element_test_type_id__volatile;
}


static void
_vala_array_destroy (gpointer array, 
                     gint array_length, 
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void
_vala_array_free (gpointer array, 
                  gint array_length, 
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint
_vala_array_length (gpointer array)
{
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



